@@ -31,33 +31,25 @@ struct _ValaCCodeCommentPrivate {
 
 #define VALA_CCODE_COMMENT_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CCODE_COMMENT, ValaCCodeCommentPrivate))
 enum  {
-	VALA_CCODE_COMMENT_DUMMY_PROPERTY,
-	VALA_CCODE_COMMENT_TEXT
+	VALA_CCODE_COMMENT_DUMMY_PROPERTY
 };
 static void vala_ccode_comment_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
 static gpointer vala_ccode_comment_parent_class = NULL;
-static void vala_ccode_comment_dispose (GObject * obj);
+static void vala_ccode_comment_finalize (ValaCCodeNode* obj);
 
 
 
+ValaCCodeComment* vala_ccode_comment_construct (GType object_type, const char* _text) {
+	ValaCCodeComment* self;
+	g_return_val_if_fail (_text != NULL, NULL);
+	self = ((ValaCCodeComment*) (g_type_create_instance (object_type)));
+	vala_ccode_comment_set_text (self, _text);
+	return self;
+}
+
+
 ValaCCodeComment* vala_ccode_comment_new (const char* _text) {
-	GParameter * __params;
-	GParameter * __params_it;
-	ValaCCodeComment * self;
-	g_return_val_if_fail (_text != NULL, NULL);
-	__params = g_new0 (GParameter, 1);
-	__params_it = __params;
-	__params_it->name = "text";
-	g_value_init (&__params_it->value, G_TYPE_STRING);
-	g_value_set_string (&__params_it->value, _text);
-	__params_it++;
-	self = g_object_newv (VALA_TYPE_CCODE_COMMENT, __params_it - __params, __params);
-	while (__params_it > __params) {
-		--__params_it;
-		g_value_unset (&__params_it->value);
-	}
-	g_free (__params);
-	return self;
+	return vala_ccode_comment_construct (VALA_TYPE_CCODE_COMMENT, _text);
 }
 
 
@@ -85,42 +77,11 @@ void vala_ccode_comment_set_text (ValaCCodeComment* self, const char* value) {
 }
 
 
-static void vala_ccode_comment_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
-	ValaCCodeComment * self;
-	self = VALA_CCODE_COMMENT (object);
-	switch (property_id) {
-		case VALA_CCODE_COMMENT_TEXT:
-		g_value_set_string (value, vala_ccode_comment_get_text (self));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
-static void vala_ccode_comment_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
-	ValaCCodeComment * self;
-	self = VALA_CCODE_COMMENT (object);
-	switch (property_id) {
-		case VALA_CCODE_COMMENT_TEXT:
-		vala_ccode_comment_set_text (self, g_value_get_string (value));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
 static void vala_ccode_comment_class_init (ValaCCodeCommentClass * klass) {
 	vala_ccode_comment_parent_class = g_type_class_peek_parent (klass);
+	VALA_CCODE_NODE_CLASS (klass)->finalize = vala_ccode_comment_finalize;
 	g_type_class_add_private (klass, sizeof (ValaCCodeCommentPrivate));
-	G_OBJECT_CLASS (klass)->get_property = vala_ccode_comment_get_property;
-	G_OBJECT_CLASS (klass)->set_property = vala_ccode_comment_set_property;
-	G_OBJECT_CLASS (klass)->dispose = vala_ccode_comment_dispose;
 	VALA_CCODE_NODE_CLASS (klass)->write = vala_ccode_comment_real_write;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_COMMENT_TEXT, g_param_spec_string ("text", "text", "text", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
 }
 
 
@@ -129,18 +90,18 @@ static void vala_ccode_comment_instance_init (ValaCCodeComment * self) {
 }
 
 
-static void vala_ccode_comment_dispose (GObject * obj) {
+static void vala_ccode_comment_finalize (ValaCCodeNode* obj) {
 	ValaCCodeComment * self;
 	self = VALA_CCODE_COMMENT (obj);
 	self->priv->_text = (g_free (self->priv->_text), NULL);
-	G_OBJECT_CLASS (vala_ccode_comment_parent_class)->dispose (obj);
+	VALA_CCODE_NODE_CLASS (vala_ccode_comment_parent_class)->finalize (obj);
 }
 
 
 GType vala_ccode_comment_get_type (void) {
 	static GType vala_ccode_comment_type_id = 0;
-	if (G_UNLIKELY (vala_ccode_comment_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeCommentClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_comment_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeComment), 0, (GInstanceInitFunc) vala_ccode_comment_instance_init };
+	if (vala_ccode_comment_type_id == 0) {
+		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeCommentClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_comment_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeComment), 0, (GInstanceInitFunc) vala_ccode_comment_instance_init, NULL };
 		vala_ccode_comment_type_id = g_type_register_static (VALA_TYPE_CCODE_NODE, "ValaCCodeComment", &g_define_type_info, 0);
 	}
 	return vala_ccode_comment_type_id;
