@@ -37,39 +37,27 @@ struct _ValaCCodeElementAccessPrivate {
 
 #define VALA_CCODE_ELEMENT_ACCESS_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CCODE_ELEMENT_ACCESS, ValaCCodeElementAccessPrivate))
 enum  {
-	VALA_CCODE_ELEMENT_ACCESS_DUMMY_PROPERTY,
-	VALA_CCODE_ELEMENT_ACCESS_CONTAINER,
-	VALA_CCODE_ELEMENT_ACCESS_INDEX
+	VALA_CCODE_ELEMENT_ACCESS_DUMMY_PROPERTY
 };
 static void vala_ccode_element_access_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
 static gpointer vala_ccode_element_access_parent_class = NULL;
-static void vala_ccode_element_access_dispose (GObject * obj);
+static void vala_ccode_element_access_finalize (ValaCCodeNode* obj);
 
 
 
+ValaCCodeElementAccess* vala_ccode_element_access_construct (GType object_type, ValaCCodeExpression* cont, ValaCCodeExpression* i) {
+	ValaCCodeElementAccess* self;
+	g_return_val_if_fail (VALA_IS_CCODE_EXPRESSION (cont), NULL);
+	g_return_val_if_fail (VALA_IS_CCODE_EXPRESSION (i), NULL);
+	self = ((ValaCCodeElementAccess*) (g_type_create_instance (object_type)));
+	vala_ccode_element_access_set_container (self, cont);
+	vala_ccode_element_access_set_index (self, i);
+	return self;
+}
+
+
 ValaCCodeElementAccess* vala_ccode_element_access_new (ValaCCodeExpression* cont, ValaCCodeExpression* i) {
-	GParameter * __params;
-	GParameter * __params_it;
-	ValaCCodeElementAccess * self;
-	g_return_val_if_fail (VALA_IS_CCODE_EXPRESSION (cont), NULL);
-	g_return_val_if_fail (VALA_IS_CCODE_EXPRESSION (i), NULL);
-	__params = g_new0 (GParameter, 2);
-	__params_it = __params;
-	__params_it->name = "container";
-	g_value_init (&__params_it->value, VALA_TYPE_CCODE_EXPRESSION);
-	g_value_set_object (&__params_it->value, cont);
-	__params_it++;
-	__params_it->name = "index";
-	g_value_init (&__params_it->value, VALA_TYPE_CCODE_EXPRESSION);
-	g_value_set_object (&__params_it->value, i);
-	__params_it++;
-	self = g_object_newv (VALA_TYPE_CCODE_ELEMENT_ACCESS, __params_it - __params, __params);
-	while (__params_it > __params) {
-		--__params_it;
-		g_value_unset (&__params_it->value);
-	}
-	g_free (__params);
-	return self;
+	return vala_ccode_element_access_construct (VALA_TYPE_CCODE_ELEMENT_ACCESS, cont, i);
 }
 
 
@@ -96,7 +84,7 @@ void vala_ccode_element_access_set_container (ValaCCodeElementAccess* self, Vala
 	g_return_if_fail (VALA_IS_CCODE_ELEMENT_ACCESS (self));
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_container = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_container == NULL ? NULL : (self->priv->_container = (g_object_unref (self->priv->_container), NULL))), _tmp2);
+	self->priv->_container = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_ccode_node_ref (_tmp1))), (self->priv->_container == NULL ? NULL : (self->priv->_container = (vala_ccode_node_unref (self->priv->_container), NULL))), _tmp2);
 }
 
 
@@ -112,53 +100,15 @@ void vala_ccode_element_access_set_index (ValaCCodeElementAccess* self, ValaCCod
 	g_return_if_fail (VALA_IS_CCODE_ELEMENT_ACCESS (self));
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_index = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_index == NULL ? NULL : (self->priv->_index = (g_object_unref (self->priv->_index), NULL))), _tmp2);
-}
-
-
-static void vala_ccode_element_access_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
-	ValaCCodeElementAccess * self;
-	self = VALA_CCODE_ELEMENT_ACCESS (object);
-	switch (property_id) {
-		case VALA_CCODE_ELEMENT_ACCESS_CONTAINER:
-		g_value_set_object (value, vala_ccode_element_access_get_container (self));
-		break;
-		case VALA_CCODE_ELEMENT_ACCESS_INDEX:
-		g_value_set_object (value, vala_ccode_element_access_get_index (self));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
-static void vala_ccode_element_access_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
-	ValaCCodeElementAccess * self;
-	self = VALA_CCODE_ELEMENT_ACCESS (object);
-	switch (property_id) {
-		case VALA_CCODE_ELEMENT_ACCESS_CONTAINER:
-		vala_ccode_element_access_set_container (self, g_value_get_object (value));
-		break;
-		case VALA_CCODE_ELEMENT_ACCESS_INDEX:
-		vala_ccode_element_access_set_index (self, g_value_get_object (value));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
+	self->priv->_index = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_ccode_node_ref (_tmp1))), (self->priv->_index == NULL ? NULL : (self->priv->_index = (vala_ccode_node_unref (self->priv->_index), NULL))), _tmp2);
 }
 
 
 static void vala_ccode_element_access_class_init (ValaCCodeElementAccessClass * klass) {
 	vala_ccode_element_access_parent_class = g_type_class_peek_parent (klass);
+	VALA_CCODE_NODE_CLASS (klass)->finalize = vala_ccode_element_access_finalize;
 	g_type_class_add_private (klass, sizeof (ValaCCodeElementAccessPrivate));
-	G_OBJECT_CLASS (klass)->get_property = vala_ccode_element_access_get_property;
-	G_OBJECT_CLASS (klass)->set_property = vala_ccode_element_access_set_property;
-	G_OBJECT_CLASS (klass)->dispose = vala_ccode_element_access_dispose;
 	VALA_CCODE_NODE_CLASS (klass)->write = vala_ccode_element_access_real_write;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_ELEMENT_ACCESS_CONTAINER, g_param_spec_object ("container", "container", "container", VALA_TYPE_CCODE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_ELEMENT_ACCESS_INDEX, g_param_spec_object ("index", "index", "index", VALA_TYPE_CCODE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
 }
 
 
@@ -167,19 +117,19 @@ static void vala_ccode_element_access_instance_init (ValaCCodeElementAccess * se
 }
 
 
-static void vala_ccode_element_access_dispose (GObject * obj) {
+static void vala_ccode_element_access_finalize (ValaCCodeNode* obj) {
 	ValaCCodeElementAccess * self;
 	self = VALA_CCODE_ELEMENT_ACCESS (obj);
-	(self->priv->_container == NULL ? NULL : (self->priv->_container = (g_object_unref (self->priv->_container), NULL)));
-	(self->priv->_index == NULL ? NULL : (self->priv->_index = (g_object_unref (self->priv->_index), NULL)));
-	G_OBJECT_CLASS (vala_ccode_element_access_parent_class)->dispose (obj);
+	(self->priv->_container == NULL ? NULL : (self->priv->_container = (vala_ccode_node_unref (self->priv->_container), NULL)));
+	(self->priv->_index == NULL ? NULL : (self->priv->_index = (vala_ccode_node_unref (self->priv->_index), NULL)));
+	VALA_CCODE_NODE_CLASS (vala_ccode_element_access_parent_class)->finalize (obj);
 }
 
 
 GType vala_ccode_element_access_get_type (void) {
 	static GType vala_ccode_element_access_type_id = 0;
-	if (G_UNLIKELY (vala_ccode_element_access_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeElementAccessClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_element_access_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeElementAccess), 0, (GInstanceInitFunc) vala_ccode_element_access_instance_init };
+	if (vala_ccode_element_access_type_id == 0) {
+		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeElementAccessClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_element_access_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeElementAccess), 0, (GInstanceInitFunc) vala_ccode_element_access_instance_init, NULL };
 		vala_ccode_element_access_type_id = g_type_register_static (VALA_TYPE_CCODE_EXPRESSION, "ValaCCodeElementAccess", &g_define_type_info, 0);
 	}
 	return vala_ccode_element_access_type_id;
