@@ -32,27 +32,30 @@ struct _ValaCCodeEnumValuePrivate {
 
 #define VALA_CCODE_ENUM_VALUE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CCODE_ENUM_VALUE, ValaCCodeEnumValuePrivate))
 enum  {
-	VALA_CCODE_ENUM_VALUE_DUMMY_PROPERTY,
-	VALA_CCODE_ENUM_VALUE_NAME,
-	VALA_CCODE_ENUM_VALUE_VALUE
+	VALA_CCODE_ENUM_VALUE_DUMMY_PROPERTY
 };
 static void vala_ccode_enum_value_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
 static gpointer vala_ccode_enum_value_parent_class = NULL;
-static void vala_ccode_enum_value_finalize (GObject * obj);
+static void vala_ccode_enum_value_finalize (ValaCCodeNode* obj);
 
 
 
-ValaCCodeEnumValue* vala_ccode_enum_value_new (const char* name, ValaCCodeExpression* value) {
-	ValaCCodeEnumValue * self;
+ValaCCodeEnumValue* vala_ccode_enum_value_construct (GType object_type, const char* name, ValaCCodeExpression* value) {
+	ValaCCodeEnumValue* self;
 	g_return_val_if_fail (name != NULL, NULL);
 	g_return_val_if_fail (value == NULL || VALA_IS_CCODE_EXPRESSION (value), NULL);
-	self = g_object_newv (VALA_TYPE_CCODE_ENUM_VALUE, 0, NULL);
+	self = ((ValaCCodeEnumValue*) (g_type_create_instance (object_type)));
 	vala_ccode_enum_value_set_name (self, name);
 	vala_ccode_enum_value_set_value (self, value);
 	return self;
 }
 
 
+ValaCCodeEnumValue* vala_ccode_enum_value_new (const char* name, ValaCCodeExpression* value) {
+	return vala_ccode_enum_value_construct (VALA_TYPE_CCODE_ENUM_VALUE, name, value);
+}
+
+
 static void vala_ccode_enum_value_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeEnumValue * self;
 	self = VALA_CCODE_ENUM_VALUE (base);
@@ -78,7 +81,6 @@ void vala_ccode_enum_value_set_name (ValaCCodeEnumValue* self, const char* value
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_name = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_name = (g_free (self->priv->_name), NULL)), _tmp2);
-	g_object_notify (((GObject *) (self)), "name");
 }
 
 
@@ -94,54 +96,15 @@ void vala_ccode_enum_value_set_value (ValaCCodeEnumValue* self, ValaCCodeExpress
 	g_return_if_fail (VALA_IS_CCODE_ENUM_VALUE (self));
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_value = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_value == NULL ? NULL : (self->priv->_value = (g_object_unref (self->priv->_value), NULL))), _tmp2);
-	g_object_notify (((GObject *) (self)), "value");
-}
-
-
-static void vala_ccode_enum_value_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
-	ValaCCodeEnumValue * self;
-	self = VALA_CCODE_ENUM_VALUE (object);
-	switch (property_id) {
-		case VALA_CCODE_ENUM_VALUE_NAME:
-		g_value_set_string (value, vala_ccode_enum_value_get_name (self));
-		break;
-		case VALA_CCODE_ENUM_VALUE_VALUE:
-		g_value_set_object (value, vala_ccode_enum_value_get_value (self));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
-static void vala_ccode_enum_value_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
-	ValaCCodeEnumValue * self;
-	self = VALA_CCODE_ENUM_VALUE (object);
-	switch (property_id) {
-		case VALA_CCODE_ENUM_VALUE_NAME:
-		vala_ccode_enum_value_set_name (self, g_value_get_string (value));
-		break;
-		case VALA_CCODE_ENUM_VALUE_VALUE:
-		vala_ccode_enum_value_set_value (self, g_value_get_object (value));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
+	self->priv->_value = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_ccode_node_ref (_tmp1))), (self->priv->_value == NULL ? NULL : (self->priv->_value = (vala_ccode_node_unref (self->priv->_value), NULL))), _tmp2);
 }
 
 
 static void vala_ccode_enum_value_class_init (ValaCCodeEnumValueClass * klass) {
 	vala_ccode_enum_value_parent_class = g_type_class_peek_parent (klass);
+	VALA_CCODE_NODE_CLASS (klass)->finalize = vala_ccode_enum_value_finalize;
 	g_type_class_add_private (klass, sizeof (ValaCCodeEnumValuePrivate));
-	G_OBJECT_CLASS (klass)->get_property = vala_ccode_enum_value_get_property;
-	G_OBJECT_CLASS (klass)->set_property = vala_ccode_enum_value_set_property;
-	G_OBJECT_CLASS (klass)->finalize = vala_ccode_enum_value_finalize;
 	VALA_CCODE_NODE_CLASS (klass)->write = vala_ccode_enum_value_real_write;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_ENUM_VALUE_NAME, g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_ENUM_VALUE_VALUE, g_param_spec_object ("value", "value", "value", VALA_TYPE_CCODE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
@@ -150,19 +113,19 @@ static void vala_ccode_enum_value_instance_init (ValaCCodeEnumValue * self) {
 }
 
 
-static void vala_ccode_enum_value_finalize (GObject * obj) {
+static void vala_ccode_enum_value_finalize (ValaCCodeNode* obj) {
 	ValaCCodeEnumValue * self;
 	self = VALA_CCODE_ENUM_VALUE (obj);
 	self->priv->_name = (g_free (self->priv->_name), NULL);
-	(self->priv->_value == NULL ? NULL : (self->priv->_value = (g_object_unref (self->priv->_value), NULL)));
-	G_OBJECT_CLASS (vala_ccode_enum_value_parent_class)->finalize (obj);
+	(self->priv->_value == NULL ? NULL : (self->priv->_value = (vala_ccode_node_unref (self->priv->_value), NULL)));
+	VALA_CCODE_NODE_CLASS (vala_ccode_enum_value_parent_class)->finalize (obj);
 }
 
 
 GType vala_ccode_enum_value_get_type (void) {
 	static GType vala_ccode_enum_value_type_id = 0;
 	if (vala_ccode_enum_value_type_id == 0) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeEnumValueClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_enum_value_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeEnumValue), 0, (GInstanceInitFunc) vala_ccode_enum_value_instance_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeEnumValueClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_enum_value_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeEnumValue), 0, (GInstanceInitFunc) vala_ccode_enum_value_instance_init, NULL };
 		vala_ccode_enum_value_type_id = g_type_register_static (VALA_TYPE_CCODE_NODE, "ValaCCodeEnumValue", &g_define_type_info, 0);
 	}
 	return vala_ccode_enum_value_type_id;
