@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,8 +20,8 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#ifndef __VALACCODEFUNCTION_H__
-#define __VALACCODEFUNCTION_H__
+#ifndef __CCODE_VALACCODEFUNCTION_H__
+#define __CCODE_VALACCODEFUNCTION_H__
 
 #include <glib.h>
 #include <glib-object.h>
@@ -30,7 +30,6 @@
 #include <ccode/valaccodenode.h>
 #include <ccode/valaccodemodifiers.h>
 #include <ccode/valaccodeformalparameter.h>
-#include <ccode/valaccodefunction.h>
 #include <ccode/valaccodewriter.h>
 #include <ccode/valaccodeblock.h>
 
@@ -52,25 +51,29 @@ typedef struct _ValaCCodeFunctionPrivate ValaCCodeFunctionPrivate;
  * Represents a function declaration in the C code.
  */
 struct _ValaCCodeFunction {
-	ValaCCodeNode parent;
+	ValaCCodeNode parent_instance;
 	ValaCCodeFunctionPrivate * priv;
 };
+
 struct _ValaCCodeFunctionClass {
-	ValaCCodeNodeClass parent;
+	ValaCCodeNodeClass parent_class;
 };
 
-ValaCCodeFunction* vala_ccode_function_new (const char* _name, const char* _return_type);
+
+ValaCCodeFunction* vala_ccode_function_construct (GType object_type, const char* name, const char* return_type);
+ValaCCodeFunction* vala_ccode_function_new (const char* name, const char* return_type);
 void vala_ccode_function_add_parameter (ValaCCodeFunction* self, ValaCCodeFormalParameter* param);
 ValaCCodeFunction* vala_ccode_function_copy (ValaCCodeFunction* self);
-char* vala_ccode_function_get_name (ValaCCodeFunction* self);
+const char* vala_ccode_function_get_name (ValaCCodeFunction* self);
 void vala_ccode_function_set_name (ValaCCodeFunction* self, const char* value);
 ValaCCodeModifiers vala_ccode_function_get_modifiers (ValaCCodeFunction* self);
 void vala_ccode_function_set_modifiers (ValaCCodeFunction* self, ValaCCodeModifiers value);
-char* vala_ccode_function_get_return_type (ValaCCodeFunction* self);
+const char* vala_ccode_function_get_return_type (ValaCCodeFunction* self);
 void vala_ccode_function_set_return_type (ValaCCodeFunction* self, const char* value);
 ValaCCodeBlock* vala_ccode_function_get_block (ValaCCodeFunction* self);
 void vala_ccode_function_set_block (ValaCCodeFunction* self, ValaCCodeBlock* value);
-GType vala_ccode_function_get_type ();
+GType vala_ccode_function_get_type (void);
+
 
 G_END_DECLS
 
