@@ -41,7 +41,7 @@ enum  {
 };
 static void vala_ccode_initializer_list_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
 static gpointer vala_ccode_initializer_list_parent_class = NULL;
-static void vala_ccode_initializer_list_finalize (GObject * obj);
+static void vala_ccode_initializer_list_finalize (ValaCCodeNode* obj);
 
 
 
@@ -80,7 +80,7 @@ static void vala_ccode_initializer_list_real_write (ValaCCodeNode* base, ValaCCo
 				if (expr != NULL) {
 					vala_ccode_node_write (VALA_CCODE_NODE (expr), writer);
 				}
-				(expr == NULL ? NULL : (expr = (g_object_unref (expr), NULL)));
+				(expr == NULL ? NULL : (expr = (vala_ccode_node_unref (expr), NULL)));
 			}
 		}
 	}
@@ -91,39 +91,44 @@ static void vala_ccode_initializer_list_real_write (ValaCCodeNode* base, ValaCCo
 /**
  * Represents a struct or array initializer list in the C code.
  */
-ValaCCodeInitializerList* vala_ccode_initializer_list_new (void) {
-	ValaCCodeInitializerList * self;
-	self = g_object_newv (VALA_TYPE_CCODE_INITIALIZER_LIST, 0, NULL);
+ValaCCodeInitializerList* vala_ccode_initializer_list_construct (GType object_type) {
+	ValaCCodeInitializerList* self;
+	self = ((ValaCCodeInitializerList*) (g_type_create_instance (object_type)));
 	return self;
 }
 
 
+ValaCCodeInitializerList* vala_ccode_initializer_list_new (void) {
+	return vala_ccode_initializer_list_construct (VALA_TYPE_CCODE_INITIALIZER_LIST);
+}
+
+
 static void vala_ccode_initializer_list_class_init (ValaCCodeInitializerListClass * klass) {
 	vala_ccode_initializer_list_parent_class = g_type_class_peek_parent (klass);
+	VALA_CCODE_NODE_CLASS (klass)->finalize = vala_ccode_initializer_list_finalize;
 	g_type_class_add_private (klass, sizeof (ValaCCodeInitializerListPrivate));
-	G_OBJECT_CLASS (klass)->finalize = vala_ccode_initializer_list_finalize;
 	VALA_CCODE_NODE_CLASS (klass)->write = vala_ccode_initializer_list_real_write;
 }
 
 
 static void vala_ccode_initializer_list_instance_init (ValaCCodeInitializerList * self) {
 	self->priv = VALA_CCODE_INITIALIZER_LIST_GET_PRIVATE (self);
-	self->priv->initializers = GEE_LIST (gee_array_list_new (VALA_TYPE_CCODE_EXPRESSION, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal));
+	self->priv->initializers = GEE_LIST (gee_array_list_new (VALA_TYPE_CCODE_EXPRESSION, ((GBoxedCopyFunc) (vala_ccode_node_ref)), vala_ccode_node_unref, g_direct_equal));
 }
 
 
-static void vala_ccode_initializer_list_finalize (GObject * obj) {
+static void vala_ccode_initializer_list_finalize (ValaCCodeNode* obj) {
 	ValaCCodeInitializerList * self;
 	self = VALA_CCODE_INITIALIZER_LIST (obj);
-	(self->priv->initializers == NULL ? NULL : (self->priv->initializers = (g_object_unref (self->priv->initializers), NULL)));
-	G_OBJECT_CLASS (vala_ccode_initializer_list_parent_class)->finalize (obj);
+	(self->priv->initializers == NULL ? NULL : (self->priv->initializers = (gee_collection_object_unref (self->priv->initializers), NULL)));
+	VALA_CCODE_NODE_CLASS (vala_ccode_initializer_list_parent_class)->finalize (obj);
 }
 
 
 GType vala_ccode_initializer_list_get_type (void) {
 	static GType vala_ccode_initializer_list_type_id = 0;
 	if (vala_ccode_initializer_list_type_id == 0) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeInitializerListClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_initializer_list_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeInitializerList), 0, (GInstanceInitFunc) vala_ccode_initializer_list_instance_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeInitializerListClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_initializer_list_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeInitializerList), 0, (GInstanceInitFunc) vala_ccode_initializer_list_instance_init, NULL };
 		vala_ccode_initializer_list_type_id = g_type_register_static (VALA_TYPE_CCODE_EXPRESSION, "ValaCCodeInitializerList", &g_define_type_info, 0);
 	}
 	return vala_ccode_initializer_list_type_id;
