@@ -35,21 +35,25 @@ struct _ValaCCodeReturnStatementPrivate {
 
 #define VALA_CCODE_RETURN_STATEMENT_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CCODE_RETURN_STATEMENT, ValaCCodeReturnStatementPrivate))
 enum  {
-	VALA_CCODE_RETURN_STATEMENT_DUMMY_PROPERTY,
-	VALA_CCODE_RETURN_STATEMENT_RETURN_EXPRESSION
+	VALA_CCODE_RETURN_STATEMENT_DUMMY_PROPERTY
 };
 static void vala_ccode_return_statement_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
 static gpointer vala_ccode_return_statement_parent_class = NULL;
-static void vala_ccode_return_statement_finalize (GObject * obj);
+static void vala_ccode_return_statement_finalize (ValaCCodeNode* obj);
 
 
 
+ValaCCodeReturnStatement* vala_ccode_return_statement_construct (GType object_type, ValaCCodeExpression* expr) {
+	ValaCCodeReturnStatement* self;
+	g_return_val_if_fail (expr == NULL || VALA_IS_CCODE_EXPRESSION (expr), NULL);
+	self = ((ValaCCodeReturnStatement*) (g_type_create_instance (object_type)));
+	vala_ccode_return_statement_set_return_expression (self, expr);
+	return self;
+}
+
+
 ValaCCodeReturnStatement* vala_ccode_return_statement_new (ValaCCodeExpression* expr) {
-	ValaCCodeReturnStatement * self;
-	g_return_val_if_fail (expr == NULL || VALA_IS_CCODE_EXPRESSION (expr), NULL);
-	self = g_object_newv (VALA_TYPE_CCODE_RETURN_STATEMENT, 0, NULL);
-	vala_ccode_return_statement_set_return_expression (self, expr);
-	return self;
+	return vala_ccode_return_statement_construct (VALA_TYPE_CCODE_RETURN_STATEMENT, expr);
 }
 
 
@@ -80,47 +84,15 @@ void vala_ccode_return_statement_set_return_expression (ValaCCodeReturnStatement
 	g_return_if_fail (VALA_IS_CCODE_RETURN_STATEMENT (self));
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_return_expression = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_return_expression == NULL ? NULL : (self->priv->_return_expression = (g_object_unref (self->priv->_return_expression), NULL))), _tmp2);
-	g_object_notify (((GObject *) (self)), "return-expression");
-}
-
-
-static void vala_ccode_return_statement_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
-	ValaCCodeReturnStatement * self;
-	self = VALA_CCODE_RETURN_STATEMENT (object);
-	switch (property_id) {
-		case VALA_CCODE_RETURN_STATEMENT_RETURN_EXPRESSION:
-		g_value_set_object (value, vala_ccode_return_statement_get_return_expression (self));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
-static void vala_ccode_return_statement_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
-	ValaCCodeReturnStatement * self;
-	self = VALA_CCODE_RETURN_STATEMENT (object);
-	switch (property_id) {
-		case VALA_CCODE_RETURN_STATEMENT_RETURN_EXPRESSION:
-		vala_ccode_return_statement_set_return_expression (self, g_value_get_object (value));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
+	self->priv->_return_expression = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_ccode_node_ref (_tmp1))), (self->priv->_return_expression == NULL ? NULL : (self->priv->_return_expression = (vala_ccode_node_unref (self->priv->_return_expression), NULL))), _tmp2);
 }
 
 
 static void vala_ccode_return_statement_class_init (ValaCCodeReturnStatementClass * klass) {
 	vala_ccode_return_statement_parent_class = g_type_class_peek_parent (klass);
+	VALA_CCODE_NODE_CLASS (klass)->finalize = vala_ccode_return_statement_finalize;
 	g_type_class_add_private (klass, sizeof (ValaCCodeReturnStatementPrivate));
-	G_OBJECT_CLASS (klass)->get_property = vala_ccode_return_statement_get_property;
-	G_OBJECT_CLASS (klass)->set_property = vala_ccode_return_statement_set_property;
-	G_OBJECT_CLASS (klass)->finalize = vala_ccode_return_statement_finalize;
 	VALA_CCODE_NODE_CLASS (klass)->write = vala_ccode_return_statement_real_write;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_RETURN_STATEMENT_RETURN_EXPRESSION, g_param_spec_object ("return-expression", "return-expression", "return-expression", VALA_TYPE_CCODE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
@@ -129,18 +101,18 @@ static void vala_ccode_return_statement_instance_init (ValaCCodeReturnStatement
 }
 
 
-static void vala_ccode_return_statement_finalize (GObject * obj) {
+static void vala_ccode_return_statement_finalize (ValaCCodeNode* obj) {
 	ValaCCodeReturnStatement * self;
 	self = VALA_CCODE_RETURN_STATEMENT (obj);
-	(self->priv->_return_expression == NULL ? NULL : (self->priv->_return_expression = (g_object_unref (self->priv->_return_expression), NULL)));
-	G_OBJECT_CLASS (vala_ccode_return_statement_parent_class)->finalize (obj);
+	(self->priv->_return_expression == NULL ? NULL : (self->priv->_return_expression = (vala_ccode_node_unref (self->priv->_return_expression), NULL)));
+	VALA_CCODE_NODE_CLASS (vala_ccode_return_statement_parent_class)->finalize (obj);
 }
 
 
 GType vala_ccode_return_statement_get_type (void) {
 	static GType vala_ccode_return_statement_type_id = 0;
 	if (vala_ccode_return_statement_type_id == 0) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeReturnStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_return_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeReturnStatement), 0, (GInstanceInitFunc) vala_ccode_return_statement_instance_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeReturnStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_return_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeReturnStatement), 0, (GInstanceInitFunc) vala_ccode_return_statement_instance_init, NULL };
 		vala_ccode_return_statement_type_id = g_type_register_static (VALA_TYPE_CCODE_STATEMENT, "ValaCCodeReturnStatement", &g_define_type_info, 0);
 	}
 	return vala_ccode_return_statement_type_id;
