@@ -40,21 +40,25 @@ struct _ValaCCodeSwitchStatementPrivate {
 
 #define VALA_CCODE_SWITCH_STATEMENT_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CCODE_SWITCH_STATEMENT, ValaCCodeSwitchStatementPrivate))
 enum  {
-	VALA_CCODE_SWITCH_STATEMENT_DUMMY_PROPERTY,
-	VALA_CCODE_SWITCH_STATEMENT_EXPRESSION
+	VALA_CCODE_SWITCH_STATEMENT_DUMMY_PROPERTY
 };
 static void vala_ccode_switch_statement_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
 static gpointer vala_ccode_switch_statement_parent_class = NULL;
-static void vala_ccode_switch_statement_finalize (GObject * obj);
+static void vala_ccode_switch_statement_finalize (ValaCCodeNode* obj);
 
 
 
+ValaCCodeSwitchStatement* vala_ccode_switch_statement_construct (GType object_type, ValaCCodeExpression* expression) {
+	ValaCCodeSwitchStatement* self;
+	g_return_val_if_fail (VALA_IS_CCODE_EXPRESSION (expression), NULL);
+	self = ((ValaCCodeSwitchStatement*) (g_type_create_instance (object_type)));
+	vala_ccode_switch_statement_set_expression (self, expression);
+	return self;
+}
+
+
 ValaCCodeSwitchStatement* vala_ccode_switch_statement_new (ValaCCodeExpression* expression) {
-	ValaCCodeSwitchStatement * self;
-	g_return_val_if_fail (VALA_IS_CCODE_EXPRESSION (expression), NULL);
-	self = g_object_newv (VALA_TYPE_CCODE_SWITCH_STATEMENT, 0, NULL);
-	vala_ccode_switch_statement_set_expression (self, expression);
-	return self;
+	return vala_ccode_switch_statement_construct (VALA_TYPE_CCODE_SWITCH_STATEMENT, expression);
 }
 
 
@@ -100,7 +104,7 @@ static void vala_ccode_switch_statement_real_write (ValaCCodeNode* base, ValaCCo
 			case_stmt = ((ValaCCodeCaseStatement*) (gee_list_get (GEE_LIST (case_stmt_collection), case_stmt_it)));
 			{
 				vala_ccode_node_write (VALA_CCODE_NODE (case_stmt), writer);
-				(case_stmt == NULL ? NULL : (case_stmt = (g_object_unref (case_stmt), NULL)));
+				(case_stmt == NULL ? NULL : (case_stmt = (vala_ccode_node_unref (case_stmt), NULL)));
 			}
 		}
 	}
@@ -117,7 +121,7 @@ static void vala_ccode_switch_statement_real_write (ValaCCodeNode* base, ValaCCo
 				stmt = ((ValaCCodeStatement*) (gee_list_get (GEE_LIST (stmt_collection), stmt_it)));
 				{
 					vala_ccode_node_write (VALA_CCODE_NODE (stmt), writer);
-					(stmt == NULL ? NULL : (stmt = (g_object_unref (stmt), NULL)));
+					(stmt == NULL ? NULL : (stmt = (vala_ccode_node_unref (stmt), NULL)));
 				}
 			}
 		}
@@ -138,71 +142,39 @@ void vala_ccode_switch_statement_set_expression (ValaCCodeSwitchStatement* self,
 	g_return_if_fail (VALA_IS_CCODE_SWITCH_STATEMENT (self));
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_expression = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_expression == NULL ? NULL : (self->priv->_expression = (g_object_unref (self->priv->_expression), NULL))), _tmp2);
-	g_object_notify (((GObject *) (self)), "expression");
-}
-
-
-static void vala_ccode_switch_statement_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
-	ValaCCodeSwitchStatement * self;
-	self = VALA_CCODE_SWITCH_STATEMENT (object);
-	switch (property_id) {
-		case VALA_CCODE_SWITCH_STATEMENT_EXPRESSION:
-		g_value_set_object (value, vala_ccode_switch_statement_get_expression (self));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
-static void vala_ccode_switch_statement_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
-	ValaCCodeSwitchStatement * self;
-	self = VALA_CCODE_SWITCH_STATEMENT (object);
-	switch (property_id) {
-		case VALA_CCODE_SWITCH_STATEMENT_EXPRESSION:
-		vala_ccode_switch_statement_set_expression (self, g_value_get_object (value));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
+	self->priv->_expression = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_ccode_node_ref (_tmp1))), (self->priv->_expression == NULL ? NULL : (self->priv->_expression = (vala_ccode_node_unref (self->priv->_expression), NULL))), _tmp2);
 }
 
 
 static void vala_ccode_switch_statement_class_init (ValaCCodeSwitchStatementClass * klass) {
 	vala_ccode_switch_statement_parent_class = g_type_class_peek_parent (klass);
+	VALA_CCODE_NODE_CLASS (klass)->finalize = vala_ccode_switch_statement_finalize;
 	g_type_class_add_private (klass, sizeof (ValaCCodeSwitchStatementPrivate));
-	G_OBJECT_CLASS (klass)->get_property = vala_ccode_switch_statement_get_property;
-	G_OBJECT_CLASS (klass)->set_property = vala_ccode_switch_statement_set_property;
-	G_OBJECT_CLASS (klass)->finalize = vala_ccode_switch_statement_finalize;
 	VALA_CCODE_NODE_CLASS (klass)->write = vala_ccode_switch_statement_real_write;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_SWITCH_STATEMENT_EXPRESSION, g_param_spec_object ("expression", "expression", "expression", VALA_TYPE_CCODE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
 static void vala_ccode_switch_statement_instance_init (ValaCCodeSwitchStatement * self) {
 	self->priv = VALA_CCODE_SWITCH_STATEMENT_GET_PRIVATE (self);
-	self->priv->case_statements = GEE_LIST (gee_array_list_new (VALA_TYPE_CCODE_CASE_STATEMENT, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal));
-	self->priv->default_statements = GEE_LIST (gee_array_list_new (VALA_TYPE_CCODE_STATEMENT, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal));
+	self->priv->case_statements = GEE_LIST (gee_array_list_new (VALA_TYPE_CCODE_CASE_STATEMENT, ((GBoxedCopyFunc) (vala_ccode_node_ref)), vala_ccode_node_unref, g_direct_equal));
+	self->priv->default_statements = GEE_LIST (gee_array_list_new (VALA_TYPE_CCODE_STATEMENT, ((GBoxedCopyFunc) (vala_ccode_node_ref)), vala_ccode_node_unref, g_direct_equal));
 }
 
 
-static void vala_ccode_switch_statement_finalize (GObject * obj) {
+static void vala_ccode_switch_statement_finalize (ValaCCodeNode* obj) {
 	ValaCCodeSwitchStatement * self;
 	self = VALA_CCODE_SWITCH_STATEMENT (obj);
-	(self->priv->_expression == NULL ? NULL : (self->priv->_expression = (g_object_unref (self->priv->_expression), NULL)));
-	(self->priv->case_statements == NULL ? NULL : (self->priv->case_statements = (g_object_unref (self->priv->case_statements), NULL)));
-	(self->priv->default_statements == NULL ? NULL : (self->priv->default_statements = (g_object_unref (self->priv->default_statements), NULL)));
-	G_OBJECT_CLASS (vala_ccode_switch_statement_parent_class)->finalize (obj);
+	(self->priv->_expression == NULL ? NULL : (self->priv->_expression = (vala_ccode_node_unref (self->priv->_expression), NULL)));
+	(self->priv->case_statements == NULL ? NULL : (self->priv->case_statements = (gee_collection_object_unref (self->priv->case_statements), NULL)));
+	(self->priv->default_statements == NULL ? NULL : (self->priv->default_statements = (gee_collection_object_unref (self->priv->default_statements), NULL)));
+	VALA_CCODE_NODE_CLASS (vala_ccode_switch_statement_parent_class)->finalize (obj);
 }
 
 
 GType vala_ccode_switch_statement_get_type (void) {
 	static GType vala_ccode_switch_statement_type_id = 0;
 	if (vala_ccode_switch_statement_type_id == 0) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeSwitchStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_switch_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeSwitchStatement), 0, (GInstanceInitFunc) vala_ccode_switch_statement_instance_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeSwitchStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_switch_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeSwitchStatement), 0, (GInstanceInitFunc) vala_ccode_switch_statement_instance_init, NULL };
 		vala_ccode_switch_statement_type_id = g_type_register_static (VALA_TYPE_CCODE_STATEMENT, "ValaCCodeSwitchStatement", &g_define_type_info, 0);
 	}
 	return vala_ccode_switch_statement_type_id;
