@@ -36,36 +36,27 @@ struct _ValaCCodeWhileStatementPrivate {
 
 #define VALA_CCODE_WHILE_STATEMENT_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CCODE_WHILE_STATEMENT, ValaCCodeWhileStatementPrivate))
 enum  {
-	VALA_CCODE_WHILE_STATEMENT_DUMMY_PROPERTY,
-	VALA_CCODE_WHILE_STATEMENT_CONDITION,
-	VALA_CCODE_WHILE_STATEMENT_BODY
+	VALA_CCODE_WHILE_STATEMENT_DUMMY_PROPERTY
 };
 static void vala_ccode_while_statement_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
 static gpointer vala_ccode_while_statement_parent_class = NULL;
-static void vala_ccode_while_statement_finalize (GObject * obj);
+static void vala_ccode_while_statement_finalize (ValaCCodeNode* obj);
 
 
 
+ValaCCodeWhileStatement* vala_ccode_while_statement_construct (GType object_type, ValaCCodeExpression* cond, ValaCCodeStatement* stmt) {
+	ValaCCodeWhileStatement* self;
+	g_return_val_if_fail (VALA_IS_CCODE_EXPRESSION (cond), NULL);
+	g_return_val_if_fail (stmt == NULL || VALA_IS_CCODE_STATEMENT (stmt), NULL);
+	self = ((ValaCCodeWhileStatement*) (g_type_create_instance (object_type)));
+	vala_ccode_while_statement_set_condition (self, cond);
+	vala_ccode_while_statement_set_body (self, stmt);
+	return self;
+}
+
+
 ValaCCodeWhileStatement* vala_ccode_while_statement_new (ValaCCodeExpression* cond, ValaCCodeStatement* stmt) {
-	GParameter * __params;
-	GParameter * __params_it;
-	ValaCCodeWhileStatement * self;
-	g_return_val_if_fail (VALA_IS_CCODE_EXPRESSION (cond), NULL);
-	g_return_val_if_fail (stmt == NULL || VALA_IS_CCODE_STATEMENT (stmt), NULL);
-	__params = g_new0 (GParameter, 1);
-	__params_it = __params;
-	__params_it->name = "condition";
-	g_value_init (&__params_it->value, VALA_TYPE_CCODE_EXPRESSION);
-	g_value_set_object (&__params_it->value, cond);
-	__params_it++;
-	self = g_object_newv (VALA_TYPE_CCODE_WHILE_STATEMENT, __params_it - __params, __params);
-	vala_ccode_while_statement_set_body (self, stmt);
-	while (__params_it > __params) {
-		--__params_it;
-		g_value_unset (&__params_it->value);
-	}
-	g_free (__params);
-	return self;
+	return vala_ccode_while_statement_construct (VALA_TYPE_CCODE_WHILE_STATEMENT, cond, stmt);
 }
 
 
@@ -93,8 +84,7 @@ void vala_ccode_while_statement_set_condition (ValaCCodeWhileStatement* self, Va
 	g_return_if_fail (VALA_IS_CCODE_WHILE_STATEMENT (self));
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_condition = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_condition == NULL ? NULL : (self->priv->_condition = (g_object_unref (self->priv->_condition), NULL))), _tmp2);
-	g_object_notify (((GObject *) (self)), "condition");
+	self->priv->_condition = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_ccode_node_ref (_tmp1))), (self->priv->_condition == NULL ? NULL : (self->priv->_condition = (vala_ccode_node_unref (self->priv->_condition), NULL))), _tmp2);
 }
 
 
@@ -110,54 +100,15 @@ void vala_ccode_while_statement_set_body (ValaCCodeWhileStatement* self, ValaCCo
 	g_return_if_fail (VALA_IS_CCODE_WHILE_STATEMENT (self));
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_body = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_body == NULL ? NULL : (self->priv->_body = (g_object_unref (self->priv->_body), NULL))), _tmp2);
-	g_object_notify (((GObject *) (self)), "body");
-}
-
-
-static void vala_ccode_while_statement_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
-	ValaCCodeWhileStatement * self;
-	self = VALA_CCODE_WHILE_STATEMENT (object);
-	switch (property_id) {
-		case VALA_CCODE_WHILE_STATEMENT_CONDITION:
-		g_value_set_object (value, vala_ccode_while_statement_get_condition (self));
-		break;
-		case VALA_CCODE_WHILE_STATEMENT_BODY:
-		g_value_set_object (value, vala_ccode_while_statement_get_body (self));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
-static void vala_ccode_while_statement_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
-	ValaCCodeWhileStatement * self;
-	self = VALA_CCODE_WHILE_STATEMENT (object);
-	switch (property_id) {
-		case VALA_CCODE_WHILE_STATEMENT_CONDITION:
-		vala_ccode_while_statement_set_condition (self, g_value_get_object (value));
-		break;
-		case VALA_CCODE_WHILE_STATEMENT_BODY:
-		vala_ccode_while_statement_set_body (self, g_value_get_object (value));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
+	self->priv->_body = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_ccode_node_ref (_tmp1))), (self->priv->_body == NULL ? NULL : (self->priv->_body = (vala_ccode_node_unref (self->priv->_body), NULL))), _tmp2);
 }
 
 
 static void vala_ccode_while_statement_class_init (ValaCCodeWhileStatementClass * klass) {
 	vala_ccode_while_statement_parent_class = g_type_class_peek_parent (klass);
+	VALA_CCODE_NODE_CLASS (klass)->finalize = vala_ccode_while_statement_finalize;
 	g_type_class_add_private (klass, sizeof (ValaCCodeWhileStatementPrivate));
-	G_OBJECT_CLASS (klass)->get_property = vala_ccode_while_statement_get_property;
-	G_OBJECT_CLASS (klass)->set_property = vala_ccode_while_statement_set_property;
-	G_OBJECT_CLASS (klass)->finalize = vala_ccode_while_statement_finalize;
 	VALA_CCODE_NODE_CLASS (klass)->write = vala_ccode_while_statement_real_write;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_WHILE_STATEMENT_CONDITION, g_param_spec_object ("condition", "condition", "condition", VALA_TYPE_CCODE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_WHILE_STATEMENT_BODY, g_param_spec_object ("body", "body", "body", VALA_TYPE_CCODE_STATEMENT, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
@@ -166,19 +117,19 @@ static void vala_ccode_while_statement_instance_init (ValaCCodeWhileStatement *
 }
 
 
-static void vala_ccode_while_statement_finalize (GObject * obj) {
+static void vala_ccode_while_statement_finalize (ValaCCodeNode* obj) {
 	ValaCCodeWhileStatement * self;
 	self = VALA_CCODE_WHILE_STATEMENT (obj);
-	(self->priv->_condition == NULL ? NULL : (self->priv->_condition = (g_object_unref (self->priv->_condition), NULL)));
-	(self->priv->_body == NULL ? NULL : (self->priv->_body = (g_object_unref (self->priv->_body), NULL)));
-	G_OBJECT_CLASS (vala_ccode_while_statement_parent_class)->finalize (obj);
+	(self->priv->_condition == NULL ? NULL : (self->priv->_condition = (vala_ccode_node_unref (self->priv->_condition), NULL)));
+	(self->priv->_body == NULL ? NULL : (self->priv->_body = (vala_ccode_node_unref (self->priv->_body), NULL)));
+	VALA_CCODE_NODE_CLASS (vala_ccode_while_statement_parent_class)->finalize (obj);
 }
 
 
 GType vala_ccode_while_statement_get_type (void) {
 	static GType vala_ccode_while_statement_type_id = 0;
 	if (vala_ccode_while_statement_type_id == 0) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeWhileStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_while_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeWhileStatement), 0, (GInstanceInitFunc) vala_ccode_while_statement_instance_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeWhileStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_while_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeWhileStatement), 0, (GInstanceInitFunc) vala_ccode_while_statement_instance_init, NULL };
 		vala_ccode_while_statement_type_id = g_type_register_static (VALA_TYPE_CCODE_STATEMENT, "ValaCCodeWhileStatement", &g_define_type_info, 0);
 	}
 	return vala_ccode_while_statement_type_id;
