@@ -38,13 +38,13 @@ typedef struct _GeeArrayListIteratorClass GeeArrayListIteratorClass;
 typedef struct _GeeArrayListIteratorPrivate GeeArrayListIteratorPrivate;
 
 struct _GeeArrayListIterator {
-	GObject parent_instance;
+	GeeCollectionObject parent_instance;
 	GeeArrayListIteratorPrivate * priv;
 	gint _stamp;
 };
 
 struct _GeeArrayListIteratorClass {
-	GObjectClass parent_class;
+	GeeCollectionObjectClass parent_class;
 };
 
 
@@ -62,12 +62,7 @@ struct _GeeArrayListPrivate {
 
 #define GEE_ARRAY_LIST_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GEE_TYPE_ARRAY_LIST, GeeArrayListPrivate))
 enum  {
-	GEE_ARRAY_LIST_DUMMY_PROPERTY,
-	GEE_ARRAY_LIST_SIZE,
-	GEE_ARRAY_LIST_EQUAL_FUNC,
-	GEE_ARRAY_LIST_G_TYPE,
-	GEE_ARRAY_LIST_G_DUP_FUNC,
-	GEE_ARRAY_LIST_G_DESTROY_FUNC
+	GEE_ARRAY_LIST_DUMMY_PROPERTY
 };
 static GType gee_array_list_real_get_element_type (GeeIterable* base);
 static GeeIterator* gee_array_list_real_iterator (GeeIterable* base);
@@ -93,59 +88,43 @@ struct _GeeArrayListIteratorPrivate {
 
 #define GEE_ARRAY_LIST_ITERATOR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GEE_ARRAY_LIST_TYPE_ITERATOR, GeeArrayListIteratorPrivate))
 enum  {
-	GEE_ARRAY_LIST_ITERATOR_DUMMY_PROPERTY,
-	GEE_ARRAY_LIST_ITERATOR_LIST,
-	GEE_ARRAY_LIST_ITERATOR_G_TYPE,
-	GEE_ARRAY_LIST_ITERATOR_G_DUP_FUNC,
-	GEE_ARRAY_LIST_ITERATOR_G_DESTROY_FUNC
+	GEE_ARRAY_LIST_ITERATOR_DUMMY_PROPERTY
 };
+static GeeArrayListIterator* gee_array_list_iterator_construct (GType object_type, GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GeeArrayList* list);
 static GeeArrayListIterator* gee_array_list_iterator_new (GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GeeArrayList* list);
 static gboolean gee_array_list_iterator_real_next (GeeIterator* base);
 static gpointer gee_array_list_iterator_real_get (GeeIterator* base);
 static void gee_array_list_iterator_set_list (GeeArrayListIterator* self, GeeArrayList* value);
 static gpointer gee_array_list_iterator_parent_class = NULL;
 static GeeIteratorIface* gee_array_list_iterator_gee_iterator_parent_iface = NULL;
-static void gee_array_list_iterator_finalize (GObject * obj);
+static void gee_array_list_iterator_finalize (GeeCollectionObject* obj);
 static GType gee_array_list_iterator_get_type (void);
 static gpointer gee_array_list_parent_class = NULL;
 static GeeIterableIface* gee_array_list_gee_iterable_parent_iface = NULL;
 static GeeCollectionIface* gee_array_list_gee_collection_parent_iface = NULL;
 static GeeListIface* gee_array_list_gee_list_parent_iface = NULL;
-static void gee_array_list_finalize (GObject * obj);
+static void gee_array_list_finalize (GeeCollectionObject* obj);
 static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
 static void _vala_array_move (gpointer array, gsize element_size, gint src, gint dest, gint length);
 
 
 
-GeeArrayList* gee_array_list_new (GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GEqualFunc equal_func) {
-	GParameter * __params;
-	GParameter * __params_it;
-	GeeArrayList * self;
-	__params = g_new0 (GParameter, 3);
-	__params_it = __params;
-	__params_it->name = "g-type";
-	g_value_init (&__params_it->value, G_TYPE_GTYPE);
-	g_value_set_gtype (&__params_it->value, g_type);
-	__params_it++;
-	__params_it->name = "g-dup-func";
-	g_value_init (&__params_it->value, G_TYPE_POINTER);
-	g_value_set_pointer (&__params_it->value, g_dup_func);
-	__params_it++;
-	__params_it->name = "g-destroy-func";
-	g_value_init (&__params_it->value, G_TYPE_POINTER);
-	g_value_set_pointer (&__params_it->value, g_destroy_func);
-	__params_it++;
-	self = g_object_newv (GEE_TYPE_ARRAY_LIST, __params_it - __params, __params);
+GeeArrayList* gee_array_list_construct (GType object_type, GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GEqualFunc equal_func) {
+	GeeArrayList* self;
+	self = ((GeeArrayList*) (g_type_create_instance (object_type)));
+	self->priv->g_type = g_type;
+	self->priv->g_dup_func = g_dup_func;
+	self->priv->g_destroy_func = g_destroy_func;
 	gee_array_list_set_equal_func (self, equal_func);
-	while (__params_it > __params) {
-		--__params_it;
-		g_value_unset (&__params_it->value);
-	}
-	g_free (__params);
 	return self;
 }
 
 
+GeeArrayList* gee_array_list_new (GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GEqualFunc equal_func) {
+	return gee_array_list_construct (GEE_TYPE_ARRAY_LIST, g_type, g_dup_func, g_destroy_func, equal_func);
+}
+
+
 static GType gee_array_list_real_get_element_type (GeeIterable* base) {
 	GeeArrayList * self;
 	self = GEE_ARRAY_LIST (base);
@@ -327,37 +306,23 @@ static gint gee_array_list_real_get_size (GeeCollection* base) {
 void gee_array_list_set_equal_func (GeeArrayList* self, GEqualFunc value) {
 	g_return_if_fail (GEE_IS_ARRAY_LIST (self));
 	self->priv->_equal_func = value;
-	g_object_notify (((GObject *) (self)), "equal-func");
+}
+
+
+static GeeArrayListIterator* gee_array_list_iterator_construct (GType object_type, GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GeeArrayList* list) {
+	GeeArrayListIterator* self;
+	g_return_val_if_fail (GEE_IS_ARRAY_LIST (list), NULL);
+	self = ((GeeArrayListIterator*) (g_type_create_instance (object_type)));
+	self->priv->g_type = g_type;
+	self->priv->g_dup_func = g_dup_func;
+	self->priv->g_destroy_func = g_destroy_func;
+	gee_array_list_iterator_set_list (self, list);
+	return self;
 }
 
 
 static GeeArrayListIterator* gee_array_list_iterator_new (GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GeeArrayList* list) {
-	GParameter * __params;
-	GParameter * __params_it;
-	GeeArrayListIterator * self;
-	g_return_val_if_fail (GEE_IS_ARRAY_LIST (list), NULL);
-	__params = g_new0 (GParameter, 3);
-	__params_it = __params;
-	__params_it->name = "g-type";
-	g_value_init (&__params_it->value, G_TYPE_GTYPE);
-	g_value_set_gtype (&__params_it->value, g_type);
-	__params_it++;
-	__params_it->name = "g-dup-func";
-	g_value_init (&__params_it->value, G_TYPE_POINTER);
-	g_value_set_pointer (&__params_it->value, g_dup_func);
-	__params_it++;
-	__params_it->name = "g-destroy-func";
-	g_value_init (&__params_it->value, G_TYPE_POINTER);
-	g_value_set_pointer (&__params_it->value, g_destroy_func);
-	__params_it++;
-	self = g_object_newv (GEE_ARRAY_LIST_TYPE_ITERATOR, __params_it - __params, __params);
-	gee_array_list_iterator_set_list (self, list);
-	while (__params_it > __params) {
-		--__params_it;
-		g_value_unset (&__params_it->value);
-	}
-	g_free (__params);
-	return self;
+	return gee_array_list_iterator_construct (GEE_ARRAY_LIST_TYPE_ITERATOR, g_type, g_dup_func, g_destroy_func, list);
 }
 
 
@@ -389,56 +354,15 @@ static void gee_array_list_iterator_set_list (GeeArrayListIterator* self, GeeArr
 	g_return_if_fail (GEE_ARRAY_LIST_IS_ITERATOR (self));
 	_tmp1 = NULL;
 	_tmp0 = NULL;
-	self->priv->_list = (_tmp1 = (_tmp0 = value, (_tmp0 == NULL ? NULL : g_object_ref (_tmp0))), (self->priv->_list == NULL ? NULL : (self->priv->_list = (g_object_unref (self->priv->_list), NULL))), _tmp1);
+	self->priv->_list = (_tmp1 = (_tmp0 = value, (_tmp0 == NULL ? NULL : gee_collection_object_ref (_tmp0))), (self->priv->_list == NULL ? NULL : (self->priv->_list = (gee_collection_object_unref (self->priv->_list), NULL))), _tmp1);
 	self->_stamp = self->priv->_list->priv->_stamp;
-	g_object_notify (((GObject *) (self)), "list");
-}
-
-
-static void gee_array_list_iterator_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
-	GeeArrayListIterator * self;
-	self = GEE_ARRAY_LIST_ITERATOR (object);
-	switch (property_id) {
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
-static void gee_array_list_iterator_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
-	GeeArrayListIterator * self;
-	self = GEE_ARRAY_LIST_ITERATOR (object);
-	switch (property_id) {
-		case GEE_ARRAY_LIST_ITERATOR_LIST:
-		gee_array_list_iterator_set_list (self, g_value_get_object (value));
-		break;
-		case GEE_ARRAY_LIST_ITERATOR_G_TYPE:
-		self->priv->g_type = g_value_get_gtype (value);
-		break;
-		case GEE_ARRAY_LIST_ITERATOR_G_DUP_FUNC:
-		self->priv->g_dup_func = g_value_get_pointer (value);
-		break;
-		case GEE_ARRAY_LIST_ITERATOR_G_DESTROY_FUNC:
-		self->priv->g_destroy_func = g_value_get_pointer (value);
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
 }
 
 
 static void gee_array_list_iterator_class_init (GeeArrayListIteratorClass * klass) {
 	gee_array_list_iterator_parent_class = g_type_class_peek_parent (klass);
+	GEE_COLLECTION_OBJECT_CLASS (klass)->finalize = gee_array_list_iterator_finalize;
 	g_type_class_add_private (klass, sizeof (GeeArrayListIteratorPrivate));
-	G_OBJECT_CLASS (klass)->get_property = gee_array_list_iterator_get_property;
-	G_OBJECT_CLASS (klass)->set_property = gee_array_list_iterator_set_property;
-	G_OBJECT_CLASS (klass)->finalize = gee_array_list_iterator_finalize;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_ARRAY_LIST_ITERATOR_G_TYPE, g_param_spec_gtype ("g-type", "type", "type", G_TYPE_NONE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_ARRAY_LIST_ITERATOR_G_DUP_FUNC, g_param_spec_pointer ("g-dup-func", "dup func", "dup func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_ARRAY_LIST_ITERATOR_G_DESTROY_FUNC, g_param_spec_pointer ("g-destroy-func", "destroy func", "destroy func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_ARRAY_LIST_ITERATOR_LIST, g_param_spec_object ("list", "list", "list", GEE_TYPE_ARRAY_LIST, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
 }
 
 
@@ -456,74 +380,30 @@ static void gee_array_list_iterator_instance_init (GeeArrayListIterator * self)
 }
 
 
-static void gee_array_list_iterator_finalize (GObject * obj) {
+static void gee_array_list_iterator_finalize (GeeCollectionObject* obj) {
 	GeeArrayListIterator * self;
 	self = GEE_ARRAY_LIST_ITERATOR (obj);
-	(self->priv->_list == NULL ? NULL : (self->priv->_list = (g_object_unref (self->priv->_list), NULL)));
-	G_OBJECT_CLASS (gee_array_list_iterator_parent_class)->finalize (obj);
+	(self->priv->_list == NULL ? NULL : (self->priv->_list = (gee_collection_object_unref (self->priv->_list), NULL)));
+	GEE_COLLECTION_OBJECT_CLASS (gee_array_list_iterator_parent_class)->finalize (obj);
 }
 
 
 static GType gee_array_list_iterator_get_type (void) {
 	static GType gee_array_list_iterator_type_id = 0;
 	if (gee_array_list_iterator_type_id == 0) {
-		static const GTypeInfo g_define_type_info = { sizeof (GeeArrayListIteratorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gee_array_list_iterator_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GeeArrayListIterator), 0, (GInstanceInitFunc) gee_array_list_iterator_instance_init };
+		static const GTypeInfo g_define_type_info = { sizeof (GeeArrayListIteratorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gee_array_list_iterator_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GeeArrayListIterator), 0, (GInstanceInitFunc) gee_array_list_iterator_instance_init, NULL };
 		static const GInterfaceInfo gee_iterator_info = { (GInterfaceInitFunc) gee_array_list_iterator_gee_iterator_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
-		gee_array_list_iterator_type_id = g_type_register_static (G_TYPE_OBJECT, "GeeArrayListIterator", &g_define_type_info, 0);
+		gee_array_list_iterator_type_id = g_type_register_static (GEE_TYPE_COLLECTION_OBJECT, "GeeArrayListIterator", &g_define_type_info, 0);
 		g_type_add_interface_static (gee_array_list_iterator_type_id, GEE_TYPE_ITERATOR, &gee_iterator_info);
 	}
 	return gee_array_list_iterator_type_id;
 }
 
 
-static void gee_array_list_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
-	GeeArrayList * self;
-	self = GEE_ARRAY_LIST (object);
-	switch (property_id) {
-		case GEE_ARRAY_LIST_SIZE:
-		g_value_set_int (value, gee_collection_get_size (GEE_COLLECTION (self)));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
-static void gee_array_list_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
-	GeeArrayList * self;
-	self = GEE_ARRAY_LIST (object);
-	switch (property_id) {
-		case GEE_ARRAY_LIST_EQUAL_FUNC:
-		gee_array_list_set_equal_func (self, g_value_get_pointer (value));
-		break;
-		case GEE_ARRAY_LIST_G_TYPE:
-		self->priv->g_type = g_value_get_gtype (value);
-		break;
-		case GEE_ARRAY_LIST_G_DUP_FUNC:
-		self->priv->g_dup_func = g_value_get_pointer (value);
-		break;
-		case GEE_ARRAY_LIST_G_DESTROY_FUNC:
-		self->priv->g_destroy_func = g_value_get_pointer (value);
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
 static void gee_array_list_class_init (GeeArrayListClass * klass) {
 	gee_array_list_parent_class = g_type_class_peek_parent (klass);
+	GEE_COLLECTION_OBJECT_CLASS (klass)->finalize = gee_array_list_finalize;
 	g_type_class_add_private (klass, sizeof (GeeArrayListPrivate));
-	G_OBJECT_CLASS (klass)->get_property = gee_array_list_get_property;
-	G_OBJECT_CLASS (klass)->set_property = gee_array_list_set_property;
-	G_OBJECT_CLASS (klass)->finalize = gee_array_list_finalize;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_ARRAY_LIST_G_TYPE, g_param_spec_gtype ("g-type", "type", "type", G_TYPE_NONE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_ARRAY_LIST_G_DUP_FUNC, g_param_spec_pointer ("g-dup-func", "dup func", "dup func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_ARRAY_LIST_G_DESTROY_FUNC, g_param_spec_pointer ("g-destroy-func", "destroy func", "destroy func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
-	g_object_class_override_property (G_OBJECT_CLASS (klass), GEE_ARRAY_LIST_SIZE, "size");
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_ARRAY_LIST_EQUAL_FUNC, g_param_spec_pointer ("equal-func", "equal-func", "equal-func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
 }
 
 
@@ -562,22 +442,22 @@ static void gee_array_list_instance_init (GeeArrayList * self) {
 }
 
 
-static void gee_array_list_finalize (GObject * obj) {
+static void gee_array_list_finalize (GeeCollectionObject* obj) {
 	GeeArrayList * self;
 	self = GEE_ARRAY_LIST (obj);
 	self->priv->_items = (_vala_array_free (self->priv->_items, self->priv->_items_length1, ((GDestroyNotify) (self->priv->g_destroy_func))), NULL);
-	G_OBJECT_CLASS (gee_array_list_parent_class)->finalize (obj);
+	GEE_COLLECTION_OBJECT_CLASS (gee_array_list_parent_class)->finalize (obj);
 }
 
 
 GType gee_array_list_get_type (void) {
 	static GType gee_array_list_type_id = 0;
 	if (gee_array_list_type_id == 0) {
-		static const GTypeInfo g_define_type_info = { sizeof (GeeArrayListClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gee_array_list_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GeeArrayList), 0, (GInstanceInitFunc) gee_array_list_instance_init };
+		static const GTypeInfo g_define_type_info = { sizeof (GeeArrayListClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gee_array_list_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GeeArrayList), 0, (GInstanceInitFunc) gee_array_list_instance_init, NULL };
 		static const GInterfaceInfo gee_iterable_info = { (GInterfaceInitFunc) gee_array_list_gee_iterable_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
 		static const GInterfaceInfo gee_collection_info = { (GInterfaceInitFunc) gee_array_list_gee_collection_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
 		static const GInterfaceInfo gee_list_info = { (GInterfaceInitFunc) gee_array_list_gee_list_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
-		gee_array_list_type_id = g_type_register_static (G_TYPE_OBJECT, "GeeArrayList", &g_define_type_info, 0);
+		gee_array_list_type_id = g_type_register_static (GEE_TYPE_COLLECTION_OBJECT, "GeeArrayList", &g_define_type_info, 0);
 		g_type_add_interface_static (gee_array_list_type_id, GEE_TYPE_ITERABLE, &gee_iterable_info);
 		g_type_add_interface_static (gee_array_list_type_id, GEE_TYPE_COLLECTION, &gee_collection_info);
 		g_type_add_interface_static (gee_array_list_type_id, GEE_TYPE_LIST, &gee_list_info);
