@@ -2,7 +2,7 @@
  *
  * Copyright (C) 2004-2005  Novell, Inc
  * Copyright (C) 2005  David Waite
- * Copyright (C) 2007  Jürg Billeter
+ * Copyright (C) 2007-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -27,6 +27,7 @@
 
 #include <glib.h>
 #include <glib-object.h>
+#include <gee/collectionobject.h>
 #include <gee/iterable.h>
 #include <gee/collection.h>
 #include <gee/list.h>
@@ -50,17 +51,21 @@ typedef struct _GeeArrayListPrivate GeeArrayListPrivate;
  * Arrays of arbitrary elements which grow automatically as elements are added.
  */
 struct _GeeArrayList {
-	GObject parent_instance;
+	GeeCollectionObject parent_instance;
 	GeeArrayListPrivate * priv;
 };
+
 struct _GeeArrayListClass {
-	GObjectClass parent_class;
+	GeeCollectionObjectClass parent_class;
 };
 
+
+GeeArrayList* gee_array_list_construct (GType object_type, GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GEqualFunc equal_func);
 GeeArrayList* gee_array_list_new (GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GEqualFunc equal_func);
 void gee_array_list_set_equal_func (GeeArrayList* self, GEqualFunc value);
 GType gee_array_list_get_type (void);
 
+
 G_END_DECLS
 
 #endif
