@@ -44,12 +44,12 @@ struct _GeeHashSetNode {
 };
 
 struct _GeeHashSetIterator {
-	GObject parent_instance;
+	GeeCollectionObject parent_instance;
 	GeeHashSetIteratorPrivate * priv;
 };
 
 struct _GeeHashSetIteratorClass {
-	GObjectClass parent_class;
+	GeeCollectionObjectClass parent_class;
 };
 
 
@@ -69,14 +69,10 @@ struct _GeeHashSetPrivate {
 
 #define GEE_HASH_SET_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GEE_TYPE_HASH_SET, GeeHashSetPrivate))
 enum  {
-	GEE_HASH_SET_DUMMY_PROPERTY,
-	GEE_HASH_SET_SIZE,
-	GEE_HASH_SET_HASH_FUNC,
-	GEE_HASH_SET_EQUAL_FUNC,
-	GEE_HASH_SET_G_TYPE,
-	GEE_HASH_SET_G_DUP_FUNC,
-	GEE_HASH_SET_G_DESTROY_FUNC
+	GEE_HASH_SET_DUMMY_PROPERTY
 };
+#define GEE_HASH_SET_MIN_SIZE 11
+#define GEE_HASH_SET_MAX_SIZE 13845163
 static GeeHashSetNode** gee_hash_set_lookup_node (GeeHashSet* self, gconstpointer key);
 static gboolean gee_hash_set_real_contains (GeeCollection* base, gconstpointer key);
 static GType gee_hash_set_real_get_element_type (GeeIterable* base);
@@ -85,7 +81,6 @@ static gboolean gee_hash_set_real_add (GeeCollection* base, gconstpointer key);
 static gboolean gee_hash_set_real_remove (GeeCollection* base, gconstpointer key);
 static void gee_hash_set_real_clear (GeeCollection* base);
 static void gee_hash_set_resize (GeeHashSet* self);
-static GObject * gee_hash_set_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
 static GeeHashSetNode* gee_hash_set_node_new (gpointer k, guint hash);
 static void gee_hash_set_node_instance_init (GeeHashSetNode * self);
 static void gee_hash_set_node_free (GeeHashSetNode* self);
@@ -101,58 +96,44 @@ struct _GeeHashSetIteratorPrivate {
 
 #define GEE_HASH_SET_ITERATOR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GEE_HASH_SET_TYPE_ITERATOR, GeeHashSetIteratorPrivate))
 enum  {
-	GEE_HASH_SET_ITERATOR_DUMMY_PROPERTY,
-	GEE_HASH_SET_ITERATOR_SET,
-	GEE_HASH_SET_ITERATOR_G_TYPE,
-	GEE_HASH_SET_ITERATOR_G_DUP_FUNC,
-	GEE_HASH_SET_ITERATOR_G_DESTROY_FUNC
+	GEE_HASH_SET_ITERATOR_DUMMY_PROPERTY
 };
+static GeeHashSetIterator* gee_hash_set_iterator_construct (GType object_type, GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GeeHashSet* set);
 static GeeHashSetIterator* gee_hash_set_iterator_new (GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GeeHashSet* set);
 static gboolean gee_hash_set_iterator_real_next (GeeIterator* base);
 static gpointer gee_hash_set_iterator_real_get (GeeIterator* base);
 static void gee_hash_set_iterator_set_set (GeeHashSetIterator* self, GeeHashSet* value);
 static gpointer gee_hash_set_iterator_parent_class = NULL;
 static GeeIteratorIface* gee_hash_set_iterator_gee_iterator_parent_iface = NULL;
-static void gee_hash_set_iterator_finalize (GObject * obj);
+static void gee_hash_set_iterator_finalize (GeeCollectionObject* obj);
 static GType gee_hash_set_iterator_get_type (void);
 static gpointer gee_hash_set_parent_class = NULL;
 static GeeIterableIface* gee_hash_set_gee_iterable_parent_iface = NULL;
 static GeeCollectionIface* gee_hash_set_gee_collection_parent_iface = NULL;
 static GeeSetIface* gee_hash_set_gee_set_parent_iface = NULL;
-static void gee_hash_set_finalize (GObject * obj);
+static void gee_hash_set_finalize (GeeCollectionObject* obj);
 static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
 
-static const gint GEE_HASH_SET_MIN_SIZE = 11;
-static const gint GEE_HASH_SET_MAX_SIZE = 13845163;
+
+
+GeeHashSet* gee_hash_set_construct (GType object_type, GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GHashFunc hash_func, GEqualFunc equal_func) {
+	GeeHashSet* self;
+	GeeHashSetNode** _tmp0;
+	self = ((GeeHashSet*) (g_type_create_instance (object_type)));
+	self->priv->g_type = g_type;
+	self->priv->g_dup_func = g_dup_func;
+	self->priv->g_destroy_func = g_destroy_func;
+	gee_hash_set_set_hash_func (self, hash_func);
+	gee_hash_set_set_equal_func (self, equal_func);
+	self->priv->_array_size = GEE_HASH_SET_MIN_SIZE;
+	_tmp0 = NULL;
+	self->priv->_nodes = (_tmp0 = g_new0 (GeeHashSetNode*, self->priv->_array_size + 1), (self->priv->_nodes = (_vala_array_free (self->priv->_nodes, self->priv->_nodes_length1, ((GDestroyNotify) (gee_hash_set_node_free))), NULL)), self->priv->_nodes_length1 = self->priv->_array_size, _tmp0);
+	return self;
+}
 
 
 GeeHashSet* gee_hash_set_new (GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GHashFunc hash_func, GEqualFunc equal_func) {
-	GParameter * __params;
-	GParameter * __params_it;
-	GeeHashSet * self;
-	__params = g_new0 (GParameter, 3);
-	__params_it = __params;
-	__params_it->name = "g-type";
-	g_value_init (&__params_it->value, G_TYPE_GTYPE);
-	g_value_set_gtype (&__params_it->value, g_type);
-	__params_it++;
-	__params_it->name = "g-dup-func";
-	g_value_init (&__params_it->value, G_TYPE_POINTER);
-	g_value_set_pointer (&__params_it->value, g_dup_func);
-	__params_it++;
-	__params_it->name = "g-destroy-func";
-	g_value_init (&__params_it->value, G_TYPE_POINTER);
-	g_value_set_pointer (&__params_it->value, g_destroy_func);
-	__params_it++;
-	self = g_object_newv (GEE_TYPE_HASH_SET, __params_it - __params, __params);
-	gee_hash_set_set_hash_func (self, hash_func);
-	gee_hash_set_set_equal_func (self, equal_func);
-	while (__params_it > __params) {
-		--__params_it;
-		g_value_unset (&__params_it->value);
-	}
-	g_free (__params);
-	return self;
+	return gee_hash_set_construct (GEE_TYPE_HASH_SET, g_type, g_dup_func, g_destroy_func, hash_func, equal_func);
 }
 
 
@@ -337,33 +318,12 @@ static gint gee_hash_set_real_get_size (GeeCollection* base) {
 void gee_hash_set_set_hash_func (GeeHashSet* self, GHashFunc value) {
 	g_return_if_fail (GEE_IS_HASH_SET (self));
 	self->priv->_hash_func = value;
-	g_object_notify (((GObject *) (self)), "hash-func");
 }
 
 
 void gee_hash_set_set_equal_func (GeeHashSet* self, GEqualFunc value) {
 	g_return_if_fail (GEE_IS_HASH_SET (self));
 	self->priv->_equal_func = value;
-	g_object_notify (((GObject *) (self)), "equal-func");
-}
-
-
-static GObject * gee_hash_set_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
-	GObject * obj;
-	GeeHashSetClass * klass;
-	GObjectClass * parent_class;
-	GeeHashSet * self;
-	klass = GEE_HASH_SET_CLASS (g_type_class_peek (GEE_TYPE_HASH_SET));
-	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
-	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
-	self = GEE_HASH_SET (obj);
-	{
-		GeeHashSetNode** _tmp0;
-		self->priv->_array_size = GEE_HASH_SET_MIN_SIZE;
-		_tmp0 = NULL;
-		self->priv->_nodes = (_tmp0 = g_new0 (GeeHashSetNode*, self->priv->_array_size + 1), (self->priv->_nodes = (_vala_array_free (self->priv->_nodes, self->priv->_nodes_length1, ((GDestroyNotify) (gee_hash_set_node_free))), NULL)), self->priv->_nodes_length1 = self->priv->_array_size, _tmp0);
-	}
-	return obj;
 }
 
 
@@ -389,36 +349,23 @@ static void gee_hash_set_node_free (GeeHashSetNode* self) {
 }
 
 
-static GeeHashSetIterator* gee_hash_set_iterator_new (GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GeeHashSet* set) {
-	GParameter * __params;
-	GParameter * __params_it;
-	GeeHashSetIterator * self;
+static GeeHashSetIterator* gee_hash_set_iterator_construct (GType object_type, GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GeeHashSet* set) {
+	GeeHashSetIterator* self;
 	g_return_val_if_fail (GEE_IS_HASH_SET (set), NULL);
-	__params = g_new0 (GParameter, 3);
-	__params_it = __params;
-	__params_it->name = "g-type";
-	g_value_init (&__params_it->value, G_TYPE_GTYPE);
-	g_value_set_gtype (&__params_it->value, g_type);
-	__params_it++;
-	__params_it->name = "g-dup-func";
-	g_value_init (&__params_it->value, G_TYPE_POINTER);
-	g_value_set_pointer (&__params_it->value, g_dup_func);
-	__params_it++;
-	__params_it->name = "g-destroy-func";
-	g_value_init (&__params_it->value, G_TYPE_POINTER);
-	g_value_set_pointer (&__params_it->value, g_destroy_func);
-	__params_it++;
-	self = g_object_newv (GEE_HASH_SET_TYPE_ITERATOR, __params_it - __params, __params);
+	self = ((GeeHashSetIterator*) (g_type_create_instance (object_type)));
+	self->priv->g_type = g_type;
+	self->priv->g_dup_func = g_dup_func;
+	self->priv->g_destroy_func = g_destroy_func;
 	gee_hash_set_iterator_set_set (self, set);
-	while (__params_it > __params) {
-		--__params_it;
-		g_value_unset (&__params_it->value);
-	}
-	g_free (__params);
 	return self;
 }
 
 
+static GeeHashSetIterator* gee_hash_set_iterator_new (GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GeeHashSet* set) {
+	return gee_hash_set_iterator_construct (GEE_HASH_SET_TYPE_ITERATOR, g_type, g_dup_func, g_destroy_func, set);
+}
+
+
 static gboolean gee_hash_set_iterator_real_next (GeeIterator* base) {
 	GeeHashSetIterator * self;
 	self = GEE_HASH_SET_ITERATOR (base);
@@ -450,56 +397,15 @@ static void gee_hash_set_iterator_set_set (GeeHashSetIterator* self, GeeHashSet*
 	g_return_if_fail (GEE_HASH_SET_IS_ITERATOR (self));
 	_tmp1 = NULL;
 	_tmp0 = NULL;
-	self->priv->_set = (_tmp1 = (_tmp0 = value, (_tmp0 == NULL ? NULL : g_object_ref (_tmp0))), (self->priv->_set == NULL ? NULL : (self->priv->_set = (g_object_unref (self->priv->_set), NULL))), _tmp1);
+	self->priv->_set = (_tmp1 = (_tmp0 = value, (_tmp0 == NULL ? NULL : gee_collection_object_ref (_tmp0))), (self->priv->_set == NULL ? NULL : (self->priv->_set = (gee_collection_object_unref (self->priv->_set), NULL))), _tmp1);
 	self->priv->_stamp = self->priv->_set->priv->_stamp;
-	g_object_notify (((GObject *) (self)), "set");
-}
-
-
-static void gee_hash_set_iterator_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
-	GeeHashSetIterator * self;
-	self = GEE_HASH_SET_ITERATOR (object);
-	switch (property_id) {
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
-static void gee_hash_set_iterator_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
-	GeeHashSetIterator * self;
-	self = GEE_HASH_SET_ITERATOR (object);
-	switch (property_id) {
-		case GEE_HASH_SET_ITERATOR_SET:
-		gee_hash_set_iterator_set_set (self, g_value_get_object (value));
-		break;
-		case GEE_HASH_SET_ITERATOR_G_TYPE:
-		self->priv->g_type = g_value_get_gtype (value);
-		break;
-		case GEE_HASH_SET_ITERATOR_G_DUP_FUNC:
-		self->priv->g_dup_func = g_value_get_pointer (value);
-		break;
-		case GEE_HASH_SET_ITERATOR_G_DESTROY_FUNC:
-		self->priv->g_destroy_func = g_value_get_pointer (value);
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
 }
 
 
 static void gee_hash_set_iterator_class_init (GeeHashSetIteratorClass * klass) {
 	gee_hash_set_iterator_parent_class = g_type_class_peek_parent (klass);
+	GEE_COLLECTION_OBJECT_CLASS (klass)->finalize = gee_hash_set_iterator_finalize;
 	g_type_class_add_private (klass, sizeof (GeeHashSetIteratorPrivate));
-	G_OBJECT_CLASS (klass)->get_property = gee_hash_set_iterator_get_property;
-	G_OBJECT_CLASS (klass)->set_property = gee_hash_set_iterator_set_property;
-	G_OBJECT_CLASS (klass)->finalize = gee_hash_set_iterator_finalize;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_SET_ITERATOR_G_TYPE, g_param_spec_gtype ("g-type", "type", "type", G_TYPE_NONE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_SET_ITERATOR_G_DUP_FUNC, g_param_spec_pointer ("g-dup-func", "dup func", "dup func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_SET_ITERATOR_G_DESTROY_FUNC, g_param_spec_pointer ("g-destroy-func", "destroy func", "destroy func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_SET_ITERATOR_SET, g_param_spec_object ("set", "set", "set", GEE_TYPE_HASH_SET, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
 }
 
 
@@ -517,79 +423,30 @@ static void gee_hash_set_iterator_instance_init (GeeHashSetIterator * self) {
 }
 
 
-static void gee_hash_set_iterator_finalize (GObject * obj) {
+static void gee_hash_set_iterator_finalize (GeeCollectionObject* obj) {
 	GeeHashSetIterator * self;
 	self = GEE_HASH_SET_ITERATOR (obj);
-	(self->priv->_set == NULL ? NULL : (self->priv->_set = (g_object_unref (self->priv->_set), NULL)));
-	G_OBJECT_CLASS (gee_hash_set_iterator_parent_class)->finalize (obj);
+	(self->priv->_set == NULL ? NULL : (self->priv->_set = (gee_collection_object_unref (self->priv->_set), NULL)));
+	GEE_COLLECTION_OBJECT_CLASS (gee_hash_set_iterator_parent_class)->finalize (obj);
 }
 
 
 static GType gee_hash_set_iterator_get_type (void) {
 	static GType gee_hash_set_iterator_type_id = 0;
 	if (gee_hash_set_iterator_type_id == 0) {
-		static const GTypeInfo g_define_type_info = { sizeof (GeeHashSetIteratorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gee_hash_set_iterator_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GeeHashSetIterator), 0, (GInstanceInitFunc) gee_hash_set_iterator_instance_init };
+		static const GTypeInfo g_define_type_info = { sizeof (GeeHashSetIteratorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gee_hash_set_iterator_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GeeHashSetIterator), 0, (GInstanceInitFunc) gee_hash_set_iterator_instance_init, NULL };
 		static const GInterfaceInfo gee_iterator_info = { (GInterfaceInitFunc) gee_hash_set_iterator_gee_iterator_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
-		gee_hash_set_iterator_type_id = g_type_register_static (G_TYPE_OBJECT, "GeeHashSetIterator", &g_define_type_info, 0);
+		gee_hash_set_iterator_type_id = g_type_register_static (GEE_TYPE_COLLECTION_OBJECT, "GeeHashSetIterator", &g_define_type_info, 0);
 		g_type_add_interface_static (gee_hash_set_iterator_type_id, GEE_TYPE_ITERATOR, &gee_iterator_info);
 	}
 	return gee_hash_set_iterator_type_id;
 }
 
 
-static void gee_hash_set_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
-	GeeHashSet * self;
-	self = GEE_HASH_SET (object);
-	switch (property_id) {
-		case GEE_HASH_SET_SIZE:
-		g_value_set_int (value, gee_collection_get_size (GEE_COLLECTION (self)));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
-static void gee_hash_set_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
-	GeeHashSet * self;
-	self = GEE_HASH_SET (object);
-	switch (property_id) {
-		case GEE_HASH_SET_HASH_FUNC:
-		gee_hash_set_set_hash_func (self, g_value_get_pointer (value));
-		break;
-		case GEE_HASH_SET_EQUAL_FUNC:
-		gee_hash_set_set_equal_func (self, g_value_get_pointer (value));
-		break;
-		case GEE_HASH_SET_G_TYPE:
-		self->priv->g_type = g_value_get_gtype (value);
-		break;
-		case GEE_HASH_SET_G_DUP_FUNC:
-		self->priv->g_dup_func = g_value_get_pointer (value);
-		break;
-		case GEE_HASH_SET_G_DESTROY_FUNC:
-		self->priv->g_destroy_func = g_value_get_pointer (value);
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
 static void gee_hash_set_class_init (GeeHashSetClass * klass) {
 	gee_hash_set_parent_class = g_type_class_peek_parent (klass);
+	GEE_COLLECTION_OBJECT_CLASS (klass)->finalize = gee_hash_set_finalize;
 	g_type_class_add_private (klass, sizeof (GeeHashSetPrivate));
-	G_OBJECT_CLASS (klass)->get_property = gee_hash_set_get_property;
-	G_OBJECT_CLASS (klass)->set_property = gee_hash_set_set_property;
-	G_OBJECT_CLASS (klass)->constructor = gee_hash_set_constructor;
-	G_OBJECT_CLASS (klass)->finalize = gee_hash_set_finalize;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_SET_G_TYPE, g_param_spec_gtype ("g-type", "type", "type", G_TYPE_NONE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_SET_G_DUP_FUNC, g_param_spec_pointer ("g-dup-func", "dup func", "dup func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_SET_G_DESTROY_FUNC, g_param_spec_pointer ("g-destroy-func", "destroy func", "destroy func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
-	g_object_class_override_property (G_OBJECT_CLASS (klass), GEE_HASH_SET_SIZE, "size");
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_SET_HASH_FUNC, g_param_spec_pointer ("hash-func", "hash-func", "hash-func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_SET_EQUAL_FUNC, g_param_spec_pointer ("equal-func", "equal-func", "equal-func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
 }
 
 
@@ -621,25 +478,25 @@ static void gee_hash_set_instance_init (GeeHashSet * self) {
 }
 
 
-static void gee_hash_set_finalize (GObject * obj) {
+static void gee_hash_set_finalize (GeeCollectionObject* obj) {
 	GeeHashSet * self;
 	self = GEE_HASH_SET (obj);
 	{
 		gee_collection_clear (GEE_COLLECTION (self));
 	}
 	self->priv->_nodes = (_vala_array_free (self->priv->_nodes, self->priv->_nodes_length1, ((GDestroyNotify) (gee_hash_set_node_free))), NULL);
-	G_OBJECT_CLASS (gee_hash_set_parent_class)->finalize (obj);
+	GEE_COLLECTION_OBJECT_CLASS (gee_hash_set_parent_class)->finalize (obj);
 }
 
 
 GType gee_hash_set_get_type (void) {
 	static GType gee_hash_set_type_id = 0;
 	if (gee_hash_set_type_id == 0) {
-		static const GTypeInfo g_define_type_info = { sizeof (GeeHashSetClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gee_hash_set_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GeeHashSet), 0, (GInstanceInitFunc) gee_hash_set_instance_init };
+		static const GTypeInfo g_define_type_info = { sizeof (GeeHashSetClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gee_hash_set_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GeeHashSet), 0, (GInstanceInitFunc) gee_hash_set_instance_init, NULL };
 		static const GInterfaceInfo gee_iterable_info = { (GInterfaceInitFunc) gee_hash_set_gee_iterable_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
 		static const GInterfaceInfo gee_collection_info = { (GInterfaceInitFunc) gee_hash_set_gee_collection_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
 		static const GInterfaceInfo gee_set_info = { (GInterfaceInitFunc) gee_hash_set_gee_set_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
-		gee_hash_set_type_id = g_type_register_static (G_TYPE_OBJECT, "GeeHashSet", &g_define_type_info, 0);
+		gee_hash_set_type_id = g_type_register_static (GEE_TYPE_COLLECTION_OBJECT, "GeeHashSet", &g_define_type_info, 0);
 		g_type_add_interface_static (gee_hash_set_type_id, GEE_TYPE_ITERABLE, &gee_iterable_info);
 		g_type_add_interface_static (gee_hash_set_type_id, GEE_TYPE_COLLECTION, &gee_collection_info);
 		g_type_add_interface_static (gee_hash_set_type_id, GEE_TYPE_SET, &gee_set_info);
