@@ -35,12 +35,12 @@ typedef struct _GeeReadOnlyCollectionIteratorClass GeeReadOnlyCollectionIterator
 typedef struct _GeeReadOnlyCollectionIteratorPrivate GeeReadOnlyCollectionIteratorPrivate;
 
 struct _GeeReadOnlyCollectionIterator {
-	GObject parent_instance;
+	GeeCollectionObject parent_instance;
 	GeeReadOnlyCollectionIteratorPrivate * priv;
 };
 
 struct _GeeReadOnlyCollectionIteratorClass {
-	GObjectClass parent_class;
+	GeeCollectionObjectClass parent_class;
 };
 
 
@@ -54,12 +54,7 @@ struct _GeeReadOnlyCollectionPrivate {
 
 #define GEE_READ_ONLY_COLLECTION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GEE_TYPE_READ_ONLY_COLLECTION, GeeReadOnlyCollectionPrivate))
 enum  {
-	GEE_READ_ONLY_COLLECTION_DUMMY_PROPERTY,
-	GEE_READ_ONLY_COLLECTION_SIZE,
-	GEE_READ_ONLY_COLLECTION_COLLECTION,
-	GEE_READ_ONLY_COLLECTION_G_TYPE,
-	GEE_READ_ONLY_COLLECTION_G_DUP_FUNC,
-	GEE_READ_ONLY_COLLECTION_G_DESTROY_FUNC
+	GEE_READ_ONLY_COLLECTION_DUMMY_PROPERTY
 };
 static GType gee_read_only_collection_real_get_element_type (GeeIterable* base);
 static GeeIterator* gee_read_only_collection_real_iterator (GeeIterable* base);
@@ -75,13 +70,11 @@ struct _GeeReadOnlyCollectionIteratorPrivate {
 
 #define GEE_READ_ONLY_COLLECTION_ITERATOR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GEE_READ_ONLY_COLLECTION_TYPE_ITERATOR, GeeReadOnlyCollectionIteratorPrivate))
 enum  {
-	GEE_READ_ONLY_COLLECTION_ITERATOR_DUMMY_PROPERTY,
-	GEE_READ_ONLY_COLLECTION_ITERATOR_G_TYPE,
-	GEE_READ_ONLY_COLLECTION_ITERATOR_G_DUP_FUNC,
-	GEE_READ_ONLY_COLLECTION_ITERATOR_G_DESTROY_FUNC
+	GEE_READ_ONLY_COLLECTION_ITERATOR_DUMMY_PROPERTY
 };
 static gboolean gee_read_only_collection_iterator_real_next (GeeIterator* base);
 static gpointer gee_read_only_collection_iterator_real_get (GeeIterator* base);
+static GeeReadOnlyCollectionIterator* gee_read_only_collection_iterator_construct (GType object_type, GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func);
 static GeeReadOnlyCollectionIterator* gee_read_only_collection_iterator_new (GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func);
 static gpointer gee_read_only_collection_iterator_parent_class = NULL;
 static GeeIteratorIface* gee_read_only_collection_iterator_gee_iterator_parent_iface = NULL;
@@ -89,37 +82,24 @@ static GType gee_read_only_collection_iterator_get_type (void);
 static gpointer gee_read_only_collection_parent_class = NULL;
 static GeeIterableIface* gee_read_only_collection_gee_iterable_parent_iface = NULL;
 static GeeCollectionIface* gee_read_only_collection_gee_collection_parent_iface = NULL;
-static void gee_read_only_collection_finalize (GObject * obj);
+static void gee_read_only_collection_finalize (GeeCollectionObject* obj);
 
 
 
+GeeReadOnlyCollection* gee_read_only_collection_construct (GType object_type, GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GeeCollection* collection) {
+	GeeReadOnlyCollection* self;
+	g_return_val_if_fail (collection == NULL || GEE_IS_COLLECTION (collection), NULL);
+	self = ((GeeReadOnlyCollection*) (g_type_create_instance (object_type)));
+	self->priv->g_type = g_type;
+	self->priv->g_dup_func = g_dup_func;
+	self->priv->g_destroy_func = g_destroy_func;
+	gee_read_only_collection_set_collection (self, collection);
+	return self;
+}
+
+
 GeeReadOnlyCollection* gee_read_only_collection_new (GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GeeCollection* collection) {
-	GParameter * __params;
-	GParameter * __params_it;
-	GeeReadOnlyCollection * self;
-	g_return_val_if_fail (collection == NULL || GEE_IS_COLLECTION (collection), NULL);
-	__params = g_new0 (GParameter, 3);
-	__params_it = __params;
-	__params_it->name = "g-type";
-	g_value_init (&__params_it->value, G_TYPE_GTYPE);
-	g_value_set_gtype (&__params_it->value, g_type);
-	__params_it++;
-	__params_it->name = "g-dup-func";
-	g_value_init (&__params_it->value, G_TYPE_POINTER);
-	g_value_set_pointer (&__params_it->value, g_dup_func);
-	__params_it++;
-	__params_it->name = "g-destroy-func";
-	g_value_init (&__params_it->value, G_TYPE_POINTER);
-	g_value_set_pointer (&__params_it->value, g_destroy_func);
-	__params_it++;
-	self = g_object_newv (GEE_TYPE_READ_ONLY_COLLECTION, __params_it - __params, __params);
-	gee_read_only_collection_set_collection (self, collection);
-	while (__params_it > __params) {
-		--__params_it;
-		g_value_unset (&__params_it->value);
-	}
-	g_free (__params);
-	return self;
+	return gee_read_only_collection_construct (GEE_TYPE_READ_ONLY_COLLECTION, g_type, g_dup_func, g_destroy_func, collection);
 }
 
 
@@ -184,8 +164,7 @@ void gee_read_only_collection_set_collection (GeeReadOnlyCollection* self, GeeCo
 	g_return_if_fail (GEE_IS_READ_ONLY_COLLECTION (self));
 	_tmp1 = NULL;
 	_tmp0 = NULL;
-	self->priv->_collection = (_tmp1 = (_tmp0 = value, (_tmp0 == NULL ? NULL : g_object_ref (_tmp0))), (self->priv->_collection == NULL ? NULL : (self->priv->_collection = (g_object_unref (self->priv->_collection), NULL))), _tmp1);
-	g_object_notify (((GObject *) (self)), "collection");
+	self->priv->_collection = (_tmp1 = (_tmp0 = value, (_tmp0 == NULL ? NULL : gee_collection_object_ref (_tmp0))), (self->priv->_collection == NULL ? NULL : (self->priv->_collection = (gee_collection_object_unref (self->priv->_collection), NULL))), _tmp1);
 }
 
 
@@ -203,73 +182,24 @@ static gpointer gee_read_only_collection_iterator_real_get (GeeIterator* base) {
 }
 
 
-static GeeReadOnlyCollectionIterator* gee_read_only_collection_iterator_new (GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func) {
-	GParameter * __params;
-	GParameter * __params_it;
-	GeeReadOnlyCollectionIterator * self;
-	__params = g_new0 (GParameter, 3);
-	__params_it = __params;
-	__params_it->name = "g-type";
-	g_value_init (&__params_it->value, G_TYPE_GTYPE);
-	g_value_set_gtype (&__params_it->value, g_type);
-	__params_it++;
-	__params_it->name = "g-dup-func";
-	g_value_init (&__params_it->value, G_TYPE_POINTER);
-	g_value_set_pointer (&__params_it->value, g_dup_func);
-	__params_it++;
-	__params_it->name = "g-destroy-func";
-	g_value_init (&__params_it->value, G_TYPE_POINTER);
-	g_value_set_pointer (&__params_it->value, g_destroy_func);
-	__params_it++;
-	self = g_object_newv (GEE_READ_ONLY_COLLECTION_TYPE_ITERATOR, __params_it - __params, __params);
-	while (__params_it > __params) {
-		--__params_it;
-		g_value_unset (&__params_it->value);
-	}
-	g_free (__params);
+static GeeReadOnlyCollectionIterator* gee_read_only_collection_iterator_construct (GType object_type, GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func) {
+	GeeReadOnlyCollectionIterator* self;
+	self = ((GeeReadOnlyCollectionIterator*) (g_type_create_instance (object_type)));
+	self->priv->g_type = g_type;
+	self->priv->g_dup_func = g_dup_func;
+	self->priv->g_destroy_func = g_destroy_func;
 	return self;
 }
 
 
-static void gee_read_only_collection_iterator_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
-	GeeReadOnlyCollectionIterator * self;
-	self = GEE_READ_ONLY_COLLECTION_ITERATOR (object);
-	switch (property_id) {
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
-static void gee_read_only_collection_iterator_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
-	GeeReadOnlyCollectionIterator * self;
-	self = GEE_READ_ONLY_COLLECTION_ITERATOR (object);
-	switch (property_id) {
-		case GEE_READ_ONLY_COLLECTION_ITERATOR_G_TYPE:
-		self->priv->g_type = g_value_get_gtype (value);
-		break;
-		case GEE_READ_ONLY_COLLECTION_ITERATOR_G_DUP_FUNC:
-		self->priv->g_dup_func = g_value_get_pointer (value);
-		break;
-		case GEE_READ_ONLY_COLLECTION_ITERATOR_G_DESTROY_FUNC:
-		self->priv->g_destroy_func = g_value_get_pointer (value);
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
+static GeeReadOnlyCollectionIterator* gee_read_only_collection_iterator_new (GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func) {
+	return gee_read_only_collection_iterator_construct (GEE_READ_ONLY_COLLECTION_TYPE_ITERATOR, g_type, g_dup_func, g_destroy_func);
 }
 
 
 static void gee_read_only_collection_iterator_class_init (GeeReadOnlyCollectionIteratorClass * klass) {
 	gee_read_only_collection_iterator_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (GeeReadOnlyCollectionIteratorPrivate));
-	G_OBJECT_CLASS (klass)->get_property = gee_read_only_collection_iterator_get_property;
-	G_OBJECT_CLASS (klass)->set_property = gee_read_only_collection_iterator_set_property;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_COLLECTION_ITERATOR_G_TYPE, g_param_spec_gtype ("g-type", "type", "type", G_TYPE_NONE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_COLLECTION_ITERATOR_G_DUP_FUNC, g_param_spec_pointer ("g-dup-func", "dup func", "dup func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_COLLECTION_ITERATOR_G_DESTROY_FUNC, g_param_spec_pointer ("g-destroy-func", "destroy func", "destroy func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
 }
 
 
@@ -288,63 +218,19 @@ static void gee_read_only_collection_iterator_instance_init (GeeReadOnlyCollecti
 static GType gee_read_only_collection_iterator_get_type (void) {
 	static GType gee_read_only_collection_iterator_type_id = 0;
 	if (gee_read_only_collection_iterator_type_id == 0) {
-		static const GTypeInfo g_define_type_info = { sizeof (GeeReadOnlyCollectionIteratorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gee_read_only_collection_iterator_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GeeReadOnlyCollectionIterator), 0, (GInstanceInitFunc) gee_read_only_collection_iterator_instance_init };
+		static const GTypeInfo g_define_type_info = { sizeof (GeeReadOnlyCollectionIteratorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gee_read_only_collection_iterator_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GeeReadOnlyCollectionIterator), 0, (GInstanceInitFunc) gee_read_only_collection_iterator_instance_init, NULL };
 		static const GInterfaceInfo gee_iterator_info = { (GInterfaceInitFunc) gee_read_only_collection_iterator_gee_iterator_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
-		gee_read_only_collection_iterator_type_id = g_type_register_static (G_TYPE_OBJECT, "GeeReadOnlyCollectionIterator", &g_define_type_info, 0);
+		gee_read_only_collection_iterator_type_id = g_type_register_static (GEE_TYPE_COLLECTION_OBJECT, "GeeReadOnlyCollectionIterator", &g_define_type_info, 0);
 		g_type_add_interface_static (gee_read_only_collection_iterator_type_id, GEE_TYPE_ITERATOR, &gee_iterator_info);
 	}
 	return gee_read_only_collection_iterator_type_id;
 }
 
 
-static void gee_read_only_collection_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
-	GeeReadOnlyCollection * self;
-	self = GEE_READ_ONLY_COLLECTION (object);
-	switch (property_id) {
-		case GEE_READ_ONLY_COLLECTION_SIZE:
-		g_value_set_int (value, gee_collection_get_size (GEE_COLLECTION (self)));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
-static void gee_read_only_collection_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
-	GeeReadOnlyCollection * self;
-	self = GEE_READ_ONLY_COLLECTION (object);
-	switch (property_id) {
-		case GEE_READ_ONLY_COLLECTION_COLLECTION:
-		gee_read_only_collection_set_collection (self, g_value_get_object (value));
-		break;
-		case GEE_READ_ONLY_COLLECTION_G_TYPE:
-		self->priv->g_type = g_value_get_gtype (value);
-		break;
-		case GEE_READ_ONLY_COLLECTION_G_DUP_FUNC:
-		self->priv->g_dup_func = g_value_get_pointer (value);
-		break;
-		case GEE_READ_ONLY_COLLECTION_G_DESTROY_FUNC:
-		self->priv->g_destroy_func = g_value_get_pointer (value);
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
 static void gee_read_only_collection_class_init (GeeReadOnlyCollectionClass * klass) {
 	gee_read_only_collection_parent_class = g_type_class_peek_parent (klass);
+	GEE_COLLECTION_OBJECT_CLASS (klass)->finalize = gee_read_only_collection_finalize;
 	g_type_class_add_private (klass, sizeof (GeeReadOnlyCollectionPrivate));
-	G_OBJECT_CLASS (klass)->get_property = gee_read_only_collection_get_property;
-	G_OBJECT_CLASS (klass)->set_property = gee_read_only_collection_set_property;
-	G_OBJECT_CLASS (klass)->finalize = gee_read_only_collection_finalize;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_COLLECTION_G_TYPE, g_param_spec_gtype ("g-type", "type", "type", G_TYPE_NONE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_COLLECTION_G_DUP_FUNC, g_param_spec_pointer ("g-dup-func", "dup func", "dup func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_COLLECTION_G_DESTROY_FUNC, g_param_spec_pointer ("g-destroy-func", "destroy func", "destroy func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
-	g_object_class_override_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_COLLECTION_SIZE, "size");
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_COLLECTION_COLLECTION, g_param_spec_object ("collection", "collection", "collection", GEE_TYPE_COLLECTION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
 }
 
 
@@ -370,21 +256,21 @@ static void gee_read_only_collection_instance_init (GeeReadOnlyCollection * self
 }
 
 
-static void gee_read_only_collection_finalize (GObject * obj) {
+static void gee_read_only_collection_finalize (GeeCollectionObject* obj) {
 	GeeReadOnlyCollection * self;
 	self = GEE_READ_ONLY_COLLECTION (obj);
-	(self->priv->_collection == NULL ? NULL : (self->priv->_collection = (g_object_unref (self->priv->_collection), NULL)));
-	G_OBJECT_CLASS (gee_read_only_collection_parent_class)->finalize (obj);
+	(self->priv->_collection == NULL ? NULL : (self->priv->_collection = (gee_collection_object_unref (self->priv->_collection), NULL)));
+	GEE_COLLECTION_OBJECT_CLASS (gee_read_only_collection_parent_class)->finalize (obj);
 }
 
 
 GType gee_read_only_collection_get_type (void) {
 	static GType gee_read_only_collection_type_id = 0;
 	if (gee_read_only_collection_type_id == 0) {
-		static const GTypeInfo g_define_type_info = { sizeof (GeeReadOnlyCollectionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gee_read_only_collection_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GeeReadOnlyCollection), 0, (GInstanceInitFunc) gee_read_only_collection_instance_init };
+		static const GTypeInfo g_define_type_info = { sizeof (GeeReadOnlyCollectionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gee_read_only_collection_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GeeReadOnlyCollection), 0, (GInstanceInitFunc) gee_read_only_collection_instance_init, NULL };
 		static const GInterfaceInfo gee_iterable_info = { (GInterfaceInitFunc) gee_read_only_collection_gee_iterable_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
 		static const GInterfaceInfo gee_collection_info = { (GInterfaceInitFunc) gee_read_only_collection_gee_collection_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
-		gee_read_only_collection_type_id = g_type_register_static (G_TYPE_OBJECT, "GeeReadOnlyCollection", &g_define_type_info, 0);
+		gee_read_only_collection_type_id = g_type_register_static (GEE_TYPE_COLLECTION_OBJECT, "GeeReadOnlyCollection", &g_define_type_info, 0);
 		g_type_add_interface_static (gee_read_only_collection_type_id, GEE_TYPE_ITERABLE, &gee_iterable_info);
 		g_type_add_interface_static (gee_read_only_collection_type_id, GEE_TYPE_COLLECTION, &gee_collection_info);
 	}
