@@ -58,29 +58,33 @@ struct _ValaCCodeDynamicSignalBindingPrivate {
 
 #define VALA_CCODE_DYNAMIC_SIGNAL_BINDING_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CCODE_DYNAMIC_SIGNAL_BINDING, ValaCCodeDynamicSignalBindingPrivate))
 enum  {
-	VALA_CCODE_DYNAMIC_SIGNAL_BINDING_DUMMY_PROPERTY,
-	VALA_CCODE_DYNAMIC_SIGNAL_BINDING_NODE
+	VALA_CCODE_DYNAMIC_SIGNAL_BINDING_DUMMY_PROPERTY
 };
 static gint vala_ccode_dynamic_signal_binding_signal_wrapper_id;
 static void vala_ccode_dynamic_signal_binding_generate_gobject_connect_wrapper (ValaCCodeDynamicSignalBinding* self, ValaCCodeBlock* block);
 static void vala_ccode_dynamic_signal_binding_generate_dbus_connect_wrapper (ValaCCodeDynamicSignalBinding* self, ValaCCodeBlock* block);
 static void vala_ccode_dynamic_signal_binding_generate_dbus_disconnect_wrapper (ValaCCodeDynamicSignalBinding* self, ValaCCodeBlock* block);
 static gpointer vala_ccode_dynamic_signal_binding_parent_class = NULL;
-static void vala_ccode_dynamic_signal_binding_dispose (GObject * obj);
+static void vala_ccode_dynamic_signal_binding_finalize (ValaCodeBinding* obj);
 
 
 
-ValaCCodeDynamicSignalBinding* vala_ccode_dynamic_signal_binding_new (ValaCCodeGenerator* codegen, ValaDynamicSignal* node) {
-	ValaCCodeDynamicSignalBinding * self;
+ValaCCodeDynamicSignalBinding* vala_ccode_dynamic_signal_binding_construct (GType object_type, ValaCCodeGenerator* codegen, ValaDynamicSignal* node) {
+	ValaCCodeDynamicSignalBinding* self;
 	g_return_val_if_fail (VALA_IS_CCODE_GENERATOR (codegen), NULL);
 	g_return_val_if_fail (VALA_IS_DYNAMIC_SIGNAL (node), NULL);
-	self = g_object_newv (VALA_TYPE_CCODE_DYNAMIC_SIGNAL_BINDING, 0, NULL);
+	self = ((ValaCCodeDynamicSignalBinding*) (g_type_create_instance (object_type)));
 	vala_ccode_dynamic_signal_binding_set_node (self, VALA_SIGNAL (node));
 	vala_ccode_binding_set_codegen (VALA_CCODE_BINDING (self), codegen);
 	return self;
 }
 
 
+ValaCCodeDynamicSignalBinding* vala_ccode_dynamic_signal_binding_new (ValaCCodeGenerator* codegen, ValaDynamicSignal* node) {
+	return vala_ccode_dynamic_signal_binding_construct (VALA_TYPE_CCODE_DYNAMIC_SIGNAL_BINDING, codegen, node);
+}
+
+
 char* vala_ccode_dynamic_signal_binding_get_dynamic_cname (ValaCCodeDynamicSignalBinding* self) {
 	const char* _tmp1;
 	g_return_val_if_fail (VALA_IS_CCODE_DYNAMIC_SIGNAL_BINDING (self), NULL);
@@ -101,7 +105,7 @@ char* vala_ccode_dynamic_signal_binding_get_connect_wrapper_name (ValaCCodeDynam
 	char* _tmp11;
 	g_return_val_if_fail (VALA_IS_CCODE_DYNAMIC_SIGNAL_BINDING (self), NULL);
 	_tmp0 = NULL;
-	dynamic_signal = (_tmp0 = VALA_DYNAMIC_SIGNAL (self->priv->_node), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
+	dynamic_signal = (_tmp0 = VALA_DYNAMIC_SIGNAL (self->priv->_node), (_tmp0 == NULL ? NULL : vala_code_node_ref (_tmp0)));
 	if (self->priv->connect_wrapper_name == NULL) {
 		char* _tmp2;
 		char* _tmp1;
@@ -119,16 +123,16 @@ char* vala_ccode_dynamic_signal_binding_get_connect_wrapper_name (ValaCCodeDynam
 		func = vala_ccode_function_new (self->priv->connect_wrapper_name, "void");
 		_tmp3 = NULL;
 		vala_ccode_function_add_parameter (func, (_tmp3 = vala_ccode_formal_parameter_new ("obj", "gpointer")));
-		(_tmp3 == NULL ? NULL : (_tmp3 = (g_object_unref (_tmp3), NULL)));
+		(_tmp3 == NULL ? NULL : (_tmp3 = (vala_ccode_node_unref (_tmp3), NULL)));
 		_tmp4 = NULL;
 		vala_ccode_function_add_parameter (func, (_tmp4 = vala_ccode_formal_parameter_new ("signal_name", "const char *")));
-		(_tmp4 == NULL ? NULL : (_tmp4 = (g_object_unref (_tmp4), NULL)));
+		(_tmp4 == NULL ? NULL : (_tmp4 = (vala_ccode_node_unref (_tmp4), NULL)));
 		_tmp5 = NULL;
 		vala_ccode_function_add_parameter (func, (_tmp5 = vala_ccode_formal_parameter_new ("handler", "GCallback")));
-		(_tmp5 == NULL ? NULL : (_tmp5 = (g_object_unref (_tmp5), NULL)));
+		(_tmp5 == NULL ? NULL : (_tmp5 = (vala_ccode_node_unref (_tmp5), NULL)));
 		_tmp6 = NULL;
 		vala_ccode_function_add_parameter (func, (_tmp6 = vala_ccode_formal_parameter_new ("data", "gpointer")));
-		(_tmp6 == NULL ? NULL : (_tmp6 = (g_object_unref (_tmp6), NULL)));
+		(_tmp6 == NULL ? NULL : (_tmp6 = (vala_ccode_node_unref (_tmp6), NULL)));
 		block = vala_ccode_block_new ();
 		if (vala_data_type_get_data_type (vala_dynamic_signal_get_dynamic_type (dynamic_signal)) == vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->dbus_object_type) {
 			vala_ccode_dynamic_signal_binding_generate_dbus_connect_wrapper (self, block);
@@ -148,15 +152,15 @@ char* vala_ccode_dynamic_signal_binding_get_connect_wrapper_name (ValaCCodeDynam
 		/* append to C source file*/
 		_tmp9 = NULL;
 		vala_ccode_fragment_append (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->source_type_member_declaration, VALA_CCODE_NODE ((_tmp9 = vala_ccode_function_copy (func))));
-		(_tmp9 == NULL ? NULL : (_tmp9 = (g_object_unref (_tmp9), NULL)));
+		(_tmp9 == NULL ? NULL : (_tmp9 = (vala_ccode_node_unref (_tmp9), NULL)));
 		vala_ccode_function_set_block (func, block);
 		vala_ccode_fragment_append (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->source_type_member_definition, VALA_CCODE_NODE (func));
-		(func == NULL ? NULL : (func = (g_object_unref (func), NULL)));
-		(block == NULL ? NULL : (block = (g_object_unref (block), NULL)));
+		(func == NULL ? NULL : (func = (vala_ccode_node_unref (func), NULL)));
+		(block == NULL ? NULL : (block = (vala_ccode_node_unref (block), NULL)));
 	}
 	_tmp10 = NULL;
 	_tmp11 = NULL;
-	return (_tmp11 = (_tmp10 = self->priv->connect_wrapper_name, (_tmp10 == NULL ? NULL : g_strdup (_tmp10))), (dynamic_signal == NULL ? NULL : (dynamic_signal = (g_object_unref (dynamic_signal), NULL))), _tmp11);
+	return (_tmp11 = (_tmp10 = self->priv->connect_wrapper_name, (_tmp10 == NULL ? NULL : g_strdup (_tmp10))), (dynamic_signal == NULL ? NULL : (dynamic_signal = (vala_code_node_unref (dynamic_signal), NULL))), _tmp11);
 }
 
 
@@ -167,7 +171,7 @@ char* vala_ccode_dynamic_signal_binding_get_disconnect_wrapper_name (ValaCCodeDy
 	char* _tmp11;
 	g_return_val_if_fail (VALA_IS_CCODE_DYNAMIC_SIGNAL_BINDING (self), NULL);
 	_tmp0 = NULL;
-	dynamic_signal = (_tmp0 = VALA_DYNAMIC_SIGNAL (self->priv->_node), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
+	dynamic_signal = (_tmp0 = VALA_DYNAMIC_SIGNAL (self->priv->_node), (_tmp0 == NULL ? NULL : vala_code_node_ref (_tmp0)));
 	if (self->priv->disconnect_wrapper_name == NULL) {
 		char* _tmp2;
 		char* _tmp1;
@@ -185,16 +189,16 @@ char* vala_ccode_dynamic_signal_binding_get_disconnect_wrapper_name (ValaCCodeDy
 		func = vala_ccode_function_new (self->priv->disconnect_wrapper_name, "void");
 		_tmp3 = NULL;
 		vala_ccode_function_add_parameter (func, (_tmp3 = vala_ccode_formal_parameter_new ("obj", "gpointer")));
-		(_tmp3 == NULL ? NULL : (_tmp3 = (g_object_unref (_tmp3), NULL)));
+		(_tmp3 == NULL ? NULL : (_tmp3 = (vala_ccode_node_unref (_tmp3), NULL)));
 		_tmp4 = NULL;
 		vala_ccode_function_add_parameter (func, (_tmp4 = vala_ccode_formal_parameter_new ("signal_name", "const char *")));
-		(_tmp4 == NULL ? NULL : (_tmp4 = (g_object_unref (_tmp4), NULL)));
+		(_tmp4 == NULL ? NULL : (_tmp4 = (vala_ccode_node_unref (_tmp4), NULL)));
 		_tmp5 = NULL;
 		vala_ccode_function_add_parameter (func, (_tmp5 = vala_ccode_formal_parameter_new ("handler", "GCallback")));
-		(_tmp5 == NULL ? NULL : (_tmp5 = (g_object_unref (_tmp5), NULL)));
+		(_tmp5 == NULL ? NULL : (_tmp5 = (vala_ccode_node_unref (_tmp5), NULL)));
 		_tmp6 = NULL;
 		vala_ccode_function_add_parameter (func, (_tmp6 = vala_ccode_formal_parameter_new ("data", "gpointer")));
-		(_tmp6 == NULL ? NULL : (_tmp6 = (g_object_unref (_tmp6), NULL)));
+		(_tmp6 == NULL ? NULL : (_tmp6 = (vala_ccode_node_unref (_tmp6), NULL)));
 		block = vala_ccode_block_new ();
 		if (vala_data_type_get_data_type (vala_dynamic_signal_get_dynamic_type (dynamic_signal)) == vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->dbus_object_type) {
 			vala_ccode_dynamic_signal_binding_generate_dbus_disconnect_wrapper (self, block);
@@ -210,15 +214,15 @@ char* vala_ccode_dynamic_signal_binding_get_disconnect_wrapper_name (ValaCCodeDy
 		/* append to C source file*/
 		_tmp9 = NULL;
 		vala_ccode_fragment_append (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->source_type_member_declaration, VALA_CCODE_NODE ((_tmp9 = vala_ccode_function_copy (func))));
-		(_tmp9 == NULL ? NULL : (_tmp9 = (g_object_unref (_tmp9), NULL)));
+		(_tmp9 == NULL ? NULL : (_tmp9 = (vala_ccode_node_unref (_tmp9), NULL)));
 		vala_ccode_function_set_block (func, block);
 		vala_ccode_fragment_append (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->source_type_member_definition, VALA_CCODE_NODE (func));
-		(func == NULL ? NULL : (func = (g_object_unref (func), NULL)));
-		(block == NULL ? NULL : (block = (g_object_unref (block), NULL)));
+		(func == NULL ? NULL : (func = (vala_ccode_node_unref (func), NULL)));
+		(block == NULL ? NULL : (block = (vala_ccode_node_unref (block), NULL)));
 	}
 	_tmp10 = NULL;
 	_tmp11 = NULL;
-	return (_tmp11 = (_tmp10 = self->priv->disconnect_wrapper_name, (_tmp10 == NULL ? NULL : g_strdup (_tmp10))), (dynamic_signal == NULL ? NULL : (dynamic_signal = (g_object_unref (dynamic_signal), NULL))), _tmp11);
+	return (_tmp11 = (_tmp10 = self->priv->disconnect_wrapper_name, (_tmp10 == NULL ? NULL : g_strdup (_tmp10))), (dynamic_signal == NULL ? NULL : (dynamic_signal = (vala_code_node_unref (dynamic_signal), NULL))), _tmp11);
 }
 
 
@@ -239,9 +243,9 @@ static void vala_ccode_dynamic_signal_binding_generate_gobject_connect_wrapper (
 	g_return_if_fail (VALA_IS_CCODE_DYNAMIC_SIGNAL_BINDING (self));
 	g_return_if_fail (VALA_IS_CCODE_BLOCK (block));
 	_tmp0 = NULL;
-	dynamic_signal = (_tmp0 = VALA_DYNAMIC_SIGNAL (self->priv->_node), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
+	dynamic_signal = (_tmp0 = VALA_DYNAMIC_SIGNAL (self->priv->_node), (_tmp0 == NULL ? NULL : vala_code_node_ref (_tmp0)));
 	_tmp1 = NULL;
-	m = (_tmp1 = VALA_METHOD (vala_expression_get_symbol_reference (vala_dynamic_signal_get_handler (dynamic_signal))), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
+	m = (_tmp1 = VALA_METHOD (vala_expression_get_symbol_reference (vala_dynamic_signal_get_handler (dynamic_signal))), (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1)));
 	vala_code_node_accept (VALA_CODE_NODE (self->priv->_node), VALA_CODE_VISITOR (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))));
 	connect_func = g_strdup ("g_signal_connect_object");
 	if (vala_method_get_binding (m) != MEMBER_BINDING_INSTANCE) {
@@ -251,32 +255,32 @@ static void vala_ccode_dynamic_signal_binding_generate_gobject_connect_wrapper (
 	}
 	_tmp3 = NULL;
 	_tmp4 = NULL;
-	call = (_tmp4 = vala_ccode_function_call_new (VALA_CCODE_EXPRESSION ((_tmp3 = vala_ccode_identifier_new (connect_func)))), (_tmp3 == NULL ? NULL : (_tmp3 = (g_object_unref (_tmp3), NULL))), _tmp4);
+	call = (_tmp4 = vala_ccode_function_call_new (VALA_CCODE_EXPRESSION ((_tmp3 = vala_ccode_identifier_new (connect_func)))), (_tmp3 == NULL ? NULL : (_tmp3 = (vala_ccode_node_unref (_tmp3), NULL))), _tmp4);
 	_tmp5 = NULL;
 	vala_ccode_function_call_add_argument (call, VALA_CCODE_EXPRESSION ((_tmp5 = vala_ccode_identifier_new ("obj"))));
-	(_tmp5 == NULL ? NULL : (_tmp5 = (g_object_unref (_tmp5), NULL)));
+	(_tmp5 == NULL ? NULL : (_tmp5 = (vala_ccode_node_unref (_tmp5), NULL)));
 	_tmp6 = NULL;
 	vala_ccode_function_call_add_argument (call, VALA_CCODE_EXPRESSION ((_tmp6 = vala_ccode_identifier_new ("signal_name"))));
-	(_tmp6 == NULL ? NULL : (_tmp6 = (g_object_unref (_tmp6), NULL)));
+	(_tmp6 == NULL ? NULL : (_tmp6 = (vala_ccode_node_unref (_tmp6), NULL)));
 	_tmp7 = NULL;
 	vala_ccode_function_call_add_argument (call, VALA_CCODE_EXPRESSION ((_tmp7 = vala_ccode_identifier_new ("handler"))));
-	(_tmp7 == NULL ? NULL : (_tmp7 = (g_object_unref (_tmp7), NULL)));
+	(_tmp7 == NULL ? NULL : (_tmp7 = (vala_ccode_node_unref (_tmp7), NULL)));
 	_tmp8 = NULL;
 	vala_ccode_function_call_add_argument (call, VALA_CCODE_EXPRESSION ((_tmp8 = vala_ccode_identifier_new ("data"))));
-	(_tmp8 == NULL ? NULL : (_tmp8 = (g_object_unref (_tmp8), NULL)));
+	(_tmp8 == NULL ? NULL : (_tmp8 = (vala_ccode_node_unref (_tmp8), NULL)));
 	if (vala_method_get_binding (m) == MEMBER_BINDING_INSTANCE) {
 		ValaCCodeConstant* _tmp9;
 		_tmp9 = NULL;
 		vala_ccode_function_call_add_argument (call, VALA_CCODE_EXPRESSION ((_tmp9 = vala_ccode_constant_new ("0"))));
-		(_tmp9 == NULL ? NULL : (_tmp9 = (g_object_unref (_tmp9), NULL)));
+		(_tmp9 == NULL ? NULL : (_tmp9 = (vala_ccode_node_unref (_tmp9), NULL)));
 	}
 	_tmp10 = NULL;
 	vala_ccode_block_add_statement (block, VALA_CCODE_NODE ((_tmp10 = vala_ccode_expression_statement_new (VALA_CCODE_EXPRESSION (call)))));
-	(_tmp10 == NULL ? NULL : (_tmp10 = (g_object_unref (_tmp10), NULL)));
-	(dynamic_signal == NULL ? NULL : (dynamic_signal = (g_object_unref (dynamic_signal), NULL)));
-	(m == NULL ? NULL : (m = (g_object_unref (m), NULL)));
+	(_tmp10 == NULL ? NULL : (_tmp10 = (vala_ccode_node_unref (_tmp10), NULL)));
+	(dynamic_signal == NULL ? NULL : (dynamic_signal = (vala_code_node_unref (dynamic_signal), NULL)));
+	(m == NULL ? NULL : (m = (vala_code_node_unref (m), NULL)));
 	connect_func = (g_free (connect_func), NULL);
-	(call == NULL ? NULL : (call = (g_object_unref (call), NULL)));
+	(call == NULL ? NULL : (call = (vala_ccode_node_unref (call), NULL)));
 }
 
 
@@ -317,38 +321,38 @@ static void vala_ccode_dynamic_signal_binding_generate_dbus_connect_wrapper (Val
 	g_return_if_fail (VALA_IS_CCODE_DYNAMIC_SIGNAL_BINDING (self));
 	g_return_if_fail (VALA_IS_CCODE_BLOCK (block));
 	_tmp0 = NULL;
-	dynamic_signal = (_tmp0 = VALA_DYNAMIC_SIGNAL (self->priv->_node), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
+	dynamic_signal = (_tmp0 = VALA_DYNAMIC_SIGNAL (self->priv->_node), (_tmp0 == NULL ? NULL : vala_code_node_ref (_tmp0)));
 	_tmp1 = NULL;
-	m = (_tmp1 = VALA_METHOD (vala_expression_get_symbol_reference (vala_dynamic_signal_get_handler (dynamic_signal))), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
+	m = (_tmp1 = VALA_METHOD (vala_expression_get_symbol_reference (vala_dynamic_signal_get_handler (dynamic_signal))), (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1)));
 	vala_code_node_accept (VALA_CODE_NODE (self->priv->_node), VALA_CODE_VISITOR (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))));
 	/* FIXME should only be done once per marshaller*/
 	_tmp2 = NULL;
 	_tmp3 = NULL;
-	register_call = (_tmp3 = vala_ccode_function_call_new (VALA_CCODE_EXPRESSION ((_tmp2 = vala_ccode_identifier_new ("dbus_g_object_register_marshaller")))), (_tmp2 == NULL ? NULL : (_tmp2 = (g_object_unref (_tmp2), NULL))), _tmp3);
+	register_call = (_tmp3 = vala_ccode_function_call_new (VALA_CCODE_EXPRESSION ((_tmp2 = vala_ccode_identifier_new ("dbus_g_object_register_marshaller")))), (_tmp2 == NULL ? NULL : (_tmp2 = (vala_ccode_node_unref (_tmp2), NULL))), _tmp3);
 	_tmp4 = NULL;
 	vala_ccode_generator_generate_marshaller (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self)), (_tmp4 = vala_signal_get_parameters (self->priv->_node)), vala_signal_get_return_type (self->priv->_node), TRUE);
-	(_tmp4 == NULL ? NULL : (_tmp4 = (g_object_unref (_tmp4), NULL)));
+	(_tmp4 == NULL ? NULL : (_tmp4 = (gee_collection_object_unref (_tmp4), NULL)));
 	_tmp7 = NULL;
 	_tmp6 = NULL;
 	_tmp5 = NULL;
 	vala_ccode_function_call_add_argument (register_call, VALA_CCODE_EXPRESSION ((_tmp7 = vala_ccode_identifier_new ((_tmp6 = vala_ccode_generator_get_marshaller_function (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self)), (_tmp5 = vala_signal_get_parameters (self->priv->_node)), vala_signal_get_return_type (self->priv->_node), NULL, TRUE))))));
-	(_tmp7 == NULL ? NULL : (_tmp7 = (g_object_unref (_tmp7), NULL)));
+	(_tmp7 == NULL ? NULL : (_tmp7 = (vala_ccode_node_unref (_tmp7), NULL)));
 	_tmp6 = (g_free (_tmp6), NULL);
-	(_tmp5 == NULL ? NULL : (_tmp5 = (g_object_unref (_tmp5), NULL)));
+	(_tmp5 == NULL ? NULL : (_tmp5 = (gee_collection_object_unref (_tmp5), NULL)));
 	_tmp8 = NULL;
 	vala_ccode_function_call_add_argument (register_call, VALA_CCODE_EXPRESSION ((_tmp8 = vala_ccode_identifier_new ("G_TYPE_NONE"))));
-	(_tmp8 == NULL ? NULL : (_tmp8 = (g_object_unref (_tmp8), NULL)));
+	(_tmp8 == NULL ? NULL : (_tmp8 = (vala_ccode_node_unref (_tmp8), NULL)));
 	_tmp9 = NULL;
 	_tmp10 = NULL;
-	add_call = (_tmp10 = vala_ccode_function_call_new (VALA_CCODE_EXPRESSION ((_tmp9 = vala_ccode_identifier_new ("dbus_g_proxy_add_signal")))), (_tmp9 == NULL ? NULL : (_tmp9 = (g_object_unref (_tmp9), NULL))), _tmp10);
+	add_call = (_tmp10 = vala_ccode_function_call_new (VALA_CCODE_EXPRESSION ((_tmp9 = vala_ccode_identifier_new ("dbus_g_proxy_add_signal")))), (_tmp9 == NULL ? NULL : (_tmp9 = (vala_ccode_node_unref (_tmp9), NULL))), _tmp10);
 	_tmp11 = NULL;
 	vala_ccode_function_call_add_argument (add_call, VALA_CCODE_EXPRESSION ((_tmp11 = vala_ccode_identifier_new ("obj"))));
-	(_tmp11 == NULL ? NULL : (_tmp11 = (g_object_unref (_tmp11), NULL)));
+	(_tmp11 == NULL ? NULL : (_tmp11 = (vala_ccode_node_unref (_tmp11), NULL)));
 	_tmp14 = NULL;
 	_tmp13 = NULL;
 	_tmp12 = NULL;
 	vala_ccode_function_call_add_argument (add_call, VALA_CCODE_EXPRESSION ((_tmp14 = vala_ccode_constant_new ((_tmp13 = g_strdup_printf ("\"%s\"", (_tmp12 = vala_symbol_lower_case_to_camel_case (vala_symbol_get_name (VALA_SYMBOL (self->priv->_node))))))))));
-	(_tmp14 == NULL ? NULL : (_tmp14 = (g_object_unref (_tmp14), NULL)));
+	(_tmp14 == NULL ? NULL : (_tmp14 = (vala_ccode_node_unref (_tmp14), NULL)));
 	_tmp13 = (g_free (_tmp13), NULL);
 	_tmp12 = (g_free (_tmp12), NULL);
 	first = TRUE;
@@ -366,22 +370,22 @@ static void vala_ccode_dynamic_signal_binding_generate_dbus_connect_wrapper (Val
 				if (first) {
 					/* skip sender parameter*/
 					first = FALSE;
-					(param == NULL ? NULL : (param = (g_object_unref (param), NULL)));
+					(param == NULL ? NULL : (param = (vala_code_node_unref (param), NULL)));
 					continue;
 				}
 				_tmp16 = NULL;
 				_tmp15 = NULL;
-				array_type = (_tmp16 = (_tmp15 = vala_formal_parameter_get_parameter_type (param), (VALA_IS_ARRAY_TYPE (_tmp15) ? ((ValaArrayType*) (_tmp15)) : NULL)), (_tmp16 == NULL ? NULL : g_object_ref (_tmp16)));
+				array_type = (_tmp16 = (_tmp15 = vala_formal_parameter_get_parameter_type (param), (VALA_IS_ARRAY_TYPE (_tmp15) ? ((ValaArrayType*) (_tmp15)) : NULL)), (_tmp16 == NULL ? NULL : vala_code_node_ref (_tmp16)));
 				if (array_type != NULL) {
 					if (vala_data_type_get_data_type (vala_array_type_get_element_type (array_type)) == vala_data_type_get_data_type (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->string_type)) {
 						ValaCCodeIdentifier* _tmp17;
 						ValaCCodeIdentifier* _tmp18;
 						_tmp17 = NULL;
 						vala_ccode_function_call_add_argument (register_call, VALA_CCODE_EXPRESSION ((_tmp17 = vala_ccode_identifier_new ("G_TYPE_STRV"))));
-						(_tmp17 == NULL ? NULL : (_tmp17 = (g_object_unref (_tmp17), NULL)));
+						(_tmp17 == NULL ? NULL : (_tmp17 = (vala_ccode_node_unref (_tmp17), NULL)));
 						_tmp18 = NULL;
 						vala_ccode_function_call_add_argument (add_call, VALA_CCODE_EXPRESSION ((_tmp18 = vala_ccode_identifier_new ("G_TYPE_STRV"))));
-						(_tmp18 == NULL ? NULL : (_tmp18 = (g_object_unref (_tmp18), NULL)));
+						(_tmp18 == NULL ? NULL : (_tmp18 = (vala_ccode_node_unref (_tmp18), NULL)));
 					} else {
 						char* _tmp19;
 						gboolean _tmp20;
@@ -394,29 +398,29 @@ static void vala_ccode_dynamic_signal_binding_generate_dbus_connect_wrapper (Val
 						_tmp19 = NULL;
 						if ((_tmp20 = (_tmp19 = vala_typesymbol_get_type_id (vala_data_type_get_data_type (vala_array_type_get_element_type (array_type)))) == NULL, (_tmp19 = (g_free (_tmp19), NULL)), _tmp20)) {
 							vala_report_error (vala_code_node_get_source_reference (VALA_CODE_NODE (param)), "unsupported parameter type for D-Bus signals");
-							(param == NULL ? NULL : (param = (g_object_unref (param), NULL)));
-							(array_type == NULL ? NULL : (array_type = (g_object_unref (array_type), NULL)));
-							(param_collection == NULL ? NULL : (param_collection = (g_object_unref (param_collection), NULL)));
-							(dynamic_signal == NULL ? NULL : (dynamic_signal = (g_object_unref (dynamic_signal), NULL)));
-							(m == NULL ? NULL : (m = (g_object_unref (m), NULL)));
-							(register_call == NULL ? NULL : (register_call = (g_object_unref (register_call), NULL)));
-							(add_call == NULL ? NULL : (add_call = (g_object_unref (add_call), NULL)));
+							(param == NULL ? NULL : (param = (vala_code_node_unref (param), NULL)));
+							(array_type == NULL ? NULL : (array_type = (vala_code_node_unref (array_type), NULL)));
+							(param_collection == NULL ? NULL : (param_collection = (gee_collection_object_unref (param_collection), NULL)));
+							(dynamic_signal == NULL ? NULL : (dynamic_signal = (vala_code_node_unref (dynamic_signal), NULL)));
+							(m == NULL ? NULL : (m = (vala_code_node_unref (m), NULL)));
+							(register_call == NULL ? NULL : (register_call = (vala_ccode_node_unref (register_call), NULL)));
+							(add_call == NULL ? NULL : (add_call = (vala_ccode_node_unref (add_call), NULL)));
 							return;
 						}
 						_tmp21 = NULL;
 						_tmp22 = NULL;
-						carray_type = (_tmp22 = vala_ccode_function_call_new (VALA_CCODE_EXPRESSION ((_tmp21 = vala_ccode_identifier_new ("dbus_g_type_get_collection")))), (_tmp21 == NULL ? NULL : (_tmp21 = (g_object_unref (_tmp21), NULL))), _tmp22);
+						carray_type = (_tmp22 = vala_ccode_function_call_new (VALA_CCODE_EXPRESSION ((_tmp21 = vala_ccode_identifier_new ("dbus_g_type_get_collection")))), (_tmp21 == NULL ? NULL : (_tmp21 = (vala_ccode_node_unref (_tmp21), NULL))), _tmp22);
 						_tmp23 = NULL;
 						vala_ccode_function_call_add_argument (carray_type, VALA_CCODE_EXPRESSION ((_tmp23 = vala_ccode_constant_new ("\"GArray\""))));
-						(_tmp23 == NULL ? NULL : (_tmp23 = (g_object_unref (_tmp23), NULL)));
+						(_tmp23 == NULL ? NULL : (_tmp23 = (vala_ccode_node_unref (_tmp23), NULL)));
 						_tmp25 = NULL;
 						_tmp24 = NULL;
 						vala_ccode_function_call_add_argument (carray_type, VALA_CCODE_EXPRESSION ((_tmp25 = vala_ccode_identifier_new ((_tmp24 = vala_typesymbol_get_type_id (vala_data_type_get_data_type (vala_array_type_get_element_type (array_type))))))));
-						(_tmp25 == NULL ? NULL : (_tmp25 = (g_object_unref (_tmp25), NULL)));
+						(_tmp25 == NULL ? NULL : (_tmp25 = (vala_ccode_node_unref (_tmp25), NULL)));
 						_tmp24 = (g_free (_tmp24), NULL);
 						vala_ccode_function_call_add_argument (register_call, VALA_CCODE_EXPRESSION (carray_type));
 						vala_ccode_function_call_add_argument (add_call, VALA_CCODE_EXPRESSION (carray_type));
-						(carray_type == NULL ? NULL : (carray_type = (g_object_unref (carray_type), NULL)));
+						(carray_type == NULL ? NULL : (carray_type = (vala_ccode_node_unref (carray_type), NULL)));
 					}
 				} else {
 					char* _tmp26;
@@ -428,70 +432,70 @@ static void vala_ccode_dynamic_signal_binding_generate_dbus_connect_wrapper (Val
 					_tmp26 = NULL;
 					if ((_tmp27 = (_tmp26 = vala_data_type_get_type_id (vala_formal_parameter_get_parameter_type (param))) == NULL, (_tmp26 = (g_free (_tmp26), NULL)), _tmp27)) {
 						vala_report_error (vala_code_node_get_source_reference (VALA_CODE_NODE (param)), "unsupported parameter type for D-Bus signals");
-						(param == NULL ? NULL : (param = (g_object_unref (param), NULL)));
-						(array_type == NULL ? NULL : (array_type = (g_object_unref (array_type), NULL)));
-						(param_collection == NULL ? NULL : (param_collection = (g_object_unref (param_collection), NULL)));
-						(dynamic_signal == NULL ? NULL : (dynamic_signal = (g_object_unref (dynamic_signal), NULL)));
-						(m == NULL ? NULL : (m = (g_object_unref (m), NULL)));
-						(register_call == NULL ? NULL : (register_call = (g_object_unref (register_call), NULL)));
-						(add_call == NULL ? NULL : (add_call = (g_object_unref (add_call), NULL)));
+						(param == NULL ? NULL : (param = (vala_code_node_unref (param), NULL)));
+						(array_type == NULL ? NULL : (array_type = (vala_code_node_unref (array_type), NULL)));
+						(param_collection == NULL ? NULL : (param_collection = (gee_collection_object_unref (param_collection), NULL)));
+						(dynamic_signal == NULL ? NULL : (dynamic_signal = (vala_code_node_unref (dynamic_signal), NULL)));
+						(m == NULL ? NULL : (m = (vala_code_node_unref (m), NULL)));
+						(register_call == NULL ? NULL : (register_call = (vala_ccode_node_unref (register_call), NULL)));
+						(add_call == NULL ? NULL : (add_call = (vala_ccode_node_unref (add_call), NULL)));
 						return;
 					}
 					_tmp29 = NULL;
 					_tmp28 = NULL;
 					vala_ccode_function_call_add_argument (register_call, VALA_CCODE_EXPRESSION ((_tmp29 = vala_ccode_identifier_new ((_tmp28 = vala_data_type_get_type_id (vala_formal_parameter_get_parameter_type (param)))))));
-					(_tmp29 == NULL ? NULL : (_tmp29 = (g_object_unref (_tmp29), NULL)));
+					(_tmp29 == NULL ? NULL : (_tmp29 = (vala_ccode_node_unref (_tmp29), NULL)));
 					_tmp28 = (g_free (_tmp28), NULL);
 					_tmp31 = NULL;
 					_tmp30 = NULL;
 					vala_ccode_function_call_add_argument (add_call, VALA_CCODE_EXPRESSION ((_tmp31 = vala_ccode_identifier_new ((_tmp30 = vala_data_type_get_type_id (vala_formal_parameter_get_parameter_type (param)))))));
-					(_tmp31 == NULL ? NULL : (_tmp31 = (g_object_unref (_tmp31), NULL)));
+					(_tmp31 == NULL ? NULL : (_tmp31 = (vala_ccode_node_unref (_tmp31), NULL)));
 					_tmp30 = (g_free (_tmp30), NULL);
 				}
-				(param == NULL ? NULL : (param = (g_object_unref (param), NULL)));
-				(array_type == NULL ? NULL : (array_type = (g_object_unref (array_type), NULL)));
+				(param == NULL ? NULL : (param = (vala_code_node_unref (param), NULL)));
+				(array_type == NULL ? NULL : (array_type = (vala_code_node_unref (array_type), NULL)));
 			}
 		}
-		(param_collection == NULL ? NULL : (param_collection = (g_object_unref (param_collection), NULL)));
+		(param_collection == NULL ? NULL : (param_collection = (gee_collection_object_unref (param_collection), NULL)));
 	}
 	_tmp32 = NULL;
 	vala_ccode_function_call_add_argument (register_call, VALA_CCODE_EXPRESSION ((_tmp32 = vala_ccode_identifier_new ("G_TYPE_INVALID"))));
-	(_tmp32 == NULL ? NULL : (_tmp32 = (g_object_unref (_tmp32), NULL)));
+	(_tmp32 == NULL ? NULL : (_tmp32 = (vala_ccode_node_unref (_tmp32), NULL)));
 	_tmp33 = NULL;
 	vala_ccode_function_call_add_argument (add_call, VALA_CCODE_EXPRESSION ((_tmp33 = vala_ccode_identifier_new ("G_TYPE_INVALID"))));
-	(_tmp33 == NULL ? NULL : (_tmp33 = (g_object_unref (_tmp33), NULL)));
+	(_tmp33 == NULL ? NULL : (_tmp33 = (vala_ccode_node_unref (_tmp33), NULL)));
 	_tmp34 = NULL;
 	vala_ccode_block_add_statement (block, VALA_CCODE_NODE ((_tmp34 = vala_ccode_expression_statement_new (VALA_CCODE_EXPRESSION (register_call)))));
-	(_tmp34 == NULL ? NULL : (_tmp34 = (g_object_unref (_tmp34), NULL)));
+	(_tmp34 == NULL ? NULL : (_tmp34 = (vala_ccode_node_unref (_tmp34), NULL)));
 	_tmp35 = NULL;
 	vala_ccode_block_add_statement (block, VALA_CCODE_NODE ((_tmp35 = vala_ccode_expression_statement_new (VALA_CCODE_EXPRESSION (add_call)))));
-	(_tmp35 == NULL ? NULL : (_tmp35 = (g_object_unref (_tmp35), NULL)));
+	(_tmp35 == NULL ? NULL : (_tmp35 = (vala_ccode_node_unref (_tmp35), NULL)));
 	_tmp36 = NULL;
 	_tmp37 = NULL;
-	call = (_tmp37 = vala_ccode_function_call_new (VALA_CCODE_EXPRESSION ((_tmp36 = vala_ccode_identifier_new ("dbus_g_proxy_connect_signal")))), (_tmp36 == NULL ? NULL : (_tmp36 = (g_object_unref (_tmp36), NULL))), _tmp37);
+	call = (_tmp37 = vala_ccode_function_call_new (VALA_CCODE_EXPRESSION ((_tmp36 = vala_ccode_identifier_new ("dbus_g_proxy_connect_signal")))), (_tmp36 == NULL ? NULL : (_tmp36 = (vala_ccode_node_unref (_tmp36), NULL))), _tmp37);
 	_tmp38 = NULL;
 	vala_ccode_function_call_add_argument (call, VALA_CCODE_EXPRESSION ((_tmp38 = vala_ccode_identifier_new ("obj"))));
-	(_tmp38 == NULL ? NULL : (_tmp38 = (g_object_unref (_tmp38), NULL)));
+	(_tmp38 == NULL ? NULL : (_tmp38 = (vala_ccode_node_unref (_tmp38), NULL)));
 	_tmp39 = NULL;
 	vala_ccode_function_call_add_argument (call, VALA_CCODE_EXPRESSION ((_tmp39 = vala_ccode_identifier_new ("signal_name"))));
-	(_tmp39 == NULL ? NULL : (_tmp39 = (g_object_unref (_tmp39), NULL)));
+	(_tmp39 == NULL ? NULL : (_tmp39 = (vala_ccode_node_unref (_tmp39), NULL)));
 	_tmp40 = NULL;
 	vala_ccode_function_call_add_argument (call, VALA_CCODE_EXPRESSION ((_tmp40 = vala_ccode_identifier_new ("handler"))));
-	(_tmp40 == NULL ? NULL : (_tmp40 = (g_object_unref (_tmp40), NULL)));
+	(_tmp40 == NULL ? NULL : (_tmp40 = (vala_ccode_node_unref (_tmp40), NULL)));
 	_tmp41 = NULL;
 	vala_ccode_function_call_add_argument (call, VALA_CCODE_EXPRESSION ((_tmp41 = vala_ccode_identifier_new ("data"))));
-	(_tmp41 == NULL ? NULL : (_tmp41 = (g_object_unref (_tmp41), NULL)));
+	(_tmp41 == NULL ? NULL : (_tmp41 = (vala_ccode_node_unref (_tmp41), NULL)));
 	_tmp42 = NULL;
 	vala_ccode_function_call_add_argument (call, VALA_CCODE_EXPRESSION ((_tmp42 = vala_ccode_constant_new ("NULL"))));
-	(_tmp42 == NULL ? NULL : (_tmp42 = (g_object_unref (_tmp42), NULL)));
+	(_tmp42 == NULL ? NULL : (_tmp42 = (vala_ccode_node_unref (_tmp42), NULL)));
 	_tmp43 = NULL;
 	vala_ccode_block_add_statement (block, VALA_CCODE_NODE ((_tmp43 = vala_ccode_expression_statement_new (VALA_CCODE_EXPRESSION (call)))));
-	(_tmp43 == NULL ? NULL : (_tmp43 = (g_object_unref (_tmp43), NULL)));
-	(dynamic_signal == NULL ? NULL : (dynamic_signal = (g_object_unref (dynamic_signal), NULL)));
-	(m == NULL ? NULL : (m = (g_object_unref (m), NULL)));
-	(register_call == NULL ? NULL : (register_call = (g_object_unref (register_call), NULL)));
-	(add_call == NULL ? NULL : (add_call = (g_object_unref (add_call), NULL)));
-	(call == NULL ? NULL : (call = (g_object_unref (call), NULL)));
+	(_tmp43 == NULL ? NULL : (_tmp43 = (vala_ccode_node_unref (_tmp43), NULL)));
+	(dynamic_signal == NULL ? NULL : (dynamic_signal = (vala_code_node_unref (dynamic_signal), NULL)));
+	(m == NULL ? NULL : (m = (vala_code_node_unref (m), NULL)));
+	(register_call == NULL ? NULL : (register_call = (vala_ccode_node_unref (register_call), NULL)));
+	(add_call == NULL ? NULL : (add_call = (vala_ccode_node_unref (add_call), NULL)));
+	(call == NULL ? NULL : (call = (vala_ccode_node_unref (call), NULL)));
 }
 
 
@@ -509,27 +513,27 @@ static void vala_ccode_dynamic_signal_binding_generate_dbus_disconnect_wrapper (
 	g_return_if_fail (VALA_IS_CCODE_DYNAMIC_SIGNAL_BINDING (self));
 	g_return_if_fail (VALA_IS_CCODE_BLOCK (block));
 	_tmp0 = NULL;
-	dynamic_signal = (_tmp0 = VALA_DYNAMIC_SIGNAL (self->priv->_node), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
+	dynamic_signal = (_tmp0 = VALA_DYNAMIC_SIGNAL (self->priv->_node), (_tmp0 == NULL ? NULL : vala_code_node_ref (_tmp0)));
 	_tmp1 = NULL;
 	_tmp2 = NULL;
-	call = (_tmp2 = vala_ccode_function_call_new (VALA_CCODE_EXPRESSION ((_tmp1 = vala_ccode_identifier_new ("dbus_g_proxy_disconnect_signal")))), (_tmp1 == NULL ? NULL : (_tmp1 = (g_object_unref (_tmp1), NULL))), _tmp2);
+	call = (_tmp2 = vala_ccode_function_call_new (VALA_CCODE_EXPRESSION ((_tmp1 = vala_ccode_identifier_new ("dbus_g_proxy_disconnect_signal")))), (_tmp1 == NULL ? NULL : (_tmp1 = (vala_ccode_node_unref (_tmp1), NULL))), _tmp2);
 	_tmp3 = NULL;
 	vala_ccode_function_call_add_argument (call, VALA_CCODE_EXPRESSION ((_tmp3 = vala_ccode_identifier_new ("obj"))));
-	(_tmp3 == NULL ? NULL : (_tmp3 = (g_object_unref (_tmp3), NULL)));
+	(_tmp3 == NULL ? NULL : (_tmp3 = (vala_ccode_node_unref (_tmp3), NULL)));
 	_tmp4 = NULL;
 	vala_ccode_function_call_add_argument (call, VALA_CCODE_EXPRESSION ((_tmp4 = vala_ccode_identifier_new ("signal_name"))));
-	(_tmp4 == NULL ? NULL : (_tmp4 = (g_object_unref (_tmp4), NULL)));
+	(_tmp4 == NULL ? NULL : (_tmp4 = (vala_ccode_node_unref (_tmp4), NULL)));
 	_tmp5 = NULL;
 	vala_ccode_function_call_add_argument (call, VALA_CCODE_EXPRESSION ((_tmp5 = vala_ccode_identifier_new ("handler"))));
-	(_tmp5 == NULL ? NULL : (_tmp5 = (g_object_unref (_tmp5), NULL)));
+	(_tmp5 == NULL ? NULL : (_tmp5 = (vala_ccode_node_unref (_tmp5), NULL)));
 	_tmp6 = NULL;
 	vala_ccode_function_call_add_argument (call, VALA_CCODE_EXPRESSION ((_tmp6 = vala_ccode_identifier_new ("data"))));
-	(_tmp6 == NULL ? NULL : (_tmp6 = (g_object_unref (_tmp6), NULL)));
+	(_tmp6 == NULL ? NULL : (_tmp6 = (vala_ccode_node_unref (_tmp6), NULL)));
 	_tmp7 = NULL;
 	vala_ccode_block_add_statement (block, VALA_CCODE_NODE ((_tmp7 = vala_ccode_expression_statement_new (VALA_CCODE_EXPRESSION (call)))));
-	(_tmp7 == NULL ? NULL : (_tmp7 = (g_object_unref (_tmp7), NULL)));
-	(dynamic_signal == NULL ? NULL : (dynamic_signal = (g_object_unref (dynamic_signal), NULL)));
-	(call == NULL ? NULL : (call = (g_object_unref (call), NULL)));
+	(_tmp7 == NULL ? NULL : (_tmp7 = (vala_ccode_node_unref (_tmp7), NULL)));
+	(dynamic_signal == NULL ? NULL : (dynamic_signal = (vala_code_node_unref (dynamic_signal), NULL)));
+	(call == NULL ? NULL : (call = (vala_ccode_node_unref (call), NULL)));
 }
 
 
@@ -545,45 +549,14 @@ void vala_ccode_dynamic_signal_binding_set_node (ValaCCodeDynamicSignalBinding*
 	g_return_if_fail (VALA_IS_CCODE_DYNAMIC_SIGNAL_BINDING (self));
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_node = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_node == NULL ? NULL : (self->priv->_node = (g_object_unref (self->priv->_node), NULL))), _tmp2);
-}
-
-
-static void vala_ccode_dynamic_signal_binding_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
-	ValaCCodeDynamicSignalBinding * self;
-	self = VALA_CCODE_DYNAMIC_SIGNAL_BINDING (object);
-	switch (property_id) {
-		case VALA_CCODE_DYNAMIC_SIGNAL_BINDING_NODE:
-		g_value_set_object (value, vala_ccode_dynamic_signal_binding_get_node (self));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
-static void vala_ccode_dynamic_signal_binding_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
-	ValaCCodeDynamicSignalBinding * self;
-	self = VALA_CCODE_DYNAMIC_SIGNAL_BINDING (object);
-	switch (property_id) {
-		case VALA_CCODE_DYNAMIC_SIGNAL_BINDING_NODE:
-		vala_ccode_dynamic_signal_binding_set_node (self, g_value_get_object (value));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
+	self->priv->_node = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1))), (self->priv->_node == NULL ? NULL : (self->priv->_node = (vala_code_node_unref (self->priv->_node), NULL))), _tmp2);
 }
 
 
 static void vala_ccode_dynamic_signal_binding_class_init (ValaCCodeDynamicSignalBindingClass * klass) {
 	vala_ccode_dynamic_signal_binding_parent_class = g_type_class_peek_parent (klass);
+	VALA_CODE_BINDING_CLASS (klass)->finalize = vala_ccode_dynamic_signal_binding_finalize;
 	g_type_class_add_private (klass, sizeof (ValaCCodeDynamicSignalBindingPrivate));
-	G_OBJECT_CLASS (klass)->get_property = vala_ccode_dynamic_signal_binding_get_property;
-	G_OBJECT_CLASS (klass)->set_property = vala_ccode_dynamic_signal_binding_set_property;
-	G_OBJECT_CLASS (klass)->dispose = vala_ccode_dynamic_signal_binding_dispose;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_DYNAMIC_SIGNAL_BINDING_NODE, g_param_spec_object ("node", "node", "node", VALA_TYPE_SIGNAL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
@@ -592,21 +565,21 @@ static void vala_ccode_dynamic_signal_binding_instance_init (ValaCCodeDynamicSig
 }
 
 
-static void vala_ccode_dynamic_signal_binding_dispose (GObject * obj) {
+static void vala_ccode_dynamic_signal_binding_finalize (ValaCodeBinding* obj) {
 	ValaCCodeDynamicSignalBinding * self;
 	self = VALA_CCODE_DYNAMIC_SIGNAL_BINDING (obj);
-	(self->priv->_node == NULL ? NULL : (self->priv->_node = (g_object_unref (self->priv->_node), NULL)));
+	(self->priv->_node == NULL ? NULL : (self->priv->_node = (vala_code_node_unref (self->priv->_node), NULL)));
 	self->priv->connect_wrapper_name = (g_free (self->priv->connect_wrapper_name), NULL);
 	self->priv->disconnect_wrapper_name = (g_free (self->priv->disconnect_wrapper_name), NULL);
 	self->priv->dynamic_cname = (g_free (self->priv->dynamic_cname), NULL);
-	G_OBJECT_CLASS (vala_ccode_dynamic_signal_binding_parent_class)->dispose (obj);
+	VALA_CODE_BINDING_CLASS (vala_ccode_dynamic_signal_binding_parent_class)->finalize (obj);
 }
 
 
 GType vala_ccode_dynamic_signal_binding_get_type (void) {
 	static GType vala_ccode_dynamic_signal_binding_type_id = 0;
-	if (G_UNLIKELY (vala_ccode_dynamic_signal_binding_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeDynamicSignalBindingClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_dynamic_signal_binding_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeDynamicSignalBinding), 0, (GInstanceInitFunc) vala_ccode_dynamic_signal_binding_instance_init };
+	if (vala_ccode_dynamic_signal_binding_type_id == 0) {
+		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeDynamicSignalBindingClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_dynamic_signal_binding_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeDynamicSignalBinding), 0, (GInstanceInitFunc) vala_ccode_dynamic_signal_binding_instance_init, NULL };
 		vala_ccode_dynamic_signal_binding_type_id = g_type_register_static (VALA_TYPE_CCODE_BINDING, "ValaCCodeDynamicSignalBinding", &g_define_type_info, 0);
 	}
 	return vala_ccode_dynamic_signal_binding_type_id;
