@@ -60,26 +60,30 @@ struct _ValaCCodeElementAccessBindingPrivate {
 
 #define VALA_CCODE_ELEMENT_ACCESS_BINDING_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CCODE_ELEMENT_ACCESS_BINDING, ValaCCodeElementAccessBindingPrivate))
 enum  {
-	VALA_CCODE_ELEMENT_ACCESS_BINDING_DUMMY_PROPERTY,
-	VALA_CCODE_ELEMENT_ACCESS_BINDING_ELEMENT_ACCESS
+	VALA_CCODE_ELEMENT_ACCESS_BINDING_DUMMY_PROPERTY
 };
 static void vala_ccode_element_access_binding_real_emit (ValaCCodeBinding* base);
 static gpointer vala_ccode_element_access_binding_parent_class = NULL;
-static void vala_ccode_element_access_binding_dispose (GObject * obj);
+static void vala_ccode_element_access_binding_finalize (ValaCodeBinding* obj);
 
 
 
-ValaCCodeElementAccessBinding* vala_ccode_element_access_binding_new (ValaCCodeGenerator* codegen, ValaElementAccess* element_access) {
-	ValaCCodeElementAccessBinding * self;
+ValaCCodeElementAccessBinding* vala_ccode_element_access_binding_construct (GType object_type, ValaCCodeGenerator* codegen, ValaElementAccess* element_access) {
+	ValaCCodeElementAccessBinding* self;
 	g_return_val_if_fail (VALA_IS_CCODE_GENERATOR (codegen), NULL);
 	g_return_val_if_fail (VALA_IS_ELEMENT_ACCESS (element_access), NULL);
-	self = g_object_newv (VALA_TYPE_CCODE_ELEMENT_ACCESS_BINDING, 0, NULL);
+	self = ((ValaCCodeElementAccessBinding*) (g_type_create_instance (object_type)));
 	vala_ccode_element_access_binding_set_element_access (self, element_access);
 	vala_ccode_binding_set_codegen (VALA_CCODE_BINDING (self), codegen);
 	return self;
 }
 
 
+ValaCCodeElementAccessBinding* vala_ccode_element_access_binding_new (ValaCCodeGenerator* codegen, ValaElementAccess* element_access) {
+	return vala_ccode_element_access_binding_construct (VALA_TYPE_CCODE_ELEMENT_ACCESS_BINDING, codegen, element_access);
+}
+
+
 static void vala_ccode_element_access_binding_real_emit (ValaCCodeBinding* base) {
 	ValaCCodeElementAccessBinding * self;
 	ValaElementAccess* _tmp0;
@@ -96,17 +100,17 @@ static void vala_ccode_element_access_binding_real_emit (ValaCCodeBinding* base)
 	ValaCCodeExpression* cindex;
 	self = VALA_CCODE_ELEMENT_ACCESS_BINDING (base);
 	_tmp0 = NULL;
-	expr = (_tmp0 = self->priv->_element_access, (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
+	expr = (_tmp0 = self->priv->_element_access, (_tmp0 == NULL ? NULL : vala_code_node_ref (_tmp0)));
 	indices = vala_element_access_get_indices (expr);
 	rank = gee_collection_get_size (GEE_COLLECTION (indices));
 	_tmp1 = NULL;
-	container_type = (_tmp1 = vala_data_type_get_data_type (vala_expression_get_value_type (vala_element_access_get_container (expr))), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
+	container_type = (_tmp1 = vala_data_type_get_data_type (vala_expression_get_value_type (vala_element_access_get_container (expr))), (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1)));
 	_tmp2 = NULL;
-	ccontainer = (_tmp2 = VALA_CCODE_EXPRESSION (vala_code_node_get_ccodenode (VALA_CODE_NODE (vala_element_access_get_container (expr)))), (_tmp2 == NULL ? NULL : g_object_ref (_tmp2)));
+	ccontainer = (_tmp2 = VALA_CCODE_EXPRESSION (vala_code_node_get_ccodenode (VALA_CODE_NODE (vala_element_access_get_container (expr)))), (_tmp2 == NULL ? NULL : vala_ccode_node_ref (_tmp2)));
 	_tmp4 = NULL;
 	_tmp3 = NULL;
 	_tmp5 = NULL;
-	cindex = (_tmp5 = (_tmp4 = VALA_CCODE_EXPRESSION (vala_code_node_get_ccodenode (VALA_CODE_NODE ((_tmp3 = ((ValaExpression*) (gee_list_get (((GeeList*) (indices)), 0))))))), (_tmp4 == NULL ? NULL : g_object_ref (_tmp4))), (_tmp3 == NULL ? NULL : (_tmp3 = (g_object_unref (_tmp3), NULL))), _tmp5);
+	cindex = (_tmp5 = (_tmp4 = VALA_CCODE_EXPRESSION (vala_code_node_get_ccodenode (VALA_CODE_NODE ((_tmp3 = ((ValaExpression*) (gee_list_get (((GeeList*) (indices)), 0))))))), (_tmp4 == NULL ? NULL : vala_ccode_node_ref (_tmp4))), (_tmp3 == NULL ? NULL : (_tmp3 = (vala_code_node_unref (_tmp3), NULL))), _tmp5);
 	if (VALA_IS_ARRAY_LENGTH_FIELD (vala_expression_get_symbol_reference (vala_element_access_get_container (expr)))) {
 		ValaExpression* _tmp6;
 		ValaIntegerLiteral* lit;
@@ -118,17 +122,17 @@ static void vala_ccode_element_access_binding_real_emit (ValaCCodeBinding* base)
 		lit = (_tmp6 = ((ValaExpression*) (gee_list_get (((GeeList*) (indices)), 0))), (VALA_IS_INTEGER_LITERAL (_tmp6) ? ((ValaIntegerLiteral*) (_tmp6)) : NULL));
 		_tmp8 = NULL;
 		_tmp7 = NULL;
-		memberaccess = (_tmp8 = (_tmp7 = vala_element_access_get_container (expr), (VALA_IS_MEMBER_ACCESS (_tmp7) ? ((ValaMemberAccess*) (_tmp7)) : NULL)), (_tmp8 == NULL ? NULL : g_object_ref (_tmp8)));
+		memberaccess = (_tmp8 = (_tmp7 = vala_element_access_get_container (expr), (VALA_IS_MEMBER_ACCESS (_tmp7) ? ((ValaMemberAccess*) (_tmp7)) : NULL)), (_tmp8 == NULL ? NULL : vala_code_node_ref (_tmp8)));
 		if (lit != NULL && memberaccess != NULL) {
 			gint dim;
 			ValaCCodeExpression* _tmp9;
 			dim = atoi (vala_integer_literal_get_value (lit));
 			_tmp9 = NULL;
 			vala_ccode_expression_binding_set_codenode (VALA_CCODE_EXPRESSION_BINDING (self), (_tmp9 = vala_ccode_generator_get_array_length_cexpression (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self)), vala_member_access_get_inner (memberaccess), dim + 1)));
-			(_tmp9 == NULL ? NULL : (_tmp9 = (g_object_unref (_tmp9), NULL)));
+			(_tmp9 == NULL ? NULL : (_tmp9 = (vala_ccode_node_unref (_tmp9), NULL)));
 		}
-		(lit == NULL ? NULL : (lit = (g_object_unref (lit), NULL)));
-		(memberaccess == NULL ? NULL : (memberaccess = (g_object_unref (memberaccess), NULL)));
+		(lit == NULL ? NULL : (lit = (vala_code_node_unref (lit), NULL)));
+		(memberaccess == NULL ? NULL : (memberaccess = (vala_code_node_unref (memberaccess), NULL)));
 	} else {
 		if (container_type == vala_data_type_get_data_type (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->string_type)) {
 			ValaCCodeIdentifier* _tmp10;
@@ -140,16 +144,16 @@ static void vala_ccode_element_access_binding_real_emit (ValaCCodeBinding* base)
 			/* access to unichar in a string*/
 			_tmp10 = NULL;
 			_tmp11 = NULL;
-			coffsetcall = (_tmp11 = vala_ccode_function_call_new (VALA_CCODE_EXPRESSION ((_tmp10 = vala_ccode_identifier_new ("g_utf8_offset_to_pointer")))), (_tmp10 == NULL ? NULL : (_tmp10 = (g_object_unref (_tmp10), NULL))), _tmp11);
+			coffsetcall = (_tmp11 = vala_ccode_function_call_new (VALA_CCODE_EXPRESSION ((_tmp10 = vala_ccode_identifier_new ("g_utf8_offset_to_pointer")))), (_tmp10 == NULL ? NULL : (_tmp10 = (vala_ccode_node_unref (_tmp10), NULL))), _tmp11);
 			vala_ccode_function_call_add_argument (coffsetcall, ccontainer);
 			vala_ccode_function_call_add_argument (coffsetcall, cindex);
 			_tmp12 = NULL;
 			_tmp13 = NULL;
-			ccall = (_tmp13 = vala_ccode_function_call_new (VALA_CCODE_EXPRESSION ((_tmp12 = vala_ccode_identifier_new ("g_utf8_get_char")))), (_tmp12 == NULL ? NULL : (_tmp12 = (g_object_unref (_tmp12), NULL))), _tmp13);
+			ccall = (_tmp13 = vala_ccode_function_call_new (VALA_CCODE_EXPRESSION ((_tmp12 = vala_ccode_identifier_new ("g_utf8_get_char")))), (_tmp12 == NULL ? NULL : (_tmp12 = (vala_ccode_node_unref (_tmp12), NULL))), _tmp13);
 			vala_ccode_function_call_add_argument (ccall, VALA_CCODE_EXPRESSION (coffsetcall));
 			vala_ccode_expression_binding_set_codenode (VALA_CCODE_EXPRESSION_BINDING (self), VALA_CCODE_EXPRESSION (ccall));
-			(coffsetcall == NULL ? NULL : (coffsetcall = (g_object_unref (coffsetcall), NULL)));
-			(ccall == NULL ? NULL : (ccall = (g_object_unref (ccall), NULL)));
+			(coffsetcall == NULL ? NULL : (coffsetcall = (vala_ccode_node_unref (coffsetcall), NULL)));
+			(ccall == NULL ? NULL : (ccall = (vala_ccode_node_unref (ccall), NULL)));
 		} else {
 			if (container_type != NULL && vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->list_type != NULL && vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->map_type != NULL && (vala_typesymbol_is_subtype_of (container_type, VALA_TYPESYMBOL (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->list_type)) || vala_typesymbol_is_subtype_of (container_type, VALA_TYPESYMBOL (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->map_type)))) {
 				ValaTypeSymbol* collection_iface;
@@ -171,14 +175,14 @@ static void vala_ccode_element_access_binding_real_emit (ValaCCodeBinding* base)
 					ValaTypeSymbol* _tmp14;
 					_tmp15 = NULL;
 					_tmp14 = NULL;
-					collection_iface = (_tmp15 = (_tmp14 = VALA_TYPESYMBOL (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->list_type), (_tmp14 == NULL ? NULL : g_object_ref (_tmp14))), (collection_iface == NULL ? NULL : (collection_iface = (g_object_unref (collection_iface), NULL))), _tmp15);
+					collection_iface = (_tmp15 = (_tmp14 = VALA_TYPESYMBOL (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->list_type), (_tmp14 == NULL ? NULL : vala_code_node_ref (_tmp14))), (collection_iface == NULL ? NULL : (collection_iface = (vala_code_node_unref (collection_iface), NULL))), _tmp15);
 				} else {
 					if (vala_typesymbol_is_subtype_of (container_type, VALA_TYPESYMBOL (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->map_type))) {
 						ValaTypeSymbol* _tmp17;
 						ValaTypeSymbol* _tmp16;
 						_tmp17 = NULL;
 						_tmp16 = NULL;
-						collection_iface = (_tmp17 = (_tmp16 = VALA_TYPESYMBOL (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->map_type), (_tmp16 == NULL ? NULL : g_object_ref (_tmp16))), (collection_iface == NULL ? NULL : (collection_iface = (g_object_unref (collection_iface), NULL))), _tmp17);
+						collection_iface = (_tmp17 = (_tmp16 = VALA_TYPESYMBOL (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->map_type), (_tmp16 == NULL ? NULL : vala_code_node_ref (_tmp16))), (collection_iface == NULL ? NULL : (collection_iface = (vala_code_node_unref (collection_iface), NULL))), _tmp17);
 					}
 				}
 				get_method = VALA_METHOD (vala_scope_lookup (vala_symbol_get_scope (VALA_SYMBOL (collection_iface)), "get"));
@@ -191,30 +195,30 @@ static void vala_ccode_element_access_binding_real_emit (ValaCCodeBinding* base)
 					ValaCCodeExpression* _tmp18;
 					index_type = vala_semantic_analyzer_get_actual_type (vala_expression_get_value_type (vala_element_access_get_container (expr)), VALA_SYMBOL (get_method), vala_formal_parameter_get_parameter_type (get_param), VALA_CODE_NODE (expr));
 					_tmp18 = NULL;
-					cindex = (_tmp18 = vala_ccode_generator_convert_to_generic_pointer (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self)), cindex, index_type), (cindex == NULL ? NULL : (cindex = (g_object_unref (cindex), NULL))), _tmp18);
-					(index_type == NULL ? NULL : (index_type = (g_object_unref (index_type), NULL)));
+					cindex = (_tmp18 = vala_ccode_generator_convert_to_generic_pointer (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self)), cindex, index_type), (cindex == NULL ? NULL : (cindex = (vala_ccode_node_unref (cindex), NULL))), _tmp18);
+					(index_type == NULL ? NULL : (index_type = (vala_code_node_unref (index_type), NULL)));
 				}
 				_tmp20 = NULL;
 				_tmp19 = NULL;
 				_tmp21 = NULL;
-				get_ccall = (_tmp21 = vala_ccode_function_call_new (VALA_CCODE_EXPRESSION ((_tmp20 = vala_ccode_identifier_new ((_tmp19 = vala_method_get_cname (get_method)))))), (_tmp20 == NULL ? NULL : (_tmp20 = (g_object_unref (_tmp20), NULL))), (_tmp19 = (g_free (_tmp19), NULL)), _tmp21);
+				get_ccall = (_tmp21 = vala_ccode_function_call_new (VALA_CCODE_EXPRESSION ((_tmp20 = vala_ccode_identifier_new ((_tmp19 = vala_method_get_cname (get_method)))))), (_tmp20 == NULL ? NULL : (_tmp20 = (vala_ccode_node_unref (_tmp20), NULL))), (_tmp19 = (g_free (_tmp19), NULL)), _tmp21);
 				_tmp24 = NULL;
 				_tmp23 = NULL;
 				_tmp22 = NULL;
 				vala_ccode_function_call_add_argument (get_ccall, VALA_CCODE_EXPRESSION ((_tmp24 = vala_ccode_cast_expression_new (ccontainer, (_tmp23 = g_strconcat ((_tmp22 = vala_typesymbol_get_cname (collection_iface, FALSE)), "*", NULL))))));
-				(_tmp24 == NULL ? NULL : (_tmp24 = (g_object_unref (_tmp24), NULL)));
+				(_tmp24 == NULL ? NULL : (_tmp24 = (vala_ccode_node_unref (_tmp24), NULL)));
 				_tmp23 = (g_free (_tmp23), NULL);
 				_tmp22 = (g_free (_tmp22), NULL);
 				vala_ccode_function_call_add_argument (get_ccall, cindex);
 				_tmp25 = NULL;
 				vala_ccode_expression_binding_set_codenode (VALA_CCODE_EXPRESSION_BINDING (self), (_tmp25 = vala_ccode_generator_convert_from_generic_pointer (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self)), VALA_CCODE_EXPRESSION (get_ccall), vala_expression_get_value_type (VALA_EXPRESSION (expr)))));
-				(_tmp25 == NULL ? NULL : (_tmp25 = (g_object_unref (_tmp25), NULL)));
-				(collection_iface == NULL ? NULL : (collection_iface = (g_object_unref (collection_iface), NULL)));
-				(get_method == NULL ? NULL : (get_method = (g_object_unref (get_method), NULL)));
-				(get_params == NULL ? NULL : (get_params = (g_object_unref (get_params), NULL)));
-				(get_params_it == NULL ? NULL : (get_params_it = (g_object_unref (get_params_it), NULL)));
-				(get_param == NULL ? NULL : (get_param = (g_object_unref (get_param), NULL)));
-				(get_ccall == NULL ? NULL : (get_ccall = (g_object_unref (get_ccall), NULL)));
+				(_tmp25 == NULL ? NULL : (_tmp25 = (vala_ccode_node_unref (_tmp25), NULL)));
+				(collection_iface == NULL ? NULL : (collection_iface = (vala_code_node_unref (collection_iface), NULL)));
+				(get_method == NULL ? NULL : (get_method = (vala_code_node_unref (get_method), NULL)));
+				(get_params == NULL ? NULL : (get_params = (gee_collection_object_unref (get_params), NULL)));
+				(get_params_it == NULL ? NULL : (get_params_it = (gee_collection_object_unref (get_params_it), NULL)));
+				(get_param == NULL ? NULL : (get_param = (vala_code_node_unref (get_param), NULL)));
+				(get_ccall == NULL ? NULL : (get_ccall = (vala_ccode_node_unref (get_ccall), NULL)));
 			} else {
 				if (VALA_IS_MEMBER_ACCESS (vala_element_access_get_container (expr)) && VALA_IS_SIGNAL (vala_expression_get_symbol_reference (vala_element_access_get_container (expr)))) {
 					ValaSignal* _tmp26;
@@ -235,33 +239,33 @@ static void vala_ccode_element_access_binding_real_emit (ValaCCodeBinding* base)
 					ValaCCodeConstant* _tmp35;
 					/* detailed signal emission*/
 					_tmp26 = NULL;
-					sig = (_tmp26 = VALA_SIGNAL (vala_expression_get_symbol_reference (VALA_EXPRESSION (expr))), (_tmp26 == NULL ? NULL : g_object_ref (_tmp26)));
+					sig = (_tmp26 = VALA_SIGNAL (vala_expression_get_symbol_reference (VALA_EXPRESSION (expr))), (_tmp26 == NULL ? NULL : vala_code_node_ref (_tmp26)));
 					_tmp27 = NULL;
-					ma = (_tmp27 = VALA_MEMBER_ACCESS (vala_element_access_get_container (expr)), (_tmp27 == NULL ? NULL : g_object_ref (_tmp27)));
+					ma = (_tmp27 = VALA_MEMBER_ACCESS (vala_element_access_get_container (expr)), (_tmp27 == NULL ? NULL : vala_code_node_ref (_tmp27)));
 					_tmp28 = NULL;
 					_tmp29 = NULL;
 					_tmp30 = NULL;
-					detail_expr = (_tmp30 = (_tmp29 = ((ValaExpression*) (gee_list_get ((_tmp28 = vala_element_access_get_indices (expr)), 0))), (VALA_IS_STRING_LITERAL (_tmp29) ? ((ValaStringLiteral*) (_tmp29)) : NULL)), (_tmp28 == NULL ? NULL : (_tmp28 = (g_object_unref (_tmp28), NULL))), _tmp30);
+					detail_expr = (_tmp30 = (_tmp29 = ((ValaExpression*) (gee_list_get ((_tmp28 = vala_element_access_get_indices (expr)), 0))), (VALA_IS_STRING_LITERAL (_tmp29) ? ((ValaStringLiteral*) (_tmp29)) : NULL)), (_tmp28 == NULL ? NULL : (_tmp28 = (gee_collection_object_unref (_tmp28), NULL))), _tmp30);
 					signal_detail = vala_string_literal_eval (detail_expr);
 					_tmp31 = NULL;
 					_tmp32 = NULL;
-					ccall = (_tmp32 = vala_ccode_function_call_new (VALA_CCODE_EXPRESSION ((_tmp31 = vala_ccode_identifier_new ("g_signal_emit_by_name")))), (_tmp31 == NULL ? NULL : (_tmp31 = (g_object_unref (_tmp31), NULL))), _tmp32);
+					ccall = (_tmp32 = vala_ccode_function_call_new (VALA_CCODE_EXPRESSION ((_tmp31 = vala_ccode_identifier_new ("g_signal_emit_by_name")))), (_tmp31 == NULL ? NULL : (_tmp31 = (vala_ccode_node_unref (_tmp31), NULL))), _tmp32);
 					/* FIXME: use C cast if debugging disabled*/
 					_tmp33 = NULL;
 					_tmp34 = NULL;
-					ccast = (_tmp34 = vala_ccode_function_call_new (VALA_CCODE_EXPRESSION ((_tmp33 = vala_ccode_identifier_new ("G_OBJECT")))), (_tmp33 == NULL ? NULL : (_tmp33 = (g_object_unref (_tmp33), NULL))), _tmp34);
+					ccast = (_tmp34 = vala_ccode_function_call_new (VALA_CCODE_EXPRESSION ((_tmp33 = vala_ccode_identifier_new ("G_OBJECT")))), (_tmp33 == NULL ? NULL : (_tmp33 = (vala_ccode_node_unref (_tmp33), NULL))), _tmp34);
 					vala_ccode_function_call_add_argument (ccast, VALA_CCODE_EXPRESSION (vala_code_node_get_ccodenode (VALA_CODE_NODE (vala_member_access_get_inner (ma)))));
 					vala_ccode_function_call_add_argument (ccall, VALA_CCODE_EXPRESSION (ccast));
 					_tmp35 = NULL;
 					vala_ccode_function_call_add_argument (ccall, VALA_CCODE_EXPRESSION ((_tmp35 = vala_signal_get_canonical_cconstant (sig, signal_detail))));
-					(_tmp35 == NULL ? NULL : (_tmp35 = (g_object_unref (_tmp35), NULL)));
+					(_tmp35 == NULL ? NULL : (_tmp35 = (vala_ccode_node_unref (_tmp35), NULL)));
 					vala_ccode_expression_binding_set_codenode (VALA_CCODE_EXPRESSION_BINDING (self), VALA_CCODE_EXPRESSION (ccall));
-					(sig == NULL ? NULL : (sig = (g_object_unref (sig), NULL)));
-					(ma == NULL ? NULL : (ma = (g_object_unref (ma), NULL)));
-					(detail_expr == NULL ? NULL : (detail_expr = (g_object_unref (detail_expr), NULL)));
+					(sig == NULL ? NULL : (sig = (vala_code_node_unref (sig), NULL)));
+					(ma == NULL ? NULL : (ma = (vala_code_node_unref (ma), NULL)));
+					(detail_expr == NULL ? NULL : (detail_expr = (vala_code_node_unref (detail_expr), NULL)));
 					signal_detail = (g_free (signal_detail), NULL);
-					(ccall == NULL ? NULL : (ccall = (g_object_unref (ccall), NULL)));
-					(ccast == NULL ? NULL : (ccast = (g_object_unref (ccast), NULL)));
+					(ccall == NULL ? NULL : (ccall = (vala_ccode_node_unref (ccall), NULL)));
+					(ccast == NULL ? NULL : (ccast = (vala_ccode_node_unref (ccast), NULL)));
 				} else {
 					ValaCCodeElementAccess* _tmp42;
 					{
@@ -279,29 +283,29 @@ static void vala_ccode_element_access_binding_real_emit (ValaCCodeBinding* base)
 							_tmp37 = NULL;
 							_tmp36 = NULL;
 							_tmp38 = NULL;
-							cmul = (_tmp38 = vala_ccode_binary_expression_new (VALA_CCODE_BINARY_OPERATOR_MUL, VALA_CCODE_EXPRESSION ((_tmp36 = vala_ccode_parenthesized_expression_new (cindex))), (_tmp37 = vala_ccode_generator_get_array_length_cexpression (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self)), vala_element_access_get_container (expr), i + 1))), (_tmp37 == NULL ? NULL : (_tmp37 = (g_object_unref (_tmp37), NULL))), (_tmp36 == NULL ? NULL : (_tmp36 = (g_object_unref (_tmp36), NULL))), _tmp38);
+							cmul = (_tmp38 = vala_ccode_binary_expression_new (VALA_CCODE_BINARY_OPERATOR_MUL, VALA_CCODE_EXPRESSION ((_tmp36 = vala_ccode_parenthesized_expression_new (cindex))), (_tmp37 = vala_ccode_generator_get_array_length_cexpression (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self)), vala_element_access_get_container (expr), i + 1))), (_tmp37 == NULL ? NULL : (_tmp37 = (vala_ccode_node_unref (_tmp37), NULL))), (_tmp36 == NULL ? NULL : (_tmp36 = (vala_ccode_node_unref (_tmp36), NULL))), _tmp38);
 							_tmp41 = NULL;
 							_tmp40 = NULL;
 							_tmp39 = NULL;
-							cindex = (_tmp41 = VALA_CCODE_EXPRESSION (vala_ccode_binary_expression_new (VALA_CCODE_BINARY_OPERATOR_PLUS, VALA_CCODE_EXPRESSION (cmul), VALA_CCODE_EXPRESSION ((_tmp40 = vala_ccode_parenthesized_expression_new (VALA_CCODE_EXPRESSION (vala_code_node_get_ccodenode (VALA_CODE_NODE ((_tmp39 = ((ValaExpression*) (gee_list_get (((GeeList*) (indices)), i)))))))))))), (cindex == NULL ? NULL : (cindex = (g_object_unref (cindex), NULL))), _tmp41);
-							(_tmp40 == NULL ? NULL : (_tmp40 = (g_object_unref (_tmp40), NULL)));
-							(_tmp39 == NULL ? NULL : (_tmp39 = (g_object_unref (_tmp39), NULL)));
-							(cmul == NULL ? NULL : (cmul = (g_object_unref (cmul), NULL)));
+							cindex = (_tmp41 = VALA_CCODE_EXPRESSION (vala_ccode_binary_expression_new (VALA_CCODE_BINARY_OPERATOR_PLUS, VALA_CCODE_EXPRESSION (cmul), VALA_CCODE_EXPRESSION ((_tmp40 = vala_ccode_parenthesized_expression_new (VALA_CCODE_EXPRESSION (vala_code_node_get_ccodenode (VALA_CODE_NODE ((_tmp39 = ((ValaExpression*) (gee_list_get (((GeeList*) (indices)), i)))))))))))), (cindex == NULL ? NULL : (cindex = (vala_ccode_node_unref (cindex), NULL))), _tmp41);
+							(_tmp40 == NULL ? NULL : (_tmp40 = (vala_ccode_node_unref (_tmp40), NULL)));
+							(_tmp39 == NULL ? NULL : (_tmp39 = (vala_code_node_unref (_tmp39), NULL)));
+							(cmul == NULL ? NULL : (cmul = (vala_ccode_node_unref (cmul), NULL)));
 						}
 					}
 					_tmp42 = NULL;
 					vala_ccode_expression_binding_set_codenode (VALA_CCODE_EXPRESSION_BINDING (self), VALA_CCODE_EXPRESSION ((_tmp42 = vala_ccode_element_access_new (ccontainer, cindex))));
-					(_tmp42 == NULL ? NULL : (_tmp42 = (g_object_unref (_tmp42), NULL)));
+					(_tmp42 == NULL ? NULL : (_tmp42 = (vala_ccode_node_unref (_tmp42), NULL)));
 				}
 			}
 		}
 	}
 	vala_code_node_set_ccodenode (VALA_CODE_NODE (expr), VALA_CCODE_NODE (vala_ccode_expression_binding_get_codenode (VALA_CCODE_EXPRESSION_BINDING (self))));
-	(expr == NULL ? NULL : (expr = (g_object_unref (expr), NULL)));
-	(indices == NULL ? NULL : (indices = (g_object_unref (indices), NULL)));
-	(container_type == NULL ? NULL : (container_type = (g_object_unref (container_type), NULL)));
-	(ccontainer == NULL ? NULL : (ccontainer = (g_object_unref (ccontainer), NULL)));
-	(cindex == NULL ? NULL : (cindex = (g_object_unref (cindex), NULL)));
+	(expr == NULL ? NULL : (expr = (vala_code_node_unref (expr), NULL)));
+	(indices == NULL ? NULL : (indices = (gee_collection_object_unref (indices), NULL)));
+	(container_type == NULL ? NULL : (container_type = (vala_code_node_unref (container_type), NULL)));
+	(ccontainer == NULL ? NULL : (ccontainer = (vala_ccode_node_unref (ccontainer), NULL)));
+	(cindex == NULL ? NULL : (cindex = (vala_ccode_node_unref (cindex), NULL)));
 }
 
 
@@ -317,46 +321,15 @@ void vala_ccode_element_access_binding_set_element_access (ValaCCodeElementAcces
 	g_return_if_fail (VALA_IS_CCODE_ELEMENT_ACCESS_BINDING (self));
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_element_access = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_element_access == NULL ? NULL : (self->priv->_element_access = (g_object_unref (self->priv->_element_access), NULL))), _tmp2);
-}
-
-
-static void vala_ccode_element_access_binding_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
-	ValaCCodeElementAccessBinding * self;
-	self = VALA_CCODE_ELEMENT_ACCESS_BINDING (object);
-	switch (property_id) {
-		case VALA_CCODE_ELEMENT_ACCESS_BINDING_ELEMENT_ACCESS:
-		g_value_set_object (value, vala_ccode_element_access_binding_get_element_access (self));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
-static void vala_ccode_element_access_binding_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
-	ValaCCodeElementAccessBinding * self;
-	self = VALA_CCODE_ELEMENT_ACCESS_BINDING (object);
-	switch (property_id) {
-		case VALA_CCODE_ELEMENT_ACCESS_BINDING_ELEMENT_ACCESS:
-		vala_ccode_element_access_binding_set_element_access (self, g_value_get_object (value));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
+	self->priv->_element_access = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1))), (self->priv->_element_access == NULL ? NULL : (self->priv->_element_access = (vala_code_node_unref (self->priv->_element_access), NULL))), _tmp2);
 }
 
 
 static void vala_ccode_element_access_binding_class_init (ValaCCodeElementAccessBindingClass * klass) {
 	vala_ccode_element_access_binding_parent_class = g_type_class_peek_parent (klass);
+	VALA_CODE_BINDING_CLASS (klass)->finalize = vala_ccode_element_access_binding_finalize;
 	g_type_class_add_private (klass, sizeof (ValaCCodeElementAccessBindingPrivate));
-	G_OBJECT_CLASS (klass)->get_property = vala_ccode_element_access_binding_get_property;
-	G_OBJECT_CLASS (klass)->set_property = vala_ccode_element_access_binding_set_property;
-	G_OBJECT_CLASS (klass)->dispose = vala_ccode_element_access_binding_dispose;
 	VALA_CCODE_BINDING_CLASS (klass)->emit = vala_ccode_element_access_binding_real_emit;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_ELEMENT_ACCESS_BINDING_ELEMENT_ACCESS, g_param_spec_object ("element-access", "element-access", "element-access", VALA_TYPE_ELEMENT_ACCESS, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
@@ -365,18 +338,18 @@ static void vala_ccode_element_access_binding_instance_init (ValaCCodeElementAcc
 }
 
 
-static void vala_ccode_element_access_binding_dispose (GObject * obj) {
+static void vala_ccode_element_access_binding_finalize (ValaCodeBinding* obj) {
 	ValaCCodeElementAccessBinding * self;
 	self = VALA_CCODE_ELEMENT_ACCESS_BINDING (obj);
-	(self->priv->_element_access == NULL ? NULL : (self->priv->_element_access = (g_object_unref (self->priv->_element_access), NULL)));
-	G_OBJECT_CLASS (vala_ccode_element_access_binding_parent_class)->dispose (obj);
+	(self->priv->_element_access == NULL ? NULL : (self->priv->_element_access = (vala_code_node_unref (self->priv->_element_access), NULL)));
+	VALA_CODE_BINDING_CLASS (vala_ccode_element_access_binding_parent_class)->finalize (obj);
 }
 
 
 GType vala_ccode_element_access_binding_get_type (void) {
 	static GType vala_ccode_element_access_binding_type_id = 0;
-	if (G_UNLIKELY (vala_ccode_element_access_binding_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeElementAccessBindingClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_element_access_binding_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeElementAccessBinding), 0, (GInstanceInitFunc) vala_ccode_element_access_binding_instance_init };
+	if (vala_ccode_element_access_binding_type_id == 0) {
+		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeElementAccessBindingClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_element_access_binding_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeElementAccessBinding), 0, (GInstanceInitFunc) vala_ccode_element_access_binding_instance_init, NULL };
 		vala_ccode_element_access_binding_type_id = g_type_register_static (VALA_TYPE_CCODE_EXPRESSION_BINDING, "ValaCCodeElementAccessBinding", &g_define_type_info, 0);
 	}
 	return vala_ccode_element_access_binding_type_id;
