@@ -33,6 +33,7 @@
 #include <gee/map.h>
 #include <ccode/valaccodefunction.h>
 #include <ccode/valaccodefunctiondeclarator.h>
+#include <ccode/valaccodefunctioncall.h>
 #include <gobject/valaccodebinding.h>
 
 G_BEGIN_DECLS
@@ -61,8 +62,9 @@ struct _ValaCCodeMethodBindingClass {
 
 
 char* vala_ccode_method_binding_get_custom_creturn_type (ValaCCodeMethodBinding* self);
+ValaCCodeMethodBinding* vala_ccode_method_binding_construct (GType object_type, ValaCCodeGenerator* codegen, ValaMethod* method);
 ValaCCodeMethodBinding* vala_ccode_method_binding_new (ValaCCodeGenerator* codegen, ValaMethod* method);
-void vala_ccode_method_binding_generate_cparameters (ValaCCodeMethodBinding* self, ValaMethod* m, ValaDataType* creturn_type, GeeMap* cparam_map, ValaCCodeFunction* func, ValaCCodeFunctionDeclarator* vdeclarator);
+void vala_ccode_method_binding_generate_cparameters (ValaCCodeMethodBinding* self, ValaMethod* m, ValaDataType* creturn_type, gboolean in_gtypeinstance_creation_method, GeeMap* cparam_map, ValaCCodeFunction* func, ValaCCodeFunctionDeclarator* vdeclarator, GeeMap* carg_map, ValaCCodeFunctionCall* vcall);
 ValaMethod* vala_ccode_method_binding_get_method (ValaCCodeMethodBinding* self);
 void vala_ccode_method_binding_set_method (ValaCCodeMethodBinding* self, ValaMethod* value);
 gboolean vala_ccode_method_binding_get_has_wrapper (ValaCCodeMethodBinding* self);
