@@ -1,6 +1,6 @@
 /* valaclassregisterfunction.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter
+ * Copyright (C) 2006-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -40,12 +40,12 @@
 struct _ValaClassRegisterFunctionPrivate {
 	ValaClass* _class_reference;
 };
+
 #define VALA_CLASS_REGISTER_FUNCTION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CLASS_REGISTER_FUNCTION, ValaClassRegisterFunctionPrivate))
 enum  {
-	VALA_CLASS_REGISTER_FUNCTION_DUMMY_PROPERTY,
-	VALA_CLASS_REGISTER_FUNCTION_CLASS_REFERENCE
+	VALA_CLASS_REGISTER_FUNCTION_DUMMY_PROPERTY
 };
-static ValaTypesymbol* vala_class_register_function_real_get_type_declaration (ValaTypeRegisterFunction* base);
+static ValaTypeSymbol* vala_class_register_function_real_get_type_declaration (ValaTypeRegisterFunction* base);
 static char* vala_class_register_function_real_get_type_struct_name (ValaTypeRegisterFunction* base);
 static char* vala_class_register_function_real_get_base_init_func_name (ValaTypeRegisterFunction* base);
 static char* vala_class_register_function_real_get_class_init_func_name (ValaTypeRegisterFunction* base);
@@ -54,10 +54,16 @@ static char* vala_class_register_function_real_get_instance_init_func_name (Vala
 static char* vala_class_register_function_real_get_parent_type_name (ValaTypeRegisterFunction* base);
 static char* vala_class_register_function_real_get_type_flags (ValaTypeRegisterFunction* base);
 static ValaSymbolAccessibility vala_class_register_function_real_get_accessibility (ValaTypeRegisterFunction* base);
+static char* vala_class_register_function_real_get_gtype_value_table_init_function_name (ValaTypeRegisterFunction* base);
+static char* vala_class_register_function_real_get_gtype_value_table_free_function_name (ValaTypeRegisterFunction* base);
+static char* vala_class_register_function_real_get_gtype_value_table_copy_function_name (ValaTypeRegisterFunction* base);
+static char* vala_class_register_function_real_get_gtype_value_table_peek_pointer_function_name (ValaTypeRegisterFunction* base);
+static char* vala_class_register_function_real_get_gtype_value_table_collect_value_function_name (ValaTypeRegisterFunction* base);
+static char* vala_class_register_function_real_get_gtype_value_table_lcopy_value_function_name (ValaTypeRegisterFunction* base);
 static ValaCCodeFragment* vala_class_register_function_real_get_type_interface_init_declaration (ValaTypeRegisterFunction* base);
 static ValaCCodeFragment* vala_class_register_function_real_get_type_interface_init_statements (ValaTypeRegisterFunction* base);
 static gpointer vala_class_register_function_parent_class = NULL;
-static void vala_class_register_function_dispose (GObject * obj);
+static void vala_class_register_function_finalize (ValaTypeRegisterFunction* obj);
 
 
 
@@ -67,21 +73,28 @@ static void vala_class_register_function_dispose (GObject * obj);
  * @param cl a class
  * @return   newly created class register function
  */
-ValaClassRegisterFunction* vala_class_register_function_new (ValaClass* cl) {
-	ValaClassRegisterFunction * self;
-	g_return_val_if_fail (cl == NULL || VALA_IS_CLASS (cl), NULL);
-	self = g_object_newv (VALA_TYPE_CLASS_REGISTER_FUNCTION, 0, NULL);
+ValaClassRegisterFunction* vala_class_register_function_construct (GType object_type, ValaClass* cl, ValaCCodeGenerator* codegen) {
+	ValaClassRegisterFunction* self;
+	g_return_val_if_fail (VALA_IS_CLASS (cl), NULL);
+	g_return_val_if_fail (VALA_IS_CCODE_GENERATOR (codegen), NULL);
+	self = ((ValaClassRegisterFunction*) (g_type_create_instance (object_type)));
 	vala_class_register_function_set_class_reference (self, cl);
+	vala_typeregister_function_set_codegen (VALA_TYPEREGISTER_FUNCTION (self), codegen);
 	return self;
 }
 
 
-static ValaTypesymbol* vala_class_register_function_real_get_type_declaration (ValaTypeRegisterFunction* base) {
+ValaClassRegisterFunction* vala_class_register_function_new (ValaClass* cl, ValaCCodeGenerator* codegen) {
+	return vala_class_register_function_construct (VALA_TYPE_CLASS_REGISTER_FUNCTION, cl, codegen);
+}
+
+
+static ValaTypeSymbol* vala_class_register_function_real_get_type_declaration (ValaTypeRegisterFunction* base) {
 	ValaClassRegisterFunction * self;
-	ValaClass* _tmp0;
+	ValaTypeSymbol* _tmp0;
 	self = VALA_CLASS_REGISTER_FUNCTION (base);
 	_tmp0 = NULL;
-	return VALA_TYPESYMBOL ((_tmp0 = self->priv->_class_reference, (_tmp0 == NULL ? NULL : g_object_ref (_tmp0))));
+	return (_tmp0 = VALA_TYPESYMBOL (self->priv->_class_reference), (_tmp0 == NULL ? NULL : vala_code_node_ref (_tmp0)));
 }
 
 
@@ -99,7 +112,15 @@ static char* vala_class_register_function_real_get_type_struct_name (ValaTypeReg
 static char* vala_class_register_function_real_get_base_init_func_name (ValaTypeRegisterFunction* base) {
 	ValaClassRegisterFunction * self;
 	self = VALA_CLASS_REGISTER_FUNCTION (base);
-	return g_strdup ("NULL");
+	if (vala_class_get_class_constructor (self->priv->_class_reference) != NULL) {
+		char* _tmp0;
+		char* _tmp1;
+		_tmp0 = NULL;
+		_tmp1 = NULL;
+		return (_tmp1 = g_strdup_printf ("%s_base_init", (_tmp0 = vala_symbol_get_lower_case_cname (VALA_SYMBOL (self->priv->_class_reference), NULL))), (_tmp0 = (g_free (_tmp0), NULL)), _tmp1);
+	} else {
+		return g_strdup ("NULL");
+	}
 }
 
 
@@ -132,14 +153,14 @@ static char* vala_class_register_function_real_get_instance_init_func_name (Vala
 	self = VALA_CLASS_REGISTER_FUNCTION (base);
 	_tmp0 = NULL;
 	_tmp1 = NULL;
-	return (_tmp1 = g_strdup_printf ("%s_init", (_tmp0 = vala_symbol_get_lower_case_cname (VALA_SYMBOL (self->priv->_class_reference), NULL))), (_tmp0 = (g_free (_tmp0), NULL)), _tmp1);
+	return (_tmp1 = g_strdup_printf ("%s_instance_init", (_tmp0 = vala_symbol_get_lower_case_cname (VALA_SYMBOL (self->priv->_class_reference), NULL))), (_tmp0 = (g_free (_tmp0), NULL)), _tmp1);
 }
 
 
 static char* vala_class_register_function_real_get_parent_type_name (ValaTypeRegisterFunction* base) {
 	ValaClassRegisterFunction * self;
 	self = VALA_CLASS_REGISTER_FUNCTION (base);
-	return vala_typesymbol_get_upper_case_cname (VALA_TYPESYMBOL (vala_class_get_base_class (self->priv->_class_reference)), "TYPE_");
+	return vala_typesymbol_get_type_id (VALA_TYPESYMBOL (vala_class_get_base_class (self->priv->_class_reference)));
 }
 
 
@@ -161,19 +182,114 @@ static ValaSymbolAccessibility vala_class_register_function_real_get_accessibili
 }
 
 
+static char* vala_class_register_function_real_get_gtype_value_table_init_function_name (ValaTypeRegisterFunction* base) {
+	ValaClassRegisterFunction * self;
+	gboolean is_fundamental;
+	self = VALA_CLASS_REGISTER_FUNCTION (base);
+	is_fundamental = !vala_class_get_is_compact (self->priv->_class_reference) && !vala_class_get_is_static (self->priv->_class_reference) && vala_class_get_base_class (self->priv->_class_reference) == NULL;
+	if (is_fundamental) {
+		char* _tmp0;
+		char* _tmp1;
+		_tmp0 = NULL;
+		_tmp1 = NULL;
+		return (_tmp1 = g_strdup_printf ("%s_init", (_tmp0 = vala_symbol_get_lower_case_cname (VALA_SYMBOL (self->priv->_class_reference), "value_"))), (_tmp0 = (g_free (_tmp0), NULL)), _tmp1);
+	}
+	return NULL;
+}
+
+
+static char* vala_class_register_function_real_get_gtype_value_table_free_function_name (ValaTypeRegisterFunction* base) {
+	ValaClassRegisterFunction * self;
+	gboolean is_fundamental;
+	self = VALA_CLASS_REGISTER_FUNCTION (base);
+	is_fundamental = !vala_class_get_is_compact (self->priv->_class_reference) && !vala_class_get_is_static (self->priv->_class_reference) && vala_class_get_base_class (self->priv->_class_reference) == NULL;
+	if (is_fundamental) {
+		char* _tmp0;
+		char* _tmp1;
+		_tmp0 = NULL;
+		_tmp1 = NULL;
+		return (_tmp1 = g_strdup_printf ("%s_free_value", (_tmp0 = vala_symbol_get_lower_case_cname (VALA_SYMBOL (self->priv->_class_reference), "value_"))), (_tmp0 = (g_free (_tmp0), NULL)), _tmp1);
+	}
+	return NULL;
+}
+
+
+static char* vala_class_register_function_real_get_gtype_value_table_copy_function_name (ValaTypeRegisterFunction* base) {
+	ValaClassRegisterFunction * self;
+	gboolean is_fundamental;
+	self = VALA_CLASS_REGISTER_FUNCTION (base);
+	is_fundamental = !vala_class_get_is_compact (self->priv->_class_reference) && !vala_class_get_is_static (self->priv->_class_reference) && vala_class_get_base_class (self->priv->_class_reference) == NULL;
+	if (is_fundamental) {
+		char* _tmp0;
+		char* _tmp1;
+		_tmp0 = NULL;
+		_tmp1 = NULL;
+		return (_tmp1 = g_strdup_printf ("%s_copy_value", (_tmp0 = vala_symbol_get_lower_case_cname (VALA_SYMBOL (self->priv->_class_reference), "value_"))), (_tmp0 = (g_free (_tmp0), NULL)), _tmp1);
+	}
+	return NULL;
+}
+
+
+static char* vala_class_register_function_real_get_gtype_value_table_peek_pointer_function_name (ValaTypeRegisterFunction* base) {
+	ValaClassRegisterFunction * self;
+	gboolean is_fundamental;
+	self = VALA_CLASS_REGISTER_FUNCTION (base);
+	is_fundamental = !vala_class_get_is_compact (self->priv->_class_reference) && !vala_class_get_is_static (self->priv->_class_reference) && vala_class_get_base_class (self->priv->_class_reference) == NULL;
+	if (is_fundamental) {
+		char* _tmp0;
+		char* _tmp1;
+		_tmp0 = NULL;
+		_tmp1 = NULL;
+		return (_tmp1 = g_strdup_printf ("%s_peek_pointer", (_tmp0 = vala_symbol_get_lower_case_cname (VALA_SYMBOL (self->priv->_class_reference), "value_"))), (_tmp0 = (g_free (_tmp0), NULL)), _tmp1);
+	}
+	return NULL;
+}
+
+
+static char* vala_class_register_function_real_get_gtype_value_table_collect_value_function_name (ValaTypeRegisterFunction* base) {
+	ValaClassRegisterFunction * self;
+	gboolean is_fundamental;
+	self = VALA_CLASS_REGISTER_FUNCTION (base);
+	is_fundamental = !vala_class_get_is_compact (self->priv->_class_reference) && !vala_class_get_is_static (self->priv->_class_reference) && vala_class_get_base_class (self->priv->_class_reference) == NULL;
+	if (is_fundamental) {
+		char* _tmp0;
+		char* _tmp1;
+		_tmp0 = NULL;
+		_tmp1 = NULL;
+		return (_tmp1 = g_strdup_printf ("%s_collect_value", (_tmp0 = vala_symbol_get_lower_case_cname (VALA_SYMBOL (self->priv->_class_reference), "value_"))), (_tmp0 = (g_free (_tmp0), NULL)), _tmp1);
+	}
+	return NULL;
+}
+
+
+static char* vala_class_register_function_real_get_gtype_value_table_lcopy_value_function_name (ValaTypeRegisterFunction* base) {
+	ValaClassRegisterFunction * self;
+	gboolean is_fundamental;
+	self = VALA_CLASS_REGISTER_FUNCTION (base);
+	is_fundamental = !vala_class_get_is_compact (self->priv->_class_reference) && !vala_class_get_is_static (self->priv->_class_reference) && vala_class_get_base_class (self->priv->_class_reference) == NULL;
+	if (is_fundamental) {
+		char* _tmp0;
+		char* _tmp1;
+		_tmp0 = NULL;
+		_tmp1 = NULL;
+		return (_tmp1 = g_strdup_printf ("%s_lcopy_value", (_tmp0 = vala_symbol_get_lower_case_cname (VALA_SYMBOL (self->priv->_class_reference), "value_"))), (_tmp0 = (g_free (_tmp0), NULL)), _tmp1);
+	}
+	return NULL;
+}
+
+
 static ValaCCodeFragment* vala_class_register_function_real_get_type_interface_init_declaration (ValaTypeRegisterFunction* base) {
 	ValaClassRegisterFunction * self;
 	ValaCCodeFragment* frag;
 	self = VALA_CLASS_REGISTER_FUNCTION (base);
 	frag = vala_ccode_fragment_new ();
 	{
-		GeeCollection* base_type_collection;
-		GeeIterator* base_type_it;
+		GeeList* base_type_collection;
+		int base_type_it;
 		base_type_collection = vala_class_get_base_types (self->priv->_class_reference);
-		base_type_it = gee_iterable_iterator (GEE_ITERABLE (base_type_collection));
-		while (gee_iterator_next (base_type_it)) {
+		for (base_type_it = 0; base_type_it < gee_collection_get_size (GEE_COLLECTION (base_type_collection)); base_type_it = base_type_it + 1) {
 			ValaDataType* base_type;
-			base_type = ((ValaDataType*) gee_iterator_get (base_type_it));
+			base_type = ((ValaDataType*) (gee_list_get (GEE_LIST (base_type_collection), base_type_it)));
 			{
 				ValaInterface* _tmp0;
 				ValaInterface* iface;
@@ -187,11 +303,11 @@ static ValaCCodeFragment* vala_class_register_function_real_get_type_interface_i
 				char* _tmp4;
 				char* _tmp3;
 				if (!(VALA_IS_INTERFACE (vala_data_type_get_data_type (base_type)))) {
-					(base_type == NULL ? NULL : (base_type = (g_object_unref (base_type), NULL)));
+					(base_type == NULL ? NULL : (base_type = (vala_code_node_unref (base_type), NULL)));
 					continue;
 				}
 				_tmp0 = NULL;
-				iface = (_tmp0 = VALA_INTERFACE (vala_data_type_get_data_type (base_type)), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
+				iface = (_tmp0 = VALA_INTERFACE (vala_data_type_get_data_type (base_type)), (_tmp0 == NULL ? NULL : vala_code_node_ref (_tmp0)));
 				_tmp1 = NULL;
 				_tmp2 = NULL;
 				iface_info_name = (_tmp2 = g_strdup_printf ("%s_info", (_tmp1 = vala_symbol_get_lower_case_cname (VALA_SYMBOL (iface), NULL))), (_tmp1 = (g_free (_tmp1), NULL)), _tmp2);
@@ -203,20 +319,19 @@ static ValaCCodeFragment* vala_class_register_function_real_get_type_interface_i
 				_tmp4 = NULL;
 				_tmp3 = NULL;
 				vala_ccode_declaration_add_declarator (ctypedecl, VALA_CCODE_DECLARATOR ((_tmp7 = vala_ccode_variable_declarator_new_with_initializer (iface_info_name, VALA_CCODE_EXPRESSION ((_tmp6 = vala_ccode_constant_new ((_tmp5 = g_strdup_printf ("{ (GInterfaceInitFunc) %s_%s_interface_init, (GInterfaceFinalizeFunc) NULL, NULL}", (_tmp3 = vala_symbol_get_lower_case_cname (VALA_SYMBOL (self->priv->_class_reference), NULL)), (_tmp4 = vala_symbol_get_lower_case_cname (VALA_SYMBOL (iface), NULL)))))))))));
-				(_tmp7 == NULL ? NULL : (_tmp7 = (g_object_unref (_tmp7), NULL)));
-				(_tmp6 == NULL ? NULL : (_tmp6 = (g_object_unref (_tmp6), NULL)));
+				(_tmp7 == NULL ? NULL : (_tmp7 = (vala_ccode_node_unref (_tmp7), NULL)));
+				(_tmp6 == NULL ? NULL : (_tmp6 = (vala_ccode_node_unref (_tmp6), NULL)));
 				_tmp5 = (g_free (_tmp5), NULL);
 				_tmp4 = (g_free (_tmp4), NULL);
 				_tmp3 = (g_free (_tmp3), NULL);
 				vala_ccode_fragment_append (frag, VALA_CCODE_NODE (ctypedecl));
-				(base_type == NULL ? NULL : (base_type = (g_object_unref (base_type), NULL)));
-				(iface == NULL ? NULL : (iface = (g_object_unref (iface), NULL)));
+				(base_type == NULL ? NULL : (base_type = (vala_code_node_unref (base_type), NULL)));
+				(iface == NULL ? NULL : (iface = (vala_code_node_unref (iface), NULL)));
 				iface_info_name = (g_free (iface_info_name), NULL);
-				(ctypedecl == NULL ? NULL : (ctypedecl = (g_object_unref (ctypedecl), NULL)));
+				(ctypedecl == NULL ? NULL : (ctypedecl = (vala_ccode_node_unref (ctypedecl), NULL)));
 			}
 		}
-		(base_type_collection == NULL ? NULL : (base_type_collection = (g_object_unref (base_type_collection), NULL)));
-		(base_type_it == NULL ? NULL : (base_type_it = (g_object_unref (base_type_it), NULL)));
+		(base_type_collection == NULL ? NULL : (base_type_collection = (gee_collection_object_unref (base_type_collection), NULL)));
 	}
 	return frag;
 }
@@ -228,13 +343,12 @@ static ValaCCodeFragment* vala_class_register_function_real_get_type_interface_i
 	self = VALA_CLASS_REGISTER_FUNCTION (base);
 	frag = vala_ccode_fragment_new ();
 	{
-		GeeCollection* base_type_collection;
-		GeeIterator* base_type_it;
+		GeeList* base_type_collection;
+		int base_type_it;
 		base_type_collection = vala_class_get_base_types (self->priv->_class_reference);
-		base_type_it = gee_iterable_iterator (GEE_ITERABLE (base_type_collection));
-		while (gee_iterator_next (base_type_it)) {
+		for (base_type_it = 0; base_type_it < gee_collection_get_size (GEE_COLLECTION (base_type_collection)); base_type_it = base_type_it + 1) {
 			ValaDataType* base_type;
-			base_type = ((ValaDataType*) gee_iterator_get (base_type_it));
+			base_type = ((ValaDataType*) (gee_list_get (GEE_LIST (base_type_collection), base_type_it)));
 			{
 				ValaInterface* _tmp0;
 				ValaInterface* iface;
@@ -253,45 +367,44 @@ static ValaCCodeFragment* vala_class_register_function_real_get_type_interface_i
 				char* _tmp10;
 				ValaCCodeExpressionStatement* _tmp12;
 				if (!(VALA_IS_INTERFACE (vala_data_type_get_data_type (base_type)))) {
-					(base_type == NULL ? NULL : (base_type = (g_object_unref (base_type), NULL)));
+					(base_type == NULL ? NULL : (base_type = (vala_code_node_unref (base_type), NULL)));
 					continue;
 				}
 				_tmp0 = NULL;
-				iface = (_tmp0 = VALA_INTERFACE (vala_data_type_get_data_type (base_type)), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
+				iface = (_tmp0 = VALA_INTERFACE (vala_data_type_get_data_type (base_type)), (_tmp0 == NULL ? NULL : vala_code_node_ref (_tmp0)));
 				_tmp1 = NULL;
 				_tmp2 = NULL;
 				iface_info_name = (_tmp2 = g_strdup_printf ("%s_info", (_tmp1 = vala_symbol_get_lower_case_cname (VALA_SYMBOL (iface), NULL))), (_tmp1 = (g_free (_tmp1), NULL)), _tmp2);
 				_tmp3 = NULL;
 				_tmp4 = NULL;
-				reg_call = (_tmp4 = vala_ccode_function_call_new (VALA_CCODE_EXPRESSION ((_tmp3 = vala_ccode_identifier_new ("g_type_add_interface_static")))), (_tmp3 == NULL ? NULL : (_tmp3 = (g_object_unref (_tmp3), NULL))), _tmp4);
+				reg_call = (_tmp4 = vala_ccode_function_call_new (VALA_CCODE_EXPRESSION ((_tmp3 = vala_ccode_identifier_new ("g_type_add_interface_static")))), (_tmp3 == NULL ? NULL : (_tmp3 = (vala_ccode_node_unref (_tmp3), NULL))), _tmp4);
 				_tmp7 = NULL;
 				_tmp6 = NULL;
 				_tmp5 = NULL;
 				vala_ccode_function_call_add_argument (reg_call, VALA_CCODE_EXPRESSION ((_tmp7 = vala_ccode_identifier_new ((_tmp6 = g_strdup_printf ("%s_type_id", (_tmp5 = vala_symbol_get_lower_case_cname (VALA_SYMBOL (self->priv->_class_reference), NULL))))))));
-				(_tmp7 == NULL ? NULL : (_tmp7 = (g_object_unref (_tmp7), NULL)));
+				(_tmp7 == NULL ? NULL : (_tmp7 = (vala_ccode_node_unref (_tmp7), NULL)));
 				_tmp6 = (g_free (_tmp6), NULL);
 				_tmp5 = (g_free (_tmp5), NULL);
 				_tmp9 = NULL;
 				_tmp8 = NULL;
-				vala_ccode_function_call_add_argument (reg_call, VALA_CCODE_EXPRESSION ((_tmp9 = vala_ccode_identifier_new ((_tmp8 = vala_typesymbol_get_upper_case_cname (VALA_TYPESYMBOL (iface), "TYPE_"))))));
-				(_tmp9 == NULL ? NULL : (_tmp9 = (g_object_unref (_tmp9), NULL)));
+				vala_ccode_function_call_add_argument (reg_call, VALA_CCODE_EXPRESSION ((_tmp9 = vala_ccode_identifier_new ((_tmp8 = vala_typesymbol_get_type_id (VALA_TYPESYMBOL (iface)))))));
+				(_tmp9 == NULL ? NULL : (_tmp9 = (vala_ccode_node_unref (_tmp9), NULL)));
 				_tmp8 = (g_free (_tmp8), NULL);
 				_tmp11 = NULL;
 				_tmp10 = NULL;
 				vala_ccode_function_call_add_argument (reg_call, VALA_CCODE_EXPRESSION ((_tmp11 = vala_ccode_identifier_new ((_tmp10 = g_strdup_printf ("&%s", iface_info_name))))));
-				(_tmp11 == NULL ? NULL : (_tmp11 = (g_object_unref (_tmp11), NULL)));
+				(_tmp11 == NULL ? NULL : (_tmp11 = (vala_ccode_node_unref (_tmp11), NULL)));
 				_tmp10 = (g_free (_tmp10), NULL);
 				_tmp12 = NULL;
 				vala_ccode_fragment_append (frag, VALA_CCODE_NODE ((_tmp12 = vala_ccode_expression_statement_new (VALA_CCODE_EXPRESSION (reg_call)))));
-				(_tmp12 == NULL ? NULL : (_tmp12 = (g_object_unref (_tmp12), NULL)));
-				(base_type == NULL ? NULL : (base_type = (g_object_unref (base_type), NULL)));
-				(iface == NULL ? NULL : (iface = (g_object_unref (iface), NULL)));
+				(_tmp12 == NULL ? NULL : (_tmp12 = (vala_ccode_node_unref (_tmp12), NULL)));
+				(base_type == NULL ? NULL : (base_type = (vala_code_node_unref (base_type), NULL)));
+				(iface == NULL ? NULL : (iface = (vala_code_node_unref (iface), NULL)));
 				iface_info_name = (g_free (iface_info_name), NULL);
-				(reg_call == NULL ? NULL : (reg_call = (g_object_unref (reg_call), NULL)));
+				(reg_call == NULL ? NULL : (reg_call = (vala_ccode_node_unref (reg_call), NULL)));
 			}
 		}
-		(base_type_collection == NULL ? NULL : (base_type_collection = (g_object_unref (base_type_collection), NULL)));
-		(base_type_it == NULL ? NULL : (base_type_it = (g_object_unref (base_type_it), NULL)));
+		(base_type_collection == NULL ? NULL : (base_type_collection = (gee_collection_object_unref (base_type_collection), NULL)));
 	}
 	return frag;
 }
@@ -309,40 +422,10 @@ void vala_class_register_function_set_class_reference (ValaClassRegisterFunction
 }
 
 
-static void vala_class_register_function_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
-	ValaClassRegisterFunction * self;
-	self = VALA_CLASS_REGISTER_FUNCTION (object);
-	switch (property_id) {
-		case VALA_CLASS_REGISTER_FUNCTION_CLASS_REFERENCE:
-		g_value_set_object (value, vala_class_register_function_get_class_reference (self));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
-static void vala_class_register_function_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
-	ValaClassRegisterFunction * self;
-	self = VALA_CLASS_REGISTER_FUNCTION (object);
-	switch (property_id) {
-		case VALA_CLASS_REGISTER_FUNCTION_CLASS_REFERENCE:
-		vala_class_register_function_set_class_reference (self, g_value_get_object (value));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
 static void vala_class_register_function_class_init (ValaClassRegisterFunctionClass * klass) {
 	vala_class_register_function_parent_class = g_type_class_peek_parent (klass);
+	VALA_TYPEREGISTER_FUNCTION_CLASS (klass)->finalize = vala_class_register_function_finalize;
 	g_type_class_add_private (klass, sizeof (ValaClassRegisterFunctionPrivate));
-	G_OBJECT_CLASS (klass)->get_property = vala_class_register_function_get_property;
-	G_OBJECT_CLASS (klass)->set_property = vala_class_register_function_set_property;
-	G_OBJECT_CLASS (klass)->dispose = vala_class_register_function_dispose;
 	VALA_TYPEREGISTER_FUNCTION_CLASS (klass)->get_type_declaration = vala_class_register_function_real_get_type_declaration;
 	VALA_TYPEREGISTER_FUNCTION_CLASS (klass)->get_type_struct_name = vala_class_register_function_real_get_type_struct_name;
 	VALA_TYPEREGISTER_FUNCTION_CLASS (klass)->get_base_init_func_name = vala_class_register_function_real_get_base_init_func_name;
@@ -352,28 +435,33 @@ static void vala_class_register_function_class_init (ValaClassRegisterFunctionCl
 	VALA_TYPEREGISTER_FUNCTION_CLASS (klass)->get_parent_type_name = vala_class_register_function_real_get_parent_type_name;
 	VALA_TYPEREGISTER_FUNCTION_CLASS (klass)->get_type_flags = vala_class_register_function_real_get_type_flags;
 	VALA_TYPEREGISTER_FUNCTION_CLASS (klass)->get_accessibility = vala_class_register_function_real_get_accessibility;
+	VALA_TYPEREGISTER_FUNCTION_CLASS (klass)->get_gtype_value_table_init_function_name = vala_class_register_function_real_get_gtype_value_table_init_function_name;
+	VALA_TYPEREGISTER_FUNCTION_CLASS (klass)->get_gtype_value_table_free_function_name = vala_class_register_function_real_get_gtype_value_table_free_function_name;
+	VALA_TYPEREGISTER_FUNCTION_CLASS (klass)->get_gtype_value_table_copy_function_name = vala_class_register_function_real_get_gtype_value_table_copy_function_name;
+	VALA_TYPEREGISTER_FUNCTION_CLASS (klass)->get_gtype_value_table_peek_pointer_function_name = vala_class_register_function_real_get_gtype_value_table_peek_pointer_function_name;
+	VALA_TYPEREGISTER_FUNCTION_CLASS (klass)->get_gtype_value_table_collect_value_function_name = vala_class_register_function_real_get_gtype_value_table_collect_value_function_name;
+	VALA_TYPEREGISTER_FUNCTION_CLASS (klass)->get_gtype_value_table_lcopy_value_function_name = vala_class_register_function_real_get_gtype_value_table_lcopy_value_function_name;
 	VALA_TYPEREGISTER_FUNCTION_CLASS (klass)->get_type_interface_init_declaration = vala_class_register_function_real_get_type_interface_init_declaration;
 	VALA_TYPEREGISTER_FUNCTION_CLASS (klass)->get_type_interface_init_statements = vala_class_register_function_real_get_type_interface_init_statements;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CLASS_REGISTER_FUNCTION_CLASS_REFERENCE, g_param_spec_object ("class-reference", "class-reference", "class-reference", VALA_TYPE_CLASS, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
-static void vala_class_register_function_init (ValaClassRegisterFunction * self) {
+static void vala_class_register_function_instance_init (ValaClassRegisterFunction * self) {
 	self->priv = VALA_CLASS_REGISTER_FUNCTION_GET_PRIVATE (self);
 }
 
 
-static void vala_class_register_function_dispose (GObject * obj) {
+static void vala_class_register_function_finalize (ValaTypeRegisterFunction* obj) {
 	ValaClassRegisterFunction * self;
 	self = VALA_CLASS_REGISTER_FUNCTION (obj);
-	G_OBJECT_CLASS (vala_class_register_function_parent_class)->dispose (obj);
+	VALA_TYPEREGISTER_FUNCTION_CLASS (vala_class_register_function_parent_class)->finalize (obj);
 }
 
 
 GType vala_class_register_function_get_type (void) {
 	static GType vala_class_register_function_type_id = 0;
-	if (G_UNLIKELY (vala_class_register_function_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaClassRegisterFunctionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_class_register_function_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaClassRegisterFunction), 0, (GInstanceInitFunc) vala_class_register_function_init };
+	if (vala_class_register_function_type_id == 0) {
+		static const GTypeInfo g_define_type_info = { sizeof (ValaClassRegisterFunctionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_class_register_function_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaClassRegisterFunction), 0, (GInstanceInitFunc) vala_class_register_function_instance_init, NULL };
 		vala_class_register_function_type_id = g_type_register_static (VALA_TYPE_TYPEREGISTER_FUNCTION, "ValaClassRegisterFunction", &g_define_type_info, 0);
 	}
 	return vala_class_register_function_type_id;
