@@ -45,17 +45,20 @@ G_BEGIN_DECLS
 typedef struct _ValaTypeRegisterFunction ValaTypeRegisterFunction;
 typedef struct _ValaTypeRegisterFunctionClass ValaTypeRegisterFunctionClass;
 typedef struct _ValaTypeRegisterFunctionPrivate ValaTypeRegisterFunctionPrivate;
+typedef struct _ValaParamSpecTypeRegisterFunction ValaParamSpecTypeRegisterFunction;
 
 /**
  * C function to register a type at runtime.
  */
 struct _ValaTypeRegisterFunction {
-	GObject parent_instance;
+	GTypeInstance parent_instance;
+	volatile int ref_count;
 	ValaTypeRegisterFunctionPrivate * priv;
 };
 
 struct _ValaTypeRegisterFunctionClass {
-	GObjectClass parent_class;
+	GTypeClass parent_class;
+	void (*finalize) (ValaTypeRegisterFunction *self);
 	ValaTypeSymbol* (*get_type_declaration) (ValaTypeRegisterFunction* self);
 	char* (*get_type_struct_name) (ValaTypeRegisterFunction* self);
 	char* (*get_base_init_func_name) (ValaTypeRegisterFunction* self);
@@ -63,12 +66,22 @@ struct _ValaTypeRegisterFunctionClass {
 	char* (*get_instance_struct_size) (ValaTypeRegisterFunction* self);
 	char* (*get_instance_init_func_name) (ValaTypeRegisterFunction* self);
 	char* (*get_parent_type_name) (ValaTypeRegisterFunction* self);
+	char* (*get_gtype_value_table_init_function_name) (ValaTypeRegisterFunction* self);
+	char* (*get_gtype_value_table_peek_pointer_function_name) (ValaTypeRegisterFunction* self);
+	char* (*get_gtype_value_table_free_function_name) (ValaTypeRegisterFunction* self);
+	char* (*get_gtype_value_table_copy_function_name) (ValaTypeRegisterFunction* self);
+	char* (*get_gtype_value_table_lcopy_value_function_name) (ValaTypeRegisterFunction* self);
+	char* (*get_gtype_value_table_collect_value_function_name) (ValaTypeRegisterFunction* self);
 	char* (*get_type_flags) (ValaTypeRegisterFunction* self);
 	ValaCCodeFragment* (*get_type_interface_init_declaration) (ValaTypeRegisterFunction* self);
 	ValaCCodeFragment* (*get_type_interface_init_statements) (ValaTypeRegisterFunction* self);
 	ValaSymbolAccessibility (*get_accessibility) (ValaTypeRegisterFunction* self);
 };
 
+struct _ValaParamSpecTypeRegisterFunction {
+	GParamSpec parent_instance;
+};
+
 
 void vala_typeregister_function_init_from_type (ValaTypeRegisterFunction* self, gboolean plugin);
 ValaTypeSymbol* vala_typeregister_function_get_type_declaration (ValaTypeRegisterFunction* self);
@@ -78,6 +91,12 @@ char* vala_typeregister_function_get_class_init_func_name (ValaTypeRegisterFunct
 char* vala_typeregister_function_get_instance_struct_size (ValaTypeRegisterFunction* self);
 char* vala_typeregister_function_get_instance_init_func_name (ValaTypeRegisterFunction* self);
 char* vala_typeregister_function_get_parent_type_name (ValaTypeRegisterFunction* self);
+char* vala_typeregister_function_get_gtype_value_table_init_function_name (ValaTypeRegisterFunction* self);
+char* vala_typeregister_function_get_gtype_value_table_peek_pointer_function_name (ValaTypeRegisterFunction* self);
+char* vala_typeregister_function_get_gtype_value_table_free_function_name (ValaTypeRegisterFunction* self);
+char* vala_typeregister_function_get_gtype_value_table_copy_function_name (ValaTypeRegisterFunction* self);
+char* vala_typeregister_function_get_gtype_value_table_lcopy_value_function_name (ValaTypeRegisterFunction* self);
+char* vala_typeregister_function_get_gtype_value_table_collect_value_function_name (ValaTypeRegisterFunction* self);
 char* vala_typeregister_function_get_type_flags (ValaTypeRegisterFunction* self);
 ValaCCodeFragment* vala_typeregister_function_get_type_interface_init_declaration (ValaTypeRegisterFunction* self);
 ValaCCodeFragment* vala_typeregister_function_get_type_interface_init_statements (ValaTypeRegisterFunction* self);
@@ -86,7 +105,12 @@ ValaCCodeFragment* vala_typeregister_function_get_definition (ValaTypeRegisterFu
 ValaSymbolAccessibility vala_typeregister_function_get_accessibility (ValaTypeRegisterFunction* self);
 ValaCCodeGenerator* vala_typeregister_function_get_codegen (ValaTypeRegisterFunction* self);
 void vala_typeregister_function_set_codegen (ValaTypeRegisterFunction* self, ValaCCodeGenerator* value);
+GParamSpec* vala_param_spec_typeregister_function (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
+gpointer vala_value_get_typeregister_function (const GValue* value);
+void vala_value_set_typeregister_function (GValue* value, gpointer v_object);
 GType vala_typeregister_function_get_type (void);
+gpointer vala_typeregister_function_ref (gpointer instance);
+void vala_typeregister_function_unref (gpointer instance);
 
 
 G_END_DECLS
