@@ -1,6 +1,6 @@
 /* valaarraycreationexpression.vala
  *
- * Copyright (C) 2006-2007  Raffaele Sandrini, Jürg Billeter
+ * Copyright (C) 2006-2008  Raffaele Sandrini, Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -29,6 +29,7 @@
 #include <gee/list.h>
 #include <vala/valaexpression.h>
 #include <vala/valacodenode.h>
+#include <vala/valacodebinding.h>
 
 G_BEGIN_DECLS
 
@@ -49,12 +50,15 @@ struct _ValaArrayCreationExpression {
 	ValaExpression parent_instance;
 	ValaArrayCreationExpressionPrivate * priv;
 };
+
 struct _ValaArrayCreationExpressionClass {
 	ValaExpressionClass parent_class;
 };
 
+
 void vala_array_creation_expression_append_size (ValaArrayCreationExpression* self, ValaExpression* size);
 GeeList* vala_array_creation_expression_get_sizes (ValaArrayCreationExpression* self);
+ValaArrayCreationExpression* vala_array_creation_expression_construct (GType object_type, ValaDataType* element_type, gint rank, ValaInitializerList* initializer_list, ValaSourceReference* source_reference);
 ValaArrayCreationExpression* vala_array_creation_expression_new (ValaDataType* element_type, gint rank, ValaInitializerList* initializer_list, ValaSourceReference* source_reference);
 ValaDataType* vala_array_creation_expression_get_element_type (ValaArrayCreationExpression* self);
 void vala_array_creation_expression_set_element_type (ValaArrayCreationExpression* self, ValaDataType* value);
