@@ -39,10 +39,11 @@ static gpointer vala_array_length_field_parent_class = NULL;
  *
  * @return newly created field
  */
-ValaArrayLengthField* vala_array_length_field_new (ValaSourceReference* source_reference) {
-	ValaArrayLengthField * self;
+ValaArrayLengthField* vala_array_length_field_construct (GType object_type, ValaSourceReference* source_reference) {
+	ValaArrayLengthField* self;
 	g_return_val_if_fail (VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
-	self = g_object_newv (VALA_TYPE_ARRAY_LENGTH_FIELD, 0, NULL);
+	self = ((ValaArrayLengthField*) (g_type_create_instance (object_type)));
+	vala_symbol_init (VALA_SYMBOL (VALA_FIELD (self)));
 	vala_symbol_set_name (VALA_SYMBOL (self), "length");
 	vala_symbol_set_external (VALA_SYMBOL (self), TRUE);
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
@@ -50,6 +51,11 @@ ValaArrayLengthField* vala_array_length_field_new (ValaSourceReference* source_r
 }
 
 
+ValaArrayLengthField* vala_array_length_field_new (ValaSourceReference* source_reference) {
+	return vala_array_length_field_construct (VALA_TYPE_ARRAY_LENGTH_FIELD, source_reference);
+}
+
+
 static void vala_array_length_field_class_init (ValaArrayLengthFieldClass * klass) {
 	vala_array_length_field_parent_class = g_type_class_peek_parent (klass);
 }
@@ -62,7 +68,7 @@ static void vala_array_length_field_instance_init (ValaArrayLengthField * self)
 GType vala_array_length_field_get_type (void) {
 	static GType vala_array_length_field_type_id = 0;
 	if (vala_array_length_field_type_id == 0) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaArrayLengthFieldClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_array_length_field_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaArrayLengthField), 0, (GInstanceInitFunc) vala_array_length_field_instance_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaArrayLengthFieldClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_array_length_field_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaArrayLengthField), 0, (GInstanceInitFunc) vala_array_length_field_instance_init, NULL };
 		vala_array_length_field_type_id = g_type_register_static (VALA_TYPE_FIELD, "ValaArrayLengthField", &g_define_type_info, 0);
 	}
 	return vala_array_length_field_type_id;
