@@ -49,9 +49,7 @@ struct _ValaArrayTypePrivate {
 
 #define VALA_ARRAY_TYPE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_ARRAY_TYPE, ValaArrayTypePrivate))
 enum  {
-	VALA_ARRAY_TYPE_DUMMY_PROPERTY,
-	VALA_ARRAY_TYPE_ELEMENT_TYPE,
-	VALA_ARRAY_TYPE_RANK
+	VALA_ARRAY_TYPE_DUMMY_PROPERTY
 };
 static ValaSymbol* vala_array_type_real_get_member (ValaDataType* base, const char* member_name);
 static ValaArrayLengthField* vala_array_type_get_length_field (ValaArrayType* self);
@@ -68,16 +66,16 @@ static void vala_array_type_real_accept_children (ValaCodeNode* base, ValaCodeVi
 static void vala_array_type_real_replace_type (ValaCodeNode* base, ValaDataType* old_type, ValaDataType* new_type);
 static GeeList* vala_array_type_real_get_symbols (ValaDataType* base);
 static gpointer vala_array_type_parent_class = NULL;
-static void vala_array_type_finalize (GObject * obj);
+static void vala_array_type_finalize (ValaCodeNode* obj);
 static int _vala_strcmp0 (const char * str1, const char * str2);
 
 
 
-ValaArrayType* vala_array_type_new (ValaDataType* element_type, gint rank, ValaSourceReference* source_reference) {
-	ValaArrayType * self;
+ValaArrayType* vala_array_type_construct (GType object_type, ValaDataType* element_type, gint rank, ValaSourceReference* source_reference) {
+	ValaArrayType* self;
 	g_return_val_if_fail (VALA_IS_DATA_TYPE (element_type), NULL);
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
-	self = g_object_newv (VALA_TYPE_ARRAY_TYPE, 0, NULL);
+	self = ((ValaArrayType*) (g_type_create_instance (object_type)));
 	vala_array_type_set_element_type (self, element_type);
 	vala_array_type_set_rank (self, rank);
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
@@ -85,6 +83,11 @@ ValaArrayType* vala_array_type_new (ValaDataType* element_type, gint rank, ValaS
 }
 
 
+ValaArrayType* vala_array_type_new (ValaDataType* element_type, gint rank, ValaSourceReference* source_reference) {
+	return vala_array_type_construct (VALA_TYPE_ARRAY_TYPE, element_type, rank, source_reference);
+}
+
+
 static ValaSymbol* vala_array_type_real_get_member (ValaDataType* base, const char* member_name) {
 	ValaArrayType * self;
 	self = VALA_ARRAY_TYPE (base);
@@ -112,10 +115,10 @@ static ValaArrayLengthField* vala_array_type_get_length_field (ValaArrayType* se
 		ValaNamespace* _tmp1;
 		ValaNamespace* root_symbol;
 		_tmp0 = NULL;
-		self->priv->length_field = (_tmp0 = vala_array_length_field_new (vala_code_node_get_source_reference (VALA_CODE_NODE (self))), (self->priv->length_field == NULL ? NULL : (self->priv->length_field = (g_object_unref (self->priv->length_field), NULL))), _tmp0);
+		self->priv->length_field = (_tmp0 = vala_array_length_field_new (vala_code_node_get_source_reference (VALA_CODE_NODE (self))), (self->priv->length_field == NULL ? NULL : (self->priv->length_field = (vala_code_node_unref (self->priv->length_field), NULL))), _tmp0);
 		vala_symbol_set_access (VALA_SYMBOL (self->priv->length_field), VALA_SYMBOL_ACCESSIBILITY_PUBLIC);
 		_tmp1 = NULL;
-		root_symbol = (_tmp1 = vala_code_context_get_root (vala_source_file_get_context (vala_source_reference_get_file (vala_code_node_get_source_reference (VALA_CODE_NODE (self))))), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
+		root_symbol = (_tmp1 = vala_code_context_get_root (vala_source_file_get_context (vala_source_reference_get_file (vala_code_node_get_source_reference (VALA_CODE_NODE (self))))), (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1)));
 		if (self->priv->_rank > 1) {
 			ValaTypeSymbol* _tmp2;
 			ValaValueType* _tmp3;
@@ -124,24 +127,24 @@ static ValaArrayLengthField* vala_array_type_get_length_field (ValaArrayType* se
 			/* length is an int[] containing the dimensions of the array, starting at 0*/
 			_tmp2 = NULL;
 			_tmp3 = NULL;
-			integer = (_tmp3 = vala_value_type_new ((_tmp2 = VALA_TYPESYMBOL (vala_scope_lookup (vala_symbol_get_scope (VALA_SYMBOL (root_symbol)), "int")))), (_tmp2 == NULL ? NULL : (_tmp2 = (g_object_unref (_tmp2), NULL))), _tmp3);
+			integer = (_tmp3 = vala_value_type_new ((_tmp2 = VALA_TYPESYMBOL (vala_scope_lookup (vala_symbol_get_scope (VALA_SYMBOL (root_symbol)), "int")))), (_tmp2 == NULL ? NULL : (_tmp2 = (vala_code_node_unref (_tmp2), NULL))), _tmp3);
 			_tmp4 = NULL;
 			vala_field_set_field_type (VALA_FIELD (self->priv->length_field), VALA_DATA_TYPE ((_tmp4 = vala_array_type_new (VALA_DATA_TYPE (integer), 1, vala_code_node_get_source_reference (VALA_CODE_NODE (self))))));
-			(_tmp4 == NULL ? NULL : (_tmp4 = (g_object_unref (_tmp4), NULL)));
-			(integer == NULL ? NULL : (integer = (g_object_unref (integer), NULL)));
+			(_tmp4 == NULL ? NULL : (_tmp4 = (vala_code_node_unref (_tmp4), NULL)));
+			(integer == NULL ? NULL : (integer = (vala_code_node_unref (integer), NULL)));
 		} else {
 			ValaValueType* _tmp6;
 			ValaTypeSymbol* _tmp5;
 			_tmp6 = NULL;
 			_tmp5 = NULL;
 			vala_field_set_field_type (VALA_FIELD (self->priv->length_field), VALA_DATA_TYPE ((_tmp6 = vala_value_type_new ((_tmp5 = VALA_TYPESYMBOL (vala_scope_lookup (vala_symbol_get_scope (VALA_SYMBOL (root_symbol)), "int")))))));
-			(_tmp6 == NULL ? NULL : (_tmp6 = (g_object_unref (_tmp6), NULL)));
-			(_tmp5 == NULL ? NULL : (_tmp5 = (g_object_unref (_tmp5), NULL)));
+			(_tmp6 == NULL ? NULL : (_tmp6 = (vala_code_node_unref (_tmp6), NULL)));
+			(_tmp5 == NULL ? NULL : (_tmp5 = (vala_code_node_unref (_tmp5), NULL)));
 		}
-		(root_symbol == NULL ? NULL : (root_symbol = (g_object_unref (root_symbol), NULL)));
+		(root_symbol == NULL ? NULL : (root_symbol = (vala_code_node_unref (root_symbol), NULL)));
 	}
 	_tmp7 = NULL;
-	return (_tmp7 = self->priv->length_field, (_tmp7 == NULL ? NULL : g_object_ref (_tmp7)));
+	return (_tmp7 = self->priv->length_field, (_tmp7 == NULL ? NULL : vala_code_node_ref (_tmp7)));
 }
 
 
@@ -158,26 +161,26 @@ static ValaArrayResizeMethod* vala_array_type_get_resize_method (ValaArrayType*
 		ValaValueType* int_type;
 		ValaFormalParameter* _tmp5;
 		_tmp0 = NULL;
-		self->priv->resize_method = (_tmp0 = vala_array_resize_method_new (vala_code_node_get_source_reference (VALA_CODE_NODE (self))), (self->priv->resize_method == NULL ? NULL : (self->priv->resize_method = (g_object_unref (self->priv->resize_method), NULL))), _tmp0);
+		self->priv->resize_method = (_tmp0 = vala_array_resize_method_new (vala_code_node_get_source_reference (VALA_CODE_NODE (self))), (self->priv->resize_method == NULL ? NULL : (self->priv->resize_method = (vala_code_node_unref (self->priv->resize_method), NULL))), _tmp0);
 		_tmp1 = NULL;
 		vala_method_set_return_type (VALA_METHOD (self->priv->resize_method), VALA_DATA_TYPE ((_tmp1 = vala_void_type_new ())));
-		(_tmp1 == NULL ? NULL : (_tmp1 = (g_object_unref (_tmp1), NULL)));
+		(_tmp1 == NULL ? NULL : (_tmp1 = (vala_code_node_unref (_tmp1), NULL)));
 		vala_symbol_set_access (VALA_SYMBOL (self->priv->resize_method), VALA_SYMBOL_ACCESSIBILITY_PUBLIC);
 		vala_method_set_cname (VALA_METHOD (self->priv->resize_method), "g_renew");
 		_tmp2 = NULL;
-		root_symbol = (_tmp2 = vala_code_context_get_root (vala_source_file_get_context (vala_source_reference_get_file (vala_code_node_get_source_reference (VALA_CODE_NODE (self))))), (_tmp2 == NULL ? NULL : g_object_ref (_tmp2)));
+		root_symbol = (_tmp2 = vala_code_context_get_root (vala_source_file_get_context (vala_source_reference_get_file (vala_code_node_get_source_reference (VALA_CODE_NODE (self))))), (_tmp2 == NULL ? NULL : vala_code_node_ref (_tmp2)));
 		_tmp3 = NULL;
 		_tmp4 = NULL;
-		int_type = (_tmp4 = vala_value_type_new ((_tmp3 = VALA_TYPESYMBOL (vala_scope_lookup (vala_symbol_get_scope (VALA_SYMBOL (root_symbol)), "int")))), (_tmp3 == NULL ? NULL : (_tmp3 = (g_object_unref (_tmp3), NULL))), _tmp4);
+		int_type = (_tmp4 = vala_value_type_new ((_tmp3 = VALA_TYPESYMBOL (vala_scope_lookup (vala_symbol_get_scope (VALA_SYMBOL (root_symbol)), "int")))), (_tmp3 == NULL ? NULL : (_tmp3 = (vala_code_node_unref (_tmp3), NULL))), _tmp4);
 		_tmp5 = NULL;
 		vala_method_add_parameter (VALA_METHOD (self->priv->resize_method), (_tmp5 = vala_formal_parameter_new ("length", VALA_DATA_TYPE (int_type), NULL)));
-		(_tmp5 == NULL ? NULL : (_tmp5 = (g_object_unref (_tmp5), NULL)));
+		(_tmp5 == NULL ? NULL : (_tmp5 = (vala_code_node_unref (_tmp5), NULL)));
 		vala_method_set_returns_modified_pointer (VALA_METHOD (self->priv->resize_method), TRUE);
-		(root_symbol == NULL ? NULL : (root_symbol = (g_object_unref (root_symbol), NULL)));
-		(int_type == NULL ? NULL : (int_type = (g_object_unref (int_type), NULL)));
+		(root_symbol == NULL ? NULL : (root_symbol = (vala_code_node_unref (root_symbol), NULL)));
+		(int_type == NULL ? NULL : (int_type = (vala_code_node_unref (int_type), NULL)));
 	}
 	_tmp6 = NULL;
-	return (_tmp6 = self->priv->resize_method, (_tmp6 == NULL ? NULL : g_object_ref (_tmp6)));
+	return (_tmp6 = self->priv->resize_method, (_tmp6 == NULL ? NULL : vala_code_node_ref (_tmp6)));
 }
 
 
@@ -196,31 +199,31 @@ static ValaArrayMoveMethod* vala_array_type_get_move_method (ValaArrayType* self
 		ValaFormalParameter* _tmp6;
 		ValaFormalParameter* _tmp7;
 		_tmp0 = NULL;
-		self->priv->move_method = (_tmp0 = vala_array_move_method_new (vala_code_node_get_source_reference (VALA_CODE_NODE (self))), (self->priv->move_method == NULL ? NULL : (self->priv->move_method = (g_object_unref (self->priv->move_method), NULL))), _tmp0);
+		self->priv->move_method = (_tmp0 = vala_array_move_method_new (vala_code_node_get_source_reference (VALA_CODE_NODE (self))), (self->priv->move_method == NULL ? NULL : (self->priv->move_method = (vala_code_node_unref (self->priv->move_method), NULL))), _tmp0);
 		_tmp1 = NULL;
 		vala_method_set_return_type (VALA_METHOD (self->priv->move_method), VALA_DATA_TYPE ((_tmp1 = vala_void_type_new ())));
-		(_tmp1 == NULL ? NULL : (_tmp1 = (g_object_unref (_tmp1), NULL)));
+		(_tmp1 == NULL ? NULL : (_tmp1 = (vala_code_node_unref (_tmp1), NULL)));
 		vala_symbol_set_access (VALA_SYMBOL (self->priv->move_method), VALA_SYMBOL_ACCESSIBILITY_PUBLIC);
 		vala_method_set_cname (VALA_METHOD (self->priv->move_method), "_vala_array_move");
 		_tmp2 = NULL;
-		root_symbol = (_tmp2 = vala_code_context_get_root (vala_source_file_get_context (vala_source_reference_get_file (vala_code_node_get_source_reference (VALA_CODE_NODE (self))))), (_tmp2 == NULL ? NULL : g_object_ref (_tmp2)));
+		root_symbol = (_tmp2 = vala_code_context_get_root (vala_source_file_get_context (vala_source_reference_get_file (vala_code_node_get_source_reference (VALA_CODE_NODE (self))))), (_tmp2 == NULL ? NULL : vala_code_node_ref (_tmp2)));
 		_tmp3 = NULL;
 		_tmp4 = NULL;
-		int_type = (_tmp4 = vala_value_type_new ((_tmp3 = VALA_TYPESYMBOL (vala_scope_lookup (vala_symbol_get_scope (VALA_SYMBOL (root_symbol)), "int")))), (_tmp3 == NULL ? NULL : (_tmp3 = (g_object_unref (_tmp3), NULL))), _tmp4);
+		int_type = (_tmp4 = vala_value_type_new ((_tmp3 = VALA_TYPESYMBOL (vala_scope_lookup (vala_symbol_get_scope (VALA_SYMBOL (root_symbol)), "int")))), (_tmp3 == NULL ? NULL : (_tmp3 = (vala_code_node_unref (_tmp3), NULL))), _tmp4);
 		_tmp5 = NULL;
 		vala_method_add_parameter (VALA_METHOD (self->priv->move_method), (_tmp5 = vala_formal_parameter_new ("src", VALA_DATA_TYPE (int_type), NULL)));
-		(_tmp5 == NULL ? NULL : (_tmp5 = (g_object_unref (_tmp5), NULL)));
+		(_tmp5 == NULL ? NULL : (_tmp5 = (vala_code_node_unref (_tmp5), NULL)));
 		_tmp6 = NULL;
 		vala_method_add_parameter (VALA_METHOD (self->priv->move_method), (_tmp6 = vala_formal_parameter_new ("dest", VALA_DATA_TYPE (int_type), NULL)));
-		(_tmp6 == NULL ? NULL : (_tmp6 = (g_object_unref (_tmp6), NULL)));
+		(_tmp6 == NULL ? NULL : (_tmp6 = (vala_code_node_unref (_tmp6), NULL)));
 		_tmp7 = NULL;
 		vala_method_add_parameter (VALA_METHOD (self->priv->move_method), (_tmp7 = vala_formal_parameter_new ("length", VALA_DATA_TYPE (int_type), NULL)));
-		(_tmp7 == NULL ? NULL : (_tmp7 = (g_object_unref (_tmp7), NULL)));
-		(root_symbol == NULL ? NULL : (root_symbol = (g_object_unref (root_symbol), NULL)));
-		(int_type == NULL ? NULL : (int_type = (g_object_unref (int_type), NULL)));
+		(_tmp7 == NULL ? NULL : (_tmp7 = (vala_code_node_unref (_tmp7), NULL)));
+		(root_symbol == NULL ? NULL : (root_symbol = (vala_code_node_unref (root_symbol), NULL)));
+		(int_type == NULL ? NULL : (int_type = (vala_code_node_unref (int_type), NULL)));
 	}
 	_tmp8 = NULL;
-	return (_tmp8 = self->priv->move_method, (_tmp8 == NULL ? NULL : g_object_ref (_tmp8)));
+	return (_tmp8 = self->priv->move_method, (_tmp8 == NULL ? NULL : vala_code_node_ref (_tmp8)));
 }
 
 
@@ -232,7 +235,7 @@ static ValaDataType* vala_array_type_real_copy (ValaDataType* base) {
 	self = VALA_ARRAY_TYPE (base);
 	_tmp0 = NULL;
 	_tmp1 = NULL;
-	result = (_tmp1 = vala_array_type_new ((_tmp0 = vala_data_type_copy (vala_array_type_get_element_type (self))), self->priv->_rank, vala_code_node_get_source_reference (VALA_CODE_NODE (self))), (_tmp0 == NULL ? NULL : (_tmp0 = (g_object_unref (_tmp0), NULL))), _tmp1);
+	result = (_tmp1 = vala_array_type_new ((_tmp0 = vala_data_type_copy (vala_array_type_get_element_type (self))), self->priv->_rank, vala_code_node_get_source_reference (VALA_CODE_NODE (self))), (_tmp0 == NULL ? NULL : (_tmp0 = (vala_code_node_unref (_tmp0), NULL))), _tmp1);
 	vala_data_type_set_value_owned (VALA_DATA_TYPE (result), vala_data_type_get_value_owned (VALA_DATA_TYPE (self)));
 	vala_data_type_set_nullable (VALA_DATA_TYPE (result), vala_data_type_get_nullable (VALA_DATA_TYPE (self)));
 	vala_data_type_set_floating_reference (VALA_DATA_TYPE (result), vala_data_type_get_floating_reference (VALA_DATA_TYPE (self)));
@@ -269,7 +272,7 @@ static char* vala_array_type_real_to_qualified_string (ValaDataType* base, ValaS
 	_tmp1 = NULL;
 	_tmp0 = NULL;
 	_tmp2 = NULL;
-	return (_tmp2 = g_strdup_printf ("%s[%s]", (_tmp0 = vala_data_type_to_qualified_string (vala_array_type_get_element_type (self), scope)), (_tmp1 = g_strnfill (((gulong) (self->priv->_rank - 1)), ','))), (_tmp1 = (g_free (_tmp1), NULL)), (_tmp0 = (g_free (_tmp0), NULL)), _tmp2);
+	return (_tmp2 = g_strdup_printf ("%s[%s]%s", (_tmp0 = vala_data_type_to_qualified_string (vala_array_type_get_element_type (self), scope)), (_tmp1 = g_strnfill (((gulong) (self->priv->_rank - 1)), ',')), (vala_data_type_get_nullable (VALA_DATA_TYPE (self)) ? "?" : "")), (_tmp1 = (g_free (_tmp1), NULL)), (_tmp0 = (g_free (_tmp0), NULL)), _tmp2);
 }
 
 
@@ -284,7 +287,7 @@ static gboolean vala_array_type_real_compatible (ValaDataType* base, ValaDataTyp
 	self = VALA_ARRAY_TYPE (base);
 	g_return_val_if_fail (VALA_IS_DATA_TYPE (target_type), FALSE);
 	_tmp0 = NULL;
-	if ((_tmp1 = VALA_IS_POINTER_TYPE (target_type) || (vala_data_type_get_data_type (target_type) != NULL && (_tmp0 = vala_code_node_get_attribute (VALA_CODE_NODE (vala_data_type_get_data_type (target_type)), "PointerType")) != NULL), (_tmp0 == NULL ? NULL : (_tmp0 = (g_object_unref (_tmp0), NULL))), _tmp1)) {
+	if ((_tmp1 = VALA_IS_POINTER_TYPE (target_type) || (vala_data_type_get_data_type (target_type) != NULL && (_tmp0 = vala_code_node_get_attribute (VALA_CODE_NODE (vala_data_type_get_data_type (target_type)), "PointerType")) != NULL), (_tmp0 == NULL ? NULL : (_tmp0 = (vala_code_node_unref (_tmp0), NULL))), _tmp1)) {
 		/* any array type can be cast to a generic pointer */
 		return TRUE;
 	}
@@ -294,16 +297,16 @@ static gboolean vala_array_type_real_compatible (ValaDataType* base, ValaDataTyp
 	}
 	_tmp5 = NULL;
 	_tmp4 = NULL;
-	target_array_type = (_tmp5 = (_tmp4 = target_type, (VALA_IS_ARRAY_TYPE (_tmp4) ? ((ValaArrayType*) (_tmp4)) : NULL)), (_tmp5 == NULL ? NULL : g_object_ref (_tmp5)));
+	target_array_type = (_tmp5 = (_tmp4 = target_type, (VALA_IS_ARRAY_TYPE (_tmp4) ? ((ValaArrayType*) (_tmp4)) : NULL)), (_tmp5 == NULL ? NULL : vala_code_node_ref (_tmp5)));
 	if (target_array_type == NULL) {
 		gboolean _tmp6;
-		return (_tmp6 = FALSE, (target_array_type == NULL ? NULL : (target_array_type = (g_object_unref (target_array_type), NULL))), _tmp6);
+		return (_tmp6 = FALSE, (target_array_type == NULL ? NULL : (target_array_type = (vala_code_node_unref (target_array_type), NULL))), _tmp6);
 	}
 	if (vala_data_type_compatible (vala_array_type_get_element_type (self), vala_array_type_get_element_type (target_array_type)) && vala_data_type_compatible (vala_array_type_get_element_type (target_array_type), vala_array_type_get_element_type (self))) {
 		gboolean _tmp7;
-		return (_tmp7 = TRUE, (target_array_type == NULL ? NULL : (target_array_type = (g_object_unref (target_array_type), NULL))), _tmp7);
+		return (_tmp7 = TRUE, (target_array_type == NULL ? NULL : (target_array_type = (vala_code_node_unref (target_array_type), NULL))), _tmp7);
 	}
-	return (_tmp8 = FALSE, (target_array_type == NULL ? NULL : (target_array_type = (g_object_unref (target_array_type), NULL))), _tmp8);
+	return (_tmp8 = FALSE, (target_array_type == NULL ? NULL : (target_array_type = (vala_code_node_unref (target_array_type), NULL))), _tmp8);
 }
 
 
@@ -368,9 +371,8 @@ void vala_array_type_set_element_type (ValaArrayType* self, ValaDataType* value)
 	g_return_if_fail (VALA_IS_ARRAY_TYPE (self));
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_element_type = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_element_type == NULL ? NULL : (self->priv->_element_type = (g_object_unref (self->priv->_element_type), NULL))), _tmp2);
+	self->priv->_element_type = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1))), (self->priv->_element_type == NULL ? NULL : (self->priv->_element_type = (vala_code_node_unref (self->priv->_element_type), NULL))), _tmp2);
 	vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_element_type), VALA_CODE_NODE (self));
-	g_object_notify (((GObject *) (self)), "element-type");
 }
 
 
@@ -383,50 +385,13 @@ gint vala_array_type_get_rank (ValaArrayType* self) {
 void vala_array_type_set_rank (ValaArrayType* self, gint value) {
 	g_return_if_fail (VALA_IS_ARRAY_TYPE (self));
 	self->priv->_rank = value;
-	g_object_notify (((GObject *) (self)), "rank");
-}
-
-
-static void vala_array_type_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
-	ValaArrayType * self;
-	self = VALA_ARRAY_TYPE (object);
-	switch (property_id) {
-		case VALA_ARRAY_TYPE_ELEMENT_TYPE:
-		g_value_set_object (value, vala_array_type_get_element_type (self));
-		break;
-		case VALA_ARRAY_TYPE_RANK:
-		g_value_set_int (value, vala_array_type_get_rank (self));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
-static void vala_array_type_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
-	ValaArrayType * self;
-	self = VALA_ARRAY_TYPE (object);
-	switch (property_id) {
-		case VALA_ARRAY_TYPE_ELEMENT_TYPE:
-		vala_array_type_set_element_type (self, g_value_get_object (value));
-		break;
-		case VALA_ARRAY_TYPE_RANK:
-		vala_array_type_set_rank (self, g_value_get_int (value));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
 }
 
 
 static void vala_array_type_class_init (ValaArrayTypeClass * klass) {
 	vala_array_type_parent_class = g_type_class_peek_parent (klass);
+	VALA_CODE_NODE_CLASS (klass)->finalize = vala_array_type_finalize;
 	g_type_class_add_private (klass, sizeof (ValaArrayTypePrivate));
-	G_OBJECT_CLASS (klass)->get_property = vala_array_type_get_property;
-	G_OBJECT_CLASS (klass)->set_property = vala_array_type_set_property;
-	G_OBJECT_CLASS (klass)->finalize = vala_array_type_finalize;
 	VALA_DATA_TYPE_CLASS (klass)->get_member = vala_array_type_real_get_member;
 	VALA_DATA_TYPE_CLASS (klass)->copy = vala_array_type_real_copy;
 	VALA_DATA_TYPE_CLASS (klass)->get_cname = vala_array_type_real_get_cname;
@@ -438,8 +403,6 @@ static void vala_array_type_class_init (ValaArrayTypeClass * klass) {
 	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_array_type_real_accept_children;
 	VALA_CODE_NODE_CLASS (klass)->replace_type = vala_array_type_real_replace_type;
 	VALA_DATA_TYPE_CLASS (klass)->get_symbols = vala_array_type_real_get_symbols;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_ARRAY_TYPE_ELEMENT_TYPE, g_param_spec_object ("element-type", "element-type", "element-type", VALA_TYPE_DATA_TYPE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_ARRAY_TYPE_RANK, g_param_spec_int ("rank", "rank", "rank", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
@@ -448,21 +411,21 @@ static void vala_array_type_instance_init (ValaArrayType * self) {
 }
 
 
-static void vala_array_type_finalize (GObject * obj) {
+static void vala_array_type_finalize (ValaCodeNode* obj) {
 	ValaArrayType * self;
 	self = VALA_ARRAY_TYPE (obj);
-	(self->priv->_element_type == NULL ? NULL : (self->priv->_element_type = (g_object_unref (self->priv->_element_type), NULL)));
-	(self->priv->length_field == NULL ? NULL : (self->priv->length_field = (g_object_unref (self->priv->length_field), NULL)));
-	(self->priv->resize_method == NULL ? NULL : (self->priv->resize_method = (g_object_unref (self->priv->resize_method), NULL)));
-	(self->priv->move_method == NULL ? NULL : (self->priv->move_method = (g_object_unref (self->priv->move_method), NULL)));
-	G_OBJECT_CLASS (vala_array_type_parent_class)->finalize (obj);
+	(self->priv->_element_type == NULL ? NULL : (self->priv->_element_type = (vala_code_node_unref (self->priv->_element_type), NULL)));
+	(self->priv->length_field == NULL ? NULL : (self->priv->length_field = (vala_code_node_unref (self->priv->length_field), NULL)));
+	(self->priv->resize_method == NULL ? NULL : (self->priv->resize_method = (vala_code_node_unref (self->priv->resize_method), NULL)));
+	(self->priv->move_method == NULL ? NULL : (self->priv->move_method = (vala_code_node_unref (self->priv->move_method), NULL)));
+	VALA_CODE_NODE_CLASS (vala_array_type_parent_class)->finalize (obj);
 }
 
 
 GType vala_array_type_get_type (void) {
 	static GType vala_array_type_type_id = 0;
 	if (vala_array_type_type_id == 0) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaArrayTypeClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_array_type_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaArrayType), 0, (GInstanceInitFunc) vala_array_type_instance_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaArrayTypeClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_array_type_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaArrayType), 0, (GInstanceInitFunc) vala_array_type_instance_init, NULL };
 		vala_array_type_type_id = g_type_register_static (VALA_TYPE_REFERENCE_TYPE, "ValaArrayType", &g_define_type_info, 0);
 	}
 	return vala_array_type_type_id;
