@@ -43,15 +43,20 @@ static gpointer vala_base_access_parent_class = NULL;
  * @param source reference to source code
  * @return       newly created base access expression
  */
-ValaBaseAccess* vala_base_access_new (ValaSourceReference* source) {
-	ValaBaseAccess * self;
+ValaBaseAccess* vala_base_access_construct (GType object_type, ValaSourceReference* source) {
+	ValaBaseAccess* self;
 	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
-	self = g_object_newv (VALA_TYPE_BASE_ACCESS, 0, NULL);
+	self = ((ValaBaseAccess*) (g_type_create_instance (object_type)));
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source);
 	return self;
 }
 
 
+ValaBaseAccess* vala_base_access_new (ValaSourceReference* source) {
+	return vala_base_access_construct (VALA_TYPE_BASE_ACCESS, source);
+}
+
+
 static void vala_base_access_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaBaseAccess * self;
 	self = VALA_BASE_ACCESS (base);
@@ -90,7 +95,7 @@ static void vala_base_access_instance_init (ValaBaseAccess * self) {
 GType vala_base_access_get_type (void) {
 	static GType vala_base_access_type_id = 0;
 	if (vala_base_access_type_id == 0) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaBaseAccessClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_base_access_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaBaseAccess), 0, (GInstanceInitFunc) vala_base_access_instance_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaBaseAccessClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_base_access_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaBaseAccess), 0, (GInstanceInitFunc) vala_base_access_instance_init, NULL };
 		vala_base_access_type_id = g_type_register_static (VALA_TYPE_EXPRESSION, "ValaBaseAccess", &g_define_type_info, 0);
 	}
 	return vala_base_access_type_id;
