@@ -42,15 +42,20 @@ static ValaStatementIface* vala_break_statement_vala_statement_parent_iface = NU
  * @param source reference to source code
  * @return       newly created break statement
  */
-ValaBreakStatement* vala_break_statement_new (ValaSourceReference* source) {
-	ValaBreakStatement * self;
+ValaBreakStatement* vala_break_statement_construct (GType object_type, ValaSourceReference* source) {
+	ValaBreakStatement* self;
 	g_return_val_if_fail (VALA_IS_SOURCE_REFERENCE (source), NULL);
-	self = g_object_newv (VALA_TYPE_BREAK_STATEMENT, 0, NULL);
+	self = ((ValaBreakStatement*) (g_type_create_instance (object_type)));
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source);
 	return self;
 }
 
 
+ValaBreakStatement* vala_break_statement_new (ValaSourceReference* source) {
+	return vala_break_statement_construct (VALA_TYPE_BREAK_STATEMENT, source);
+}
+
+
 static void vala_break_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaBreakStatement * self;
 	self = VALA_BREAK_STATEMENT (base);
@@ -76,8 +81,8 @@ static void vala_break_statement_instance_init (ValaBreakStatement * self) {
 
 GType vala_break_statement_get_type (void) {
 	static GType vala_break_statement_type_id = 0;
-	if (G_UNLIKELY (vala_break_statement_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaBreakStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_break_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaBreakStatement), 0, (GInstanceInitFunc) vala_break_statement_instance_init };
+	if (vala_break_statement_type_id == 0) {
+		static const GTypeInfo g_define_type_info = { sizeof (ValaBreakStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_break_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaBreakStatement), 0, (GInstanceInitFunc) vala_break_statement_instance_init, NULL };
 		static const GInterfaceInfo vala_statement_info = { (GInterfaceInitFunc) vala_break_statement_vala_statement_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
 		vala_break_statement_type_id = g_type_register_static (VALA_TYPE_CODE_NODE, "ValaBreakStatement", &g_define_type_info, 0);
 		g_type_add_interface_static (vala_break_statement_type_id, VALA_TYPE_STATEMENT, &vala_statement_info);
