@@ -36,17 +36,14 @@ struct _ValaCastExpressionPrivate {
 
 #define VALA_CAST_EXPRESSION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CAST_EXPRESSION, ValaCastExpressionPrivate))
 enum  {
-	VALA_CAST_EXPRESSION_DUMMY_PROPERTY,
-	VALA_CAST_EXPRESSION_INNER,
-	VALA_CAST_EXPRESSION_TYPE_REFERENCE,
-	VALA_CAST_EXPRESSION_IS_SILENT_CAST
+	VALA_CAST_EXPRESSION_DUMMY_PROPERTY
 };
 static void vala_cast_expression_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_cast_expression_real_replace_expression (ValaCodeNode* base, ValaExpression* old_node, ValaExpression* new_node);
 static gboolean vala_cast_expression_real_is_pure (ValaExpression* base);
 static void vala_cast_expression_real_replace_type (ValaCodeNode* base, ValaDataType* old_type, ValaDataType* new_type);
 static gpointer vala_cast_expression_parent_class = NULL;
-static void vala_cast_expression_finalize (GObject * obj);
+static void vala_cast_expression_finalize (ValaCodeNode* obj);
 
 
 
@@ -57,35 +54,25 @@ static void vala_cast_expression_finalize (GObject * obj);
  * @param type  target type
  * @return      newly created cast expression
  */
-ValaCastExpression* vala_cast_expression_new (ValaExpression* inner, ValaDataType* type_reference, ValaSourceReference* source_reference, gboolean is_silent_cast) {
-	GParameter * __params;
-	GParameter * __params_it;
-	ValaCastExpression * self;
+ValaCastExpression* vala_cast_expression_construct (GType object_type, ValaExpression* inner, ValaDataType* type_reference, ValaSourceReference* source_reference, gboolean is_silent_cast) {
+	ValaCastExpression* self;
 	g_return_val_if_fail (VALA_IS_EXPRESSION (inner), NULL);
 	g_return_val_if_fail (VALA_IS_DATA_TYPE (type_reference), NULL);
 	g_return_val_if_fail (VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
-	__params = g_new0 (GParameter, 2);
-	__params_it = __params;
-	__params_it->name = "is-silent-cast";
-	g_value_init (&__params_it->value, G_TYPE_BOOLEAN);
-	g_value_set_boolean (&__params_it->value, is_silent_cast);
-	__params_it++;
-	__params_it->name = "inner";
-	g_value_init (&__params_it->value, VALA_TYPE_EXPRESSION);
-	g_value_set_object (&__params_it->value, inner);
-	__params_it++;
-	self = g_object_newv (VALA_TYPE_CAST_EXPRESSION, __params_it - __params, __params);
+	self = ((ValaCastExpression*) (g_type_create_instance (object_type)));
 	vala_cast_expression_set_type_reference (self, type_reference);
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
-	while (__params_it > __params) {
-		--__params_it;
-		g_value_unset (&__params_it->value);
-	}
-	g_free (__params);
+	vala_cast_expression_set_is_silent_cast (self, is_silent_cast);
+	vala_cast_expression_set_inner (self, inner);
 	return self;
 }
 
 
+ValaCastExpression* vala_cast_expression_new (ValaExpression* inner, ValaDataType* type_reference, ValaSourceReference* source_reference, gboolean is_silent_cast) {
+	return vala_cast_expression_construct (VALA_TYPE_CAST_EXPRESSION, inner, type_reference, source_reference, is_silent_cast);
+}
+
+
 static void vala_cast_expression_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaCastExpression * self;
 	self = VALA_CAST_EXPRESSION (base);
@@ -138,9 +125,8 @@ void vala_cast_expression_set_inner (ValaCastExpression* self, ValaExpression* v
 	g_return_if_fail (VALA_IS_CAST_EXPRESSION (self));
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_inner = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_inner == NULL ? NULL : (self->priv->_inner = (g_object_unref (self->priv->_inner), NULL))), _tmp2);
+	self->priv->_inner = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1))), (self->priv->_inner == NULL ? NULL : (self->priv->_inner = (vala_code_node_unref (self->priv->_inner), NULL))), _tmp2);
 	vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_inner), VALA_CODE_NODE (self));
-	g_object_notify (((GObject *) (self)), "inner");
 }
 
 
@@ -156,9 +142,8 @@ void vala_cast_expression_set_type_reference (ValaCastExpression* self, ValaData
 	g_return_if_fail (VALA_IS_CAST_EXPRESSION (self));
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_data_type = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_data_type == NULL ? NULL : (self->priv->_data_type = (g_object_unref (self->priv->_data_type), NULL))), _tmp2);
+	self->priv->_data_type = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1))), (self->priv->_data_type == NULL ? NULL : (self->priv->_data_type = (vala_code_node_unref (self->priv->_data_type), NULL))), _tmp2);
 	vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_data_type), VALA_CODE_NODE (self));
-	g_object_notify (((GObject *) (self)), "type-reference");
 }
 
 
@@ -171,63 +156,17 @@ gboolean vala_cast_expression_get_is_silent_cast (ValaCastExpression* self) {
 void vala_cast_expression_set_is_silent_cast (ValaCastExpression* self, gboolean value) {
 	g_return_if_fail (VALA_IS_CAST_EXPRESSION (self));
 	self->priv->_is_silent_cast = value;
-	g_object_notify (((GObject *) (self)), "is-silent-cast");
-}
-
-
-static void vala_cast_expression_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
-	ValaCastExpression * self;
-	self = VALA_CAST_EXPRESSION (object);
-	switch (property_id) {
-		case VALA_CAST_EXPRESSION_INNER:
-		g_value_set_object (value, vala_cast_expression_get_inner (self));
-		break;
-		case VALA_CAST_EXPRESSION_TYPE_REFERENCE:
-		g_value_set_object (value, vala_cast_expression_get_type_reference (self));
-		break;
-		case VALA_CAST_EXPRESSION_IS_SILENT_CAST:
-		g_value_set_boolean (value, vala_cast_expression_get_is_silent_cast (self));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
-static void vala_cast_expression_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
-	ValaCastExpression * self;
-	self = VALA_CAST_EXPRESSION (object);
-	switch (property_id) {
-		case VALA_CAST_EXPRESSION_INNER:
-		vala_cast_expression_set_inner (self, g_value_get_object (value));
-		break;
-		case VALA_CAST_EXPRESSION_TYPE_REFERENCE:
-		vala_cast_expression_set_type_reference (self, g_value_get_object (value));
-		break;
-		case VALA_CAST_EXPRESSION_IS_SILENT_CAST:
-		vala_cast_expression_set_is_silent_cast (self, g_value_get_boolean (value));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
 }
 
 
 static void vala_cast_expression_class_init (ValaCastExpressionClass * klass) {
 	vala_cast_expression_parent_class = g_type_class_peek_parent (klass);
+	VALA_CODE_NODE_CLASS (klass)->finalize = vala_cast_expression_finalize;
 	g_type_class_add_private (klass, sizeof (ValaCastExpressionPrivate));
-	G_OBJECT_CLASS (klass)->get_property = vala_cast_expression_get_property;
-	G_OBJECT_CLASS (klass)->set_property = vala_cast_expression_set_property;
-	G_OBJECT_CLASS (klass)->finalize = vala_cast_expression_finalize;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_cast_expression_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->replace_expression = vala_cast_expression_real_replace_expression;
 	VALA_EXPRESSION_CLASS (klass)->is_pure = vala_cast_expression_real_is_pure;
 	VALA_CODE_NODE_CLASS (klass)->replace_type = vala_cast_expression_real_replace_type;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CAST_EXPRESSION_INNER, g_param_spec_object ("inner", "inner", "inner", VALA_TYPE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CAST_EXPRESSION_TYPE_REFERENCE, g_param_spec_object ("type-reference", "type-reference", "type-reference", VALA_TYPE_DATA_TYPE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CAST_EXPRESSION_IS_SILENT_CAST, g_param_spec_boolean ("is-silent-cast", "is-silent-cast", "is-silent-cast", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
 }
 
 
@@ -236,19 +175,19 @@ static void vala_cast_expression_instance_init (ValaCastExpression * self) {
 }
 
 
-static void vala_cast_expression_finalize (GObject * obj) {
+static void vala_cast_expression_finalize (ValaCodeNode* obj) {
 	ValaCastExpression * self;
 	self = VALA_CAST_EXPRESSION (obj);
-	(self->priv->_inner == NULL ? NULL : (self->priv->_inner = (g_object_unref (self->priv->_inner), NULL)));
-	(self->priv->_data_type == NULL ? NULL : (self->priv->_data_type = (g_object_unref (self->priv->_data_type), NULL)));
-	G_OBJECT_CLASS (vala_cast_expression_parent_class)->finalize (obj);
+	(self->priv->_inner == NULL ? NULL : (self->priv->_inner = (vala_code_node_unref (self->priv->_inner), NULL)));
+	(self->priv->_data_type == NULL ? NULL : (self->priv->_data_type = (vala_code_node_unref (self->priv->_data_type), NULL)));
+	VALA_CODE_NODE_CLASS (vala_cast_expression_parent_class)->finalize (obj);
 }
 
 
 GType vala_cast_expression_get_type (void) {
 	static GType vala_cast_expression_type_id = 0;
 	if (vala_cast_expression_type_id == 0) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaCastExpressionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_cast_expression_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCastExpression), 0, (GInstanceInitFunc) vala_cast_expression_instance_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaCastExpressionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_cast_expression_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCastExpression), 0, (GInstanceInitFunc) vala_cast_expression_instance_init, NULL };
 		vala_cast_expression_type_id = g_type_register_static (VALA_TYPE_EXPRESSION, "ValaCastExpression", &g_define_type_info, 0);
 	}
 	return vala_cast_expression_type_id;
