@@ -35,13 +35,12 @@ struct _ValaCharacterLiteralPrivate {
 
 #define VALA_CHARACTER_LITERAL_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CHARACTER_LITERAL, ValaCharacterLiteralPrivate))
 enum  {
-	VALA_CHARACTER_LITERAL_DUMMY_PROPERTY,
-	VALA_CHARACTER_LITERAL_VALUE
+	VALA_CHARACTER_LITERAL_DUMMY_PROPERTY
 };
 static void vala_character_literal_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static gboolean vala_character_literal_real_is_pure (ValaExpression* base);
 static gpointer vala_character_literal_parent_class = NULL;
-static void vala_character_literal_finalize (GObject * obj);
+static void vala_character_literal_finalize (ValaCodeNode* obj);
 
 
 
@@ -52,29 +51,22 @@ static void vala_character_literal_finalize (GObject * obj);
  * @param source reference to source code
  * @return       newly created character literal
  */
-ValaCharacterLiteral* vala_character_literal_new (const char* c, ValaSourceReference* source) {
-	GParameter * __params;
-	GParameter * __params_it;
-	ValaCharacterLiteral * self;
+ValaCharacterLiteral* vala_character_literal_construct (GType object_type, const char* c, ValaSourceReference* source) {
+	ValaCharacterLiteral* self;
 	g_return_val_if_fail (c != NULL, NULL);
 	g_return_val_if_fail (VALA_IS_SOURCE_REFERENCE (source), NULL);
-	__params = g_new0 (GParameter, 1);
-	__params_it = __params;
-	__params_it->name = "value";
-	g_value_init (&__params_it->value, G_TYPE_STRING);
-	g_value_set_string (&__params_it->value, c);
-	__params_it++;
-	self = g_object_newv (VALA_TYPE_CHARACTER_LITERAL, __params_it - __params, __params);
+	self = ((ValaCharacterLiteral*) (g_type_create_instance (object_type)));
+	vala_character_literal_set_value (self, c);
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source);
-	while (__params_it > __params) {
-		--__params_it;
-		g_value_unset (&__params_it->value);
-	}
-	g_free (__params);
 	return self;
 }
 
 
+ValaCharacterLiteral* vala_character_literal_new (const char* c, ValaSourceReference* source) {
+	return vala_character_literal_construct (VALA_TYPE_CHARACTER_LITERAL, c, source);
+}
+
+
 static void vala_character_literal_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaCharacterLiteral * self;
 	self = VALA_CHARACTER_LITERAL (base);
@@ -119,47 +111,15 @@ void vala_character_literal_set_value (ValaCharacterLiteral* self, const char* v
 	if (!g_utf8_validate (value, -1, NULL) || (g_utf8_strlen (value, -1) != 3 && g_utf8_get_char (g_utf8_next_char (value)) != '\\')) {
 		vala_code_node_set_error (VALA_CODE_NODE (self), TRUE);
 	}
-	g_object_notify (((GObject *) (self)), "value");
-}
-
-
-static void vala_character_literal_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
-	ValaCharacterLiteral * self;
-	self = VALA_CHARACTER_LITERAL (object);
-	switch (property_id) {
-		case VALA_CHARACTER_LITERAL_VALUE:
-		g_value_set_string (value, vala_character_literal_get_value (self));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
-static void vala_character_literal_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
-	ValaCharacterLiteral * self;
-	self = VALA_CHARACTER_LITERAL (object);
-	switch (property_id) {
-		case VALA_CHARACTER_LITERAL_VALUE:
-		vala_character_literal_set_value (self, g_value_get_string (value));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
 }
 
 
 static void vala_character_literal_class_init (ValaCharacterLiteralClass * klass) {
 	vala_character_literal_parent_class = g_type_class_peek_parent (klass);
+	VALA_CODE_NODE_CLASS (klass)->finalize = vala_character_literal_finalize;
 	g_type_class_add_private (klass, sizeof (ValaCharacterLiteralPrivate));
-	G_OBJECT_CLASS (klass)->get_property = vala_character_literal_get_property;
-	G_OBJECT_CLASS (klass)->set_property = vala_character_literal_set_property;
-	G_OBJECT_CLASS (klass)->finalize = vala_character_literal_finalize;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_character_literal_real_accept;
 	VALA_EXPRESSION_CLASS (klass)->is_pure = vala_character_literal_real_is_pure;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CHARACTER_LITERAL_VALUE, g_param_spec_string ("value", "value", "value", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
 }
 
 
@@ -168,18 +128,18 @@ static void vala_character_literal_instance_init (ValaCharacterLiteral * self) {
 }
 
 
-static void vala_character_literal_finalize (GObject * obj) {
+static void vala_character_literal_finalize (ValaCodeNode* obj) {
 	ValaCharacterLiteral * self;
 	self = VALA_CHARACTER_LITERAL (obj);
 	self->priv->_value = (g_free (self->priv->_value), NULL);
-	G_OBJECT_CLASS (vala_character_literal_parent_class)->finalize (obj);
+	VALA_CODE_NODE_CLASS (vala_character_literal_parent_class)->finalize (obj);
 }
 
 
 GType vala_character_literal_get_type (void) {
 	static GType vala_character_literal_type_id = 0;
 	if (vala_character_literal_type_id == 0) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaCharacterLiteralClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_character_literal_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCharacterLiteral), 0, (GInstanceInitFunc) vala_character_literal_instance_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaCharacterLiteralClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_character_literal_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCharacterLiteral), 0, (GInstanceInitFunc) vala_character_literal_instance_init, NULL };
 		vala_character_literal_type_id = g_type_register_static (VALA_TYPE_LITERAL, "ValaCharacterLiteral", &g_define_type_info, 0);
 	}
 	return vala_character_literal_type_id;
