@@ -25,9 +25,9 @@
 
 #include <glib.h>
 #include <glib-object.h>
+#include <gee/list.h>
 #include <stdlib.h>
 #include <string.h>
-#include <gee/list.h>
 #include <vala/valaobjecttypesymbol.h>
 #include <vala/valacodenode.h>
 #include <vala/valatypesymbol.h>
@@ -58,6 +58,11 @@ struct _ValaClassClass {
 };
 
 
+GeeList* vala_class_get_classes (ValaClass* self);
+GeeList* vala_class_get_structs (ValaClass* self);
+GeeList* vala_class_get_enums (ValaClass* self);
+GeeList* vala_class_get_delegates (ValaClass* self);
+ValaClass* vala_class_construct (GType object_type, const char* name, ValaSourceReference* source_reference);
 ValaClass* vala_class_new (const char* name, ValaSourceReference* source_reference);
 void vala_class_add_base_type (ValaClass* self, ValaDataType* type);
 GeeList* vala_class_get_base_types (ValaClass* self);
@@ -66,6 +71,7 @@ GeeList* vala_class_get_type_parameters (ValaClass* self);
 void vala_class_add_constant (ValaClass* self, ValaConstant* c);
 void vala_class_add_field (ValaClass* self, ValaField* f);
 GeeList* vala_class_get_fields (ValaClass* self);
+GeeList* vala_class_get_constants (ValaClass* self);
 void vala_class_add_method (ValaClass* self, ValaMethod* m);
 void vala_class_add_property (ValaClass* self, ValaProperty* prop);
 void vala_class_add_signal (ValaClass* self, ValaSignal* sig);
@@ -77,6 +83,8 @@ char* vala_class_get_default_cname (ValaClass* self);
 void vala_class_set_cname (ValaClass* self, const char* cname);
 void vala_class_process_attributes (ValaClass* self);
 void vala_class_set_type_id (ValaClass* self, const char* type_id);
+void vala_class_set_param_spec_function (ValaClass* self, const char* name);
+gboolean vala_class_is_fundamental (ValaClass* self);
 void vala_class_set_ref_function (ValaClass* self, const char* name);
 void vala_class_set_unref_function (ValaClass* self, const char* name);
 void vala_class_set_dup_function (ValaClass* self, const char* name);
