@@ -39,21 +39,33 @@ G_BEGIN_DECLS
 typedef struct _ValaCodeBinding ValaCodeBinding;
 typedef struct _ValaCodeBindingClass ValaCodeBindingClass;
 typedef struct _ValaCodeBindingPrivate ValaCodeBindingPrivate;
+typedef struct _ValaParamSpecCodeBinding ValaParamSpecCodeBinding;
 
 /**
  * The link between a source code node and generated code.
  */
 struct _ValaCodeBinding {
-	GObject parent_instance;
+	GTypeInstance parent_instance;
+	volatile int ref_count;
 	ValaCodeBindingPrivate * priv;
 };
 
 struct _ValaCodeBindingClass {
-	GObjectClass parent_class;
+	GTypeClass parent_class;
+	void (*finalize) (ValaCodeBinding *self);
+};
+
+struct _ValaParamSpecCodeBinding {
+	GParamSpec parent_instance;
 };
 
 
+GParamSpec* vala_param_spec_code_binding (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
+gpointer vala_value_get_code_binding (const GValue* value);
+void vala_value_set_code_binding (GValue* value, gpointer v_object);
 GType vala_code_binding_get_type (void);
+gpointer vala_code_binding_ref (gpointer instance);
+void vala_code_binding_unref (gpointer instance);
 
 
 G_END_DECLS
