@@ -1047,13 +1047,18 @@ ValaCodeBinding* vala_code_generator_create_assignment_binding (ValaCodeGenerato
 /**
  * Abstract code visitor generating code.
  */
-ValaCodeGenerator* vala_code_generator_new (void) {
-	ValaCodeGenerator * self;
-	self = g_object_newv (VALA_TYPE_CODE_GENERATOR, 0, NULL);
+ValaCodeGenerator* vala_code_generator_construct (GType object_type) {
+	ValaCodeGenerator* self;
+	self = ((ValaCodeGenerator*) (g_type_create_instance (object_type)));
 	return self;
 }
 
 
+ValaCodeGenerator* vala_code_generator_new (void) {
+	return vala_code_generator_construct (VALA_TYPE_CODE_GENERATOR);
+}
+
+
 static void vala_code_generator_class_init (ValaCodeGeneratorClass * klass) {
 	vala_code_generator_parent_class = g_type_class_peek_parent (klass);
 	VALA_CODE_GENERATOR_CLASS (klass)->emit = vala_code_generator_real_emit;
@@ -1138,7 +1143,7 @@ static void vala_code_generator_instance_init (ValaCodeGenerator * self) {
 GType vala_code_generator_get_type (void) {
 	static GType vala_code_generator_type_id = 0;
 	if (vala_code_generator_type_id == 0) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaCodeGeneratorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_code_generator_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCodeGenerator), 0, (GInstanceInitFunc) vala_code_generator_instance_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaCodeGeneratorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_code_generator_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCodeGenerator), 0, (GInstanceInitFunc) vala_code_generator_instance_init, NULL };
 		vala_code_generator_type_id = g_type_register_static (VALA_TYPE_CODE_VISITOR, "ValaCodeGenerator", &g_define_type_info, 0);
 	}
 	return vala_code_generator_type_id;
