@@ -32,6 +32,7 @@
 #include <vala/valaattribute.h>
 #include <vala/valacodegenerator.h>
 #include <vala/valasourcefile.h>
+#include <gobject/gvaluecollector.h>
 
 
 
@@ -47,14 +48,9 @@ struct _ValaCodeNodePrivate {
 
 #define VALA_CODE_NODE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CODE_NODE, ValaCodeNodePrivate))
 enum  {
-	VALA_CODE_NODE_DUMMY_PROPERTY,
-	VALA_CODE_NODE_PARENT_NODE,
-	VALA_CODE_NODE_SOURCE_REFERENCE,
-	VALA_CODE_NODE_CCODENODE,
-	VALA_CODE_NODE_ERROR,
-	VALA_CODE_NODE_TREE_CAN_FAIL
+	VALA_CODE_NODE_DUMMY_PROPERTY
 };
-static void _g_list_free_g_object_unref (GList* self);
+static void _g_list_free_vala_code_node_unref (GList* self);
 static GeeList* vala_code_node__empty_type_list;
 static void vala_code_node_real_accept (ValaCodeNode* self, ValaCodeVisitor* visitor);
 static void vala_code_node_real_accept_children (ValaCodeNode* self, ValaCodeVisitor* visitor);
@@ -63,13 +59,13 @@ static void vala_code_node_real_replace_expression (ValaCodeNode* self, ValaExpr
 static char* vala_code_node_real_to_string (ValaCodeNode* self);
 static ValaCodeBinding* vala_code_node_real_create_code_binding (ValaCodeNode* self, ValaCodeGenerator* codegen);
 static gpointer vala_code_node_parent_class = NULL;
-static void vala_code_node_dispose (GObject * obj);
+static void vala_code_node_finalize (ValaCodeNode* obj);
 static int _vala_strcmp0 (const char * str1, const char * str2);
 
 
 
-static void _g_list_free_g_object_unref (GList* self) {
-	g_list_foreach (self, ((GFunc) (g_object_unref)), NULL);
+static void _g_list_free_vala_code_node_unref (GList* self) {
+	g_list_foreach (self, ((GFunc) (vala_code_node_unref)), NULL);
 	g_list_free (self);
 }
 
@@ -83,18 +79,18 @@ GeeList* vala_code_node_get_error_types (ValaCodeNode* self) {
 	if (self->priv->_error_types != NULL) {
 		GeeList* _tmp0;
 		_tmp0 = NULL;
-		return (_tmp0 = self->priv->_error_types, (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
+		return (_tmp0 = self->priv->_error_types, (_tmp0 == NULL ? NULL : gee_collection_object_ref (_tmp0)));
 	}
 	if (vala_code_node__empty_type_list == NULL) {
 		GeeList* _tmp3;
 		GeeArrayList* _tmp2;
 		_tmp3 = NULL;
 		_tmp2 = NULL;
-		vala_code_node__empty_type_list = (_tmp3 = GEE_LIST (gee_read_only_list_new (VALA_TYPE_DATA_TYPE, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, GEE_LIST ((_tmp2 = gee_array_list_new (VALA_TYPE_DATA_TYPE, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal))))), (vala_code_node__empty_type_list == NULL ? NULL : (vala_code_node__empty_type_list = (g_object_unref (vala_code_node__empty_type_list), NULL))), _tmp3);
-		(_tmp2 == NULL ? NULL : (_tmp2 = (g_object_unref (_tmp2), NULL)));
+		vala_code_node__empty_type_list = (_tmp3 = GEE_LIST (gee_read_only_list_new (VALA_TYPE_DATA_TYPE, ((GBoxedCopyFunc) (vala_code_node_ref)), vala_code_node_unref, GEE_LIST ((_tmp2 = gee_array_list_new (VALA_TYPE_DATA_TYPE, ((GBoxedCopyFunc) (vala_code_node_ref)), vala_code_node_unref, g_direct_equal))))), (vala_code_node__empty_type_list == NULL ? NULL : (vala_code_node__empty_type_list = (gee_collection_object_unref (vala_code_node__empty_type_list), NULL))), _tmp3);
+		(_tmp2 == NULL ? NULL : (_tmp2 = (gee_collection_object_unref (_tmp2), NULL)));
 	}
 	_tmp4 = NULL;
-	return (_tmp4 = vala_code_node__empty_type_list, (_tmp4 == NULL ? NULL : g_object_ref (_tmp4)));
+	return (_tmp4 = vala_code_node__empty_type_list, (_tmp4 == NULL ? NULL : gee_collection_object_ref (_tmp4)));
 }
 
 
@@ -108,7 +104,7 @@ void vala_code_node_add_error_type (ValaCodeNode* self, ValaDataType* error_type
 	if (self->priv->_error_types == NULL) {
 		GeeList* _tmp0;
 		_tmp0 = NULL;
-		self->priv->_error_types = (_tmp0 = GEE_LIST (gee_array_list_new (VALA_TYPE_DATA_TYPE, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal)), (self->priv->_error_types == NULL ? NULL : (self->priv->_error_types = (g_object_unref (self->priv->_error_types), NULL))), _tmp0);
+		self->priv->_error_types = (_tmp0 = GEE_LIST (gee_array_list_new (VALA_TYPE_DATA_TYPE, ((GBoxedCopyFunc) (vala_code_node_ref)), vala_code_node_unref, g_direct_equal)), (self->priv->_error_types == NULL ? NULL : (self->priv->_error_types = (gee_collection_object_unref (self->priv->_error_types), NULL))), _tmp0);
 	}
 	gee_collection_add (GEE_COLLECTION (self->priv->_error_types), error_type);
 	vala_code_node_set_parent_node (VALA_CODE_NODE (error_type), self);
@@ -131,7 +127,7 @@ void vala_code_node_add_error_types (ValaCodeNode* self, GeeList* error_types) {
 			error_type = ((ValaDataType*) (gee_list_get (GEE_LIST (error_type_collection), error_type_it)));
 			{
 				vala_code_node_add_error_type (self, error_type);
-				(error_type == NULL ? NULL : (error_type = (g_object_unref (error_type), NULL)));
+				(error_type == NULL ? NULL : (error_type = (vala_code_node_unref (error_type), NULL)));
 			}
 		}
 	}
@@ -212,12 +208,12 @@ ValaAttribute* vala_code_node_get_attribute (ValaCodeNode* self, const char* nam
 			ValaAttribute* _tmp1;
 			ValaAttribute* a;
 			_tmp1 = NULL;
-			a = (_tmp1 = ((ValaAttribute*) (a_it->data)), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
+			a = (_tmp1 = ((ValaAttribute*) (a_it->data)), (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1)));
 			{
 				if (_vala_strcmp0 (vala_attribute_get_name (a), name) == 0) {
 					return a;
 				}
-				(a == NULL ? NULL : (a = (g_object_unref (a), NULL)));
+				(a == NULL ? NULL : (a = (vala_code_node_unref (a), NULL)));
 			}
 		}
 	}
@@ -236,7 +232,7 @@ static char* vala_code_node_real_to_string (ValaCodeNode* self) {
 	char* _tmp2;
 	g_return_val_if_fail (VALA_IS_CODE_NODE (self), NULL);
 	str = g_string_new ("");
-	g_string_append (g_string_append (str, "/* "), g_type_name (G_TYPE_FROM_INSTANCE (G_OBJECT (self))));
+	g_string_append (str, "/* ");
 	if (self->priv->_source_reference != NULL) {
 		char* _tmp0;
 		_tmp0 = NULL;
@@ -266,10 +262,10 @@ ValaCodeBinding* vala_code_node_get_code_binding (ValaCodeNode* self, ValaCodeGe
 	if (self->priv->code_binding == NULL) {
 		ValaCodeBinding* _tmp0;
 		_tmp0 = NULL;
-		self->priv->code_binding = (_tmp0 = vala_code_node_create_code_binding (self, codegen), (self->priv->code_binding == NULL ? NULL : (self->priv->code_binding = (g_object_unref (self->priv->code_binding), NULL))), _tmp0);
+		self->priv->code_binding = (_tmp0 = vala_code_node_create_code_binding (self, codegen), (self->priv->code_binding == NULL ? NULL : (self->priv->code_binding = (vala_code_binding_unref (self->priv->code_binding), NULL))), _tmp0);
 	}
 	_tmp1 = NULL;
-	return (_tmp1 = self->priv->code_binding, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
+	return (_tmp1 = self->priv->code_binding, (_tmp1 == NULL ? NULL : vala_code_binding_ref (_tmp1)));
 }
 
 
@@ -312,7 +308,7 @@ void vala_code_node_set_source_reference (ValaCodeNode* self, ValaSourceReferenc
 	g_return_if_fail (VALA_IS_CODE_NODE (self));
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_source_reference = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_source_reference == NULL ? NULL : (self->priv->_source_reference = (g_object_unref (self->priv->_source_reference), NULL))), _tmp2);
+	self->priv->_source_reference = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_source_reference_ref (_tmp1))), (self->priv->_source_reference == NULL ? NULL : (self->priv->_source_reference = (vala_source_reference_unref (self->priv->_source_reference), NULL))), _tmp2);
 }
 
 
@@ -332,12 +328,12 @@ void vala_code_node_set_ccodenode (ValaCodeNode* self, ValaCCodeNode* value) {
 		_tmp2 = NULL;
 		_tmp1 = NULL;
 		vala_ccode_node_set_line (value, (_tmp2 = vala_ccode_line_directive_new ((_tmp1 = g_path_get_basename (vala_source_file_get_filename (vala_source_reference_get_file (self->priv->_source_reference)))), vala_source_reference_get_first_line (self->priv->_source_reference))));
-		(_tmp2 == NULL ? NULL : (_tmp2 = (g_object_unref (_tmp2), NULL)));
+		(_tmp2 == NULL ? NULL : (_tmp2 = (vala_ccode_node_unref (_tmp2), NULL)));
 		_tmp1 = (g_free (_tmp1), NULL);
 	}
 	_tmp4 = NULL;
 	_tmp3 = NULL;
-	self->priv->_ccodenode = (_tmp4 = (_tmp3 = value, (_tmp3 == NULL ? NULL : g_object_ref (_tmp3))), (self->priv->_ccodenode == NULL ? NULL : (self->priv->_ccodenode = (g_object_unref (self->priv->_ccodenode), NULL))), _tmp4);
+	self->priv->_ccodenode = (_tmp4 = (_tmp3 = value, (_tmp3 == NULL ? NULL : vala_ccode_node_ref (_tmp3))), (self->priv->_ccodenode == NULL ? NULL : (self->priv->_ccodenode = (vala_ccode_node_unref (self->priv->_ccodenode), NULL))), _tmp4);
 }
 
 
@@ -359,102 +355,157 @@ gboolean vala_code_node_get_tree_can_fail (ValaCodeNode* self) {
 }
 
 
-static void vala_code_node_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
-	ValaCodeNode * self;
-	self = VALA_CODE_NODE (object);
-	switch (property_id) {
-		case VALA_CODE_NODE_PARENT_NODE:
-		g_value_set_object (value, vala_code_node_get_parent_node (self));
-		break;
-		case VALA_CODE_NODE_SOURCE_REFERENCE:
-		g_value_set_object (value, vala_code_node_get_source_reference (self));
-		break;
-		case VALA_CODE_NODE_CCODENODE:
-		g_value_set_object (value, vala_code_node_get_ccodenode (self));
-		break;
-		case VALA_CODE_NODE_ERROR:
-		g_value_set_boolean (value, vala_code_node_get_error (self));
-		break;
-		case VALA_CODE_NODE_TREE_CAN_FAIL:
-		g_value_set_boolean (value, vala_code_node_get_tree_can_fail (self));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
+static void vala_value_code_node_init (GValue* value) {
+	value->data[0].v_pointer = NULL;
+}
+
+
+static void vala_value_code_node_free_value (GValue* value) {
+	if (value->data[0].v_pointer) {
+		vala_code_node_unref (value->data[0].v_pointer);
 	}
 }
 
 
-static void vala_code_node_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
-	ValaCodeNode * self;
-	self = VALA_CODE_NODE (object);
-	switch (property_id) {
-		case VALA_CODE_NODE_PARENT_NODE:
-		vala_code_node_set_parent_node (self, g_value_get_object (value));
-		break;
-		case VALA_CODE_NODE_SOURCE_REFERENCE:
-		vala_code_node_set_source_reference (self, g_value_get_object (value));
-		break;
-		case VALA_CODE_NODE_CCODENODE:
-		vala_code_node_set_ccodenode (self, g_value_get_object (value));
-		break;
-		case VALA_CODE_NODE_ERROR:
-		vala_code_node_set_error (self, g_value_get_boolean (value));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
+static void vala_value_code_node_copy_value (const GValue* src_value, GValue* dest_value) {
+	if (src_value->data[0].v_pointer) {
+		dest_value->data[0].v_pointer = vala_code_node_ref (src_value->data[0].v_pointer);
+	} else {
+		dest_value->data[0].v_pointer = NULL;
+	}
+}
+
+
+static gpointer vala_value_code_node_peek_pointer (const GValue* value) {
+	return value->data[0].v_pointer;
+}
+
+
+static gchar* vala_value_code_node_collect_value (GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
+	if (collect_values[0].v_pointer) {
+		ValaCodeNode* object;
+		object = value->data[0].v_pointer;
+		if (object->parent_instance.g_class == NULL) {
+			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
+		} else if (!g_value_type_compatible (G_OBJECT_TYPE (object), G_VALUE_TYPE (value))) {
+			return g_strconcat ("invalid object type `", G_OBJECT_TYPE (object), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
+		}
+	} else {
+		value->data[0].v_pointer = NULL;
+	}
+	return NULL;
+}
+
+
+static gchar* vala_value_code_node_lcopy_value (const GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
+	ValaCodeNode** object_p;
+	object_p = collect_values[0].v_pointer;
+	if (!object_p) {
+	}
+	if (!value->data[0].v_pointer) {
+		*object_p = NULL;
+	} else if (collect_flags && G_VALUE_NOCOPY_CONTENTS) {
+		*object_p = value->data[0].v_pointer;
+	} else {
+		*object_p = vala_code_node_ref (value->data[0].v_pointer);
+	}
+	return NULL;
+}
+
+
+GParamSpec* vala_param_spec_code_node (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) {
+	ValaParamSpecCodeNode* spec;
+	g_return_val_if_fail (g_type_is_a (object_type, VALA_TYPE_CODE_NODE), NULL);
+	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
+	G_PARAM_SPEC (spec)->value_type = object_type;
+	return G_PARAM_SPEC (spec);
+}
+
+
+gpointer vala_value_get_code_node (const GValue* value) {
+	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, VALA_TYPE_CODE_NODE), NULL);
+	return value->data[0].v_pointer;
+}
+
+
+void vala_value_set_code_node (GValue* value, gpointer v_object) {
+	ValaCodeNode* old;
+	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, VALA_TYPE_CODE_NODE));
+	old = value->data[0].v_pointer;
+	if (v_object) {
+		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, VALA_TYPE_CODE_NODE));
+		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
+		value->data[0].v_pointer = v_object;
+		vala_code_node_ref (value->data[0].v_pointer);
+	} else {
+		value->data[0].v_pointer = NULL;
+	}
+	if (old) {
+		vala_code_node_unref (old);
 	}
 }
 
 
 static void vala_code_node_class_init (ValaCodeNodeClass * klass) {
 	vala_code_node_parent_class = g_type_class_peek_parent (klass);
+	VALA_CODE_NODE_CLASS (klass)->finalize = vala_code_node_finalize;
 	g_type_class_add_private (klass, sizeof (ValaCodeNodePrivate));
-	G_OBJECT_CLASS (klass)->get_property = vala_code_node_get_property;
-	G_OBJECT_CLASS (klass)->set_property = vala_code_node_set_property;
-	G_OBJECT_CLASS (klass)->dispose = vala_code_node_dispose;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_code_node_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_code_node_real_accept_children;
 	VALA_CODE_NODE_CLASS (klass)->replace_type = vala_code_node_real_replace_type;
 	VALA_CODE_NODE_CLASS (klass)->replace_expression = vala_code_node_real_replace_expression;
 	VALA_CODE_NODE_CLASS (klass)->to_string = vala_code_node_real_to_string;
 	VALA_CODE_NODE_CLASS (klass)->create_code_binding = vala_code_node_real_create_code_binding;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CODE_NODE_PARENT_NODE, g_param_spec_object ("parent-node", "parent-node", "parent-node", VALA_TYPE_CODE_NODE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CODE_NODE_SOURCE_REFERENCE, g_param_spec_object ("source-reference", "source-reference", "source-reference", VALA_TYPE_SOURCE_REFERENCE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CODE_NODE_CCODENODE, g_param_spec_object ("ccodenode", "ccodenode", "ccodenode", VALA_TYPE_CCODE_NODE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CODE_NODE_ERROR, g_param_spec_boolean ("error", "error", "error", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CODE_NODE_TREE_CAN_FAIL, g_param_spec_boolean ("tree-can-fail", "tree-can-fail", "tree-can-fail", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
 }
 
 
 static void vala_code_node_instance_init (ValaCodeNode * self) {
 	self->priv = VALA_CODE_NODE_GET_PRIVATE (self);
+	self->ref_count = 1;
 }
 
 
-static void vala_code_node_dispose (GObject * obj) {
+static void vala_code_node_finalize (ValaCodeNode* obj) {
 	ValaCodeNode * self;
 	self = VALA_CODE_NODE (obj);
-	(self->priv->_source_reference == NULL ? NULL : (self->priv->_source_reference = (g_object_unref (self->priv->_source_reference), NULL)));
-	(self->attributes == NULL ? NULL : (self->attributes = (_g_list_free_g_object_unref (self->attributes), NULL)));
-	(self->priv->_error_types == NULL ? NULL : (self->priv->_error_types = (g_object_unref (self->priv->_error_types), NULL)));
-	(self->priv->code_binding == NULL ? NULL : (self->priv->code_binding = (g_object_unref (self->priv->code_binding), NULL)));
-	(self->priv->_ccodenode == NULL ? NULL : (self->priv->_ccodenode = (g_object_unref (self->priv->_ccodenode), NULL)));
-	G_OBJECT_CLASS (vala_code_node_parent_class)->dispose (obj);
+	(self->priv->_source_reference == NULL ? NULL : (self->priv->_source_reference = (vala_source_reference_unref (self->priv->_source_reference), NULL)));
+	(self->attributes == NULL ? NULL : (self->attributes = (_g_list_free_vala_code_node_unref (self->attributes), NULL)));
+	(self->priv->_error_types == NULL ? NULL : (self->priv->_error_types = (gee_collection_object_unref (self->priv->_error_types), NULL)));
+	(self->priv->code_binding == NULL ? NULL : (self->priv->code_binding = (vala_code_binding_unref (self->priv->code_binding), NULL)));
+	(self->priv->_ccodenode == NULL ? NULL : (self->priv->_ccodenode = (vala_ccode_node_unref (self->priv->_ccodenode), NULL)));
 }
 
 
 GType vala_code_node_get_type (void) {
 	static GType vala_code_node_type_id = 0;
-	if (G_UNLIKELY (vala_code_node_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaCodeNodeClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_code_node_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCodeNode), 0, (GInstanceInitFunc) vala_code_node_instance_init };
-		vala_code_node_type_id = g_type_register_static (G_TYPE_OBJECT, "ValaCodeNode", &g_define_type_info, G_TYPE_FLAG_ABSTRACT);
+	if (vala_code_node_type_id == 0) {
+		static const GTypeValueTable g_define_type_value_table = { vala_value_code_node_init, vala_value_code_node_free_value, vala_value_code_node_copy_value, vala_value_code_node_peek_pointer, "p", vala_value_code_node_collect_value, "p", vala_value_code_node_lcopy_value };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaCodeNodeClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_code_node_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCodeNode), 0, (GInstanceInitFunc) vala_code_node_instance_init, &g_define_type_value_table };
+		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
+		vala_code_node_type_id = g_type_register_fundamental (g_type_fundamental_next (), "ValaCodeNode", &g_define_type_info, &g_define_type_fundamental_info, G_TYPE_FLAG_ABSTRACT);
 	}
 	return vala_code_node_type_id;
 }
 
 
+gpointer vala_code_node_ref (gpointer instance) {
+	ValaCodeNode* self;
+	self = instance;
+	g_atomic_int_inc (&self->ref_count);
+	return instance;
+}
+
+
+void vala_code_node_unref (gpointer instance) {
+	ValaCodeNode* self;
+	self = instance;
+	if (g_atomic_int_dec_and_test (&self->ref_count)) {
+		VALA_CODE_NODE_GET_CLASS (self)->finalize (self);
+		g_type_free_instance (((GTypeInstance *) (self)));
+	}
+}
+
+
 static int _vala_strcmp0 (const char * str1, const char * str2) {
 	if (str1 == NULL) {
 		return -(str1 != str2);
