@@ -45,7 +45,7 @@
 #include <vala/valadestructor.h>
 #include <vala/valanamedargument.h>
 #include <vala/valatypeparameter.h>
-#include <vala/valanamespacereference.h>
+#include <vala/valausingdirective.h>
 #include <vala/valadatatype.h>
 #include <vala/valablock.h>
 #include <vala/valaemptystatement.h>
@@ -96,6 +96,7 @@
 #include <vala/valaconditionalexpression.h>
 #include <vala/valalambdaexpression.h>
 #include <vala/valaassignment.h>
+#include <gobject/gvaluecollector.h>
 
 
 
@@ -126,7 +127,7 @@ static void vala_code_visitor_real_visit_constructor (ValaCodeVisitor* self, Val
 static void vala_code_visitor_real_visit_destructor (ValaCodeVisitor* self, ValaDestructor* d);
 static void vala_code_visitor_real_visit_named_argument (ValaCodeVisitor* self, ValaNamedArgument* n);
 static void vala_code_visitor_real_visit_type_parameter (ValaCodeVisitor* self, ValaTypeParameter* p);
-static void vala_code_visitor_real_visit_namespace_reference (ValaCodeVisitor* self, ValaNamespaceReference* ns);
+static void vala_code_visitor_real_visit_using_directive (ValaCodeVisitor* self, ValaUsingDirective* ns);
 static void vala_code_visitor_real_visit_data_type (ValaCodeVisitor* self, ValaDataType* type);
 static void vala_code_visitor_real_visit_block (ValaCodeVisitor* self, ValaBlock* b);
 static void vala_code_visitor_real_visit_empty_statement (ValaCodeVisitor* self, ValaEmptyStatement* stmt);
@@ -179,6 +180,7 @@ static void vala_code_visitor_real_visit_lambda_expression (ValaCodeVisitor* sel
 static void vala_code_visitor_real_visit_assignment (ValaCodeVisitor* self, ValaAssignment* a);
 static void vala_code_visitor_real_visit_end_full_expression (ValaCodeVisitor* self, ValaExpression* expr);
 static gpointer vala_code_visitor_parent_class = NULL;
+static void vala_code_visitor_finalize (ValaCodeVisitor* obj);
 
 
 
@@ -551,18 +553,18 @@ void vala_code_visitor_visit_type_parameter (ValaCodeVisitor* self, ValaTypePara
 
 
 /**
- * Visit operation called for namespace references.
+ * Visit operation called for using directives.
  *
- * @param ns a namespace reference
+ * @param ns a using directive
  */
-static void vala_code_visitor_real_visit_namespace_reference (ValaCodeVisitor* self, ValaNamespaceReference* ns) {
+static void vala_code_visitor_real_visit_using_directive (ValaCodeVisitor* self, ValaUsingDirective* ns) {
 	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (VALA_IS_NAMESPACE_REFERENCE (ns));
+	g_return_if_fail (VALA_IS_USING_DIRECTIVE (ns));
 }
 
 
-void vala_code_visitor_visit_namespace_reference (ValaCodeVisitor* self, ValaNamespaceReference* ns) {
-	VALA_CODE_VISITOR_GET_CLASS (self)->visit_namespace_reference (self, ns);
+void vala_code_visitor_visit_using_directive (ValaCodeVisitor* self, ValaUsingDirective* ns) {
+	VALA_CODE_VISITOR_GET_CLASS (self)->visit_using_directive (self, ns);
 }
 
 
@@ -1382,8 +1384,100 @@ void vala_code_visitor_visit_end_full_expression (ValaCodeVisitor* self, ValaExp
 }
 
 
+static void vala_value_code_visitor_init (GValue* value) {
+	value->data[0].v_pointer = NULL;
+}
+
+
+static void vala_value_code_visitor_free_value (GValue* value) {
+	if (value->data[0].v_pointer) {
+		vala_code_visitor_unref (value->data[0].v_pointer);
+	}
+}
+
+
+static void vala_value_code_visitor_copy_value (const GValue* src_value, GValue* dest_value) {
+	if (src_value->data[0].v_pointer) {
+		dest_value->data[0].v_pointer = vala_code_visitor_ref (src_value->data[0].v_pointer);
+	} else {
+		dest_value->data[0].v_pointer = NULL;
+	}
+}
+
+
+static gpointer vala_value_code_visitor_peek_pointer (const GValue* value) {
+	return value->data[0].v_pointer;
+}
+
+
+static gchar* vala_value_code_visitor_collect_value (GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
+	if (collect_values[0].v_pointer) {
+		ValaCodeVisitor* object;
+		object = value->data[0].v_pointer;
+		if (object->parent_instance.g_class == NULL) {
+			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
+		} else if (!g_value_type_compatible (G_OBJECT_TYPE (object), G_VALUE_TYPE (value))) {
+			return g_strconcat ("invalid object type `", G_OBJECT_TYPE (object), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
+		}
+	} else {
+		value->data[0].v_pointer = NULL;
+	}
+	return NULL;
+}
+
+
+static gchar* vala_value_code_visitor_lcopy_value (const GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
+	ValaCodeVisitor** object_p;
+	object_p = collect_values[0].v_pointer;
+	if (!object_p) {
+	}
+	if (!value->data[0].v_pointer) {
+		*object_p = NULL;
+	} else if (collect_flags && G_VALUE_NOCOPY_CONTENTS) {
+		*object_p = value->data[0].v_pointer;
+	} else {
+		*object_p = vala_code_visitor_ref (value->data[0].v_pointer);
+	}
+	return NULL;
+}
+
+
+GParamSpec* vala_param_spec_code_visitor (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) {
+	ValaParamSpecCodeVisitor* spec;
+	g_return_val_if_fail (g_type_is_a (object_type, VALA_TYPE_CODE_VISITOR), NULL);
+	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
+	G_PARAM_SPEC (spec)->value_type = object_type;
+	return G_PARAM_SPEC (spec);
+}
+
+
+gpointer vala_value_get_code_visitor (const GValue* value) {
+	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, VALA_TYPE_CODE_VISITOR), NULL);
+	return value->data[0].v_pointer;
+}
+
+
+void vala_value_set_code_visitor (GValue* value, gpointer v_object) {
+	ValaCodeVisitor* old;
+	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, VALA_TYPE_CODE_VISITOR));
+	old = value->data[0].v_pointer;
+	if (v_object) {
+		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, VALA_TYPE_CODE_VISITOR));
+		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
+		value->data[0].v_pointer = v_object;
+		vala_code_visitor_ref (value->data[0].v_pointer);
+	} else {
+		value->data[0].v_pointer = NULL;
+	}
+	if (old) {
+		vala_code_visitor_unref (old);
+	}
+}
+
+
 static void vala_code_visitor_class_init (ValaCodeVisitorClass * klass) {
 	vala_code_visitor_parent_class = g_type_class_peek_parent (klass);
+	VALA_CODE_VISITOR_CLASS (klass)->finalize = vala_code_visitor_finalize;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_source_file = vala_code_visitor_real_visit_source_file;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_namespace = vala_code_visitor_real_visit_namespace;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_class = vala_code_visitor_real_visit_class;
@@ -1407,7 +1501,7 @@ static void vala_code_visitor_class_init (ValaCodeVisitorClass * klass) {
 	VALA_CODE_VISITOR_CLASS (klass)->visit_destructor = vala_code_visitor_real_visit_destructor;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_named_argument = vala_code_visitor_real_visit_named_argument;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_type_parameter = vala_code_visitor_real_visit_type_parameter;
-	VALA_CODE_VISITOR_CLASS (klass)->visit_namespace_reference = vala_code_visitor_real_visit_namespace_reference;
+	VALA_CODE_VISITOR_CLASS (klass)->visit_using_directive = vala_code_visitor_real_visit_using_directive;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_data_type = vala_code_visitor_real_visit_data_type;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_block = vala_code_visitor_real_visit_block;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_empty_statement = vala_code_visitor_real_visit_empty_statement;
@@ -1463,18 +1557,45 @@ static void vala_code_visitor_class_init (ValaCodeVisitorClass * klass) {
 
 
 static void vala_code_visitor_instance_init (ValaCodeVisitor * self) {
+	self->ref_count = 1;
+}
+
+
+static void vala_code_visitor_finalize (ValaCodeVisitor* obj) {
+	ValaCodeVisitor * self;
+	self = VALA_CODE_VISITOR (obj);
 }
 
 
 GType vala_code_visitor_get_type (void) {
 	static GType vala_code_visitor_type_id = 0;
-	if (G_UNLIKELY (vala_code_visitor_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaCodeVisitorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_code_visitor_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCodeVisitor), 0, (GInstanceInitFunc) vala_code_visitor_instance_init };
-		vala_code_visitor_type_id = g_type_register_static (G_TYPE_OBJECT, "ValaCodeVisitor", &g_define_type_info, G_TYPE_FLAG_ABSTRACT);
+	if (vala_code_visitor_type_id == 0) {
+		static const GTypeValueTable g_define_type_value_table = { vala_value_code_visitor_init, vala_value_code_visitor_free_value, vala_value_code_visitor_copy_value, vala_value_code_visitor_peek_pointer, "p", vala_value_code_visitor_collect_value, "p", vala_value_code_visitor_lcopy_value };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaCodeVisitorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_code_visitor_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCodeVisitor), 0, (GInstanceInitFunc) vala_code_visitor_instance_init, &g_define_type_value_table };
+		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
+		vala_code_visitor_type_id = g_type_register_fundamental (g_type_fundamental_next (), "ValaCodeVisitor", &g_define_type_info, &g_define_type_fundamental_info, G_TYPE_FLAG_ABSTRACT);
 	}
 	return vala_code_visitor_type_id;
 }
 
 
+gpointer vala_code_visitor_ref (gpointer instance) {
+	ValaCodeVisitor* self;
+	self = instance;
+	g_atomic_int_inc (&self->ref_count);
+	return instance;
+}
+
+
+void vala_code_visitor_unref (gpointer instance) {
+	ValaCodeVisitor* self;
+	self = instance;
+	if (g_atomic_int_dec_and_test (&self->ref_count)) {
+		VALA_CODE_VISITOR_GET_CLASS (self)->finalize (self);
+		g_type_free_instance (((GTypeInstance *) (self)));
+	}
+}
+
+
 
 
