@@ -32,6 +32,7 @@
 #include <vala/valatypesymbol.h>
 #include <vala/valastruct.h>
 #include <vala/valacodegenerator.h>
+#include <vala/valaclass.h>
 
 
 
@@ -40,21 +41,21 @@ struct _ValaCreationMethodPrivate {
 	char* _type_name;
 	gint _n_construction_params;
 	char* _custom_return_type_cname;
+	gboolean _chain_up;
 };
 
 #define VALA_CREATION_METHOD_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CREATION_METHOD, ValaCreationMethodPrivate))
 enum  {
-	VALA_CREATION_METHOD_DUMMY_PROPERTY,
-	VALA_CREATION_METHOD_TYPE_NAME,
-	VALA_CREATION_METHOD_N_CONSTRUCTION_PARAMS,
-	VALA_CREATION_METHOD_CUSTOM_RETURN_TYPE_CNAME
+	VALA_CREATION_METHOD_DUMMY_PROPERTY
 };
 static void vala_creation_method_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_creation_method_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static char* vala_creation_method_real_get_default_cname (ValaMethod* base);
 static ValaCodeBinding* vala_creation_method_real_create_code_binding (ValaCodeNode* base, ValaCodeGenerator* codegen);
+static char* vala_creation_method_real_get_real_cname (ValaMethod* base);
 static gpointer vala_creation_method_parent_class = NULL;
-static void vala_creation_method_finalize (GObject * obj);
+static void vala_creation_method_finalize (ValaCodeNode* obj);
+static int _vala_strcmp0 (const char * str1, const char * str2);
 
 
 
@@ -65,21 +66,29 @@ static void vala_creation_method_finalize (GObject * obj);
  * @param source_reference reference to source code
  * @return                 newly created method
  */
-ValaCreationMethod* vala_creation_method_new (const char* type_name, const char* name, ValaSourceReference* source_reference) {
-	ValaCreationMethod * self;
+ValaCreationMethod* vala_creation_method_construct (GType object_type, const char* type_name, const char* name, ValaSourceReference* source_reference) {
+	ValaCreationMethod* self;
 	ValaVoidType* _tmp0;
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
-	self = g_object_newv (VALA_TYPE_CREATION_METHOD, 0, NULL);
+	self = ((ValaCreationMethod*) (g_type_create_instance (object_type)));
+	vala_symbol_init (VALA_SYMBOL (VALA_METHOD (self)));
 	vala_symbol_set_name (VALA_SYMBOL (self), name);
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
 	vala_creation_method_set_type_name (self, type_name);
 	_tmp0 = NULL;
 	vala_method_set_return_type (VALA_METHOD (self), VALA_DATA_TYPE ((_tmp0 = vala_void_type_new ())));
-	(_tmp0 == NULL ? NULL : (_tmp0 = (g_object_unref (_tmp0), NULL)));
+	(_tmp0 == NULL ? NULL : (_tmp0 = (vala_code_node_unref (_tmp0), NULL)));
+	vala_method_set_carray_length_parameter_position (VALA_METHOD (self), ((double) (-3)));
+	vala_method_set_cdelegate_target_parameter_position (VALA_METHOD (self), ((double) (-3)));
 	return self;
 }
 
 
+ValaCreationMethod* vala_creation_method_new (const char* type_name, const char* name, ValaSourceReference* source_reference) {
+	return vala_creation_method_construct (VALA_TYPE_CREATION_METHOD, type_name, name, source_reference);
+}
+
+
 static void vala_creation_method_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaCreationMethod * self;
 	self = VALA_CREATION_METHOD (base);
@@ -101,10 +110,10 @@ static void vala_creation_method_real_accept_children (ValaCodeNode* base, ValaC
 			param = ((ValaFormalParameter*) (gee_list_get (GEE_LIST (param_collection), param_it)));
 			{
 				vala_code_node_accept (VALA_CODE_NODE (param), visitor);
-				(param == NULL ? NULL : (param = (g_object_unref (param), NULL)));
+				(param == NULL ? NULL : (param = (vala_code_node_unref (param), NULL)));
 			}
 		}
-		(param_collection == NULL ? NULL : (param_collection = (g_object_unref (param_collection), NULL)));
+		(param_collection == NULL ? NULL : (param_collection = (gee_collection_object_unref (param_collection), NULL)));
 	}
 	{
 		GeeList* error_type_collection;
@@ -115,10 +124,10 @@ static void vala_creation_method_real_accept_children (ValaCodeNode* base, ValaC
 			error_type = ((ValaDataType*) (gee_list_get (GEE_LIST (error_type_collection), error_type_it)));
 			{
 				vala_code_node_accept (VALA_CODE_NODE (error_type), visitor);
-				(error_type == NULL ? NULL : (error_type = (g_object_unref (error_type), NULL)));
+				(error_type == NULL ? NULL : (error_type = (vala_code_node_unref (error_type), NULL)));
 			}
 		}
-		(error_type_collection == NULL ? NULL : (error_type_collection = (g_object_unref (error_type_collection), NULL)));
+		(error_type_collection == NULL ? NULL : (error_type_collection = (gee_collection_object_unref (error_type_collection), NULL)));
 	}
 	if (vala_method_get_body (VALA_METHOD (self)) != NULL) {
 		vala_code_node_accept (VALA_CODE_NODE (vala_method_get_body (VALA_METHOD (self))), visitor);
@@ -135,21 +144,21 @@ static char* vala_creation_method_real_get_default_cname (ValaMethod* base) {
 	self = VALA_CREATION_METHOD (base);
 	_tmp1 = NULL;
 	_tmp0 = NULL;
-	parent = (_tmp1 = (_tmp0 = vala_symbol_get_parent_symbol (VALA_SYMBOL (self)), (VALA_IS_TYPESYMBOL (_tmp0) ? ((ValaTypeSymbol*) (_tmp0)) : NULL)), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
+	parent = (_tmp1 = (_tmp0 = vala_symbol_get_parent_symbol (VALA_SYMBOL (self)), (VALA_IS_TYPESYMBOL (_tmp0) ? ((ValaTypeSymbol*) (_tmp0)) : NULL)), (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1)));
 	infix = g_strdup ("new");
 	if (VALA_IS_STRUCT (parent)) {
 		char* _tmp2;
 		_tmp2 = NULL;
 		infix = (_tmp2 = g_strdup ("init"), (infix = (g_free (infix), NULL)), _tmp2);
 	}
-	if (g_utf8_strlen (vala_symbol_get_name (VALA_SYMBOL (self)), -1) == g_utf8_strlen (".new", -1)) {
+	if (_vala_strcmp0 (vala_symbol_get_name (VALA_SYMBOL (self)), "new") == 0) {
 		char* _tmp3;
 		char* _tmp4;
 		char* _tmp5;
 		_tmp3 = NULL;
 		_tmp4 = NULL;
 		_tmp5 = NULL;
-		return (_tmp5 = (_tmp4 = g_strdup_printf ("%s%s", (_tmp3 = vala_symbol_get_lower_case_cprefix (VALA_SYMBOL (parent))), infix), (_tmp3 = (g_free (_tmp3), NULL)), _tmp4), (parent == NULL ? NULL : (parent = (g_object_unref (parent), NULL))), (infix = (g_free (infix), NULL)), _tmp5);
+		return (_tmp5 = (_tmp4 = g_strdup_printf ("%s%s", (_tmp3 = vala_symbol_get_lower_case_cprefix (VALA_SYMBOL (parent))), infix), (_tmp3 = (g_free (_tmp3), NULL)), _tmp4), (parent == NULL ? NULL : (parent = (vala_code_node_unref (parent), NULL))), (infix = (g_free (infix), NULL)), _tmp5);
 	} else {
 		char* _tmp6;
 		char* _tmp7;
@@ -157,9 +166,9 @@ static char* vala_creation_method_real_get_default_cname (ValaMethod* base) {
 		_tmp6 = NULL;
 		_tmp7 = NULL;
 		_tmp8 = NULL;
-		return (_tmp8 = (_tmp7 = g_strdup_printf ("%s%s_%s", (_tmp6 = vala_symbol_get_lower_case_cprefix (VALA_SYMBOL (parent))), infix, g_utf8_offset_to_pointer (vala_symbol_get_name (VALA_SYMBOL (self)), g_utf8_strlen (".new.", -1))), (_tmp6 = (g_free (_tmp6), NULL)), _tmp7), (parent == NULL ? NULL : (parent = (g_object_unref (parent), NULL))), (infix = (g_free (infix), NULL)), _tmp8);
+		return (_tmp8 = (_tmp7 = g_strdup_printf ("%s%s_%s", (_tmp6 = vala_symbol_get_lower_case_cprefix (VALA_SYMBOL (parent))), infix, vala_symbol_get_name (VALA_SYMBOL (self))), (_tmp6 = (g_free (_tmp6), NULL)), _tmp7), (parent == NULL ? NULL : (parent = (vala_code_node_unref (parent), NULL))), (infix = (g_free (infix), NULL)), _tmp8);
 	}
-	(parent == NULL ? NULL : (parent = (g_object_unref (parent), NULL)));
+	(parent == NULL ? NULL : (parent = (vala_code_node_unref (parent), NULL)));
 	infix = (g_free (infix), NULL);
 }
 
@@ -172,6 +181,44 @@ static ValaCodeBinding* vala_creation_method_real_create_code_binding (ValaCodeN
 }
 
 
+static char* vala_creation_method_real_get_real_cname (ValaMethod* base) {
+	ValaCreationMethod * self;
+	ValaClass* _tmp1;
+	ValaSymbol* _tmp0;
+	ValaClass* parent;
+	char* infix;
+	self = VALA_CREATION_METHOD (base);
+	_tmp1 = NULL;
+	_tmp0 = NULL;
+	parent = (_tmp1 = (_tmp0 = vala_symbol_get_parent_symbol (VALA_SYMBOL (self)), (VALA_IS_CLASS (_tmp0) ? ((ValaClass*) (_tmp0)) : NULL)), (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1)));
+	if (parent == NULL || vala_class_get_is_compact (parent)) {
+		char* _tmp2;
+		_tmp2 = NULL;
+		return (_tmp2 = vala_method_get_cname (VALA_METHOD (self)), (parent == NULL ? NULL : (parent = (vala_code_node_unref (parent), NULL))), _tmp2);
+	}
+	infix = g_strdup ("construct");
+	if (_vala_strcmp0 (vala_symbol_get_name (VALA_SYMBOL (self)), "new") == 0) {
+		char* _tmp3;
+		char* _tmp4;
+		char* _tmp5;
+		_tmp3 = NULL;
+		_tmp4 = NULL;
+		_tmp5 = NULL;
+		return (_tmp5 = (_tmp4 = g_strdup_printf ("%s%s", (_tmp3 = vala_symbol_get_lower_case_cprefix (VALA_SYMBOL (parent))), infix), (_tmp3 = (g_free (_tmp3), NULL)), _tmp4), (parent == NULL ? NULL : (parent = (vala_code_node_unref (parent), NULL))), (infix = (g_free (infix), NULL)), _tmp5);
+	} else {
+		char* _tmp6;
+		char* _tmp7;
+		char* _tmp8;
+		_tmp6 = NULL;
+		_tmp7 = NULL;
+		_tmp8 = NULL;
+		return (_tmp8 = (_tmp7 = g_strdup_printf ("%s%s_%s", (_tmp6 = vala_symbol_get_lower_case_cprefix (VALA_SYMBOL (parent))), infix, vala_symbol_get_name (VALA_SYMBOL (self))), (_tmp6 = (g_free (_tmp6), NULL)), _tmp7), (parent == NULL ? NULL : (parent = (vala_code_node_unref (parent), NULL))), (infix = (g_free (infix), NULL)), _tmp8);
+	}
+	(parent == NULL ? NULL : (parent = (vala_code_node_unref (parent), NULL)));
+	infix = (g_free (infix), NULL);
+}
+
+
 const char* vala_creation_method_get_type_name (ValaCreationMethod* self) {
 	g_return_val_if_fail (VALA_IS_CREATION_METHOD (self), NULL);
 	return self->priv->_type_name;
@@ -185,7 +232,6 @@ void vala_creation_method_set_type_name (ValaCreationMethod* self, const char* v
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_type_name = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_type_name = (g_free (self->priv->_type_name), NULL)), _tmp2);
-	g_object_notify (((GObject *) (self)), "type-name");
 }
 
 
@@ -198,7 +244,6 @@ gint vala_creation_method_get_n_construction_params (ValaCreationMethod* self) {
 void vala_creation_method_set_n_construction_params (ValaCreationMethod* self, gint value) {
 	g_return_if_fail (VALA_IS_CREATION_METHOD (self));
 	self->priv->_n_construction_params = value;
-	g_object_notify (((GObject *) (self)), "n-construction-params");
 }
 
 
@@ -215,63 +260,30 @@ void vala_creation_method_set_custom_return_type_cname (ValaCreationMethod* self
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_custom_return_type_cname = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_custom_return_type_cname = (g_free (self->priv->_custom_return_type_cname), NULL)), _tmp2);
-	g_object_notify (((GObject *) (self)), "custom-return-type-cname");
 }
 
 
-static void vala_creation_method_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
-	ValaCreationMethod * self;
-	self = VALA_CREATION_METHOD (object);
-	switch (property_id) {
-		case VALA_CREATION_METHOD_TYPE_NAME:
-		g_value_set_string (value, vala_creation_method_get_type_name (self));
-		break;
-		case VALA_CREATION_METHOD_N_CONSTRUCTION_PARAMS:
-		g_value_set_int (value, vala_creation_method_get_n_construction_params (self));
-		break;
-		case VALA_CREATION_METHOD_CUSTOM_RETURN_TYPE_CNAME:
-		g_value_set_string (value, vala_creation_method_get_custom_return_type_cname (self));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
+gboolean vala_creation_method_get_chain_up (ValaCreationMethod* self) {
+	g_return_val_if_fail (VALA_IS_CREATION_METHOD (self), FALSE);
+	return self->priv->_chain_up;
 }
 
 
-static void vala_creation_method_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
-	ValaCreationMethod * self;
-	self = VALA_CREATION_METHOD (object);
-	switch (property_id) {
-		case VALA_CREATION_METHOD_TYPE_NAME:
-		vala_creation_method_set_type_name (self, g_value_get_string (value));
-		break;
-		case VALA_CREATION_METHOD_N_CONSTRUCTION_PARAMS:
-		vala_creation_method_set_n_construction_params (self, g_value_get_int (value));
-		break;
-		case VALA_CREATION_METHOD_CUSTOM_RETURN_TYPE_CNAME:
-		vala_creation_method_set_custom_return_type_cname (self, g_value_get_string (value));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
+void vala_creation_method_set_chain_up (ValaCreationMethod* self, gboolean value) {
+	g_return_if_fail (VALA_IS_CREATION_METHOD (self));
+	self->priv->_chain_up = value;
 }
 
 
 static void vala_creation_method_class_init (ValaCreationMethodClass * klass) {
 	vala_creation_method_parent_class = g_type_class_peek_parent (klass);
+	VALA_CODE_NODE_CLASS (klass)->finalize = vala_creation_method_finalize;
 	g_type_class_add_private (klass, sizeof (ValaCreationMethodPrivate));
-	G_OBJECT_CLASS (klass)->get_property = vala_creation_method_get_property;
-	G_OBJECT_CLASS (klass)->set_property = vala_creation_method_set_property;
-	G_OBJECT_CLASS (klass)->finalize = vala_creation_method_finalize;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_creation_method_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_creation_method_real_accept_children;
 	VALA_METHOD_CLASS (klass)->get_default_cname = vala_creation_method_real_get_default_cname;
 	VALA_CODE_NODE_CLASS (klass)->create_code_binding = vala_creation_method_real_create_code_binding;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CREATION_METHOD_TYPE_NAME, g_param_spec_string ("type-name", "type-name", "type-name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CREATION_METHOD_N_CONSTRUCTION_PARAMS, g_param_spec_int ("n-construction-params", "n-construction-params", "n-construction-params", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CREATION_METHOD_CUSTOM_RETURN_TYPE_CNAME, g_param_spec_string ("custom-return-type-cname", "custom-return-type-cname", "custom-return-type-cname", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	VALA_METHOD_CLASS (klass)->get_real_cname = vala_creation_method_real_get_real_cname;
 }
 
 
@@ -280,24 +292,35 @@ static void vala_creation_method_instance_init (ValaCreationMethod * self) {
 }
 
 
-static void vala_creation_method_finalize (GObject * obj) {
+static void vala_creation_method_finalize (ValaCodeNode* obj) {
 	ValaCreationMethod * self;
 	self = VALA_CREATION_METHOD (obj);
 	self->priv->_type_name = (g_free (self->priv->_type_name), NULL);
 	self->priv->_custom_return_type_cname = (g_free (self->priv->_custom_return_type_cname), NULL);
-	G_OBJECT_CLASS (vala_creation_method_parent_class)->finalize (obj);
+	VALA_CODE_NODE_CLASS (vala_creation_method_parent_class)->finalize (obj);
 }
 
 
 GType vala_creation_method_get_type (void) {
 	static GType vala_creation_method_type_id = 0;
 	if (vala_creation_method_type_id == 0) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaCreationMethodClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_creation_method_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCreationMethod), 0, (GInstanceInitFunc) vala_creation_method_instance_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaCreationMethodClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_creation_method_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCreationMethod), 0, (GInstanceInitFunc) vala_creation_method_instance_init, NULL };
 		vala_creation_method_type_id = g_type_register_static (VALA_TYPE_METHOD, "ValaCreationMethod", &g_define_type_info, 0);
 	}
 	return vala_creation_method_type_id;
 }
 
 
+static int _vala_strcmp0 (const char * str1, const char * str2) {
+	if (str1 == NULL) {
+		return -(str1 != str2);
+	}
+	if (str2 == NULL) {
+		return (str1 != str2);
+	}
+	return strcmp (str1, str2);
+}
+
+
 
 
