@@ -37,7 +37,6 @@
 #include <vala/valaenum.h>
 #include <vala/valastruct.h>
 #include <vala/valasemanticanalyzer.h>
-#include <vala/valavaluetype.h>
 
 
 
@@ -55,14 +54,7 @@ struct _ValaDataTypePrivate {
 
 #define VALA_DATA_TYPE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_DATA_TYPE, ValaDataTypePrivate))
 enum  {
-	VALA_DATA_TYPE_DUMMY_PROPERTY,
-	VALA_DATA_TYPE_VALUE_OWNED,
-	VALA_DATA_TYPE_NULLABLE,
-	VALA_DATA_TYPE_IS_TYPE_ARGUMENT,
-	VALA_DATA_TYPE_DATA_TYPE,
-	VALA_DATA_TYPE_TYPE_PARAMETER,
-	VALA_DATA_TYPE_FLOATING_REFERENCE,
-	VALA_DATA_TYPE_IS_DYNAMIC
+	VALA_DATA_TYPE_DUMMY_PROPERTY
 };
 static GeeList* vala_data_type__empty_type_list;
 static void vala_data_type_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
@@ -70,6 +62,7 @@ static char* vala_data_type_real_get_cname (ValaDataType* self);
 static char* vala_data_type_real_get_lower_case_cname (ValaDataType* self, const char* infix);
 static char* vala_data_type_real_to_string (ValaCodeNode* base);
 static char* vala_data_type_real_to_qualified_string (ValaDataType* self, ValaScope* scope);
+static ValaDataType* vala_data_type_real_copy (ValaDataType* self);
 static gboolean vala_data_type_real_equals (ValaDataType* self, ValaDataType* type2);
 static gboolean vala_data_type_real_stricter (ValaDataType* self, ValaDataType* type2);
 static void vala_data_type_real_replace_type (ValaCodeNode* base, ValaDataType* old_type, ValaDataType* new_type);
@@ -87,7 +80,7 @@ static char* vala_data_type_real_get_type_id (ValaDataType* self);
 static char* vala_data_type_real_get_type_signature (ValaDataType* self);
 static gboolean vala_data_type_real_is_disposable (ValaDataType* self);
 static gpointer vala_data_type_parent_class = NULL;
-static void vala_data_type_dispose (GObject * obj);
+static void vala_data_type_finalize (ValaCodeNode* obj);
 
 
 
@@ -102,7 +95,7 @@ void vala_data_type_add_type_argument (ValaDataType* self, ValaDataType* arg) {
 	if (self->priv->type_argument_list == NULL) {
 		GeeList* _tmp0;
 		_tmp0 = NULL;
-		self->priv->type_argument_list = (_tmp0 = GEE_LIST (gee_array_list_new (VALA_TYPE_DATA_TYPE, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal)), (self->priv->type_argument_list == NULL ? NULL : (self->priv->type_argument_list = (g_object_unref (self->priv->type_argument_list), NULL))), _tmp0);
+		self->priv->type_argument_list = (_tmp0 = GEE_LIST (gee_array_list_new (VALA_TYPE_DATA_TYPE, ((GBoxedCopyFunc) (vala_code_node_ref)), vala_code_node_unref, g_direct_equal)), (self->priv->type_argument_list == NULL ? NULL : (self->priv->type_argument_list = (gee_collection_object_unref (self->priv->type_argument_list), NULL))), _tmp0);
 	}
 	gee_collection_add (GEE_COLLECTION (self->priv->type_argument_list), arg);
 	vala_code_node_set_parent_node (VALA_CODE_NODE (arg), VALA_CODE_NODE (self));
@@ -120,18 +113,18 @@ GeeList* vala_data_type_get_type_arguments (ValaDataType* self) {
 	if (self->priv->type_argument_list != NULL) {
 		GeeList* _tmp0;
 		_tmp0 = NULL;
-		return (_tmp0 = self->priv->type_argument_list, (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
+		return (_tmp0 = self->priv->type_argument_list, (_tmp0 == NULL ? NULL : gee_collection_object_ref (_tmp0)));
 	}
 	if (vala_data_type__empty_type_list == NULL) {
 		GeeList* _tmp3;
 		GeeArrayList* _tmp2;
 		_tmp3 = NULL;
 		_tmp2 = NULL;
-		vala_data_type__empty_type_list = (_tmp3 = GEE_LIST (gee_read_only_list_new (VALA_TYPE_DATA_TYPE, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, GEE_LIST ((_tmp2 = gee_array_list_new (VALA_TYPE_DATA_TYPE, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal))))), (vala_data_type__empty_type_list == NULL ? NULL : (vala_data_type__empty_type_list = (g_object_unref (vala_data_type__empty_type_list), NULL))), _tmp3);
-		(_tmp2 == NULL ? NULL : (_tmp2 = (g_object_unref (_tmp2), NULL)));
+		vala_data_type__empty_type_list = (_tmp3 = GEE_LIST (gee_read_only_list_new (VALA_TYPE_DATA_TYPE, ((GBoxedCopyFunc) (vala_code_node_ref)), vala_code_node_unref, GEE_LIST ((_tmp2 = gee_array_list_new (VALA_TYPE_DATA_TYPE, ((GBoxedCopyFunc) (vala_code_node_ref)), vala_code_node_unref, g_direct_equal))))), (vala_data_type__empty_type_list == NULL ? NULL : (vala_data_type__empty_type_list = (gee_collection_object_unref (vala_data_type__empty_type_list), NULL))), _tmp3);
+		(_tmp2 == NULL ? NULL : (_tmp2 = (gee_collection_object_unref (_tmp2), NULL)));
 	}
 	_tmp4 = NULL;
-	return (_tmp4 = vala_data_type__empty_type_list, (_tmp4 == NULL ? NULL : g_object_ref (_tmp4)));
+	return (_tmp4 = vala_data_type__empty_type_list, (_tmp4 == NULL ? NULL : gee_collection_object_ref (_tmp4)));
 }
 
 
@@ -142,7 +135,7 @@ void vala_data_type_remove_all_type_arguments (ValaDataType* self) {
 	GeeList* _tmp0;
 	g_return_if_fail (VALA_IS_DATA_TYPE (self));
 	_tmp0 = NULL;
-	self->priv->type_argument_list = (_tmp0 = NULL, (self->priv->type_argument_list == NULL ? NULL : (self->priv->type_argument_list = (g_object_unref (self->priv->type_argument_list), NULL))), _tmp0);
+	self->priv->type_argument_list = (_tmp0 = NULL, (self->priv->type_argument_list == NULL ? NULL : (self->priv->type_argument_list = (gee_collection_object_unref (self->priv->type_argument_list), NULL))), _tmp0);
 }
 
 
@@ -160,7 +153,7 @@ static void vala_data_type_real_accept (ValaCodeNode* base, ValaCodeVisitor* vis
 				type_arg = ((ValaDataType*) (gee_list_get (GEE_LIST (type_arg_collection), type_arg_it)));
 				{
 					vala_code_node_accept (VALA_CODE_NODE (type_arg), visitor);
-					(type_arg == NULL ? NULL : (type_arg = (g_object_unref (type_arg), NULL)));
+					(type_arg == NULL ? NULL : (type_arg = (vala_code_node_unref (type_arg), NULL)));
 				}
 			}
 		}
@@ -208,13 +201,13 @@ char* vala_data_type_get_const_cname (ValaDataType* self) {
 		ValaTypeSymbol* _tmp0;
 		_tmp1 = NULL;
 		_tmp0 = NULL;
-		t = (_tmp1 = (_tmp0 = vala_array_type_get_element_type ((VALA_ARRAY_TYPE (self)))->priv->_data_type, (_tmp0 == NULL ? NULL : g_object_ref (_tmp0))), (t == NULL ? NULL : (t = (g_object_unref (t), NULL))), _tmp1);
+		t = (_tmp1 = (_tmp0 = vala_array_type_get_element_type ((VALA_ARRAY_TYPE (self)))->priv->_data_type, (_tmp0 == NULL ? NULL : vala_code_node_ref (_tmp0))), (t == NULL ? NULL : (t = (vala_code_node_unref (t), NULL))), _tmp1);
 	} else {
 		ValaTypeSymbol* _tmp3;
 		ValaTypeSymbol* _tmp2;
 		_tmp3 = NULL;
 		_tmp2 = NULL;
-		t = (_tmp3 = (_tmp2 = self->priv->_data_type, (_tmp2 == NULL ? NULL : g_object_ref (_tmp2))), (t == NULL ? NULL : (t = (g_object_unref (t), NULL))), _tmp3);
+		t = (_tmp3 = (_tmp2 = self->priv->_data_type, (_tmp2 == NULL ? NULL : vala_code_node_ref (_tmp2))), (t == NULL ? NULL : (t = (vala_code_node_unref (t), NULL))), _tmp3);
 	}
 	if (!vala_typesymbol_is_reference_type (t)) {
 		char* _tmp4;
@@ -228,7 +221,7 @@ char* vala_data_type_get_const_cname (ValaDataType* self) {
 	_tmp6 = NULL;
 	_tmp7 = NULL;
 	_tmp8 = NULL;
-	return (_tmp8 = (_tmp7 = g_strdup_printf ("const %s%s", (_tmp6 = vala_typesymbol_get_cname (t, FALSE)), ptr), (_tmp6 = (g_free (_tmp6), NULL)), _tmp7), (ptr = (g_free (ptr), NULL)), (t == NULL ? NULL : (t = (g_object_unref (t), NULL))), _tmp8);
+	return (_tmp8 = (_tmp7 = g_strdup_printf ("const %s%s", (_tmp6 = vala_typesymbol_get_cname (t, FALSE)), ptr), (_tmp6 = (g_free (_tmp6), NULL)), _tmp7), (ptr = (g_free (ptr), NULL)), (t == NULL ? NULL : (t = (vala_code_node_unref (t), NULL))), _tmp8);
 }
 
 
@@ -272,26 +265,26 @@ static char* vala_data_type_real_to_qualified_string (ValaDataType* self, ValaSc
 		ValaScope* _tmp3;
 		ValaScope* parent_scope;
 		_tmp0 = NULL;
-		global_symbol = (_tmp0 = VALA_SYMBOL (self->priv->_data_type), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
+		global_symbol = (_tmp0 = VALA_SYMBOL (self->priv->_data_type), (_tmp0 == NULL ? NULL : vala_code_node_ref (_tmp0)));
 		while (vala_symbol_get_name (vala_symbol_get_parent_symbol (global_symbol)) != NULL) {
 			ValaSymbol* _tmp2;
 			ValaSymbol* _tmp1;
 			_tmp2 = NULL;
 			_tmp1 = NULL;
-			global_symbol = (_tmp2 = (_tmp1 = vala_symbol_get_parent_symbol (global_symbol), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (global_symbol == NULL ? NULL : (global_symbol = (g_object_unref (global_symbol), NULL))), _tmp2);
+			global_symbol = (_tmp2 = (_tmp1 = vala_symbol_get_parent_symbol (global_symbol), (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1))), (global_symbol == NULL ? NULL : (global_symbol = (vala_code_node_unref (global_symbol), NULL))), _tmp2);
 		}
 		sym = NULL;
 		_tmp3 = NULL;
-		parent_scope = (_tmp3 = scope, (_tmp3 == NULL ? NULL : g_object_ref (_tmp3)));
+		parent_scope = (_tmp3 = scope, (_tmp3 == NULL ? NULL : vala_scope_ref (_tmp3)));
 		while (sym == NULL && parent_scope != NULL) {
 			ValaSymbol* _tmp4;
 			ValaScope* _tmp6;
 			ValaScope* _tmp5;
 			_tmp4 = NULL;
-			sym = (_tmp4 = vala_scope_lookup (parent_scope, vala_symbol_get_name (global_symbol)), (sym == NULL ? NULL : (sym = (g_object_unref (sym), NULL))), _tmp4);
+			sym = (_tmp4 = vala_scope_lookup (parent_scope, vala_symbol_get_name (global_symbol)), (sym == NULL ? NULL : (sym = (vala_code_node_unref (sym), NULL))), _tmp4);
 			_tmp6 = NULL;
 			_tmp5 = NULL;
-			parent_scope = (_tmp6 = (_tmp5 = vala_scope_get_parent_scope (parent_scope), (_tmp5 == NULL ? NULL : g_object_ref (_tmp5))), (parent_scope == NULL ? NULL : (parent_scope = (g_object_unref (parent_scope), NULL))), _tmp6);
+			parent_scope = (_tmp6 = (_tmp5 = vala_scope_get_parent_scope (parent_scope), (_tmp5 == NULL ? NULL : vala_scope_ref (_tmp5))), (parent_scope == NULL ? NULL : (parent_scope = (vala_scope_unref (parent_scope), NULL))), _tmp6);
 		}
 		if (sym != NULL && global_symbol != sym) {
 			char* _tmp8;
@@ -306,9 +299,9 @@ static char* vala_data_type_real_to_qualified_string (ValaDataType* self, ValaSc
 			_tmp9 = NULL;
 			s = (_tmp9 = vala_symbol_get_full_name (VALA_SYMBOL (self->priv->_data_type)), (s = (g_free (s), NULL)), _tmp9);
 		}
-		(global_symbol == NULL ? NULL : (global_symbol = (g_object_unref (global_symbol), NULL)));
-		(sym == NULL ? NULL : (sym = (g_object_unref (sym), NULL)));
-		(parent_scope == NULL ? NULL : (parent_scope = (g_object_unref (parent_scope), NULL)));
+		(global_symbol == NULL ? NULL : (global_symbol = (vala_code_node_unref (global_symbol), NULL)));
+		(sym == NULL ? NULL : (sym = (vala_code_node_unref (sym), NULL)));
+		(parent_scope == NULL ? NULL : (parent_scope = (vala_scope_unref (parent_scope), NULL)));
 	} else {
 		if (self->priv->_type_parameter != NULL) {
 			char* _tmp11;
@@ -323,7 +316,7 @@ static char* vala_data_type_real_to_qualified_string (ValaDataType* self, ValaSc
 		}
 	}
 	type_args = vala_data_type_get_type_arguments (self);
-	if (!(VALA_IS_ARRAY_TYPE (self)) && gee_collection_get_size (GEE_COLLECTION (type_args)) > 0) {
+	if (gee_collection_get_size (GEE_COLLECTION (type_args)) > 0) {
 		char* _tmp13;
 		gboolean first;
 		char* _tmp18;
@@ -356,7 +349,7 @@ static char* vala_data_type_real_to_qualified_string (ValaDataType* self, ValaSc
 					_tmp16 = NULL;
 					s = (_tmp17 = g_strconcat (s, (_tmp16 = (vala_data_type_to_qualified_string (type_arg, scope))), NULL), (s = (g_free (s), NULL)), _tmp17);
 					_tmp16 = (g_free (_tmp16), NULL);
-					(type_arg == NULL ? NULL : (type_arg = (g_object_unref (type_arg), NULL)));
+					(type_arg == NULL ? NULL : (type_arg = (vala_code_node_unref (type_arg), NULL)));
 				}
 			}
 		}
@@ -369,7 +362,7 @@ static char* vala_data_type_real_to_qualified_string (ValaDataType* self, ValaSc
 		s = (_tmp19 = g_strconcat (s, ("?"), NULL), (s = (g_free (s), NULL)), _tmp19);
 	}
 	_tmp20 = NULL;
-	return (_tmp20 = s, (type_args == NULL ? NULL : (type_args = (g_object_unref (type_args), NULL))), _tmp20);
+	return (_tmp20 = s, (type_args == NULL ? NULL : (type_args = (gee_collection_object_unref (type_args), NULL))), _tmp20);
 }
 
 
@@ -378,6 +371,13 @@ char* vala_data_type_to_qualified_string (ValaDataType* self, ValaScope* scope)
 }
 
 
+static ValaDataType* vala_data_type_real_copy (ValaDataType* self) {
+	g_return_val_if_fail (VALA_IS_DATA_TYPE (self), NULL);
+	g_critical ("Type `%s' does not implement abstract method `vala_data_type_copy'", g_type_name (G_TYPE_FROM_INSTANCE (self)));
+	return NULL;
+}
+
+
 /**
  * Creates a shallow copy of this type reference.
  *
@@ -478,7 +478,7 @@ static void vala_data_type_real_replace_type (ValaCodeNode* base, ValaDataType*
 				ValaDataType* _tmp0;
 				gboolean _tmp1;
 				_tmp0 = NULL;
-				if ((_tmp1 = (_tmp0 = ((ValaDataType*) (gee_list_get (((GeeList*) (self->priv->type_argument_list)), i)))) == old_type, (_tmp0 == NULL ? NULL : (_tmp0 = (g_object_unref (_tmp0), NULL))), _tmp1)) {
+				if ((_tmp1 = (_tmp0 = ((ValaDataType*) (gee_list_get (((GeeList*) (self->priv->type_argument_list)), i)))) == old_type, (_tmp0 == NULL ? NULL : (_tmp0 = (vala_code_node_unref (_tmp0), NULL))), _tmp1)) {
 					gee_list_set (((GeeList*) (self->priv->type_argument_list)), i, new_type);
 					return;
 				}
@@ -520,22 +520,22 @@ static gboolean vala_data_type_real_compatible (ValaDataType* self, ValaDataType
 		ValaStruct* _tmp8;
 		ValaStruct* expect_struct;
 		_tmp7 = NULL;
-		expr_struct = (_tmp7 = VALA_STRUCT (self->priv->_data_type), (_tmp7 == NULL ? NULL : g_object_ref (_tmp7)));
+		expr_struct = (_tmp7 = VALA_STRUCT (self->priv->_data_type), (_tmp7 == NULL ? NULL : vala_code_node_ref (_tmp7)));
 		_tmp8 = NULL;
-		expect_struct = (_tmp8 = VALA_STRUCT (target_type->priv->_data_type), (_tmp8 == NULL ? NULL : g_object_ref (_tmp8)));
+		expect_struct = (_tmp8 = VALA_STRUCT (target_type->priv->_data_type), (_tmp8 == NULL ? NULL : vala_code_node_ref (_tmp8)));
 		/* integer types may be implicitly cast to floating point types */
 		if (vala_struct_is_integer_type (expr_struct) && vala_struct_is_floating_type (expect_struct)) {
 			gboolean _tmp9;
-			return (_tmp9 = TRUE, (expr_struct == NULL ? NULL : (expr_struct = (g_object_unref (expr_struct), NULL))), (expect_struct == NULL ? NULL : (expect_struct = (g_object_unref (expect_struct), NULL))), _tmp9);
+			return (_tmp9 = TRUE, (expr_struct == NULL ? NULL : (expr_struct = (vala_code_node_unref (expr_struct), NULL))), (expect_struct == NULL ? NULL : (expect_struct = (vala_code_node_unref (expect_struct), NULL))), _tmp9);
 		}
 		if ((vala_struct_is_integer_type (expr_struct) && vala_struct_is_integer_type (expect_struct)) || (vala_struct_is_floating_type (expr_struct) && vala_struct_is_floating_type (expect_struct))) {
 			if (vala_struct_get_rank (expr_struct) <= vala_struct_get_rank (expect_struct)) {
 				gboolean _tmp10;
-				return (_tmp10 = TRUE, (expr_struct == NULL ? NULL : (expr_struct = (g_object_unref (expr_struct), NULL))), (expect_struct == NULL ? NULL : (expect_struct = (g_object_unref (expect_struct), NULL))), _tmp10);
+				return (_tmp10 = TRUE, (expr_struct == NULL ? NULL : (expr_struct = (vala_code_node_unref (expr_struct), NULL))), (expect_struct == NULL ? NULL : (expect_struct = (vala_code_node_unref (expect_struct), NULL))), _tmp10);
 			}
 		}
-		(expr_struct == NULL ? NULL : (expr_struct = (g_object_unref (expr_struct), NULL)));
-		(expect_struct == NULL ? NULL : (expect_struct = (g_object_unref (expect_struct), NULL)));
+		(expr_struct == NULL ? NULL : (expr_struct = (vala_code_node_unref (expr_struct), NULL)));
+		(expect_struct == NULL ? NULL : (expect_struct = (vala_code_node_unref (expect_struct), NULL)));
 	}
 	if (self->priv->_data_type != NULL && target_type->priv->_data_type != NULL && vala_typesymbol_is_subtype_of (self->priv->_data_type, target_type->priv->_data_type)) {
 		return TRUE;
@@ -627,7 +627,7 @@ gboolean vala_data_type_is_array (ValaDataType* self) {
 static GeeList* vala_data_type_real_get_symbols (ValaDataType* self) {
 	GeeArrayList* symbols;
 	g_return_val_if_fail (VALA_IS_DATA_TYPE (self), NULL);
-	symbols = gee_array_list_new (VALA_TYPE_SYMBOL, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal);
+	symbols = gee_array_list_new (VALA_TYPE_SYMBOL, ((GBoxedCopyFunc) (vala_code_node_ref)), vala_code_node_unref, g_direct_equal);
 	if (self->priv->_data_type != NULL) {
 		gee_collection_add (GEE_COLLECTION (symbols), VALA_SYMBOL (self->priv->_data_type));
 	}
@@ -679,12 +679,12 @@ static gboolean vala_data_type_real_is_real_struct_type (ValaDataType* self) {
 	g_return_val_if_fail (VALA_IS_DATA_TYPE (self), FALSE);
 	_tmp1 = NULL;
 	_tmp0 = NULL;
-	s = (_tmp1 = (_tmp0 = self->priv->_data_type, (VALA_IS_STRUCT (_tmp0) ? ((ValaStruct*) (_tmp0)) : NULL)), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
+	s = (_tmp1 = (_tmp0 = self->priv->_data_type, (VALA_IS_STRUCT (_tmp0) ? ((ValaStruct*) (_tmp0)) : NULL)), (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1)));
 	if (s != NULL && !vala_struct_is_simple_type (s)) {
 		gboolean _tmp2;
-		return (_tmp2 = TRUE, (s == NULL ? NULL : (s = (g_object_unref (s), NULL))), _tmp2);
+		return (_tmp2 = TRUE, (s == NULL ? NULL : (s = (vala_code_node_unref (s), NULL))), _tmp2);
 	}
-	return (_tmp3 = FALSE, (s == NULL ? NULL : (s = (g_object_unref (s), NULL))), _tmp3);
+	return (_tmp3 = FALSE, (s == NULL ? NULL : (s = (vala_code_node_unref (s), NULL))), _tmp3);
 }
 
 
@@ -738,11 +738,6 @@ static gboolean vala_data_type_real_is_disposable (ValaDataType* self) {
 	}
 	if (vala_data_type_is_reference_type_or_type_parameter (self)) {
 		return TRUE;
-	} else {
-		if (VALA_IS_VALUE_TYPE (self)) {
-			/* nullable structs are heap allocated*/
-			return self->priv->_nullable;
-		}
 	}
 	return FALSE;
 }
@@ -813,7 +808,7 @@ void vala_data_type_set_type_parameter (ValaDataType* self, ValaTypeParameter* v
 	g_return_if_fail (VALA_IS_DATA_TYPE (self));
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_type_parameter = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_type_parameter == NULL ? NULL : (self->priv->_type_parameter = (g_object_unref (self->priv->_type_parameter), NULL))), _tmp2);
+	self->priv->_type_parameter = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1))), (self->priv->_type_parameter == NULL ? NULL : (self->priv->_type_parameter = (vala_code_node_unref (self->priv->_type_parameter), NULL))), _tmp2);
 }
 
 
@@ -841,81 +836,16 @@ void vala_data_type_set_is_dynamic (ValaDataType* self, gboolean value) {
 }
 
 
-static void vala_data_type_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
-	ValaDataType * self;
-	self = VALA_DATA_TYPE (object);
-	switch (property_id) {
-		case VALA_DATA_TYPE_VALUE_OWNED:
-		g_value_set_boolean (value, vala_data_type_get_value_owned (self));
-		break;
-		case VALA_DATA_TYPE_NULLABLE:
-		g_value_set_boolean (value, vala_data_type_get_nullable (self));
-		break;
-		case VALA_DATA_TYPE_IS_TYPE_ARGUMENT:
-		g_value_set_boolean (value, vala_data_type_get_is_type_argument (self));
-		break;
-		case VALA_DATA_TYPE_DATA_TYPE:
-		g_value_set_object (value, vala_data_type_get_data_type (self));
-		break;
-		case VALA_DATA_TYPE_TYPE_PARAMETER:
-		g_value_set_object (value, vala_data_type_get_type_parameter (self));
-		break;
-		case VALA_DATA_TYPE_FLOATING_REFERENCE:
-		g_value_set_boolean (value, vala_data_type_get_floating_reference (self));
-		break;
-		case VALA_DATA_TYPE_IS_DYNAMIC:
-		g_value_set_boolean (value, vala_data_type_get_is_dynamic (self));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
-static void vala_data_type_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
-	ValaDataType * self;
-	self = VALA_DATA_TYPE (object);
-	switch (property_id) {
-		case VALA_DATA_TYPE_VALUE_OWNED:
-		vala_data_type_set_value_owned (self, g_value_get_boolean (value));
-		break;
-		case VALA_DATA_TYPE_NULLABLE:
-		vala_data_type_set_nullable (self, g_value_get_boolean (value));
-		break;
-		case VALA_DATA_TYPE_IS_TYPE_ARGUMENT:
-		vala_data_type_set_is_type_argument (self, g_value_get_boolean (value));
-		break;
-		case VALA_DATA_TYPE_DATA_TYPE:
-		vala_data_type_set_data_type (self, g_value_get_object (value));
-		break;
-		case VALA_DATA_TYPE_TYPE_PARAMETER:
-		vala_data_type_set_type_parameter (self, g_value_get_object (value));
-		break;
-		case VALA_DATA_TYPE_FLOATING_REFERENCE:
-		vala_data_type_set_floating_reference (self, g_value_get_boolean (value));
-		break;
-		case VALA_DATA_TYPE_IS_DYNAMIC:
-		vala_data_type_set_is_dynamic (self, g_value_get_boolean (value));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
 static void vala_data_type_class_init (ValaDataTypeClass * klass) {
 	vala_data_type_parent_class = g_type_class_peek_parent (klass);
+	VALA_CODE_NODE_CLASS (klass)->finalize = vala_data_type_finalize;
 	g_type_class_add_private (klass, sizeof (ValaDataTypePrivate));
-	G_OBJECT_CLASS (klass)->get_property = vala_data_type_get_property;
-	G_OBJECT_CLASS (klass)->set_property = vala_data_type_set_property;
-	G_OBJECT_CLASS (klass)->dispose = vala_data_type_dispose;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_data_type_real_accept;
 	VALA_DATA_TYPE_CLASS (klass)->get_cname = vala_data_type_real_get_cname;
 	VALA_DATA_TYPE_CLASS (klass)->get_lower_case_cname = vala_data_type_real_get_lower_case_cname;
 	VALA_CODE_NODE_CLASS (klass)->to_string = vala_data_type_real_to_string;
 	VALA_DATA_TYPE_CLASS (klass)->to_qualified_string = vala_data_type_real_to_qualified_string;
+	VALA_DATA_TYPE_CLASS (klass)->copy = vala_data_type_real_copy;
 	VALA_DATA_TYPE_CLASS (klass)->equals = vala_data_type_real_equals;
 	VALA_DATA_TYPE_CLASS (klass)->stricter = vala_data_type_real_stricter;
 	VALA_CODE_NODE_CLASS (klass)->replace_type = vala_data_type_real_replace_type;
@@ -932,13 +862,6 @@ static void vala_data_type_class_init (ValaDataTypeClass * klass) {
 	VALA_DATA_TYPE_CLASS (klass)->get_type_id = vala_data_type_real_get_type_id;
 	VALA_DATA_TYPE_CLASS (klass)->get_type_signature = vala_data_type_real_get_type_signature;
 	VALA_DATA_TYPE_CLASS (klass)->is_disposable = vala_data_type_real_is_disposable;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_DATA_TYPE_VALUE_OWNED, g_param_spec_boolean ("value-owned", "value-owned", "value-owned", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_DATA_TYPE_NULLABLE, g_param_spec_boolean ("nullable", "nullable", "nullable", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_DATA_TYPE_IS_TYPE_ARGUMENT, g_param_spec_boolean ("is-type-argument", "is-type-argument", "is-type-argument", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_DATA_TYPE_DATA_TYPE, g_param_spec_object ("data-type", "data-type", "data-type", VALA_TYPE_TYPESYMBOL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_DATA_TYPE_TYPE_PARAMETER, g_param_spec_object ("type-parameter", "type-parameter", "type-parameter", VALA_TYPE_TYPEPARAMETER, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_DATA_TYPE_FLOATING_REFERENCE, g_param_spec_boolean ("floating-reference", "floating-reference", "floating-reference", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_DATA_TYPE_IS_DYNAMIC, g_param_spec_boolean ("is-dynamic", "is-dynamic", "is-dynamic", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
@@ -947,19 +870,19 @@ static void vala_data_type_instance_init (ValaDataType * self) {
 }
 
 
-static void vala_data_type_dispose (GObject * obj) {
+static void vala_data_type_finalize (ValaCodeNode* obj) {
 	ValaDataType * self;
 	self = VALA_DATA_TYPE (obj);
-	(self->priv->_type_parameter == NULL ? NULL : (self->priv->_type_parameter = (g_object_unref (self->priv->_type_parameter), NULL)));
-	(self->priv->type_argument_list == NULL ? NULL : (self->priv->type_argument_list = (g_object_unref (self->priv->type_argument_list), NULL)));
-	G_OBJECT_CLASS (vala_data_type_parent_class)->dispose (obj);
+	(self->priv->_type_parameter == NULL ? NULL : (self->priv->_type_parameter = (vala_code_node_unref (self->priv->_type_parameter), NULL)));
+	(self->priv->type_argument_list == NULL ? NULL : (self->priv->type_argument_list = (gee_collection_object_unref (self->priv->type_argument_list), NULL)));
+	VALA_CODE_NODE_CLASS (vala_data_type_parent_class)->finalize (obj);
 }
 
 
 GType vala_data_type_get_type (void) {
 	static GType vala_data_type_type_id = 0;
-	if (G_UNLIKELY (vala_data_type_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaDataTypeClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_data_type_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaDataType), 0, (GInstanceInitFunc) vala_data_type_instance_init };
+	if (vala_data_type_type_id == 0) {
+		static const GTypeInfo g_define_type_info = { sizeof (ValaDataTypeClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_data_type_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaDataType), 0, (GInstanceInitFunc) vala_data_type_instance_init, NULL };
 		vala_data_type_type_id = g_type_register_static (VALA_TYPE_CODE_NODE, "ValaDataType", &g_define_type_info, G_TYPE_FLAG_ABSTRACT);
 	}
 	return vala_data_type_type_id;
