@@ -34,8 +34,7 @@ struct _ValaDelegateTypePrivate {
 
 #define VALA_DELEGATE_TYPE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_DELEGATE_TYPE, ValaDelegateTypePrivate))
 enum  {
-	VALA_DELEGATE_TYPE_DUMMY_PROPERTY,
-	VALA_DELEGATE_TYPE_DELEGATE_SYMBOL
+	VALA_DELEGATE_TYPE_DUMMY_PROPERTY
 };
 static gboolean vala_delegate_type_real_is_invokable (ValaDataType* base);
 static ValaDataType* vala_delegate_type_real_get_return_type (ValaDataType* base);
@@ -46,16 +45,21 @@ static char* vala_delegate_type_real_get_cname (ValaDataType* base);
 static GeeList* vala_delegate_type_real_get_symbols (ValaDataType* base);
 static char* vala_delegate_type_real_get_type_id (ValaDataType* base);
 static gpointer vala_delegate_type_parent_class = NULL;
-static void vala_delegate_type_finalize (GObject * obj);
+static void vala_delegate_type_finalize (ValaCodeNode* obj);
 
 
 
+ValaDelegateType* vala_delegate_type_construct (GType object_type, ValaDelegate* delegate_symbol) {
+	ValaDelegateType* self;
+	g_return_val_if_fail (VALA_IS_DELEGATE (delegate_symbol), NULL);
+	self = ((ValaDelegateType*) (g_type_create_instance (object_type)));
+	vala_delegate_type_set_delegate_symbol (self, delegate_symbol);
+	return self;
+}
+
+
 ValaDelegateType* vala_delegate_type_new (ValaDelegate* delegate_symbol) {
-	ValaDelegateType * self;
-	g_return_val_if_fail (VALA_IS_DELEGATE (delegate_symbol), NULL);
-	self = g_object_newv (VALA_TYPE_DELEGATE_TYPE, 0, NULL);
-	vala_delegate_type_set_delegate_symbol (self, delegate_symbol);
-	return self;
+	return vala_delegate_type_construct (VALA_TYPE_DELEGATE_TYPE, delegate_symbol);
 }
 
 
@@ -71,7 +75,7 @@ static ValaDataType* vala_delegate_type_real_get_return_type (ValaDataType* base
 	ValaDataType* _tmp0;
 	self = VALA_DELEGATE_TYPE (base);
 	_tmp0 = NULL;
-	return (_tmp0 = vala_delegate_get_return_type (self->priv->_delegate_symbol), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
+	return (_tmp0 = vala_delegate_get_return_type (self->priv->_delegate_symbol), (_tmp0 == NULL ? NULL : vala_code_node_ref (_tmp0)));
 }
 
 
@@ -115,7 +119,7 @@ static GeeList* vala_delegate_type_real_get_symbols (ValaDataType* base) {
 	ValaDelegateType * self;
 	GeeArrayList* symbols;
 	self = VALA_DELEGATE_TYPE (base);
-	symbols = gee_array_list_new (VALA_TYPE_SYMBOL, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal);
+	symbols = gee_array_list_new (VALA_TYPE_SYMBOL, ((GBoxedCopyFunc) (vala_code_node_ref)), vala_code_node_unref, g_direct_equal);
 	gee_collection_add (GEE_COLLECTION (symbols), VALA_SYMBOL (self->priv->_delegate_symbol));
 	return GEE_LIST (symbols);
 }
@@ -140,45 +144,14 @@ void vala_delegate_type_set_delegate_symbol (ValaDelegateType* self, ValaDelegat
 	g_return_if_fail (VALA_IS_DELEGATE_TYPE (self));
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_delegate_symbol = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_delegate_symbol == NULL ? NULL : (self->priv->_delegate_symbol = (g_object_unref (self->priv->_delegate_symbol), NULL))), _tmp2);
-	g_object_notify (((GObject *) (self)), "delegate-symbol");
-}
-
-
-static void vala_delegate_type_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
-	ValaDelegateType * self;
-	self = VALA_DELEGATE_TYPE (object);
-	switch (property_id) {
-		case VALA_DELEGATE_TYPE_DELEGATE_SYMBOL:
-		g_value_set_object (value, vala_delegate_type_get_delegate_symbol (self));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
-static void vala_delegate_type_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
-	ValaDelegateType * self;
-	self = VALA_DELEGATE_TYPE (object);
-	switch (property_id) {
-		case VALA_DELEGATE_TYPE_DELEGATE_SYMBOL:
-		vala_delegate_type_set_delegate_symbol (self, g_value_get_object (value));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
+	self->priv->_delegate_symbol = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1))), (self->priv->_delegate_symbol == NULL ? NULL : (self->priv->_delegate_symbol = (vala_code_node_unref (self->priv->_delegate_symbol), NULL))), _tmp2);
 }
 
 
 static void vala_delegate_type_class_init (ValaDelegateTypeClass * klass) {
 	vala_delegate_type_parent_class = g_type_class_peek_parent (klass);
+	VALA_CODE_NODE_CLASS (klass)->finalize = vala_delegate_type_finalize;
 	g_type_class_add_private (klass, sizeof (ValaDelegateTypePrivate));
-	G_OBJECT_CLASS (klass)->get_property = vala_delegate_type_get_property;
-	G_OBJECT_CLASS (klass)->set_property = vala_delegate_type_set_property;
-	G_OBJECT_CLASS (klass)->finalize = vala_delegate_type_finalize;
 	VALA_DATA_TYPE_CLASS (klass)->is_invokable = vala_delegate_type_real_is_invokable;
 	VALA_DATA_TYPE_CLASS (klass)->get_return_type = vala_delegate_type_real_get_return_type;
 	VALA_DATA_TYPE_CLASS (klass)->get_parameters = vala_delegate_type_real_get_parameters;
@@ -187,7 +160,6 @@ static void vala_delegate_type_class_init (ValaDelegateTypeClass * klass) {
 	VALA_DATA_TYPE_CLASS (klass)->get_cname = vala_delegate_type_real_get_cname;
 	VALA_DATA_TYPE_CLASS (klass)->get_symbols = vala_delegate_type_real_get_symbols;
 	VALA_DATA_TYPE_CLASS (klass)->get_type_id = vala_delegate_type_real_get_type_id;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_DELEGATE_TYPE_DELEGATE_SYMBOL, g_param_spec_object ("delegate-symbol", "delegate-symbol", "delegate-symbol", VALA_TYPE_DELEGATE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
@@ -196,18 +168,18 @@ static void vala_delegate_type_instance_init (ValaDelegateType * self) {
 }
 
 
-static void vala_delegate_type_finalize (GObject * obj) {
+static void vala_delegate_type_finalize (ValaCodeNode* obj) {
 	ValaDelegateType * self;
 	self = VALA_DELEGATE_TYPE (obj);
-	(self->priv->_delegate_symbol == NULL ? NULL : (self->priv->_delegate_symbol = (g_object_unref (self->priv->_delegate_symbol), NULL)));
-	G_OBJECT_CLASS (vala_delegate_type_parent_class)->finalize (obj);
+	(self->priv->_delegate_symbol == NULL ? NULL : (self->priv->_delegate_symbol = (vala_code_node_unref (self->priv->_delegate_symbol), NULL)));
+	VALA_CODE_NODE_CLASS (vala_delegate_type_parent_class)->finalize (obj);
 }
 
 
 GType vala_delegate_type_get_type (void) {
 	static GType vala_delegate_type_type_id = 0;
 	if (vala_delegate_type_type_id == 0) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaDelegateTypeClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_delegate_type_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaDelegateType), 0, (GInstanceInitFunc) vala_delegate_type_instance_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaDelegateTypeClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_delegate_type_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaDelegateType), 0, (GInstanceInitFunc) vala_delegate_type_instance_init, NULL };
 		vala_delegate_type_type_id = g_type_register_static (VALA_TYPE_DATA_TYPE, "ValaDelegateType", &g_define_type_info, 0);
 	}
 	return vala_delegate_type_type_id;
