@@ -37,15 +37,12 @@ struct _ValaDestructorPrivate {
 
 #define VALA_DESTRUCTOR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_DESTRUCTOR, ValaDestructorPrivate))
 enum  {
-	VALA_DESTRUCTOR_DUMMY_PROPERTY,
-	VALA_DESTRUCTOR_BODY,
-	VALA_DESTRUCTOR_THIS_PARAMETER,
-	VALA_DESTRUCTOR_BINDING
+	VALA_DESTRUCTOR_DUMMY_PROPERTY
 };
 static void vala_destructor_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_destructor_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static gpointer vala_destructor_parent_class = NULL;
-static void vala_destructor_finalize (GObject * obj);
+static void vala_destructor_finalize (ValaCodeNode* obj);
 
 
 
@@ -55,15 +52,21 @@ static void vala_destructor_finalize (GObject * obj);
  * @param source_reference reference to source code
  * @return                 newly created destructor
  */
-ValaDestructor* vala_destructor_new (ValaSourceReference* source_reference) {
-	ValaDestructor * self;
+ValaDestructor* vala_destructor_construct (GType object_type, ValaSourceReference* source_reference) {
+	ValaDestructor* self;
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
-	self = g_object_newv (VALA_TYPE_DESTRUCTOR, 0, NULL);
+	self = ((ValaDestructor*) (g_type_create_instance (object_type)));
+	vala_symbol_init (VALA_SYMBOL (self));
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
 	return self;
 }
 
 
+ValaDestructor* vala_destructor_new (ValaSourceReference* source_reference) {
+	return vala_destructor_construct (VALA_TYPE_DESTRUCTOR, source_reference);
+}
+
+
 static void vala_destructor_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaDestructor * self;
 	self = VALA_DESTRUCTOR (base);
@@ -94,8 +97,7 @@ void vala_destructor_set_body (ValaDestructor* self, ValaBlock* value) {
 	g_return_if_fail (VALA_IS_DESTRUCTOR (self));
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_body = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_body == NULL ? NULL : (self->priv->_body = (g_object_unref (self->priv->_body), NULL))), _tmp2);
-	g_object_notify (((GObject *) (self)), "body");
+	self->priv->_body = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1))), (self->priv->_body == NULL ? NULL : (self->priv->_body = (vala_code_node_unref (self->priv->_body), NULL))), _tmp2);
 }
 
 
@@ -111,8 +113,7 @@ void vala_destructor_set_this_parameter (ValaDestructor* self, ValaFormalParamet
 	g_return_if_fail (VALA_IS_DESTRUCTOR (self));
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_this_parameter = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_this_parameter == NULL ? NULL : (self->priv->_this_parameter = (g_object_unref (self->priv->_this_parameter), NULL))), _tmp2);
-	g_object_notify (((GObject *) (self)), "this-parameter");
+	self->priv->_this_parameter = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1))), (self->priv->_this_parameter == NULL ? NULL : (self->priv->_this_parameter = (vala_code_node_unref (self->priv->_this_parameter), NULL))), _tmp2);
 }
 
 
@@ -125,61 +126,15 @@ MemberBinding vala_destructor_get_binding (ValaDestructor* self) {
 void vala_destructor_set_binding (ValaDestructor* self, MemberBinding value) {
 	g_return_if_fail (VALA_IS_DESTRUCTOR (self));
 	self->priv->_binding = value;
-	g_object_notify (((GObject *) (self)), "binding");
-}
-
-
-static void vala_destructor_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
-	ValaDestructor * self;
-	self = VALA_DESTRUCTOR (object);
-	switch (property_id) {
-		case VALA_DESTRUCTOR_BODY:
-		g_value_set_object (value, vala_destructor_get_body (self));
-		break;
-		case VALA_DESTRUCTOR_THIS_PARAMETER:
-		g_value_set_object (value, vala_destructor_get_this_parameter (self));
-		break;
-		case VALA_DESTRUCTOR_BINDING:
-		g_value_set_enum (value, vala_destructor_get_binding (self));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
-static void vala_destructor_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
-	ValaDestructor * self;
-	self = VALA_DESTRUCTOR (object);
-	switch (property_id) {
-		case VALA_DESTRUCTOR_BODY:
-		vala_destructor_set_body (self, g_value_get_object (value));
-		break;
-		case VALA_DESTRUCTOR_THIS_PARAMETER:
-		vala_destructor_set_this_parameter (self, g_value_get_object (value));
-		break;
-		case VALA_DESTRUCTOR_BINDING:
-		vala_destructor_set_binding (self, g_value_get_enum (value));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
 }
 
 
 static void vala_destructor_class_init (ValaDestructorClass * klass) {
 	vala_destructor_parent_class = g_type_class_peek_parent (klass);
+	VALA_CODE_NODE_CLASS (klass)->finalize = vala_destructor_finalize;
 	g_type_class_add_private (klass, sizeof (ValaDestructorPrivate));
-	G_OBJECT_CLASS (klass)->get_property = vala_destructor_get_property;
-	G_OBJECT_CLASS (klass)->set_property = vala_destructor_set_property;
-	G_OBJECT_CLASS (klass)->finalize = vala_destructor_finalize;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_destructor_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_destructor_real_accept_children;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_DESTRUCTOR_BODY, g_param_spec_object ("body", "body", "body", VALA_TYPE_BLOCK, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_DESTRUCTOR_THIS_PARAMETER, g_param_spec_object ("this-parameter", "this-parameter", "this-parameter", VALA_TYPE_FORMAL_PARAMETER, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_DESTRUCTOR_BINDING, g_param_spec_enum ("binding", "binding", "binding", TYPE_MEMBER_BINDING, MEMBER_BINDING_INSTANCE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
@@ -189,19 +144,19 @@ static void vala_destructor_instance_init (ValaDestructor * self) {
 }
 
 
-static void vala_destructor_finalize (GObject * obj) {
+static void vala_destructor_finalize (ValaCodeNode* obj) {
 	ValaDestructor * self;
 	self = VALA_DESTRUCTOR (obj);
-	(self->priv->_body == NULL ? NULL : (self->priv->_body = (g_object_unref (self->priv->_body), NULL)));
-	(self->priv->_this_parameter == NULL ? NULL : (self->priv->_this_parameter = (g_object_unref (self->priv->_this_parameter), NULL)));
-	G_OBJECT_CLASS (vala_destructor_parent_class)->finalize (obj);
+	(self->priv->_body == NULL ? NULL : (self->priv->_body = (vala_code_node_unref (self->priv->_body), NULL)));
+	(self->priv->_this_parameter == NULL ? NULL : (self->priv->_this_parameter = (vala_code_node_unref (self->priv->_this_parameter), NULL)));
+	VALA_CODE_NODE_CLASS (vala_destructor_parent_class)->finalize (obj);
 }
 
 
 GType vala_destructor_get_type (void) {
 	static GType vala_destructor_type_id = 0;
 	if (vala_destructor_type_id == 0) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaDestructorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_destructor_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaDestructor), 0, (GInstanceInitFunc) vala_destructor_instance_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaDestructorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_destructor_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaDestructor), 0, (GInstanceInitFunc) vala_destructor_instance_init, NULL };
 		vala_destructor_type_id = g_type_register_static (VALA_TYPE_SYMBOL, "ValaDestructor", &g_define_type_info, 0);
 	}
 	return vala_destructor_type_id;
