@@ -39,26 +39,25 @@ struct _ValaDynamicMethodPrivate {
 
 #define VALA_DYNAMIC_METHOD_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_DYNAMIC_METHOD, ValaDynamicMethodPrivate))
 enum  {
-	VALA_DYNAMIC_METHOD_DUMMY_PROPERTY,
-	VALA_DYNAMIC_METHOD_DYNAMIC_TYPE,
-	VALA_DYNAMIC_METHOD_INVOCATION
+	VALA_DYNAMIC_METHOD_DUMMY_PROPERTY
 };
 static gint vala_dynamic_method_dynamic_method_id;
 static GeeList* vala_dynamic_method_real_get_cheader_filenames (ValaSymbol* base);
 static char* vala_dynamic_method_real_get_default_cname (ValaMethod* base);
 static ValaCodeBinding* vala_dynamic_method_real_create_code_binding (ValaCodeNode* base, ValaCodeGenerator* codegen);
 static gpointer vala_dynamic_method_parent_class = NULL;
-static void vala_dynamic_method_finalize (GObject * obj);
+static void vala_dynamic_method_finalize (ValaCodeNode* obj);
 
 
 
-ValaDynamicMethod* vala_dynamic_method_new (ValaDataType* dynamic_type, const char* name, ValaDataType* return_type, ValaSourceReference* source_reference) {
-	ValaDynamicMethod * self;
+ValaDynamicMethod* vala_dynamic_method_construct (GType object_type, ValaDataType* dynamic_type, const char* name, ValaDataType* return_type, ValaSourceReference* source_reference) {
+	ValaDynamicMethod* self;
 	g_return_val_if_fail (VALA_IS_DATA_TYPE (dynamic_type), NULL);
 	g_return_val_if_fail (name != NULL, NULL);
 	g_return_val_if_fail (VALA_IS_DATA_TYPE (return_type), NULL);
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
-	self = g_object_newv (VALA_TYPE_DYNAMIC_METHOD, 0, NULL);
+	self = ((ValaDynamicMethod*) (g_type_create_instance (object_type)));
+	vala_symbol_init (VALA_SYMBOL (VALA_METHOD (self)));
 	vala_dynamic_method_set_dynamic_type (self, dynamic_type);
 	vala_symbol_set_name (VALA_SYMBOL (self), name);
 	vala_method_set_return_type (VALA_METHOD (self), return_type);
@@ -67,6 +66,11 @@ ValaDynamicMethod* vala_dynamic_method_new (ValaDataType* dynamic_type, const ch
 }
 
 
+ValaDynamicMethod* vala_dynamic_method_new (ValaDataType* dynamic_type, const char* name, ValaDataType* return_type, ValaSourceReference* source_reference) {
+	return vala_dynamic_method_construct (VALA_TYPE_DYNAMIC_METHOD, dynamic_type, name, return_type, source_reference);
+}
+
+
 static GeeList* vala_dynamic_method_real_get_cheader_filenames (ValaSymbol* base) {
 	ValaDynamicMethod * self;
 	self = VALA_DYNAMIC_METHOD (base);
@@ -109,8 +113,7 @@ void vala_dynamic_method_set_dynamic_type (ValaDynamicMethod* self, ValaDataType
 	g_return_if_fail (VALA_IS_DYNAMIC_METHOD (self));
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_dynamic_type = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_dynamic_type == NULL ? NULL : (self->priv->_dynamic_type = (g_object_unref (self->priv->_dynamic_type), NULL))), _tmp2);
-	g_object_notify (((GObject *) (self)), "dynamic-type");
+	self->priv->_dynamic_type = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1))), (self->priv->_dynamic_type == NULL ? NULL : (self->priv->_dynamic_type = (vala_code_node_unref (self->priv->_dynamic_type), NULL))), _tmp2);
 }
 
 
@@ -126,56 +129,17 @@ void vala_dynamic_method_set_invocation (ValaDynamicMethod* self, ValaInvocation
 	g_return_if_fail (VALA_IS_DYNAMIC_METHOD (self));
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_invocation = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_invocation == NULL ? NULL : (self->priv->_invocation = (g_object_unref (self->priv->_invocation), NULL))), _tmp2);
-	g_object_notify (((GObject *) (self)), "invocation");
-}
-
-
-static void vala_dynamic_method_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
-	ValaDynamicMethod * self;
-	self = VALA_DYNAMIC_METHOD (object);
-	switch (property_id) {
-		case VALA_DYNAMIC_METHOD_DYNAMIC_TYPE:
-		g_value_set_object (value, vala_dynamic_method_get_dynamic_type (self));
-		break;
-		case VALA_DYNAMIC_METHOD_INVOCATION:
-		g_value_set_object (value, vala_dynamic_method_get_invocation (self));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
-static void vala_dynamic_method_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
-	ValaDynamicMethod * self;
-	self = VALA_DYNAMIC_METHOD (object);
-	switch (property_id) {
-		case VALA_DYNAMIC_METHOD_DYNAMIC_TYPE:
-		vala_dynamic_method_set_dynamic_type (self, g_value_get_object (value));
-		break;
-		case VALA_DYNAMIC_METHOD_INVOCATION:
-		vala_dynamic_method_set_invocation (self, g_value_get_object (value));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
+	self->priv->_invocation = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1))), (self->priv->_invocation == NULL ? NULL : (self->priv->_invocation = (vala_code_node_unref (self->priv->_invocation), NULL))), _tmp2);
 }
 
 
 static void vala_dynamic_method_class_init (ValaDynamicMethodClass * klass) {
 	vala_dynamic_method_parent_class = g_type_class_peek_parent (klass);
+	VALA_CODE_NODE_CLASS (klass)->finalize = vala_dynamic_method_finalize;
 	g_type_class_add_private (klass, sizeof (ValaDynamicMethodPrivate));
-	G_OBJECT_CLASS (klass)->get_property = vala_dynamic_method_get_property;
-	G_OBJECT_CLASS (klass)->set_property = vala_dynamic_method_set_property;
-	G_OBJECT_CLASS (klass)->finalize = vala_dynamic_method_finalize;
 	VALA_SYMBOL_CLASS (klass)->get_cheader_filenames = vala_dynamic_method_real_get_cheader_filenames;
 	VALA_METHOD_CLASS (klass)->get_default_cname = vala_dynamic_method_real_get_default_cname;
 	VALA_CODE_NODE_CLASS (klass)->create_code_binding = vala_dynamic_method_real_create_code_binding;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_DYNAMIC_METHOD_DYNAMIC_TYPE, g_param_spec_object ("dynamic-type", "dynamic-type", "dynamic-type", VALA_TYPE_DATA_TYPE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_DYNAMIC_METHOD_INVOCATION, g_param_spec_object ("invocation", "invocation", "invocation", VALA_TYPE_INVOCATION_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
@@ -184,20 +148,20 @@ static void vala_dynamic_method_instance_init (ValaDynamicMethod * self) {
 }
 
 
-static void vala_dynamic_method_finalize (GObject * obj) {
+static void vala_dynamic_method_finalize (ValaCodeNode* obj) {
 	ValaDynamicMethod * self;
 	self = VALA_DYNAMIC_METHOD (obj);
-	(self->priv->_dynamic_type == NULL ? NULL : (self->priv->_dynamic_type = (g_object_unref (self->priv->_dynamic_type), NULL)));
-	(self->priv->_invocation == NULL ? NULL : (self->priv->_invocation = (g_object_unref (self->priv->_invocation), NULL)));
+	(self->priv->_dynamic_type == NULL ? NULL : (self->priv->_dynamic_type = (vala_code_node_unref (self->priv->_dynamic_type), NULL)));
+	(self->priv->_invocation == NULL ? NULL : (self->priv->_invocation = (vala_code_node_unref (self->priv->_invocation), NULL)));
 	self->priv->cname = (g_free (self->priv->cname), NULL);
-	G_OBJECT_CLASS (vala_dynamic_method_parent_class)->finalize (obj);
+	VALA_CODE_NODE_CLASS (vala_dynamic_method_parent_class)->finalize (obj);
 }
 
 
 GType vala_dynamic_method_get_type (void) {
 	static GType vala_dynamic_method_type_id = 0;
 	if (vala_dynamic_method_type_id == 0) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaDynamicMethodClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_dynamic_method_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaDynamicMethod), 0, (GInstanceInitFunc) vala_dynamic_method_instance_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaDynamicMethodClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_dynamic_method_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaDynamicMethod), 0, (GInstanceInitFunc) vala_dynamic_method_instance_init, NULL };
 		vala_dynamic_method_type_id = g_type_register_static (VALA_TYPE_METHOD, "ValaDynamicMethod", &g_define_type_info, 0);
 	}
 	return vala_dynamic_method_type_id;
