@@ -42,19 +42,24 @@ static ValaStatementIface* vala_empty_statement_vala_statement_parent_iface = NU
  * @param source reference to source code
  * @return       newly created empty statement
  */
-ValaEmptyStatement* vala_empty_statement_new (ValaSourceReference* source) {
-	ValaEmptyStatement * self;
-	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
-	self = g_object_newv (VALA_TYPE_EMPTY_STATEMENT, 0, NULL);
+ValaEmptyStatement* vala_empty_statement_construct (GType object_type, ValaSourceReference* source) {
+	ValaEmptyStatement* self;
+	g_return_val_if_fail (VALA_IS_SOURCE_REFERENCE (source), NULL);
+	self = ((ValaEmptyStatement*) (g_type_create_instance (object_type)));
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source);
 	return self;
 }
 
 
+ValaEmptyStatement* vala_empty_statement_new (ValaSourceReference* source) {
+	return vala_empty_statement_construct (VALA_TYPE_EMPTY_STATEMENT, source);
+}
+
+
 static void vala_empty_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaEmptyStatement * self;
 	self = VALA_EMPTY_STATEMENT (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_empty_statement (visitor, self);
 }
 
@@ -70,14 +75,14 @@ static void vala_empty_statement_vala_statement_interface_init (ValaStatementIfa
 }
 
 
-static void vala_empty_statement_init (ValaEmptyStatement * self) {
+static void vala_empty_statement_instance_init (ValaEmptyStatement * self) {
 }
 
 
 GType vala_empty_statement_get_type (void) {
 	static GType vala_empty_statement_type_id = 0;
-	if (G_UNLIKELY (vala_empty_statement_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaEmptyStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_empty_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaEmptyStatement), 0, (GInstanceInitFunc) vala_empty_statement_init };
+	if (vala_empty_statement_type_id == 0) {
+		static const GTypeInfo g_define_type_info = { sizeof (ValaEmptyStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_empty_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaEmptyStatement), 0, (GInstanceInitFunc) vala_empty_statement_instance_init, NULL };
 		static const GInterfaceInfo vala_statement_info = { (GInterfaceInitFunc) vala_empty_statement_vala_statement_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
 		vala_empty_statement_type_id = g_type_register_static (VALA_TYPE_CODE_NODE, "ValaEmptyStatement", &g_define_type_info, 0);
 		g_type_add_interface_static (vala_empty_statement_type_id, VALA_TYPE_STATEMENT, &vala_statement_info);
