@@ -55,9 +55,7 @@ struct _ValaEnumPrivate {
 
 #define VALA_ENUM_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_ENUM, ValaEnumPrivate))
 enum  {
-	VALA_ENUM_DUMMY_PROPERTY,
-	VALA_ENUM_IS_FLAGS,
-	VALA_ENUM_HAS_TYPE_ID
+	VALA_ENUM_DUMMY_PROPERTY
 };
 static void vala_enum_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_enum_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
@@ -75,7 +73,7 @@ static char* vala_enum_real_get_get_value_function (ValaTypeSymbol* base);
 static char* vala_enum_real_get_set_value_function (ValaTypeSymbol* base);
 static char* vala_enum_real_get_default_value (ValaTypeSymbol* base);
 static gpointer vala_enum_parent_class = NULL;
-static void vala_enum_finalize (GObject * obj);
+static void vala_enum_finalize (ValaCodeNode* obj);
 static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
 static int _vala_strcmp0 (const char * str1, const char * str2);
 
@@ -88,17 +86,23 @@ static int _vala_strcmp0 (const char * str1, const char * str2);
  * @param source_reference reference to source code
  * @return                 newly created enum
  */
-ValaEnum* vala_enum_new (const char* name, ValaSourceReference* source_reference) {
-	ValaEnum * self;
+ValaEnum* vala_enum_construct (GType object_type, const char* name, ValaSourceReference* source_reference) {
+	ValaEnum* self;
 	g_return_val_if_fail (name != NULL, NULL);
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
-	self = g_object_newv (VALA_TYPE_ENUM, 0, NULL);
+	self = ((ValaEnum*) (g_type_create_instance (object_type)));
+	vala_symbol_init (VALA_SYMBOL (VALA_TYPESYMBOL (self)));
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
 	vala_symbol_set_name (VALA_SYMBOL (self), name);
 	return self;
 }
 
 
+ValaEnum* vala_enum_new (const char* name, ValaSourceReference* source_reference) {
+	return vala_enum_construct (VALA_TYPE_ENUM, name, source_reference);
+}
+
+
 /**
  * Appends the specified enum value to the list of values.
  *
@@ -131,8 +135,8 @@ void vala_enum_add_method (ValaEnum* self, ValaMethod* m) {
 		_tmp1 = NULL;
 		_tmp0 = NULL;
 		vala_method_set_this_parameter (m, (_tmp1 = vala_formal_parameter_new ("this", VALA_DATA_TYPE ((_tmp0 = vala_value_type_new (VALA_TYPESYMBOL (self)))), NULL)));
-		(_tmp1 == NULL ? NULL : (_tmp1 = (g_object_unref (_tmp1), NULL)));
-		(_tmp0 == NULL ? NULL : (_tmp0 = (g_object_unref (_tmp0), NULL)));
+		(_tmp1 == NULL ? NULL : (_tmp1 = (vala_code_node_unref (_tmp1), NULL)));
+		(_tmp0 == NULL ? NULL : (_tmp0 = (vala_code_node_unref (_tmp0), NULL)));
 		vala_scope_add (vala_symbol_get_scope (VALA_SYMBOL (m)), vala_symbol_get_name (VALA_SYMBOL (vala_method_get_this_parameter (m))), VALA_SYMBOL (vala_method_get_this_parameter (m)));
 	}
 	gee_collection_add (GEE_COLLECTION (self->priv->methods), m);
@@ -147,7 +151,7 @@ void vala_enum_add_method (ValaEnum* self, ValaMethod* m) {
  */
 GeeList* vala_enum_get_values (ValaEnum* self) {
 	g_return_val_if_fail (VALA_IS_ENUM (self), NULL);
-	return GEE_LIST (gee_read_only_list_new (VALA_TYPE_ENUM_VALUE, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, self->priv->values));
+	return GEE_LIST (gee_read_only_list_new (VALA_TYPE_ENUM_VALUE, ((GBoxedCopyFunc) (vala_code_node_ref)), vala_code_node_unref, self->priv->values));
 }
 
 
@@ -158,7 +162,7 @@ GeeList* vala_enum_get_values (ValaEnum* self) {
  */
 GeeList* vala_enum_get_methods (ValaEnum* self) {
 	g_return_val_if_fail (VALA_IS_ENUM (self), NULL);
-	return GEE_LIST (gee_read_only_list_new (VALA_TYPE_METHOD, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, self->priv->methods));
+	return GEE_LIST (gee_read_only_list_new (VALA_TYPE_METHOD, ((GBoxedCopyFunc) (vala_code_node_ref)), vala_code_node_unref, self->priv->methods));
 }
 
 
@@ -183,7 +187,7 @@ static void vala_enum_real_accept_children (ValaCodeNode* base, ValaCodeVisitor*
 			value = ((ValaEnumValue*) (gee_list_get (GEE_LIST (value_collection), value_it)));
 			{
 				vala_code_node_accept (VALA_CODE_NODE (value), visitor);
-				(value == NULL ? NULL : (value = (g_object_unref (value), NULL)));
+				(value == NULL ? NULL : (value = (vala_code_node_unref (value), NULL)));
 			}
 		}
 	}
@@ -196,7 +200,7 @@ static void vala_enum_real_accept_children (ValaCodeNode* base, ValaCodeVisitor*
 			m = ((ValaMethod*) (gee_list_get (GEE_LIST (m_collection), m_it)));
 			{
 				vala_code_node_accept (VALA_CODE_NODE (m), visitor);
-				(m == NULL ? NULL : (m = (g_object_unref (m), NULL)));
+				(m == NULL ? NULL : (m = (vala_code_node_unref (m), NULL)));
 			}
 		}
 	}
@@ -400,7 +404,7 @@ void vala_enum_process_attributes (ValaEnum* self) {
 			ValaAttribute* _tmp0;
 			ValaAttribute* a;
 			_tmp0 = NULL;
-			a = (_tmp0 = ((ValaAttribute*) (a_it->data)), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
+			a = (_tmp0 = ((ValaAttribute*) (a_it->data)), (_tmp0 == NULL ? NULL : vala_code_node_ref (_tmp0)));
 			{
 				if (_vala_strcmp0 (vala_attribute_get_name (a), "CCode") == 0) {
 					vala_enum_process_ccode_attribute (self, a);
@@ -409,7 +413,7 @@ void vala_enum_process_attributes (ValaEnum* self) {
 						vala_enum_set_is_flags (self, TRUE);
 					}
 				}
-				(a == NULL ? NULL : (a = (g_object_unref (a), NULL)));
+				(a == NULL ? NULL : (a = (vala_code_node_unref (a), NULL)));
 			}
 		}
 	}
@@ -497,9 +501,9 @@ static char* vala_enum_real_get_set_value_function (ValaTypeSymbol* base) {
 		}
 	} else {
 		if (self->priv->_is_flags) {
-			return g_strdup ("g_value_set_int");
-		} else {
 			return g_strdup ("g_value_set_uint");
+		} else {
+			return g_strdup ("g_value_set_int");
 		}
 	}
 }
@@ -521,7 +525,6 @@ gboolean vala_enum_get_is_flags (ValaEnum* self) {
 void vala_enum_set_is_flags (ValaEnum* self, gboolean value) {
 	g_return_if_fail (VALA_IS_ENUM (self));
 	self->priv->_is_flags = value;
-	g_object_notify (((GObject *) (self)), "is-flags");
 }
 
 
@@ -534,50 +537,13 @@ gboolean vala_enum_get_has_type_id (ValaEnum* self) {
 void vala_enum_set_has_type_id (ValaEnum* self, gboolean value) {
 	g_return_if_fail (VALA_IS_ENUM (self));
 	self->priv->_has_type_id = value;
-	g_object_notify (((GObject *) (self)), "has-type-id");
-}
-
-
-static void vala_enum_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
-	ValaEnum * self;
-	self = VALA_ENUM (object);
-	switch (property_id) {
-		case VALA_ENUM_IS_FLAGS:
-		g_value_set_boolean (value, vala_enum_get_is_flags (self));
-		break;
-		case VALA_ENUM_HAS_TYPE_ID:
-		g_value_set_boolean (value, vala_enum_get_has_type_id (self));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
-static void vala_enum_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
-	ValaEnum * self;
-	self = VALA_ENUM (object);
-	switch (property_id) {
-		case VALA_ENUM_IS_FLAGS:
-		vala_enum_set_is_flags (self, g_value_get_boolean (value));
-		break;
-		case VALA_ENUM_HAS_TYPE_ID:
-		vala_enum_set_has_type_id (self, g_value_get_boolean (value));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
 }
 
 
 static void vala_enum_class_init (ValaEnumClass * klass) {
 	vala_enum_parent_class = g_type_class_peek_parent (klass);
+	VALA_CODE_NODE_CLASS (klass)->finalize = vala_enum_finalize;
 	g_type_class_add_private (klass, sizeof (ValaEnumPrivate));
-	G_OBJECT_CLASS (klass)->get_property = vala_enum_get_property;
-	G_OBJECT_CLASS (klass)->set_property = vala_enum_set_property;
-	G_OBJECT_CLASS (klass)->finalize = vala_enum_finalize;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_enum_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_enum_real_accept_children;
 	VALA_TYPESYMBOL_CLASS (klass)->get_cname = vala_enum_real_get_cname;
@@ -590,37 +556,35 @@ static void vala_enum_class_init (ValaEnumClass * klass) {
 	VALA_TYPESYMBOL_CLASS (klass)->get_get_value_function = vala_enum_real_get_get_value_function;
 	VALA_TYPESYMBOL_CLASS (klass)->get_set_value_function = vala_enum_real_get_set_value_function;
 	VALA_TYPESYMBOL_CLASS (klass)->get_default_value = vala_enum_real_get_default_value;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_ENUM_IS_FLAGS, g_param_spec_boolean ("is-flags", "is-flags", "is-flags", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_ENUM_HAS_TYPE_ID, g_param_spec_boolean ("has-type-id", "has-type-id", "has-type-id", TRUE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
 static void vala_enum_instance_init (ValaEnum * self) {
 	self->priv = VALA_ENUM_GET_PRIVATE (self);
 	self->priv->_has_type_id = TRUE;
-	self->priv->values = GEE_LIST (gee_array_list_new (VALA_TYPE_ENUM_VALUE, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal));
-	self->priv->methods = GEE_LIST (gee_array_list_new (VALA_TYPE_METHOD, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal));
+	self->priv->values = GEE_LIST (gee_array_list_new (VALA_TYPE_ENUM_VALUE, ((GBoxedCopyFunc) (vala_code_node_ref)), vala_code_node_unref, g_direct_equal));
+	self->priv->methods = GEE_LIST (gee_array_list_new (VALA_TYPE_METHOD, ((GBoxedCopyFunc) (vala_code_node_ref)), vala_code_node_unref, g_direct_equal));
 }
 
 
-static void vala_enum_finalize (GObject * obj) {
+static void vala_enum_finalize (ValaCodeNode* obj) {
 	ValaEnum * self;
 	self = VALA_ENUM (obj);
-	(self->priv->values == NULL ? NULL : (self->priv->values = (g_object_unref (self->priv->values), NULL)));
-	(self->priv->methods == NULL ? NULL : (self->priv->methods = (g_object_unref (self->priv->methods), NULL)));
+	(self->priv->values == NULL ? NULL : (self->priv->values = (gee_collection_object_unref (self->priv->values), NULL)));
+	(self->priv->methods == NULL ? NULL : (self->priv->methods = (gee_collection_object_unref (self->priv->methods), NULL)));
 	self->priv->cname = (g_free (self->priv->cname), NULL);
 	self->priv->cprefix = (g_free (self->priv->cprefix), NULL);
 	self->priv->lower_case_cprefix = (g_free (self->priv->lower_case_cprefix), NULL);
 	self->priv->lower_case_csuffix = (g_free (self->priv->lower_case_csuffix), NULL);
 	self->priv->type_id = (g_free (self->priv->type_id), NULL);
-	G_OBJECT_CLASS (vala_enum_parent_class)->finalize (obj);
+	VALA_CODE_NODE_CLASS (vala_enum_parent_class)->finalize (obj);
 }
 
 
 GType vala_enum_get_type (void) {
 	static GType vala_enum_type_id = 0;
 	if (vala_enum_type_id == 0) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaEnumClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_enum_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaEnum), 0, (GInstanceInitFunc) vala_enum_instance_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaEnumClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_enum_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaEnum), 0, (GInstanceInitFunc) vala_enum_instance_init, NULL };
 		vala_enum_type_id = g_type_register_static (VALA_TYPE_TYPESYMBOL, "ValaEnum", &g_define_type_info, 0);
 	}
 	return vala_enum_type_id;
