@@ -48,26 +48,24 @@ struct _ValaExpression {
 	ValaExpressionPrivate * priv;
 	GeeArrayList* temp_vars;
 };
+
 struct _ValaExpressionClass {
 	ValaCodeNodeClass parent_class;
+	gboolean (*is_constant) (ValaExpression* self);
 	gboolean (*is_pure) (ValaExpression* self);
+	gboolean (*is_non_null) (ValaExpression* self);
 };
 
+
+gboolean vala_expression_is_constant (ValaExpression* self);
 gboolean vala_expression_is_pure (ValaExpression* self);
-ValaDataType* vala_expression_get_static_type (ValaExpression* self);
-void vala_expression_set_static_type (ValaExpression* self, ValaDataType* value);
-ValaDataType* vala_expression_get_expected_type (ValaExpression* self);
-void vala_expression_set_expected_type (ValaExpression* self, ValaDataType* value);
+gboolean vala_expression_is_non_null (ValaExpression* self);
+ValaDataType* vala_expression_get_value_type (ValaExpression* self);
+void vala_expression_set_value_type (ValaExpression* self, ValaDataType* value);
+ValaDataType* vala_expression_get_target_type (ValaExpression* self);
+void vala_expression_set_target_type (ValaExpression* self, ValaDataType* value);
 ValaSymbol* vala_expression_get_symbol_reference (ValaExpression* self);
 void vala_expression_set_symbol_reference (ValaExpression* self, ValaSymbol* value);
-gboolean vala_expression_get_ref_leaked (ValaExpression* self);
-void vala_expression_set_ref_leaked (ValaExpression* self, gboolean value);
-gboolean vala_expression_get_ref_missing (ValaExpression* self);
-void vala_expression_set_ref_missing (ValaExpression* self, gboolean value);
-gboolean vala_expression_get_ref_sink (ValaExpression* self);
-void vala_expression_set_ref_sink (ValaExpression* self, gboolean value);
-gboolean vala_expression_get_can_fail (ValaExpression* self);
-void vala_expression_set_can_fail (ValaExpression* self, gboolean value);
 gboolean vala_expression_get_lvalue (ValaExpression* self);
 void vala_expression_set_lvalue (ValaExpression* self, gboolean value);
 GType vala_expression_get_type (void);
