@@ -37,15 +37,14 @@ struct _ValaInitializerListPrivate {
 
 #define VALA_INITIALIZER_LIST_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_INITIALIZER_LIST, ValaInitializerListPrivate))
 enum  {
-	VALA_INITIALIZER_LIST_DUMMY_PROPERTY,
-	VALA_INITIALIZER_LIST_SIZE
+	VALA_INITIALIZER_LIST_DUMMY_PROPERTY
 };
 static void vala_initializer_list_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_initializer_list_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static gboolean vala_initializer_list_real_is_pure (ValaExpression* base);
 static void vala_initializer_list_real_replace_expression (ValaCodeNode* base, ValaExpression* old_node, ValaExpression* new_node);
 static gpointer vala_initializer_list_parent_class = NULL;
-static void vala_initializer_list_finalize (GObject * obj);
+static void vala_initializer_list_finalize (ValaCodeNode* obj);
 
 
 
@@ -69,7 +68,7 @@ void vala_initializer_list_append (ValaInitializerList* self, ValaExpression* ex
  */
 GeeList* vala_initializer_list_get_initializers (ValaInitializerList* self) {
 	g_return_val_if_fail (VALA_IS_INITIALIZER_LIST (self), NULL);
-	return GEE_LIST (gee_read_only_list_new (VALA_TYPE_EXPRESSION, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, self->priv->initializers));
+	return GEE_LIST (gee_read_only_list_new (VALA_TYPE_EXPRESSION, ((GBoxedCopyFunc) (vala_code_node_ref)), vala_code_node_unref, self->priv->initializers));
 }
 
 
@@ -79,15 +78,20 @@ GeeList* vala_initializer_list_get_initializers (ValaInitializerList* self) {
  * @param source_reference reference to source code
  * @return                 newly created initializer list
  */
-ValaInitializerList* vala_initializer_list_new (ValaSourceReference* source_reference) {
-	ValaInitializerList * self;
+ValaInitializerList* vala_initializer_list_construct (GType object_type, ValaSourceReference* source_reference) {
+	ValaInitializerList* self;
 	g_return_val_if_fail (VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
-	self = g_object_newv (VALA_TYPE_INITIALIZER_LIST, 0, NULL);
+	self = ((ValaInitializerList*) (g_type_create_instance (object_type)));
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
 	return self;
 }
 
 
+ValaInitializerList* vala_initializer_list_new (ValaSourceReference* source_reference) {
+	return vala_initializer_list_construct (VALA_TYPE_INITIALIZER_LIST, source_reference);
+}
+
+
 static void vala_initializer_list_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaInitializerList * self;
 	self = VALA_INITIALIZER_LIST (base);
@@ -101,7 +105,7 @@ static void vala_initializer_list_real_accept_children (ValaCodeNode* base, Vala
 			expr = ((ValaExpression*) (gee_list_get (GEE_LIST (expr_collection), expr_it)));
 			{
 				vala_code_node_accept (VALA_CODE_NODE (expr), visitor);
-				(expr == NULL ? NULL : (expr = (g_object_unref (expr), NULL)));
+				(expr == NULL ? NULL : (expr = (vala_code_node_unref (expr), NULL)));
 			}
 		}
 	}
@@ -129,9 +133,9 @@ static gboolean vala_initializer_list_real_is_pure (ValaExpression* base) {
 			{
 				if (!vala_expression_is_pure (initializer)) {
 					gboolean _tmp0;
-					return (_tmp0 = FALSE, (initializer == NULL ? NULL : (initializer = (g_object_unref (initializer), NULL))), _tmp0);
+					return (_tmp0 = FALSE, (initializer == NULL ? NULL : (initializer = (vala_code_node_unref (initializer), NULL))), _tmp0);
 				}
-				(initializer == NULL ? NULL : (initializer = (g_object_unref (initializer), NULL)));
+				(initializer == NULL ? NULL : (initializer = (vala_code_node_unref (initializer), NULL)));
 			}
 		}
 	}
@@ -151,7 +155,7 @@ static void vala_initializer_list_real_replace_expression (ValaCodeNode* base, V
 			ValaExpression* _tmp0;
 			gboolean _tmp1;
 			_tmp0 = NULL;
-			if ((_tmp1 = (_tmp0 = ((ValaExpression*) (gee_list_get (((GeeList*) (self->priv->initializers)), i)))) == old_node, (_tmp0 == NULL ? NULL : (_tmp0 = (g_object_unref (_tmp0), NULL))), _tmp1)) {
+			if ((_tmp1 = (_tmp0 = ((ValaExpression*) (gee_list_get (((GeeList*) (self->priv->initializers)), i)))) == old_node, (_tmp0 == NULL ? NULL : (_tmp0 = (vala_code_node_unref (_tmp0), NULL))), _tmp1)) {
 				gee_list_set (((GeeList*) (self->priv->initializers)), i, new_node);
 			}
 		}
@@ -165,51 +169,35 @@ gint vala_initializer_list_get_size (ValaInitializerList* self) {
 }
 
 
-static void vala_initializer_list_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
-	ValaInitializerList * self;
-	self = VALA_INITIALIZER_LIST (object);
-	switch (property_id) {
-		case VALA_INITIALIZER_LIST_SIZE:
-		g_value_set_int (value, vala_initializer_list_get_size (self));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
 static void vala_initializer_list_class_init (ValaInitializerListClass * klass) {
 	vala_initializer_list_parent_class = g_type_class_peek_parent (klass);
+	VALA_CODE_NODE_CLASS (klass)->finalize = vala_initializer_list_finalize;
 	g_type_class_add_private (klass, sizeof (ValaInitializerListPrivate));
-	G_OBJECT_CLASS (klass)->get_property = vala_initializer_list_get_property;
-	G_OBJECT_CLASS (klass)->finalize = vala_initializer_list_finalize;
 	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_initializer_list_real_accept_children;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_initializer_list_real_accept;
 	VALA_EXPRESSION_CLASS (klass)->is_pure = vala_initializer_list_real_is_pure;
 	VALA_CODE_NODE_CLASS (klass)->replace_expression = vala_initializer_list_real_replace_expression;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_INITIALIZER_LIST_SIZE, g_param_spec_int ("size", "size", "size", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
 }
 
 
 static void vala_initializer_list_instance_init (ValaInitializerList * self) {
 	self->priv = VALA_INITIALIZER_LIST_GET_PRIVATE (self);
-	self->priv->initializers = GEE_LIST (gee_array_list_new (VALA_TYPE_EXPRESSION, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal));
+	self->priv->initializers = GEE_LIST (gee_array_list_new (VALA_TYPE_EXPRESSION, ((GBoxedCopyFunc) (vala_code_node_ref)), vala_code_node_unref, g_direct_equal));
 }
 
 
-static void vala_initializer_list_finalize (GObject * obj) {
+static void vala_initializer_list_finalize (ValaCodeNode* obj) {
 	ValaInitializerList * self;
 	self = VALA_INITIALIZER_LIST (obj);
-	(self->priv->initializers == NULL ? NULL : (self->priv->initializers = (g_object_unref (self->priv->initializers), NULL)));
-	G_OBJECT_CLASS (vala_initializer_list_parent_class)->finalize (obj);
+	(self->priv->initializers == NULL ? NULL : (self->priv->initializers = (gee_collection_object_unref (self->priv->initializers), NULL)));
+	VALA_CODE_NODE_CLASS (vala_initializer_list_parent_class)->finalize (obj);
 }
 
 
 GType vala_initializer_list_get_type (void) {
 	static GType vala_initializer_list_type_id = 0;
 	if (vala_initializer_list_type_id == 0) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaInitializerListClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_initializer_list_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaInitializerList), 0, (GInstanceInitFunc) vala_initializer_list_instance_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaInitializerListClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_initializer_list_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaInitializerList), 0, (GInstanceInitFunc) vala_initializer_list_instance_init, NULL };
 		vala_initializer_list_type_id = g_type_register_static (VALA_TYPE_EXPRESSION, "ValaInitializerList", &g_define_type_info, 0);
 	}
 	return vala_initializer_list_type_id;
