@@ -34,14 +34,19 @@ static gpointer vala_invalid_type_parent_class = NULL;
 
 
 
-ValaInvalidType* vala_invalid_type_new (void) {
-	ValaInvalidType * self;
-	self = g_object_newv (VALA_TYPE_INVALID_TYPE, 0, NULL);
+ValaInvalidType* vala_invalid_type_construct (GType object_type) {
+	ValaInvalidType* self;
+	self = ((ValaInvalidType*) (g_type_create_instance (object_type)));
 	vala_code_node_set_error (VALA_CODE_NODE (self), TRUE);
 	return self;
 }
 
 
+ValaInvalidType* vala_invalid_type_new (void) {
+	return vala_invalid_type_construct (VALA_TYPE_INVALID_TYPE);
+}
+
+
 static ValaDataType* vala_invalid_type_real_copy (ValaDataType* base) {
 	ValaInvalidType * self;
 	self = VALA_INVALID_TYPE (base);
@@ -55,14 +60,14 @@ static void vala_invalid_type_class_init (ValaInvalidTypeClass * klass) {
 }
 
 
-static void vala_invalid_type_init (ValaInvalidType * self) {
+static void vala_invalid_type_instance_init (ValaInvalidType * self) {
 }
 
 
 GType vala_invalid_type_get_type (void) {
 	static GType vala_invalid_type_type_id = 0;
-	if (G_UNLIKELY (vala_invalid_type_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaInvalidTypeClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_invalid_type_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaInvalidType), 0, (GInstanceInitFunc) vala_invalid_type_init };
+	if (vala_invalid_type_type_id == 0) {
+		static const GTypeInfo g_define_type_info = { sizeof (ValaInvalidTypeClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_invalid_type_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaInvalidType), 0, (GInstanceInitFunc) vala_invalid_type_instance_init, NULL };
 		vala_invalid_type_type_id = g_type_register_static (VALA_TYPE_DATA_TYPE, "ValaInvalidType", &g_define_type_info, 0);
 	}
 	return vala_invalid_type_type_id;
