@@ -28,11 +28,19 @@
 enum  {
 	VALA_LITERAL_DUMMY_PROPERTY
 };
+static gboolean vala_literal_real_is_constant (ValaExpression* base);
 static gboolean vala_literal_real_is_pure (ValaExpression* base);
 static gpointer vala_literal_parent_class = NULL;
 
 
 
+static gboolean vala_literal_real_is_constant (ValaExpression* base) {
+	ValaLiteral * self;
+	self = VALA_LITERAL (base);
+	return TRUE;
+}
+
+
 static gboolean vala_literal_real_is_pure (ValaExpression* base) {
 	ValaLiteral * self;
 	self = VALA_LITERAL (base);
@@ -42,6 +50,7 @@ static gboolean vala_literal_real_is_pure (ValaExpression* base) {
 
 static void vala_literal_class_init (ValaLiteralClass * klass) {
 	vala_literal_parent_class = g_type_class_peek_parent (klass);
+	VALA_EXPRESSION_CLASS (klass)->is_constant = vala_literal_real_is_constant;
 	VALA_EXPRESSION_CLASS (klass)->is_pure = vala_literal_real_is_pure;
 }
 
@@ -52,8 +61,8 @@ static void vala_literal_instance_init (ValaLiteral * self) {
 
 GType vala_literal_get_type (void) {
 	static GType vala_literal_type_id = 0;
-	if (G_UNLIKELY (vala_literal_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaLiteralClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_literal_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaLiteral), 0, (GInstanceInitFunc) vala_literal_instance_init };
+	if (vala_literal_type_id == 0) {
+		static const GTypeInfo g_define_type_info = { sizeof (ValaLiteralClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_literal_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaLiteral), 0, (GInstanceInitFunc) vala_literal_instance_init, NULL };
 		vala_literal_type_id = g_type_register_static (VALA_TYPE_EXPRESSION, "ValaLiteral", &g_define_type_info, G_TYPE_FLAG_ABSTRACT);
 	}
 	return vala_literal_type_id;
