@@ -25,7 +25,7 @@
 
 #include <glib.h>
 #include <glib-object.h>
-#include <gee/collection.h>
+#include <gee/list.h>
 #include <stdlib.h>
 #include <string.h>
 #include <vala/valasymbol.h>
@@ -43,6 +43,8 @@ G_BEGIN_DECLS
 
 typedef struct _ValaMemberPrivate ValaMemberPrivate;
 
+#define TYPE_MEMBER_BINDING (member_binding_get_type ())
+
 /**
  * Represents a general class member.
  */
@@ -50,13 +52,21 @@ struct _ValaMember {
 	ValaSymbol parent_instance;
 	ValaMemberPrivate * priv;
 };
+
 struct _ValaMemberClass {
 	ValaSymbolClass parent_class;
 };
 
+typedef enum  {
+	MEMBER_BINDING_INSTANCE,
+	MEMBER_BINDING_CLASS,
+	MEMBER_BINDING_STATIC
+} MemberBinding;
+
+
 void vala_member_add_cheader_filename (ValaMember* self, const char* filename);
-ValaMember* vala_member_new (void);
 GType vala_member_get_type (void);
+GType member_binding_get_type (void);
 
 
 G_END_DECLS
