@@ -29,6 +29,7 @@
 #include <vala/valacodevisitor.h>
 #include <vala/valaproperty.h>
 #include <vala/valacodegenerator.h>
+#include <vala/valaconstant.h>
 
 
 
@@ -45,13 +46,7 @@ struct _ValaMemberAccessPrivate {
 
 #define VALA_MEMBER_ACCESS_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_MEMBER_ACCESS, ValaMemberAccessPrivate))
 enum  {
-	VALA_MEMBER_ACCESS_DUMMY_PROPERTY,
-	VALA_MEMBER_ACCESS_INNER,
-	VALA_MEMBER_ACCESS_MEMBER_NAME,
-	VALA_MEMBER_ACCESS_POINTER_MEMBER_ACCESS,
-	VALA_MEMBER_ACCESS_PROTOTYPE_ACCESS,
-	VALA_MEMBER_ACCESS_CREATION_MEMBER,
-	VALA_MEMBER_ACCESS_QUALIFIED
+	VALA_MEMBER_ACCESS_DUMMY_PROPERTY
 };
 static void vala_member_access_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static char* vala_member_access_real_to_string (ValaCodeNode* base);
@@ -59,8 +54,10 @@ static void vala_member_access_real_replace_expression (ValaCodeNode* base, Vala
 static gboolean vala_member_access_real_is_pure (ValaExpression* base);
 static void vala_member_access_real_replace_type (ValaCodeNode* base, ValaDataType* old_type, ValaDataType* new_type);
 static ValaCodeBinding* vala_member_access_real_create_code_binding (ValaCodeNode* base, ValaCodeGenerator* codegen);
+static gboolean vala_member_access_real_is_constant (ValaExpression* base);
+static gboolean vala_member_access_real_is_non_null (ValaExpression* base);
 static gpointer vala_member_access_parent_class = NULL;
-static void vala_member_access_dispose (GObject * obj);
+static void vala_member_access_finalize (ValaCodeNode* obj);
 
 
 
@@ -72,12 +69,12 @@ static void vala_member_access_dispose (GObject * obj);
  * @param source_reference reference to source code
  * @return                 newly created member access expression
  */
-ValaMemberAccess* vala_member_access_new (ValaExpression* inner, const char* member_name, ValaSourceReference* source_reference) {
-	ValaMemberAccess * self;
+ValaMemberAccess* vala_member_access_construct (GType object_type, ValaExpression* inner, const char* member_name, ValaSourceReference* source_reference) {
+	ValaMemberAccess* self;
 	g_return_val_if_fail (inner == NULL || VALA_IS_EXPRESSION (inner), NULL);
 	g_return_val_if_fail (member_name != NULL, NULL);
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
-	self = g_object_newv (VALA_TYPE_MEMBER_ACCESS, 0, NULL);
+	self = ((ValaMemberAccess*) (g_type_create_instance (object_type)));
 	vala_member_access_set_inner (self, inner);
 	vala_member_access_set_member_name (self, member_name);
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
@@ -85,23 +82,33 @@ ValaMemberAccess* vala_member_access_new (ValaExpression* inner, const char* mem
 }
 
 
+ValaMemberAccess* vala_member_access_new (ValaExpression* inner, const char* member_name, ValaSourceReference* source_reference) {
+	return vala_member_access_construct (VALA_TYPE_MEMBER_ACCESS, inner, member_name, source_reference);
+}
+
+
+ValaMemberAccess* vala_member_access_construct_simple (GType object_type, const char* member_name, ValaSourceReference* source_reference) {
+	ValaMemberAccess* self;
+	g_return_val_if_fail (member_name != NULL, NULL);
+	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
+	self = ((ValaMemberAccess*) (g_type_create_instance (object_type)));
+	vala_member_access_set_member_name (self, member_name);
+	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
+	return self;
+}
+
+
 ValaMemberAccess* vala_member_access_new_simple (const char* member_name, ValaSourceReference* source_reference) {
-	ValaMemberAccess * self;
-	g_return_val_if_fail (member_name != NULL, NULL);
-	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
-	self = g_object_newv (VALA_TYPE_MEMBER_ACCESS, 0, NULL);
-	vala_member_access_set_member_name (self, member_name);
-	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
-	return self;
+	return vala_member_access_construct_simple (VALA_TYPE_MEMBER_ACCESS, member_name, source_reference);
 }
 
 
-ValaMemberAccess* vala_member_access_new_pointer (ValaExpression* inner, const char* member_name, ValaSourceReference* source_reference) {
-	ValaMemberAccess * self;
+ValaMemberAccess* vala_member_access_construct_pointer (GType object_type, ValaExpression* inner, const char* member_name, ValaSourceReference* source_reference) {
+	ValaMemberAccess* self;
 	g_return_val_if_fail (VALA_IS_EXPRESSION (inner), NULL);
 	g_return_val_if_fail (member_name != NULL, NULL);
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
-	self = g_object_newv (VALA_TYPE_MEMBER_ACCESS, 0, NULL);
+	self = ((ValaMemberAccess*) (g_type_create_instance (object_type)));
 	vala_member_access_set_inner (self, inner);
 	vala_member_access_set_member_name (self, member_name);
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
@@ -110,6 +117,11 @@ ValaMemberAccess* vala_member_access_new_pointer (ValaExpression* inner, const c
 }
 
 
+ValaMemberAccess* vala_member_access_new_pointer (ValaExpression* inner, const char* member_name, ValaSourceReference* source_reference) {
+	return vala_member_access_construct_pointer (VALA_TYPE_MEMBER_ACCESS, inner, member_name, source_reference);
+}
+
+
 /**
  * Appends the specified type as generic type argument.
  *
@@ -130,7 +142,7 @@ void vala_member_access_add_type_argument (ValaMemberAccess* self, ValaDataType*
  */
 GeeList* vala_member_access_get_type_arguments (ValaMemberAccess* self) {
 	g_return_val_if_fail (VALA_IS_MEMBER_ACCESS (self), NULL);
-	return GEE_LIST (gee_read_only_list_new (VALA_TYPE_DATA_TYPE, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, self->priv->type_argument_list));
+	return GEE_LIST (gee_read_only_list_new (VALA_TYPE_DATA_TYPE, ((GBoxedCopyFunc) (vala_code_node_ref)), vala_code_node_unref, self->priv->type_argument_list));
 }
 
 
@@ -150,7 +162,7 @@ static void vala_member_access_real_accept (ValaCodeNode* base, ValaCodeVisitor*
 			type_arg = ((ValaDataType*) (gee_list_get (GEE_LIST (type_arg_collection), type_arg_it)));
 			{
 				vala_code_node_accept (VALA_CODE_NODE (type_arg), visitor);
-				(type_arg == NULL ? NULL : (type_arg = (g_object_unref (type_arg), NULL)));
+				(type_arg == NULL ? NULL : (type_arg = (vala_code_node_unref (type_arg), NULL)));
 			}
 		}
 	}
@@ -207,7 +219,7 @@ static void vala_member_access_real_replace_type (ValaCodeNode* base, ValaDataTy
 			ValaDataType* _tmp0;
 			gboolean _tmp1;
 			_tmp0 = NULL;
-			if ((_tmp1 = (_tmp0 = ((ValaDataType*) (gee_list_get (((GeeList*) (self->priv->type_argument_list)), i)))) == old_type, (_tmp0 == NULL ? NULL : (_tmp0 = (g_object_unref (_tmp0), NULL))), _tmp1)) {
+			if ((_tmp1 = (_tmp0 = ((ValaDataType*) (gee_list_get (((GeeList*) (self->priv->type_argument_list)), i)))) == old_type, (_tmp0 == NULL ? NULL : (_tmp0 = (vala_code_node_unref (_tmp0), NULL))), _tmp1)) {
 				gee_list_set (((GeeList*) (self->priv->type_argument_list)), i, new_type);
 				return;
 			}
@@ -224,6 +236,37 @@ static ValaCodeBinding* vala_member_access_real_create_code_binding (ValaCodeNod
 }
 
 
+static gboolean vala_member_access_real_is_constant (ValaExpression* base) {
+	ValaMemberAccess * self;
+	self = VALA_MEMBER_ACCESS (base);
+	if (VALA_IS_CONSTANT (vala_expression_get_symbol_reference (VALA_EXPRESSION (self)))) {
+		return TRUE;
+	} else {
+		return FALSE;
+	}
+}
+
+
+static gboolean vala_member_access_real_is_non_null (ValaExpression* base) {
+	ValaMemberAccess * self;
+	ValaConstant* _tmp1;
+	ValaSymbol* _tmp0;
+	ValaConstant* c;
+	self = VALA_MEMBER_ACCESS (base);
+	_tmp1 = NULL;
+	_tmp0 = NULL;
+	c = (_tmp1 = (_tmp0 = vala_expression_get_symbol_reference (VALA_EXPRESSION (self)), (VALA_IS_CONSTANT (_tmp0) ? ((ValaConstant*) (_tmp0)) : NULL)), (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1)));
+	if (c != NULL) {
+		gboolean _tmp2;
+		return (_tmp2 = !vala_data_type_get_nullable (vala_constant_get_type_reference (c)), (c == NULL ? NULL : (c = (vala_code_node_unref (c), NULL))), _tmp2);
+	} else {
+		gboolean _tmp3;
+		return (_tmp3 = FALSE, (c == NULL ? NULL : (c = (vala_code_node_unref (c), NULL))), _tmp3);
+	}
+	(c == NULL ? NULL : (c = (vala_code_node_unref (c), NULL)));
+}
+
+
 ValaExpression* vala_member_access_get_inner (ValaMemberAccess* self) {
 	g_return_val_if_fail (VALA_IS_MEMBER_ACCESS (self), NULL);
 	return self->priv->_inner;
@@ -236,7 +279,7 @@ void vala_member_access_set_inner (ValaMemberAccess* self, ValaExpression* value
 	g_return_if_fail (VALA_IS_MEMBER_ACCESS (self));
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_inner = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_inner == NULL ? NULL : (self->priv->_inner = (g_object_unref (self->priv->_inner), NULL))), _tmp2);
+	self->priv->_inner = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1))), (self->priv->_inner == NULL ? NULL : (self->priv->_inner = (vala_code_node_unref (self->priv->_inner), NULL))), _tmp2);
 	if (self->priv->_inner != NULL) {
 		vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_inner), VALA_CODE_NODE (self));
 	}
@@ -307,105 +350,41 @@ void vala_member_access_set_qualified (ValaMemberAccess* self, gboolean value) {
 }
 
 
-static void vala_member_access_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
-	ValaMemberAccess * self;
-	self = VALA_MEMBER_ACCESS (object);
-	switch (property_id) {
-		case VALA_MEMBER_ACCESS_INNER:
-		g_value_set_object (value, vala_member_access_get_inner (self));
-		break;
-		case VALA_MEMBER_ACCESS_MEMBER_NAME:
-		g_value_set_string (value, vala_member_access_get_member_name (self));
-		break;
-		case VALA_MEMBER_ACCESS_POINTER_MEMBER_ACCESS:
-		g_value_set_boolean (value, vala_member_access_get_pointer_member_access (self));
-		break;
-		case VALA_MEMBER_ACCESS_PROTOTYPE_ACCESS:
-		g_value_set_boolean (value, vala_member_access_get_prototype_access (self));
-		break;
-		case VALA_MEMBER_ACCESS_CREATION_MEMBER:
-		g_value_set_boolean (value, vala_member_access_get_creation_member (self));
-		break;
-		case VALA_MEMBER_ACCESS_QUALIFIED:
-		g_value_set_boolean (value, vala_member_access_get_qualified (self));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
-static void vala_member_access_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
-	ValaMemberAccess * self;
-	self = VALA_MEMBER_ACCESS (object);
-	switch (property_id) {
-		case VALA_MEMBER_ACCESS_INNER:
-		vala_member_access_set_inner (self, g_value_get_object (value));
-		break;
-		case VALA_MEMBER_ACCESS_MEMBER_NAME:
-		vala_member_access_set_member_name (self, g_value_get_string (value));
-		break;
-		case VALA_MEMBER_ACCESS_POINTER_MEMBER_ACCESS:
-		vala_member_access_set_pointer_member_access (self, g_value_get_boolean (value));
-		break;
-		case VALA_MEMBER_ACCESS_PROTOTYPE_ACCESS:
-		vala_member_access_set_prototype_access (self, g_value_get_boolean (value));
-		break;
-		case VALA_MEMBER_ACCESS_CREATION_MEMBER:
-		vala_member_access_set_creation_member (self, g_value_get_boolean (value));
-		break;
-		case VALA_MEMBER_ACCESS_QUALIFIED:
-		vala_member_access_set_qualified (self, g_value_get_boolean (value));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
 static void vala_member_access_class_init (ValaMemberAccessClass * klass) {
 	vala_member_access_parent_class = g_type_class_peek_parent (klass);
+	VALA_CODE_NODE_CLASS (klass)->finalize = vala_member_access_finalize;
 	g_type_class_add_private (klass, sizeof (ValaMemberAccessPrivate));
-	G_OBJECT_CLASS (klass)->get_property = vala_member_access_get_property;
-	G_OBJECT_CLASS (klass)->set_property = vala_member_access_set_property;
-	G_OBJECT_CLASS (klass)->dispose = vala_member_access_dispose;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_member_access_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->to_string = vala_member_access_real_to_string;
 	VALA_CODE_NODE_CLASS (klass)->replace_expression = vala_member_access_real_replace_expression;
 	VALA_EXPRESSION_CLASS (klass)->is_pure = vala_member_access_real_is_pure;
 	VALA_CODE_NODE_CLASS (klass)->replace_type = vala_member_access_real_replace_type;
 	VALA_CODE_NODE_CLASS (klass)->create_code_binding = vala_member_access_real_create_code_binding;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_MEMBER_ACCESS_INNER, g_param_spec_object ("inner", "inner", "inner", VALA_TYPE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_MEMBER_ACCESS_MEMBER_NAME, g_param_spec_string ("member-name", "member-name", "member-name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_MEMBER_ACCESS_POINTER_MEMBER_ACCESS, g_param_spec_boolean ("pointer-member-access", "pointer-member-access", "pointer-member-access", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_MEMBER_ACCESS_PROTOTYPE_ACCESS, g_param_spec_boolean ("prototype-access", "prototype-access", "prototype-access", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_MEMBER_ACCESS_CREATION_MEMBER, g_param_spec_boolean ("creation-member", "creation-member", "creation-member", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_MEMBER_ACCESS_QUALIFIED, g_param_spec_boolean ("qualified", "qualified", "qualified", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	VALA_EXPRESSION_CLASS (klass)->is_constant = vala_member_access_real_is_constant;
+	VALA_EXPRESSION_CLASS (klass)->is_non_null = vala_member_access_real_is_non_null;
 }
 
 
 static void vala_member_access_instance_init (ValaMemberAccess * self) {
 	self->priv = VALA_MEMBER_ACCESS_GET_PRIVATE (self);
-	self->priv->type_argument_list = GEE_LIST (gee_array_list_new (VALA_TYPE_DATA_TYPE, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal));
+	self->priv->type_argument_list = GEE_LIST (gee_array_list_new (VALA_TYPE_DATA_TYPE, ((GBoxedCopyFunc) (vala_code_node_ref)), vala_code_node_unref, g_direct_equal));
 }
 
 
-static void vala_member_access_dispose (GObject * obj) {
+static void vala_member_access_finalize (ValaCodeNode* obj) {
 	ValaMemberAccess * self;
 	self = VALA_MEMBER_ACCESS (obj);
 	self->priv->_member_name = (g_free (self->priv->_member_name), NULL);
-	(self->priv->_inner == NULL ? NULL : (self->priv->_inner = (g_object_unref (self->priv->_inner), NULL)));
-	(self->priv->type_argument_list == NULL ? NULL : (self->priv->type_argument_list = (g_object_unref (self->priv->type_argument_list), NULL)));
-	G_OBJECT_CLASS (vala_member_access_parent_class)->dispose (obj);
+	(self->priv->_inner == NULL ? NULL : (self->priv->_inner = (vala_code_node_unref (self->priv->_inner), NULL)));
+	(self->priv->type_argument_list == NULL ? NULL : (self->priv->type_argument_list = (gee_collection_object_unref (self->priv->type_argument_list), NULL)));
+	VALA_CODE_NODE_CLASS (vala_member_access_parent_class)->finalize (obj);
 }
 
 
 GType vala_member_access_get_type (void) {
 	static GType vala_member_access_type_id = 0;
-	if (G_UNLIKELY (vala_member_access_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaMemberAccessClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_member_access_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaMemberAccess), 0, (GInstanceInitFunc) vala_member_access_instance_init };
+	if (vala_member_access_type_id == 0) {
+		static const GTypeInfo g_define_type_info = { sizeof (ValaMemberAccessClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_member_access_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaMemberAccess), 0, (GInstanceInitFunc) vala_member_access_instance_init, NULL };
 		vala_member_access_type_id = g_type_register_static (VALA_TYPE_EXPRESSION, "ValaMemberAccess", &g_define_type_info, 0);
 	}
 	return vala_member_access_type_id;
