@@ -58,10 +58,12 @@ struct _ValaMethod {
 struct _ValaMethodClass {
 	ValaMemberClass parent_class;
 	char* (*get_default_cname) (ValaMethod* self);
+	char* (*get_real_cname) (ValaMethod* self);
 };
 
 
 #define VALA_METHOD_DEFAULT_SENTINEL "NULL"
+ValaMethod* vala_method_construct (GType object_type, const char* name, ValaDataType* return_type, ValaSourceReference* source_reference);
 ValaMethod* vala_method_new (const char* name, ValaDataType* return_type, ValaSourceReference* source_reference);
 void vala_method_add_parameter (ValaMethod* self, ValaFormalParameter* param);
 GeeList* vala_method_get_parameters (ValaMethod* self);
@@ -116,6 +118,8 @@ gboolean vala_method_get_no_array_length (ValaMethod* self);
 void vala_method_set_no_array_length (ValaMethod* self, gboolean value);
 gboolean vala_method_get_printf_format (ValaMethod* self);
 void vala_method_set_printf_format (ValaMethod* self, gboolean value);
+gboolean vala_method_get_has_construct_function (ValaMethod* self);
+void vala_method_set_has_construct_function (ValaMethod* self, gboolean value);
 GType vala_method_get_type (void);
 
 
