@@ -35,13 +35,11 @@ struct _ValaNamedArgumentPrivate {
 
 #define VALA_NAMED_ARGUMENT_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_NAMED_ARGUMENT, ValaNamedArgumentPrivate))
 enum  {
-	VALA_NAMED_ARGUMENT_DUMMY_PROPERTY,
-	VALA_NAMED_ARGUMENT_NAME,
-	VALA_NAMED_ARGUMENT_ARGUMENT
+	VALA_NAMED_ARGUMENT_DUMMY_PROPERTY
 };
 static void vala_named_argument_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static gpointer vala_named_argument_parent_class = NULL;
-static void vala_named_argument_dispose (GObject * obj);
+static void vala_named_argument_finalize (ValaCodeNode* obj);
 
 
 
@@ -53,34 +51,24 @@ static void vala_named_argument_dispose (GObject * obj);
  * @param source reference to source code
  * @return       newly created named argument
  */
-ValaNamedArgument* vala_named_argument_new (const char* name, ValaExpression* argument, ValaSourceReference* source_reference) {
-	GParameter * __params;
-	GParameter * __params_it;
-	ValaNamedArgument * self;
+ValaNamedArgument* vala_named_argument_construct (GType object_type, const char* name, ValaExpression* argument, ValaSourceReference* source_reference) {
+	ValaNamedArgument* self;
 	g_return_val_if_fail (name != NULL, NULL);
 	g_return_val_if_fail (VALA_IS_EXPRESSION (argument), NULL);
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
-	__params = g_new0 (GParameter, 2);
-	__params_it = __params;
-	__params_it->name = "name";
-	g_value_init (&__params_it->value, G_TYPE_STRING);
-	g_value_set_string (&__params_it->value, name);
-	__params_it++;
-	__params_it->name = "argument";
-	g_value_init (&__params_it->value, VALA_TYPE_EXPRESSION);
-	g_value_set_object (&__params_it->value, argument);
-	__params_it++;
-	self = g_object_newv (VALA_TYPE_NAMED_ARGUMENT, __params_it - __params, __params);
+	self = ((ValaNamedArgument*) (g_type_create_instance (object_type)));
+	vala_named_argument_set_name (self, name);
+	vala_named_argument_set_argument (self, argument);
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
-	while (__params_it > __params) {
-		--__params_it;
-		g_value_unset (&__params_it->value);
-	}
-	g_free (__params);
 	return self;
 }
 
 
+ValaNamedArgument* vala_named_argument_new (const char* name, ValaExpression* argument, ValaSourceReference* source_reference) {
+	return vala_named_argument_construct (VALA_TYPE_NAMED_ARGUMENT, name, argument, source_reference);
+}
+
+
 static void vala_named_argument_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaNamedArgument * self;
 	self = VALA_NAMED_ARGUMENT (base);
@@ -118,53 +106,15 @@ void vala_named_argument_set_argument (ValaNamedArgument* self, ValaExpression*
 	g_return_if_fail (VALA_IS_NAMED_ARGUMENT (self));
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_argument = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_argument == NULL ? NULL : (self->priv->_argument = (g_object_unref (self->priv->_argument), NULL))), _tmp2);
-}
-
-
-static void vala_named_argument_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
-	ValaNamedArgument * self;
-	self = VALA_NAMED_ARGUMENT (object);
-	switch (property_id) {
-		case VALA_NAMED_ARGUMENT_NAME:
-		g_value_set_string (value, vala_named_argument_get_name (self));
-		break;
-		case VALA_NAMED_ARGUMENT_ARGUMENT:
-		g_value_set_object (value, vala_named_argument_get_argument (self));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
-static void vala_named_argument_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
-	ValaNamedArgument * self;
-	self = VALA_NAMED_ARGUMENT (object);
-	switch (property_id) {
-		case VALA_NAMED_ARGUMENT_NAME:
-		vala_named_argument_set_name (self, g_value_get_string (value));
-		break;
-		case VALA_NAMED_ARGUMENT_ARGUMENT:
-		vala_named_argument_set_argument (self, g_value_get_object (value));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
+	self->priv->_argument = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1))), (self->priv->_argument == NULL ? NULL : (self->priv->_argument = (vala_code_node_unref (self->priv->_argument), NULL))), _tmp2);
 }
 
 
 static void vala_named_argument_class_init (ValaNamedArgumentClass * klass) {
 	vala_named_argument_parent_class = g_type_class_peek_parent (klass);
+	VALA_CODE_NODE_CLASS (klass)->finalize = vala_named_argument_finalize;
 	g_type_class_add_private (klass, sizeof (ValaNamedArgumentPrivate));
-	G_OBJECT_CLASS (klass)->get_property = vala_named_argument_get_property;
-	G_OBJECT_CLASS (klass)->set_property = vala_named_argument_set_property;
-	G_OBJECT_CLASS (klass)->dispose = vala_named_argument_dispose;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_named_argument_real_accept;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_NAMED_ARGUMENT_NAME, g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_NAMED_ARGUMENT_ARGUMENT, g_param_spec_object ("argument", "argument", "argument", VALA_TYPE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
 }
 
 
@@ -173,19 +123,19 @@ static void vala_named_argument_instance_init (ValaNamedArgument * self) {
 }
 
 
-static void vala_named_argument_dispose (GObject * obj) {
+static void vala_named_argument_finalize (ValaCodeNode* obj) {
 	ValaNamedArgument * self;
 	self = VALA_NAMED_ARGUMENT (obj);
 	self->priv->_name = (g_free (self->priv->_name), NULL);
-	(self->priv->_argument == NULL ? NULL : (self->priv->_argument = (g_object_unref (self->priv->_argument), NULL)));
-	G_OBJECT_CLASS (vala_named_argument_parent_class)->dispose (obj);
+	(self->priv->_argument == NULL ? NULL : (self->priv->_argument = (vala_code_node_unref (self->priv->_argument), NULL)));
+	VALA_CODE_NODE_CLASS (vala_named_argument_parent_class)->finalize (obj);
 }
 
 
 GType vala_named_argument_get_type (void) {
 	static GType vala_named_argument_type_id = 0;
-	if (G_UNLIKELY (vala_named_argument_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaNamedArgumentClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_named_argument_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaNamedArgument), 0, (GInstanceInitFunc) vala_named_argument_instance_init };
+	if (vala_named_argument_type_id == 0) {
+		static const GTypeInfo g_define_type_info = { sizeof (ValaNamedArgumentClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_named_argument_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaNamedArgument), 0, (GInstanceInitFunc) vala_named_argument_instance_init, NULL };
 		vala_named_argument_type_id = g_type_register_static (VALA_TYPE_CODE_NODE, "ValaNamedArgument", &g_define_type_info, 0);
 	}
 	return vala_named_argument_type_id;
