@@ -27,7 +27,6 @@
 #include <glib-object.h>
 #include <stdlib.h>
 #include <string.h>
-#include <gee/collection.h>
 #include <gee/list.h>
 #include <vala/valasymbol.h>
 #include <vala/valacodenode.h>
@@ -51,22 +50,31 @@ struct _ValaNamespace {
 	ValaSymbol parent_instance;
 	ValaNamespacePrivate * priv;
 };
+
 struct _ValaNamespaceClass {
 	ValaSymbolClass parent_class;
 };
 
+
+ValaNamespace* vala_namespace_construct (GType object_type, const char* name, ValaSourceReference* source_reference);
 ValaNamespace* vala_namespace_new (const char* name, ValaSourceReference* source_reference);
 void vala_namespace_add_namespace (ValaNamespace* self, ValaNamespace* ns);
-GeeCollection* vala_namespace_get_namespaces (ValaNamespace* self);
+GeeList* vala_namespace_get_namespaces (ValaNamespace* self);
 void vala_namespace_add_class (ValaNamespace* self, ValaClass* cl);
 void vala_namespace_add_interface (ValaNamespace* self, ValaInterface* iface);
 void vala_namespace_add_struct (ValaNamespace* self, ValaStruct* st);
 void vala_namespace_add_enum (ValaNamespace* self, ValaEnum* en);
 void vala_namespace_add_error_domain (ValaNamespace* self, ValaErrorDomain* edomain);
 void vala_namespace_add_delegate (ValaNamespace* self, ValaDelegate* d);
-GeeCollection* vala_namespace_get_structs (ValaNamespace* self);
-GeeCollection* vala_namespace_get_classes (ValaNamespace* self);
-GeeCollection* vala_namespace_get_interfaces (ValaNamespace* self);
+GeeList* vala_namespace_get_structs (ValaNamespace* self);
+GeeList* vala_namespace_get_classes (ValaNamespace* self);
+GeeList* vala_namespace_get_interfaces (ValaNamespace* self);
+GeeList* vala_namespace_get_enums (ValaNamespace* self);
+GeeList* vala_namespace_get_error_types (ValaNamespace* self);
+GeeList* vala_namespace_get_fields (ValaNamespace* self);
+GeeList* vala_namespace_get_constants (ValaNamespace* self);
+GeeList* vala_namespace_get_delegates (ValaNamespace* self);
+GeeList* vala_namespace_get_methods (ValaNamespace* self);
 void vala_namespace_add_constant (ValaNamespace* self, ValaConstant* constant);
 void vala_namespace_add_field (ValaNamespace* self, ValaField* f);
 void vala_namespace_add_method (ValaNamespace* self, ValaMethod* m);
@@ -76,8 +84,6 @@ void vala_namespace_set_lower_case_cprefix (ValaNamespace* self, const char* cpr
 char* vala_namespace_get_cheader_filename (ValaNamespace* self);
 void vala_namespace_set_cheader_filename (ValaNamespace* self, const char* cheader_filename);
 void vala_namespace_process_attributes (ValaNamespace* self);
-gboolean vala_namespace_get_pkg (ValaNamespace* self);
-void vala_namespace_set_pkg (ValaNamespace* self, gboolean value);
 GType vala_namespace_get_type (void);
 
 
