@@ -49,22 +49,12 @@ struct _ValaPropertyAccessorPrivate {
 
 #define VALA_PROPERTY_ACCESSOR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_PROPERTY_ACCESSOR, ValaPropertyAccessorPrivate))
 enum  {
-	VALA_PROPERTY_ACCESSOR_DUMMY_PROPERTY,
-	VALA_PROPERTY_ACCESSOR_PROP,
-	VALA_PROPERTY_ACCESSOR_READABLE,
-	VALA_PROPERTY_ACCESSOR_WRITABLE,
-	VALA_PROPERTY_ACCESSOR_CONSTRUCTION,
-	VALA_PROPERTY_ACCESSOR_ACCESS,
-	VALA_PROPERTY_ACCESSOR_BODY,
-	VALA_PROPERTY_ACCESSOR_ENTRY_BLOCK,
-	VALA_PROPERTY_ACCESSOR_EXIT_BLOCK,
-	VALA_PROPERTY_ACCESSOR_AUTOMATIC_BODY,
-	VALA_PROPERTY_ACCESSOR_VALUE_PARAMETER
+	VALA_PROPERTY_ACCESSOR_DUMMY_PROPERTY
 };
 static void vala_property_accessor_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_property_accessor_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static gpointer vala_property_accessor_parent_class = NULL;
-static void vala_property_accessor_finalize (GObject * obj);
+static void vala_property_accessor_finalize (ValaCodeNode* obj);
 static int _vala_strcmp0 (const char * str1, const char * str2);
 
 
@@ -83,7 +73,7 @@ char* vala_property_accessor_get_cname (ValaPropertyAccessor* self) {
 		return (_tmp0 = self->priv->_cname, (_tmp0 == NULL ? NULL : g_strdup (_tmp0)));
 	}
 	_tmp2 = NULL;
-	t = (_tmp2 = VALA_TYPESYMBOL (vala_symbol_get_parent_symbol (VALA_SYMBOL (self->priv->_prop))), (_tmp2 == NULL ? NULL : g_object_ref (_tmp2)));
+	t = (_tmp2 = VALA_TYPESYMBOL (vala_symbol_get_parent_symbol (VALA_SYMBOL (self->priv->_prop))), (_tmp2 == NULL ? NULL : vala_code_node_ref (_tmp2)));
 	if (self->priv->_readable) {
 		char* _tmp3;
 		char* _tmp4;
@@ -91,7 +81,7 @@ char* vala_property_accessor_get_cname (ValaPropertyAccessor* self) {
 		_tmp3 = NULL;
 		_tmp4 = NULL;
 		_tmp5 = NULL;
-		return (_tmp5 = (_tmp4 = g_strdup_printf ("%s_get_%s", (_tmp3 = vala_symbol_get_lower_case_cname (VALA_SYMBOL (t), NULL)), vala_symbol_get_name (VALA_SYMBOL (self->priv->_prop))), (_tmp3 = (g_free (_tmp3), NULL)), _tmp4), (t == NULL ? NULL : (t = (g_object_unref (t), NULL))), _tmp5);
+		return (_tmp5 = (_tmp4 = g_strdup_printf ("%s_get_%s", (_tmp3 = vala_symbol_get_lower_case_cname (VALA_SYMBOL (t), NULL)), vala_symbol_get_name (VALA_SYMBOL (self->priv->_prop))), (_tmp3 = (g_free (_tmp3), NULL)), _tmp4), (t == NULL ? NULL : (t = (vala_code_node_unref (t), NULL))), _tmp5);
 	} else {
 		char* _tmp6;
 		char* _tmp7;
@@ -99,9 +89,9 @@ char* vala_property_accessor_get_cname (ValaPropertyAccessor* self) {
 		_tmp6 = NULL;
 		_tmp7 = NULL;
 		_tmp8 = NULL;
-		return (_tmp8 = (_tmp7 = g_strdup_printf ("%s_set_%s", (_tmp6 = vala_symbol_get_lower_case_cname (VALA_SYMBOL (t), NULL)), vala_symbol_get_name (VALA_SYMBOL (self->priv->_prop))), (_tmp6 = (g_free (_tmp6), NULL)), _tmp7), (t == NULL ? NULL : (t = (g_object_unref (t), NULL))), _tmp8);
+		return (_tmp8 = (_tmp7 = g_strdup_printf ("%s_set_%s", (_tmp6 = vala_symbol_get_lower_case_cname (VALA_SYMBOL (t), NULL)), vala_symbol_get_name (VALA_SYMBOL (self->priv->_prop))), (_tmp6 = (g_free (_tmp6), NULL)), _tmp7), (t == NULL ? NULL : (t = (vala_code_node_unref (t), NULL))), _tmp8);
 	}
-	(t == NULL ? NULL : (t = (g_object_unref (t), NULL)));
+	(t == NULL ? NULL : (t = (vala_code_node_unref (t), NULL)));
 }
 
 
@@ -115,11 +105,11 @@ char* vala_property_accessor_get_cname (ValaPropertyAccessor* self) {
  * @param source       reference to source code
  * @return             newly created property accessor
  */
-ValaPropertyAccessor* vala_property_accessor_new (gboolean readable, gboolean writable, gboolean construction, ValaBlock* body, ValaSourceReference* source_reference) {
-	ValaPropertyAccessor * self;
+ValaPropertyAccessor* vala_property_accessor_construct (GType object_type, gboolean readable, gboolean writable, gboolean construction, ValaBlock* body, ValaSourceReference* source_reference) {
+	ValaPropertyAccessor* self;
 	g_return_val_if_fail (body == NULL || VALA_IS_BLOCK (body), NULL);
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
-	self = g_object_newv (VALA_TYPE_PROPERTY_ACCESSOR, 0, NULL);
+	self = ((ValaPropertyAccessor*) (g_type_create_instance (object_type)));
 	vala_property_accessor_set_readable (self, readable);
 	vala_property_accessor_set_writable (self, writable);
 	vala_property_accessor_set_construction (self, construction);
@@ -129,6 +119,11 @@ ValaPropertyAccessor* vala_property_accessor_new (gboolean readable, gboolean wr
 }
 
 
+ValaPropertyAccessor* vala_property_accessor_new (gboolean readable, gboolean writable, gboolean construction, ValaBlock* body, ValaSourceReference* source_reference) {
+	return vala_property_accessor_construct (VALA_TYPE_PROPERTY_ACCESSOR, readable, writable, construction, body, source_reference);
+}
+
+
 static void vala_property_accessor_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaPropertyAccessor * self;
 	self = VALA_PROPERTY_ACCESSOR (base);
@@ -160,7 +155,7 @@ void vala_property_accessor_process_attributes (ValaPropertyAccessor* self) {
 			ValaAttribute* _tmp1;
 			ValaAttribute* a;
 			_tmp1 = NULL;
-			a = (_tmp1 = ((ValaAttribute*) (a_it->data)), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
+			a = (_tmp1 = ((ValaAttribute*) (a_it->data)), (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1)));
 			{
 				if (_vala_strcmp0 (vala_attribute_get_name (a), "CCode") == 0) {
 					if (vala_attribute_has_argument (a, "cname")) {
@@ -169,7 +164,7 @@ void vala_property_accessor_process_attributes (ValaPropertyAccessor* self) {
 						self->priv->_cname = (_tmp0 = vala_attribute_get_string (a, "cname"), (self->priv->_cname = (g_free (self->priv->_cname), NULL)), _tmp0);
 					}
 				}
-				(a == NULL ? NULL : (a = (g_object_unref (a), NULL)));
+				(a == NULL ? NULL : (a = (vala_code_node_unref (a), NULL)));
 			}
 		}
 	}
@@ -185,7 +180,6 @@ ValaProperty* vala_property_accessor_get_prop (ValaPropertyAccessor* self) {
 void vala_property_accessor_set_prop (ValaPropertyAccessor* self, ValaProperty* value) {
 	g_return_if_fail (VALA_IS_PROPERTY_ACCESSOR (self));
 	self->priv->_prop = value;
-	g_object_notify (((GObject *) (self)), "prop");
 }
 
 
@@ -198,7 +192,6 @@ gboolean vala_property_accessor_get_readable (ValaPropertyAccessor* self) {
 void vala_property_accessor_set_readable (ValaPropertyAccessor* self, gboolean value) {
 	g_return_if_fail (VALA_IS_PROPERTY_ACCESSOR (self));
 	self->priv->_readable = value;
-	g_object_notify (((GObject *) (self)), "readable");
 }
 
 
@@ -211,7 +204,6 @@ gboolean vala_property_accessor_get_writable (ValaPropertyAccessor* self) {
 void vala_property_accessor_set_writable (ValaPropertyAccessor* self, gboolean value) {
 	g_return_if_fail (VALA_IS_PROPERTY_ACCESSOR (self));
 	self->priv->_writable = value;
-	g_object_notify (((GObject *) (self)), "writable");
 }
 
 
@@ -224,7 +216,6 @@ gboolean vala_property_accessor_get_construction (ValaPropertyAccessor* self) {
 void vala_property_accessor_set_construction (ValaPropertyAccessor* self, gboolean value) {
 	g_return_if_fail (VALA_IS_PROPERTY_ACCESSOR (self));
 	self->priv->_construction = value;
-	g_object_notify (((GObject *) (self)), "construction");
 }
 
 
@@ -237,7 +228,6 @@ ValaSymbolAccessibility vala_property_accessor_get_access (ValaPropertyAccessor*
 void vala_property_accessor_set_access (ValaPropertyAccessor* self, ValaSymbolAccessibility value) {
 	g_return_if_fail (VALA_IS_PROPERTY_ACCESSOR (self));
 	self->priv->_access = value;
-	g_object_notify (((GObject *) (self)), "access");
 }
 
 
@@ -253,8 +243,7 @@ void vala_property_accessor_set_body (ValaPropertyAccessor* self, ValaBlock* val
 	g_return_if_fail (VALA_IS_PROPERTY_ACCESSOR (self));
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_body = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_body == NULL ? NULL : (self->priv->_body = (g_object_unref (self->priv->_body), NULL))), _tmp2);
-	g_object_notify (((GObject *) (self)), "body");
+	self->priv->_body = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1))), (self->priv->_body == NULL ? NULL : (self->priv->_body = (vala_code_node_unref (self->priv->_body), NULL))), _tmp2);
 }
 
 
@@ -270,8 +259,7 @@ void vala_property_accessor_set_entry_block (ValaPropertyAccessor* self, ValaBas
 	g_return_if_fail (VALA_IS_PROPERTY_ACCESSOR (self));
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_entry_block = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_entry_block == NULL ? NULL : (self->priv->_entry_block = (g_object_unref (self->priv->_entry_block), NULL))), _tmp2);
-	g_object_notify (((GObject *) (self)), "entry-block");
+	self->priv->_entry_block = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_basic_block_ref (_tmp1))), (self->priv->_entry_block == NULL ? NULL : (self->priv->_entry_block = (vala_basic_block_unref (self->priv->_entry_block), NULL))), _tmp2);
 }
 
 
@@ -287,8 +275,7 @@ void vala_property_accessor_set_exit_block (ValaPropertyAccessor* self, ValaBasi
 	g_return_if_fail (VALA_IS_PROPERTY_ACCESSOR (self));
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_exit_block = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_exit_block == NULL ? NULL : (self->priv->_exit_block = (g_object_unref (self->priv->_exit_block), NULL))), _tmp2);
-	g_object_notify (((GObject *) (self)), "exit-block");
+	self->priv->_exit_block = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_basic_block_ref (_tmp1))), (self->priv->_exit_block == NULL ? NULL : (self->priv->_exit_block = (vala_basic_block_unref (self->priv->_exit_block), NULL))), _tmp2);
 }
 
 
@@ -301,7 +288,6 @@ gboolean vala_property_accessor_get_automatic_body (ValaPropertyAccessor* self)
 void vala_property_accessor_set_automatic_body (ValaPropertyAccessor* self, gboolean value) {
 	g_return_if_fail (VALA_IS_PROPERTY_ACCESSOR (self));
 	self->priv->_automatic_body = value;
-	g_object_notify (((GObject *) (self)), "automatic-body");
 }
 
 
@@ -317,111 +303,16 @@ void vala_property_accessor_set_value_parameter (ValaPropertyAccessor* self, Val
 	g_return_if_fail (VALA_IS_PROPERTY_ACCESSOR (self));
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_value_parameter = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_value_parameter == NULL ? NULL : (self->priv->_value_parameter = (g_object_unref (self->priv->_value_parameter), NULL))), _tmp2);
-	g_object_notify (((GObject *) (self)), "value-parameter");
-}
-
-
-static void vala_property_accessor_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
-	ValaPropertyAccessor * self;
-	self = VALA_PROPERTY_ACCESSOR (object);
-	switch (property_id) {
-		case VALA_PROPERTY_ACCESSOR_PROP:
-		g_value_set_object (value, vala_property_accessor_get_prop (self));
-		break;
-		case VALA_PROPERTY_ACCESSOR_READABLE:
-		g_value_set_boolean (value, vala_property_accessor_get_readable (self));
-		break;
-		case VALA_PROPERTY_ACCESSOR_WRITABLE:
-		g_value_set_boolean (value, vala_property_accessor_get_writable (self));
-		break;
-		case VALA_PROPERTY_ACCESSOR_CONSTRUCTION:
-		g_value_set_boolean (value, vala_property_accessor_get_construction (self));
-		break;
-		case VALA_PROPERTY_ACCESSOR_ACCESS:
-		g_value_set_enum (value, vala_property_accessor_get_access (self));
-		break;
-		case VALA_PROPERTY_ACCESSOR_BODY:
-		g_value_set_object (value, vala_property_accessor_get_body (self));
-		break;
-		case VALA_PROPERTY_ACCESSOR_ENTRY_BLOCK:
-		g_value_set_object (value, vala_property_accessor_get_entry_block (self));
-		break;
-		case VALA_PROPERTY_ACCESSOR_EXIT_BLOCK:
-		g_value_set_object (value, vala_property_accessor_get_exit_block (self));
-		break;
-		case VALA_PROPERTY_ACCESSOR_AUTOMATIC_BODY:
-		g_value_set_boolean (value, vala_property_accessor_get_automatic_body (self));
-		break;
-		case VALA_PROPERTY_ACCESSOR_VALUE_PARAMETER:
-		g_value_set_object (value, vala_property_accessor_get_value_parameter (self));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
-static void vala_property_accessor_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
-	ValaPropertyAccessor * self;
-	self = VALA_PROPERTY_ACCESSOR (object);
-	switch (property_id) {
-		case VALA_PROPERTY_ACCESSOR_PROP:
-		vala_property_accessor_set_prop (self, g_value_get_object (value));
-		break;
-		case VALA_PROPERTY_ACCESSOR_READABLE:
-		vala_property_accessor_set_readable (self, g_value_get_boolean (value));
-		break;
-		case VALA_PROPERTY_ACCESSOR_WRITABLE:
-		vala_property_accessor_set_writable (self, g_value_get_boolean (value));
-		break;
-		case VALA_PROPERTY_ACCESSOR_CONSTRUCTION:
-		vala_property_accessor_set_construction (self, g_value_get_boolean (value));
-		break;
-		case VALA_PROPERTY_ACCESSOR_ACCESS:
-		vala_property_accessor_set_access (self, g_value_get_enum (value));
-		break;
-		case VALA_PROPERTY_ACCESSOR_BODY:
-		vala_property_accessor_set_body (self, g_value_get_object (value));
-		break;
-		case VALA_PROPERTY_ACCESSOR_ENTRY_BLOCK:
-		vala_property_accessor_set_entry_block (self, g_value_get_object (value));
-		break;
-		case VALA_PROPERTY_ACCESSOR_EXIT_BLOCK:
-		vala_property_accessor_set_exit_block (self, g_value_get_object (value));
-		break;
-		case VALA_PROPERTY_ACCESSOR_AUTOMATIC_BODY:
-		vala_property_accessor_set_automatic_body (self, g_value_get_boolean (value));
-		break;
-		case VALA_PROPERTY_ACCESSOR_VALUE_PARAMETER:
-		vala_property_accessor_set_value_parameter (self, g_value_get_object (value));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
+	self->priv->_value_parameter = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1))), (self->priv->_value_parameter == NULL ? NULL : (self->priv->_value_parameter = (vala_code_node_unref (self->priv->_value_parameter), NULL))), _tmp2);
 }
 
 
 static void vala_property_accessor_class_init (ValaPropertyAccessorClass * klass) {
 	vala_property_accessor_parent_class = g_type_class_peek_parent (klass);
+	VALA_CODE_NODE_CLASS (klass)->finalize = vala_property_accessor_finalize;
 	g_type_class_add_private (klass, sizeof (ValaPropertyAccessorPrivate));
-	G_OBJECT_CLASS (klass)->get_property = vala_property_accessor_get_property;
-	G_OBJECT_CLASS (klass)->set_property = vala_property_accessor_set_property;
-	G_OBJECT_CLASS (klass)->finalize = vala_property_accessor_finalize;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_property_accessor_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_property_accessor_real_accept_children;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_ACCESSOR_PROP, g_param_spec_object ("prop", "prop", "prop", VALA_TYPE_PROPERTY, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_ACCESSOR_READABLE, g_param_spec_boolean ("readable", "readable", "readable", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_ACCESSOR_WRITABLE, g_param_spec_boolean ("writable", "writable", "writable", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_ACCESSOR_CONSTRUCTION, g_param_spec_boolean ("construction", "construction", "construction", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_ACCESSOR_ACCESS, g_param_spec_enum ("access", "access", "access", VALA_TYPE_SYMBOL_ACCESSIBILITY, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_ACCESSOR_BODY, g_param_spec_object ("body", "body", "body", VALA_TYPE_BLOCK, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_ACCESSOR_ENTRY_BLOCK, g_param_spec_object ("entry-block", "entry-block", "entry-block", VALA_TYPE_BASIC_BLOCK, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_ACCESSOR_EXIT_BLOCK, g_param_spec_object ("exit-block", "exit-block", "exit-block", VALA_TYPE_BASIC_BLOCK, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_ACCESSOR_AUTOMATIC_BODY, g_param_spec_boolean ("automatic-body", "automatic-body", "automatic-body", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_ACCESSOR_VALUE_PARAMETER, g_param_spec_object ("value-parameter", "value-parameter", "value-parameter", VALA_TYPE_FORMAL_PARAMETER, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
@@ -430,22 +321,22 @@ static void vala_property_accessor_instance_init (ValaPropertyAccessor * self) {
 }
 
 
-static void vala_property_accessor_finalize (GObject * obj) {
+static void vala_property_accessor_finalize (ValaCodeNode* obj) {
 	ValaPropertyAccessor * self;
 	self = VALA_PROPERTY_ACCESSOR (obj);
-	(self->priv->_body == NULL ? NULL : (self->priv->_body = (g_object_unref (self->priv->_body), NULL)));
-	(self->priv->_entry_block == NULL ? NULL : (self->priv->_entry_block = (g_object_unref (self->priv->_entry_block), NULL)));
-	(self->priv->_exit_block == NULL ? NULL : (self->priv->_exit_block = (g_object_unref (self->priv->_exit_block), NULL)));
-	(self->priv->_value_parameter == NULL ? NULL : (self->priv->_value_parameter = (g_object_unref (self->priv->_value_parameter), NULL)));
+	(self->priv->_body == NULL ? NULL : (self->priv->_body = (vala_code_node_unref (self->priv->_body), NULL)));
+	(self->priv->_entry_block == NULL ? NULL : (self->priv->_entry_block = (vala_basic_block_unref (self->priv->_entry_block), NULL)));
+	(self->priv->_exit_block == NULL ? NULL : (self->priv->_exit_block = (vala_basic_block_unref (self->priv->_exit_block), NULL)));
+	(self->priv->_value_parameter == NULL ? NULL : (self->priv->_value_parameter = (vala_code_node_unref (self->priv->_value_parameter), NULL)));
 	self->priv->_cname = (g_free (self->priv->_cname), NULL);
-	G_OBJECT_CLASS (vala_property_accessor_parent_class)->finalize (obj);
+	VALA_CODE_NODE_CLASS (vala_property_accessor_parent_class)->finalize (obj);
 }
 
 
 GType vala_property_accessor_get_type (void) {
 	static GType vala_property_accessor_type_id = 0;
 	if (vala_property_accessor_type_id == 0) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaPropertyAccessorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_property_accessor_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaPropertyAccessor), 0, (GInstanceInitFunc) vala_property_accessor_instance_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaPropertyAccessorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_property_accessor_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaPropertyAccessor), 0, (GInstanceInitFunc) vala_property_accessor_instance_init, NULL };
 		vala_property_accessor_type_id = g_type_register_static (VALA_TYPE_CODE_NODE, "ValaPropertyAccessor", &g_define_type_info, 0);
 	}
 	return vala_property_accessor_type_id;
