@@ -34,13 +34,13 @@ struct _ValaRealLiteralPrivate {
 
 #define VALA_REAL_LITERAL_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_REAL_LITERAL, ValaRealLiteralPrivate))
 enum  {
-	VALA_REAL_LITERAL_DUMMY_PROPERTY,
-	VALA_REAL_LITERAL_VALUE
+	VALA_REAL_LITERAL_DUMMY_PROPERTY
 };
 static void vala_real_literal_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static gboolean vala_real_literal_real_is_pure (ValaExpression* base);
+static char* vala_real_literal_real_to_string (ValaCodeNode* base);
 static gpointer vala_real_literal_parent_class = NULL;
-static void vala_real_literal_finalize (GObject * obj);
+static void vala_real_literal_finalize (ValaCodeNode* obj);
 
 
 
@@ -51,17 +51,22 @@ static void vala_real_literal_finalize (GObject * obj);
  * @param source reference to source code
  * @return       newly created real literal
  */
-ValaRealLiteral* vala_real_literal_new (const char* r, ValaSourceReference* source) {
-	ValaRealLiteral * self;
+ValaRealLiteral* vala_real_literal_construct (GType object_type, const char* r, ValaSourceReference* source) {
+	ValaRealLiteral* self;
 	g_return_val_if_fail (r != NULL, NULL);
 	g_return_val_if_fail (VALA_IS_SOURCE_REFERENCE (source), NULL);
-	self = g_object_newv (VALA_TYPE_REAL_LITERAL, 0, NULL);
+	self = ((ValaRealLiteral*) (g_type_create_instance (object_type)));
 	vala_real_literal_set_value (self, r);
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source);
 	return self;
 }
 
 
+ValaRealLiteral* vala_real_literal_new (const char* r, ValaSourceReference* source) {
+	return vala_real_literal_construct (VALA_TYPE_REAL_LITERAL, r, source);
+}
+
+
 static void vala_real_literal_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaRealLiteral * self;
 	self = VALA_REAL_LITERAL (base);
@@ -92,6 +97,15 @@ static gboolean vala_real_literal_real_is_pure (ValaExpression* base) {
 }
 
 
+static char* vala_real_literal_real_to_string (ValaCodeNode* base) {
+	ValaRealLiteral * self;
+	const char* _tmp0;
+	self = VALA_REAL_LITERAL (base);
+	_tmp0 = NULL;
+	return (_tmp0 = self->priv->_value, (_tmp0 == NULL ? NULL : g_strdup (_tmp0)));
+}
+
+
 const char* vala_real_literal_get_value (ValaRealLiteral* self) {
 	g_return_val_if_fail (VALA_IS_REAL_LITERAL (self), NULL);
 	return self->priv->_value;
@@ -105,47 +119,16 @@ void vala_real_literal_set_value (ValaRealLiteral* self, const char* value) {
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_value = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_value = (g_free (self->priv->_value), NULL)), _tmp2);
-	g_object_notify (((GObject *) (self)), "value");
-}
-
-
-static void vala_real_literal_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
-	ValaRealLiteral * self;
-	self = VALA_REAL_LITERAL (object);
-	switch (property_id) {
-		case VALA_REAL_LITERAL_VALUE:
-		g_value_set_string (value, vala_real_literal_get_value (self));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
-static void vala_real_literal_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
-	ValaRealLiteral * self;
-	self = VALA_REAL_LITERAL (object);
-	switch (property_id) {
-		case VALA_REAL_LITERAL_VALUE:
-		vala_real_literal_set_value (self, g_value_get_string (value));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
 }
 
 
 static void vala_real_literal_class_init (ValaRealLiteralClass * klass) {
 	vala_real_literal_parent_class = g_type_class_peek_parent (klass);
+	VALA_CODE_NODE_CLASS (klass)->finalize = vala_real_literal_finalize;
 	g_type_class_add_private (klass, sizeof (ValaRealLiteralPrivate));
-	G_OBJECT_CLASS (klass)->get_property = vala_real_literal_get_property;
-	G_OBJECT_CLASS (klass)->set_property = vala_real_literal_set_property;
-	G_OBJECT_CLASS (klass)->finalize = vala_real_literal_finalize;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_real_literal_real_accept;
 	VALA_EXPRESSION_CLASS (klass)->is_pure = vala_real_literal_real_is_pure;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_REAL_LITERAL_VALUE, g_param_spec_string ("value", "value", "value", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	VALA_CODE_NODE_CLASS (klass)->to_string = vala_real_literal_real_to_string;
 }
 
 
@@ -154,18 +137,18 @@ static void vala_real_literal_instance_init (ValaRealLiteral * self) {
 }
 
 
-static void vala_real_literal_finalize (GObject * obj) {
+static void vala_real_literal_finalize (ValaCodeNode* obj) {
 	ValaRealLiteral * self;
 	self = VALA_REAL_LITERAL (obj);
 	self->priv->_value = (g_free (self->priv->_value), NULL);
-	G_OBJECT_CLASS (vala_real_literal_parent_class)->finalize (obj);
+	VALA_CODE_NODE_CLASS (vala_real_literal_parent_class)->finalize (obj);
 }
 
 
 GType vala_real_literal_get_type (void) {
 	static GType vala_real_literal_type_id = 0;
 	if (vala_real_literal_type_id == 0) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaRealLiteralClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_real_literal_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaRealLiteral), 0, (GInstanceInitFunc) vala_real_literal_instance_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaRealLiteralClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_real_literal_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaRealLiteral), 0, (GInstanceInitFunc) vala_real_literal_instance_init, NULL };
 		vala_real_literal_type_id = g_type_register_static (VALA_TYPE_LITERAL, "ValaRealLiteral", &g_define_type_info, 0);
 	}
 	return vala_real_literal_type_id;
