@@ -33,15 +33,14 @@ struct _ValaReferenceTransferExpressionPrivate {
 
 #define VALA_REFERENCE_TRANSFER_EXPRESSION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_REFERENCE_TRANSFER_EXPRESSION, ValaReferenceTransferExpressionPrivate))
 enum  {
-	VALA_REFERENCE_TRANSFER_EXPRESSION_DUMMY_PROPERTY,
-	VALA_REFERENCE_TRANSFER_EXPRESSION_INNER
+	VALA_REFERENCE_TRANSFER_EXPRESSION_DUMMY_PROPERTY
 };
 static void vala_reference_transfer_expression_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_reference_transfer_expression_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_reference_transfer_expression_real_replace_expression (ValaCodeNode* base, ValaExpression* old_node, ValaExpression* new_node);
 static gboolean vala_reference_transfer_expression_real_is_pure (ValaExpression* base);
 static gpointer vala_reference_transfer_expression_parent_class = NULL;
-static void vala_reference_transfer_expression_finalize (GObject * obj);
+static void vala_reference_transfer_expression_finalize (ValaCodeNode* obj);
 
 
 
@@ -51,29 +50,22 @@ static void vala_reference_transfer_expression_finalize (GObject * obj);
  * @param inner variable whose reference is to be transferred
  * @return      newly created reference transfer expression
  */
-ValaReferenceTransferExpression* vala_reference_transfer_expression_new (ValaExpression* inner, ValaSourceReference* source_reference) {
-	GParameter * __params;
-	GParameter * __params_it;
-	ValaReferenceTransferExpression * self;
+ValaReferenceTransferExpression* vala_reference_transfer_expression_construct (GType object_type, ValaExpression* inner, ValaSourceReference* source_reference) {
+	ValaReferenceTransferExpression* self;
 	g_return_val_if_fail (VALA_IS_EXPRESSION (inner), NULL);
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
-	__params = g_new0 (GParameter, 1);
-	__params_it = __params;
-	__params_it->name = "inner";
-	g_value_init (&__params_it->value, VALA_TYPE_EXPRESSION);
-	g_value_set_object (&__params_it->value, inner);
-	__params_it++;
-	self = g_object_newv (VALA_TYPE_REFERENCE_TRANSFER_EXPRESSION, __params_it - __params, __params);
+	self = ((ValaReferenceTransferExpression*) (g_type_create_instance (object_type)));
+	vala_reference_transfer_expression_set_inner (self, inner);
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
-	while (__params_it > __params) {
-		--__params_it;
-		g_value_unset (&__params_it->value);
-	}
-	g_free (__params);
 	return self;
 }
 
 
+ValaReferenceTransferExpression* vala_reference_transfer_expression_new (ValaExpression* inner, ValaSourceReference* source_reference) {
+	return vala_reference_transfer_expression_construct (VALA_TYPE_REFERENCE_TRANSFER_EXPRESSION, inner, source_reference);
+}
+
+
 static void vala_reference_transfer_expression_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaReferenceTransferExpression * self;
 	self = VALA_REFERENCE_TRANSFER_EXPRESSION (base);
@@ -121,51 +113,19 @@ void vala_reference_transfer_expression_set_inner (ValaReferenceTransferExpressi
 	g_return_if_fail (VALA_IS_REFERENCE_TRANSFER_EXPRESSION (self));
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_inner = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_inner == NULL ? NULL : (self->priv->_inner = (g_object_unref (self->priv->_inner), NULL))), _tmp2);
+	self->priv->_inner = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1))), (self->priv->_inner == NULL ? NULL : (self->priv->_inner = (vala_code_node_unref (self->priv->_inner), NULL))), _tmp2);
 	vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_inner), VALA_CODE_NODE (self));
-	g_object_notify (((GObject *) (self)), "inner");
-}
-
-
-static void vala_reference_transfer_expression_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
-	ValaReferenceTransferExpression * self;
-	self = VALA_REFERENCE_TRANSFER_EXPRESSION (object);
-	switch (property_id) {
-		case VALA_REFERENCE_TRANSFER_EXPRESSION_INNER:
-		g_value_set_object (value, vala_reference_transfer_expression_get_inner (self));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
-static void vala_reference_transfer_expression_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
-	ValaReferenceTransferExpression * self;
-	self = VALA_REFERENCE_TRANSFER_EXPRESSION (object);
-	switch (property_id) {
-		case VALA_REFERENCE_TRANSFER_EXPRESSION_INNER:
-		vala_reference_transfer_expression_set_inner (self, g_value_get_object (value));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
 }
 
 
 static void vala_reference_transfer_expression_class_init (ValaReferenceTransferExpressionClass * klass) {
 	vala_reference_transfer_expression_parent_class = g_type_class_peek_parent (klass);
+	VALA_CODE_NODE_CLASS (klass)->finalize = vala_reference_transfer_expression_finalize;
 	g_type_class_add_private (klass, sizeof (ValaReferenceTransferExpressionPrivate));
-	G_OBJECT_CLASS (klass)->get_property = vala_reference_transfer_expression_get_property;
-	G_OBJECT_CLASS (klass)->set_property = vala_reference_transfer_expression_set_property;
-	G_OBJECT_CLASS (klass)->finalize = vala_reference_transfer_expression_finalize;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_reference_transfer_expression_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_reference_transfer_expression_real_accept_children;
 	VALA_CODE_NODE_CLASS (klass)->replace_expression = vala_reference_transfer_expression_real_replace_expression;
 	VALA_EXPRESSION_CLASS (klass)->is_pure = vala_reference_transfer_expression_real_is_pure;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_REFERENCE_TRANSFER_EXPRESSION_INNER, g_param_spec_object ("inner", "inner", "inner", VALA_TYPE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
 }
 
 
@@ -174,18 +134,18 @@ static void vala_reference_transfer_expression_instance_init (ValaReferenceTrans
 }
 
 
-static void vala_reference_transfer_expression_finalize (GObject * obj) {
+static void vala_reference_transfer_expression_finalize (ValaCodeNode* obj) {
 	ValaReferenceTransferExpression * self;
 	self = VALA_REFERENCE_TRANSFER_EXPRESSION (obj);
-	(self->priv->_inner == NULL ? NULL : (self->priv->_inner = (g_object_unref (self->priv->_inner), NULL)));
-	G_OBJECT_CLASS (vala_reference_transfer_expression_parent_class)->finalize (obj);
+	(self->priv->_inner == NULL ? NULL : (self->priv->_inner = (vala_code_node_unref (self->priv->_inner), NULL)));
+	VALA_CODE_NODE_CLASS (vala_reference_transfer_expression_parent_class)->finalize (obj);
 }
 
 
 GType vala_reference_transfer_expression_get_type (void) {
 	static GType vala_reference_transfer_expression_type_id = 0;
 	if (vala_reference_transfer_expression_type_id == 0) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaReferenceTransferExpressionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_reference_transfer_expression_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaReferenceTransferExpression), 0, (GInstanceInitFunc) vala_reference_transfer_expression_instance_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaReferenceTransferExpressionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_reference_transfer_expression_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaReferenceTransferExpression), 0, (GInstanceInitFunc) vala_reference_transfer_expression_instance_init, NULL };
 		vala_reference_transfer_expression_type_id = g_type_register_static (VALA_TYPE_EXPRESSION, "ValaReferenceTransferExpression", &g_define_type_info, 0);
 	}
 	return vala_reference_transfer_expression_type_id;
