@@ -68,13 +68,14 @@ struct _ValaStructPrivate {
 	char* default_value;
 	gboolean simple_type;
 	char* type_signature;
+	char* copy_function;
+	char* destroy_function;
 	ValaMethod* _default_construction_method;
 };
 
 #define VALA_STRUCT_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_STRUCT, ValaStructPrivate))
 enum  {
-	VALA_STRUCT_DUMMY_PROPERTY,
-	VALA_STRUCT_DEFAULT_CONSTRUCTION_METHOD
+	VALA_STRUCT_DUMMY_PROPERTY
 };
 static void vala_struct_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_struct_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
@@ -101,8 +102,10 @@ static void vala_struct_set_default_value (ValaStruct* self, const char* value);
 static gint vala_struct_real_get_type_parameter_index (ValaTypeSymbol* base, const char* name);
 static void vala_struct_real_replace_type (ValaCodeNode* base, ValaDataType* old_type, ValaDataType* new_type);
 static gboolean vala_struct_real_is_subtype_of (ValaTypeSymbol* base, ValaTypeSymbol* t);
+static char* vala_struct_real_get_copy_function (ValaTypeSymbol* base);
+static char* vala_struct_real_get_destroy_function (ValaTypeSymbol* base);
 static gpointer vala_struct_parent_class = NULL;
-static void vala_struct_finalize (GObject * obj);
+static void vala_struct_finalize (ValaCodeNode* obj);
 static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
 static int _vala_strcmp0 (const char * str1, const char * str2);
 
@@ -115,17 +118,23 @@ static int _vala_strcmp0 (const char * str1, const char * str2);
  * @param source_reference reference to source code
  * @return                 newly created struct
  */
-ValaStruct* vala_struct_new (const char* name, ValaSourceReference* source_reference) {
-	ValaStruct * self;
+ValaStruct* vala_struct_construct (GType object_type, const char* name, ValaSourceReference* source_reference) {
+	ValaStruct* self;
 	g_return_val_if_fail (name != NULL, NULL);
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
-	self = g_object_newv (VALA_TYPE_STRUCT, 0, NULL);
+	self = ((ValaStruct*) (g_type_create_instance (object_type)));
+	vala_symbol_init (VALA_SYMBOL (VALA_TYPESYMBOL (self)));
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
 	vala_symbol_set_name (VALA_SYMBOL (self), name);
 	return self;
 }
 
 
+ValaStruct* vala_struct_new (const char* name, ValaSourceReference* source_reference) {
+	return vala_struct_construct (VALA_TYPE_STRUCT, name, source_reference);
+}
+
+
 /**
  * Appends the specified parameter to the list of type parameters.
  *
@@ -147,7 +156,7 @@ void vala_struct_add_type_parameter (ValaStruct* self, ValaTypeParameter* p) {
  */
 GeeList* vala_struct_get_type_parameters (ValaStruct* self) {
 	g_return_val_if_fail (VALA_IS_STRUCT (self), NULL);
-	return GEE_LIST (gee_read_only_list_new (VALA_TYPE_TYPEPARAMETER, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, self->priv->type_parameters));
+	return GEE_LIST (gee_read_only_list_new (VALA_TYPE_TYPEPARAMETER, ((GBoxedCopyFunc) (vala_code_node_ref)), vala_code_node_unref, self->priv->type_parameters));
 }
 
 
@@ -184,7 +193,18 @@ void vala_struct_add_field (ValaStruct* self, ValaField* f) {
  */
 GeeList* vala_struct_get_fields (ValaStruct* self) {
 	g_return_val_if_fail (VALA_IS_STRUCT (self), NULL);
-	return GEE_LIST (gee_read_only_list_new (VALA_TYPE_FIELD, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, self->priv->fields));
+	return GEE_LIST (gee_read_only_list_new (VALA_TYPE_FIELD, ((GBoxedCopyFunc) (vala_code_node_ref)), vala_code_node_unref, self->priv->fields));
+}
+
+
+/**
+ * Returns a copy of the list of constants.
+ *
+ * @return list of constants
+ */
+GeeList* vala_struct_get_constants (ValaStruct* self) {
+	g_return_val_if_fail (VALA_IS_STRUCT (self), NULL);
+	return GEE_LIST (gee_read_only_list_new (VALA_TYPE_CONSTANT, ((GBoxedCopyFunc) (vala_code_node_ref)), vala_code_node_unref, self->priv->constants));
 }
 
 
@@ -205,49 +225,44 @@ void vala_struct_add_method (ValaStruct* self, ValaMethod* m) {
 		_tmp1 = NULL;
 		_tmp0 = NULL;
 		vala_method_set_this_parameter (m, (_tmp1 = vala_formal_parameter_new ("this", VALA_DATA_TYPE ((_tmp0 = vala_value_type_new (VALA_TYPESYMBOL (self)))), NULL)));
-		(_tmp1 == NULL ? NULL : (_tmp1 = (g_object_unref (_tmp1), NULL)));
-		(_tmp0 == NULL ? NULL : (_tmp0 = (g_object_unref (_tmp0), NULL)));
+		(_tmp1 == NULL ? NULL : (_tmp1 = (vala_code_node_unref (_tmp1), NULL)));
+		(_tmp0 == NULL ? NULL : (_tmp0 = (vala_code_node_unref (_tmp0), NULL)));
 		vala_scope_add (vala_symbol_get_scope (VALA_SYMBOL (m)), vala_symbol_get_name (VALA_SYMBOL (vala_method_get_this_parameter (m))), VALA_SYMBOL (vala_method_get_this_parameter (m)));
 	}
 	_tmp2 = NULL;
-	if ((_tmp3 = !(VALA_IS_VOID_TYPE (vala_method_get_return_type (m))) && gee_collection_get_size (GEE_COLLECTION ((_tmp2 = vala_method_get_postconditions (m)))) > 0, (_tmp2 == NULL ? NULL : (_tmp2 = (g_object_unref (_tmp2), NULL))), _tmp3)) {
+	if ((_tmp3 = !(VALA_IS_VOID_TYPE (vala_method_get_return_type (m))) && gee_collection_get_size (GEE_COLLECTION ((_tmp2 = vala_method_get_postconditions (m)))) > 0, (_tmp2 == NULL ? NULL : (_tmp2 = (gee_collection_object_unref (_tmp2), NULL))), _tmp3)) {
 		ValaLocalVariable* _tmp5;
 		ValaDataType* _tmp4;
 		_tmp5 = NULL;
 		_tmp4 = NULL;
 		vala_method_set_result_var (m, (_tmp5 = vala_local_variable_new ((_tmp4 = vala_data_type_copy (vala_method_get_return_type (m))), "result", NULL, NULL)));
-		(_tmp5 == NULL ? NULL : (_tmp5 = (g_object_unref (_tmp5), NULL)));
-		(_tmp4 == NULL ? NULL : (_tmp4 = (g_object_unref (_tmp4), NULL)));
+		(_tmp5 == NULL ? NULL : (_tmp5 = (vala_code_node_unref (_tmp5), NULL)));
+		(_tmp4 == NULL ? NULL : (_tmp4 = (vala_code_node_unref (_tmp4), NULL)));
 		vala_scope_add (vala_symbol_get_scope (VALA_SYMBOL (m)), vala_symbol_get_name (VALA_SYMBOL (vala_method_get_result_var (m))), VALA_SYMBOL (vala_method_get_result_var (m)));
 	}
 	if (VALA_IS_CREATION_METHOD (m)) {
-		ValaCreationMethod* _tmp7;
+		ValaCreationMethod* _tmp6;
 		ValaCreationMethod* cm;
 		if (vala_symbol_get_name (VALA_SYMBOL (m)) == NULL) {
 			vala_struct_set_default_construction_method (self, m);
-			vala_symbol_set_name (VALA_SYMBOL (m), ".new");
-		} else {
-			char* _tmp6;
-			_tmp6 = NULL;
-			vala_symbol_set_name (VALA_SYMBOL (m), (_tmp6 = g_strconcat (".new.", vala_symbol_get_name (VALA_SYMBOL (m)), NULL)));
-			_tmp6 = (g_free (_tmp6), NULL);
+			vala_symbol_set_name (VALA_SYMBOL (m), "new");
 		}
-		_tmp7 = NULL;
-		cm = (_tmp7 = VALA_CREATION_METHOD (m), (_tmp7 == NULL ? NULL : g_object_ref (_tmp7)));
+		_tmp6 = NULL;
+		cm = (_tmp6 = VALA_CREATION_METHOD (m), (_tmp6 == NULL ? NULL : vala_code_node_ref (_tmp6)));
 		if (vala_creation_method_get_type_name (cm) != NULL && _vala_strcmp0 (vala_creation_method_get_type_name (cm), vala_symbol_get_name (VALA_SYMBOL (self))) != 0) {
-			char* _tmp9;
 			char* _tmp8;
+			char* _tmp7;
 			/* type_name is null for constructors generated by GIdlParser*/
-			_tmp9 = NULL;
 			_tmp8 = NULL;
-			vala_report_error (vala_code_node_get_source_reference (VALA_CODE_NODE (m)), (_tmp9 = g_strdup_printf ("missing return type in method `%s.%s´", (_tmp8 = vala_symbol_get_full_name (VALA_SYMBOL (self))), vala_creation_method_get_type_name (cm))));
-			_tmp9 = (g_free (_tmp9), NULL);
+			_tmp7 = NULL;
+			vala_report_error (vala_code_node_get_source_reference (VALA_CODE_NODE (m)), (_tmp8 = g_strdup_printf ("missing return type in method `%s.%s´", (_tmp7 = vala_symbol_get_full_name (VALA_SYMBOL (self))), vala_creation_method_get_type_name (cm))));
 			_tmp8 = (g_free (_tmp8), NULL);
+			_tmp7 = (g_free (_tmp7), NULL);
 			vala_code_node_set_error (VALA_CODE_NODE (m), TRUE);
-			(cm == NULL ? NULL : (cm = (g_object_unref (cm), NULL)));
+			(cm == NULL ? NULL : (cm = (vala_code_node_unref (cm), NULL)));
 			return;
 		}
-		(cm == NULL ? NULL : (cm = (g_object_unref (cm), NULL)));
+		(cm == NULL ? NULL : (cm = (vala_code_node_unref (cm), NULL)));
 	}
 	gee_collection_add (GEE_COLLECTION (self->priv->methods), m);
 	vala_scope_add (vala_symbol_get_scope (VALA_SYMBOL (self)), vala_symbol_get_name (VALA_SYMBOL (m)), VALA_SYMBOL (m));
@@ -261,7 +276,7 @@ void vala_struct_add_method (ValaStruct* self, ValaMethod* m) {
  */
 GeeList* vala_struct_get_methods (ValaStruct* self) {
 	g_return_val_if_fail (VALA_IS_STRUCT (self), NULL);
-	return GEE_LIST (gee_read_only_list_new (VALA_TYPE_METHOD, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, self->priv->methods));
+	return GEE_LIST (gee_read_only_list_new (VALA_TYPE_METHOD, ((GBoxedCopyFunc) (vala_code_node_ref)), vala_code_node_unref, self->priv->methods));
 }
 
 
@@ -286,7 +301,7 @@ static void vala_struct_real_accept_children (ValaCodeNode* base, ValaCodeVisito
 			type = ((ValaDataType*) (gee_list_get (GEE_LIST (type_collection), type_it)));
 			{
 				vala_code_node_accept (VALA_CODE_NODE (type), visitor);
-				(type == NULL ? NULL : (type = (g_object_unref (type), NULL)));
+				(type == NULL ? NULL : (type = (vala_code_node_unref (type), NULL)));
 			}
 		}
 	}
@@ -299,7 +314,7 @@ static void vala_struct_real_accept_children (ValaCodeNode* base, ValaCodeVisito
 			p = ((ValaTypeParameter*) (gee_list_get (GEE_LIST (p_collection), p_it)));
 			{
 				vala_code_node_accept (VALA_CODE_NODE (p), visitor);
-				(p == NULL ? NULL : (p = (g_object_unref (p), NULL)));
+				(p == NULL ? NULL : (p = (vala_code_node_unref (p), NULL)));
 			}
 		}
 	}
@@ -312,7 +327,7 @@ static void vala_struct_real_accept_children (ValaCodeNode* base, ValaCodeVisito
 			f = ((ValaField*) (gee_list_get (GEE_LIST (f_collection), f_it)));
 			{
 				vala_code_node_accept (VALA_CODE_NODE (f), visitor);
-				(f == NULL ? NULL : (f = (g_object_unref (f), NULL)));
+				(f == NULL ? NULL : (f = (vala_code_node_unref (f), NULL)));
 			}
 		}
 	}
@@ -325,7 +340,7 @@ static void vala_struct_real_accept_children (ValaCodeNode* base, ValaCodeVisito
 			c = ((ValaConstant*) (gee_list_get (GEE_LIST (c_collection), c_it)));
 			{
 				vala_code_node_accept (VALA_CODE_NODE (c), visitor);
-				(c == NULL ? NULL : (c = (g_object_unref (c), NULL)));
+				(c == NULL ? NULL : (c = (vala_code_node_unref (c), NULL)));
 			}
 		}
 	}
@@ -338,7 +353,7 @@ static void vala_struct_real_accept_children (ValaCodeNode* base, ValaCodeVisito
 			m = ((ValaMethod*) (gee_list_get (GEE_LIST (m_collection), m_it)));
 			{
 				vala_code_node_accept (VALA_CODE_NODE (m), visitor);
-				(m == NULL ? NULL : (m = (g_object_unref (m), NULL)));
+				(m == NULL ? NULL : (m = (vala_code_node_unref (m), NULL)));
 			}
 		}
 	}
@@ -482,7 +497,7 @@ static char* vala_struct_real_get_type_signature (ValaTypeSymbol* base) {
 						g_string_append (str, (_tmp0 = vala_data_type_get_type_signature (vala_field_get_field_type (f))));
 						_tmp0 = (g_free (_tmp0), NULL);
 					}
-					(f == NULL ? NULL : (f = (g_object_unref (f), NULL)));
+					(f == NULL ? NULL : (f = (vala_code_node_unref (f), NULL)));
 				}
 			}
 		}
@@ -516,13 +531,13 @@ gboolean vala_struct_is_integer_type (ValaStruct* self) {
 				ValaStruct* st;
 				_tmp1 = NULL;
 				_tmp0 = NULL;
-				st = (_tmp1 = (_tmp0 = vala_data_type_get_data_type (type), (VALA_IS_STRUCT (_tmp0) ? ((ValaStruct*) (_tmp0)) : NULL)), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
+				st = (_tmp1 = (_tmp0 = vala_data_type_get_data_type (type), (VALA_IS_STRUCT (_tmp0) ? ((ValaStruct*) (_tmp0)) : NULL)), (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1)));
 				if (st != NULL && vala_struct_is_integer_type (st)) {
 					gboolean _tmp2;
-					return (_tmp2 = TRUE, (type == NULL ? NULL : (type = (g_object_unref (type), NULL))), (st == NULL ? NULL : (st = (g_object_unref (st), NULL))), _tmp2);
+					return (_tmp2 = TRUE, (type == NULL ? NULL : (type = (vala_code_node_unref (type), NULL))), (st == NULL ? NULL : (st = (vala_code_node_unref (st), NULL))), _tmp2);
 				}
-				(type == NULL ? NULL : (type = (g_object_unref (type), NULL)));
-				(st == NULL ? NULL : (st = (g_object_unref (st), NULL)));
+				(type == NULL ? NULL : (type = (vala_code_node_unref (type), NULL)));
+				(st == NULL ? NULL : (st = (vala_code_node_unref (st), NULL)));
 			}
 		}
 	}
@@ -550,13 +565,13 @@ gboolean vala_struct_is_floating_type (ValaStruct* self) {
 				ValaStruct* st;
 				_tmp1 = NULL;
 				_tmp0 = NULL;
-				st = (_tmp1 = (_tmp0 = vala_data_type_get_data_type (type), (VALA_IS_STRUCT (_tmp0) ? ((ValaStruct*) (_tmp0)) : NULL)), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
+				st = (_tmp1 = (_tmp0 = vala_data_type_get_data_type (type), (VALA_IS_STRUCT (_tmp0) ? ((ValaStruct*) (_tmp0)) : NULL)), (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1)));
 				if (st != NULL && vala_struct_is_floating_type (st)) {
 					gboolean _tmp2;
-					return (_tmp2 = TRUE, (type == NULL ? NULL : (type = (g_object_unref (type), NULL))), (st == NULL ? NULL : (st = (g_object_unref (st), NULL))), _tmp2);
+					return (_tmp2 = TRUE, (type == NULL ? NULL : (type = (vala_code_node_unref (type), NULL))), (st == NULL ? NULL : (st = (vala_code_node_unref (st), NULL))), _tmp2);
 				}
-				(type == NULL ? NULL : (type = (g_object_unref (type), NULL)));
-				(st == NULL ? NULL : (st = (g_object_unref (st), NULL)));
+				(type == NULL ? NULL : (type = (vala_code_node_unref (type), NULL)));
+				(st == NULL ? NULL : (st = (vala_code_node_unref (st), NULL)));
 			}
 		}
 	}
@@ -653,6 +668,18 @@ static void vala_struct_process_ccode_attribute (ValaStruct* self, ValaAttribute
 		_tmp9 = NULL;
 		self->priv->type_signature = (_tmp9 = vala_attribute_get_string (a, "type_signature"), (self->priv->type_signature = (g_free (self->priv->type_signature), NULL)), _tmp9);
 	}
+	if (vala_attribute_has_argument (a, "copy_function")) {
+		char* _tmp10;
+		_tmp10 = NULL;
+		vala_struct_set_copy_function (self, (_tmp10 = vala_attribute_get_string (a, "copy_function")));
+		_tmp10 = (g_free (_tmp10), NULL);
+	}
+	if (vala_attribute_has_argument (a, "destroy_function")) {
+		char* _tmp11;
+		_tmp11 = NULL;
+		vala_struct_set_destroy_function (self, (_tmp11 = vala_attribute_get_string (a, "destroy_function")));
+		_tmp11 = (g_free (_tmp11), NULL);
+	}
 }
 
 
@@ -689,7 +716,7 @@ void vala_struct_process_attributes (ValaStruct* self) {
 			ValaAttribute* _tmp0;
 			ValaAttribute* a;
 			_tmp0 = NULL;
-			a = (_tmp0 = ((ValaAttribute*) (a_it->data)), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
+			a = (_tmp0 = ((ValaAttribute*) (a_it->data)), (_tmp0 == NULL ? NULL : vala_code_node_ref (_tmp0)));
 			{
 				if (_vala_strcmp0 (vala_attribute_get_name (a), "CCode") == 0) {
 					vala_struct_process_ccode_attribute (self, a);
@@ -706,7 +733,7 @@ void vala_struct_process_attributes (ValaStruct* self) {
 						}
 					}
 				}
-				(a == NULL ? NULL : (a = (g_object_unref (a), NULL)));
+				(a == NULL ? NULL : (a = (vala_code_node_unref (a), NULL)));
 			}
 		}
 	}
@@ -731,14 +758,14 @@ static char* vala_struct_real_get_type_id (ValaTypeSymbol* base) {
 					ValaStruct* st;
 					_tmp1 = NULL;
 					_tmp0 = NULL;
-					st = (_tmp1 = (_tmp0 = vala_data_type_get_data_type (type), (VALA_IS_STRUCT (_tmp0) ? ((ValaStruct*) (_tmp0)) : NULL)), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
+					st = (_tmp1 = (_tmp0 = vala_data_type_get_data_type (type), (VALA_IS_STRUCT (_tmp0) ? ((ValaStruct*) (_tmp0)) : NULL)), (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1)));
 					if (st != NULL) {
 						char* _tmp2;
 						_tmp2 = NULL;
-						return (_tmp2 = vala_typesymbol_get_type_id (VALA_TYPESYMBOL (st)), (type == NULL ? NULL : (type = (g_object_unref (type), NULL))), (st == NULL ? NULL : (st = (g_object_unref (st), NULL))), _tmp2);
+						return (_tmp2 = vala_typesymbol_get_type_id (VALA_TYPESYMBOL (st)), (type == NULL ? NULL : (type = (vala_code_node_unref (type), NULL))), (st == NULL ? NULL : (st = (vala_code_node_unref (st), NULL))), _tmp2);
 					}
-					(type == NULL ? NULL : (type = (g_object_unref (type), NULL)));
-					(st == NULL ? NULL : (st = (g_object_unref (st), NULL)));
+					(type == NULL ? NULL : (type = (vala_code_node_unref (type), NULL)));
+					(st == NULL ? NULL : (st = (vala_code_node_unref (st), NULL)));
 				}
 			}
 		}
@@ -787,14 +814,14 @@ static char* vala_struct_real_get_marshaller_type_name (ValaTypeSymbol* base) {
 					ValaStruct* st;
 					_tmp1 = NULL;
 					_tmp0 = NULL;
-					st = (_tmp1 = (_tmp0 = vala_data_type_get_data_type (type), (VALA_IS_STRUCT (_tmp0) ? ((ValaStruct*) (_tmp0)) : NULL)), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
+					st = (_tmp1 = (_tmp0 = vala_data_type_get_data_type (type), (VALA_IS_STRUCT (_tmp0) ? ((ValaStruct*) (_tmp0)) : NULL)), (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1)));
 					if (st != NULL) {
 						char* _tmp2;
 						_tmp2 = NULL;
-						return (_tmp2 = vala_typesymbol_get_marshaller_type_name (VALA_TYPESYMBOL (st)), (type == NULL ? NULL : (type = (g_object_unref (type), NULL))), (st == NULL ? NULL : (st = (g_object_unref (st), NULL))), _tmp2);
+						return (_tmp2 = vala_typesymbol_get_marshaller_type_name (VALA_TYPESYMBOL (st)), (type == NULL ? NULL : (type = (vala_code_node_unref (type), NULL))), (st == NULL ? NULL : (st = (vala_code_node_unref (st), NULL))), _tmp2);
 					}
-					(type == NULL ? NULL : (type = (g_object_unref (type), NULL)));
-					(st == NULL ? NULL : (st = (g_object_unref (st), NULL)));
+					(type == NULL ? NULL : (type = (vala_code_node_unref (type), NULL)));
+					(st == NULL ? NULL : (st = (vala_code_node_unref (st), NULL)));
 				}
 			}
 		}
@@ -842,14 +869,14 @@ static char* vala_struct_real_get_get_value_function (ValaTypeSymbol* base) {
 					ValaStruct* st;
 					_tmp1 = NULL;
 					_tmp0 = NULL;
-					st = (_tmp1 = (_tmp0 = vala_data_type_get_data_type (type), (VALA_IS_STRUCT (_tmp0) ? ((ValaStruct*) (_tmp0)) : NULL)), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
+					st = (_tmp1 = (_tmp0 = vala_data_type_get_data_type (type), (VALA_IS_STRUCT (_tmp0) ? ((ValaStruct*) (_tmp0)) : NULL)), (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1)));
 					if (st != NULL) {
 						char* _tmp2;
 						_tmp2 = NULL;
-						return (_tmp2 = vala_typesymbol_get_get_value_function (VALA_TYPESYMBOL (st)), (type == NULL ? NULL : (type = (g_object_unref (type), NULL))), (st == NULL ? NULL : (st = (g_object_unref (st), NULL))), _tmp2);
+						return (_tmp2 = vala_typesymbol_get_get_value_function (VALA_TYPESYMBOL (st)), (type == NULL ? NULL : (type = (vala_code_node_unref (type), NULL))), (st == NULL ? NULL : (st = (vala_code_node_unref (st), NULL))), _tmp2);
 					}
-					(type == NULL ? NULL : (type = (g_object_unref (type), NULL)));
-					(st == NULL ? NULL : (st = (g_object_unref (st), NULL)));
+					(type == NULL ? NULL : (type = (vala_code_node_unref (type), NULL)));
+					(st == NULL ? NULL : (st = (vala_code_node_unref (st), NULL)));
 				}
 			}
 		}
@@ -890,14 +917,14 @@ static char* vala_struct_real_get_set_value_function (ValaTypeSymbol* base) {
 					ValaStruct* st;
 					_tmp1 = NULL;
 					_tmp0 = NULL;
-					st = (_tmp1 = (_tmp0 = vala_data_type_get_data_type (type), (VALA_IS_STRUCT (_tmp0) ? ((ValaStruct*) (_tmp0)) : NULL)), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
+					st = (_tmp1 = (_tmp0 = vala_data_type_get_data_type (type), (VALA_IS_STRUCT (_tmp0) ? ((ValaStruct*) (_tmp0)) : NULL)), (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1)));
 					if (st != NULL) {
 						char* _tmp2;
 						_tmp2 = NULL;
-						return (_tmp2 = vala_typesymbol_get_set_value_function (VALA_TYPESYMBOL (st)), (type == NULL ? NULL : (type = (g_object_unref (type), NULL))), (st == NULL ? NULL : (st = (g_object_unref (st), NULL))), _tmp2);
+						return (_tmp2 = vala_typesymbol_get_set_value_function (VALA_TYPESYMBOL (st)), (type == NULL ? NULL : (type = (vala_code_node_unref (type), NULL))), (st == NULL ? NULL : (st = (vala_code_node_unref (st), NULL))), _tmp2);
 					}
-					(type == NULL ? NULL : (type = (g_object_unref (type), NULL)));
-					(st == NULL ? NULL : (st = (g_object_unref (st), NULL)));
+					(type == NULL ? NULL : (type = (vala_code_node_unref (type), NULL)));
+					(st == NULL ? NULL : (st = (vala_code_node_unref (st), NULL)));
 				}
 			}
 		}
@@ -963,14 +990,14 @@ static char* vala_struct_real_get_default_value (ValaTypeSymbol* base) {
 				ValaStruct* st;
 				_tmp3 = NULL;
 				_tmp2 = NULL;
-				st = (_tmp3 = (_tmp2 = vala_data_type_get_data_type (type), (VALA_IS_STRUCT (_tmp2) ? ((ValaStruct*) (_tmp2)) : NULL)), (_tmp3 == NULL ? NULL : g_object_ref (_tmp3)));
+				st = (_tmp3 = (_tmp2 = vala_data_type_get_data_type (type), (VALA_IS_STRUCT (_tmp2) ? ((ValaStruct*) (_tmp2)) : NULL)), (_tmp3 == NULL ? NULL : vala_code_node_ref (_tmp3)));
 				if (st != NULL) {
 					char* _tmp4;
 					_tmp4 = NULL;
-					return (_tmp4 = vala_typesymbol_get_default_value (VALA_TYPESYMBOL (st)), (type == NULL ? NULL : (type = (g_object_unref (type), NULL))), (st == NULL ? NULL : (st = (g_object_unref (st), NULL))), _tmp4);
+					return (_tmp4 = vala_typesymbol_get_default_value (VALA_TYPESYMBOL (st)), (type == NULL ? NULL : (type = (vala_code_node_unref (type), NULL))), (st == NULL ? NULL : (st = (vala_code_node_unref (st), NULL))), _tmp4);
 				}
-				(type == NULL ? NULL : (type = (g_object_unref (type), NULL)));
-				(st == NULL ? NULL : (st = (g_object_unref (st), NULL)));
+				(type == NULL ? NULL : (type = (vala_code_node_unref (type), NULL)));
+				(st == NULL ? NULL : (st = (vala_code_node_unref (st), NULL)));
 			}
 		}
 	}
@@ -1008,7 +1035,7 @@ void vala_struct_add_base_type (ValaStruct* self, ValaDataType* type) {
  */
 GeeList* vala_struct_get_base_types (ValaStruct* self) {
 	g_return_val_if_fail (VALA_IS_STRUCT (self), NULL);
-	return GEE_LIST (gee_read_only_list_new (VALA_TYPE_DATA_TYPE, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, self->priv->base_types));
+	return GEE_LIST (gee_read_only_list_new (VALA_TYPE_DATA_TYPE, ((GBoxedCopyFunc) (vala_code_node_ref)), vala_code_node_unref, self->priv->base_types));
 }
 
 
@@ -1028,10 +1055,10 @@ static gint vala_struct_real_get_type_parameter_index (ValaTypeSymbol* base, con
 			{
 				if (_vala_strcmp0 (vala_symbol_get_name (VALA_SYMBOL (p)), name) == 0) {
 					gint _tmp0;
-					return (_tmp0 = (i), (p == NULL ? NULL : (p = (g_object_unref (p), NULL))), _tmp0);
+					return (_tmp0 = (i), (p == NULL ? NULL : (p = (vala_code_node_unref (p), NULL))), _tmp0);
 				}
 				i++;
-				(p == NULL ? NULL : (p = (g_object_unref (p), NULL)));
+				(p == NULL ? NULL : (p = (vala_code_node_unref (p), NULL)));
 			}
 		}
 	}
@@ -1058,13 +1085,13 @@ gboolean vala_struct_is_simple_type (ValaStruct* self) {
 				ValaStruct* st;
 				_tmp1 = NULL;
 				_tmp0 = NULL;
-				st = (_tmp1 = (_tmp0 = vala_data_type_get_data_type (type), (VALA_IS_STRUCT (_tmp0) ? ((ValaStruct*) (_tmp0)) : NULL)), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
+				st = (_tmp1 = (_tmp0 = vala_data_type_get_data_type (type), (VALA_IS_STRUCT (_tmp0) ? ((ValaStruct*) (_tmp0)) : NULL)), (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1)));
 				if (st != NULL && vala_struct_is_simple_type (st)) {
 					gboolean _tmp2;
-					return (_tmp2 = TRUE, (type == NULL ? NULL : (type = (g_object_unref (type), NULL))), (st == NULL ? NULL : (st = (g_object_unref (st), NULL))), _tmp2);
+					return (_tmp2 = TRUE, (type == NULL ? NULL : (type = (vala_code_node_unref (type), NULL))), (st == NULL ? NULL : (st = (vala_code_node_unref (st), NULL))), _tmp2);
 				}
-				(type == NULL ? NULL : (type = (g_object_unref (type), NULL)));
-				(st == NULL ? NULL : (st = (g_object_unref (st), NULL)));
+				(type == NULL ? NULL : (type = (vala_code_node_unref (type), NULL)));
+				(st == NULL ? NULL : (st = (vala_code_node_unref (st), NULL)));
 			}
 		}
 	}
@@ -1094,7 +1121,7 @@ static void vala_struct_real_replace_type (ValaCodeNode* base, ValaDataType* old
 			ValaDataType* _tmp0;
 			gboolean _tmp1;
 			_tmp0 = NULL;
-			if ((_tmp1 = (_tmp0 = ((ValaDataType*) (gee_list_get (((GeeList*) (self->priv->base_types)), i)))) == old_type, (_tmp0 == NULL ? NULL : (_tmp0 = (g_object_unref (_tmp0), NULL))), _tmp1)) {
+			if ((_tmp1 = (_tmp0 = ((ValaDataType*) (gee_list_get (((GeeList*) (self->priv->base_types)), i)))) == old_type, (_tmp0 == NULL ? NULL : (_tmp0 = (vala_code_node_unref (_tmp0), NULL))), _tmp1)) {
 				gee_list_set (((GeeList*) (self->priv->base_types)), i, new_type);
 				return;
 			}
@@ -1120,9 +1147,104 @@ static gboolean vala_struct_real_is_subtype_of (ValaTypeSymbol* base, ValaTypeSy
 			{
 				if (vala_data_type_get_data_type (base_type) != NULL && vala_typesymbol_is_subtype_of (vala_data_type_get_data_type (base_type), t)) {
 					gboolean _tmp1;
-					return (_tmp1 = TRUE, (base_type == NULL ? NULL : (base_type = (g_object_unref (base_type), NULL))), _tmp1);
+					return (_tmp1 = TRUE, (base_type == NULL ? NULL : (base_type = (vala_code_node_unref (base_type), NULL))), _tmp1);
 				}
-				(base_type == NULL ? NULL : (base_type = (g_object_unref (base_type), NULL)));
+				(base_type == NULL ? NULL : (base_type = (vala_code_node_unref (base_type), NULL)));
+			}
+		}
+	}
+	return FALSE;
+}
+
+
+char* vala_struct_get_default_copy_function (ValaStruct* self) {
+	char* _tmp0;
+	char* _tmp1;
+	g_return_val_if_fail (VALA_IS_STRUCT (self), NULL);
+	_tmp0 = NULL;
+	_tmp1 = NULL;
+	return (_tmp1 = g_strconcat ((_tmp0 = vala_symbol_get_lower_case_cprefix (VALA_SYMBOL (self))), "copy", NULL), (_tmp0 = (g_free (_tmp0), NULL)), _tmp1);
+}
+
+
+static char* vala_struct_real_get_copy_function (ValaTypeSymbol* base) {
+	ValaStruct * self;
+	const char* _tmp1;
+	self = VALA_STRUCT (base);
+	if (self->priv->copy_function == NULL) {
+		char* _tmp0;
+		_tmp0 = NULL;
+		self->priv->copy_function = (_tmp0 = vala_struct_get_default_copy_function (self), (self->priv->copy_function = (g_free (self->priv->copy_function), NULL)), _tmp0);
+	}
+	_tmp1 = NULL;
+	return (_tmp1 = self->priv->copy_function, (_tmp1 == NULL ? NULL : g_strdup (_tmp1)));
+}
+
+
+void vala_struct_set_copy_function (ValaStruct* self, const char* name) {
+	char* _tmp1;
+	const char* _tmp0;
+	g_return_if_fail (VALA_IS_STRUCT (self));
+	g_return_if_fail (name != NULL);
+	_tmp1 = NULL;
+	_tmp0 = NULL;
+	self->priv->copy_function = (_tmp1 = (_tmp0 = name, (_tmp0 == NULL ? NULL : g_strdup (_tmp0))), (self->priv->copy_function = (g_free (self->priv->copy_function), NULL)), _tmp1);
+}
+
+
+char* vala_struct_get_default_destroy_function (ValaStruct* self) {
+	char* _tmp0;
+	char* _tmp1;
+	g_return_val_if_fail (VALA_IS_STRUCT (self), NULL);
+	_tmp0 = NULL;
+	_tmp1 = NULL;
+	return (_tmp1 = g_strconcat ((_tmp0 = vala_symbol_get_lower_case_cprefix (VALA_SYMBOL (self))), "destroy", NULL), (_tmp0 = (g_free (_tmp0), NULL)), _tmp1);
+}
+
+
+static char* vala_struct_real_get_destroy_function (ValaTypeSymbol* base) {
+	ValaStruct * self;
+	const char* _tmp1;
+	self = VALA_STRUCT (base);
+	if (self->priv->destroy_function == NULL) {
+		char* _tmp0;
+		_tmp0 = NULL;
+		self->priv->destroy_function = (_tmp0 = vala_struct_get_default_destroy_function (self), (self->priv->destroy_function = (g_free (self->priv->destroy_function), NULL)), _tmp0);
+	}
+	_tmp1 = NULL;
+	return (_tmp1 = self->priv->destroy_function, (_tmp1 == NULL ? NULL : g_strdup (_tmp1)));
+}
+
+
+void vala_struct_set_destroy_function (ValaStruct* self, const char* name) {
+	char* _tmp1;
+	const char* _tmp0;
+	g_return_if_fail (VALA_IS_STRUCT (self));
+	g_return_if_fail (name != NULL);
+	_tmp1 = NULL;
+	_tmp0 = NULL;
+	self->priv->destroy_function = (_tmp1 = (_tmp0 = name, (_tmp0 == NULL ? NULL : g_strdup (_tmp0))), (self->priv->destroy_function = (g_free (self->priv->destroy_function), NULL)), _tmp1);
+}
+
+
+gboolean vala_struct_is_disposable (ValaStruct* self) {
+	g_return_val_if_fail (VALA_IS_STRUCT (self), FALSE);
+	if (self->priv->destroy_function != NULL) {
+		return TRUE;
+	}
+	{
+		GeeList* f_collection;
+		int f_it;
+		f_collection = self->priv->fields;
+		for (f_it = 0; f_it < gee_collection_get_size (GEE_COLLECTION (f_collection)); f_it = f_it + 1) {
+			ValaField* f;
+			f = ((ValaField*) (gee_list_get (GEE_LIST (f_collection), f_it)));
+			{
+				if (vala_field_get_binding (f) == MEMBER_BINDING_INSTANCE && vala_data_type_is_disposable (vala_field_get_field_type (f))) {
+					gboolean _tmp1;
+					return (_tmp1 = TRUE, (f == NULL ? NULL : (f = (vala_code_node_unref (f), NULL))), _tmp1);
+				}
+				(f == NULL ? NULL : (f = (vala_code_node_unref (f), NULL)));
 			}
 		}
 	}
@@ -1142,45 +1264,14 @@ void vala_struct_set_default_construction_method (ValaStruct* self, ValaMethod*
 	g_return_if_fail (VALA_IS_STRUCT (self));
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_default_construction_method = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_default_construction_method == NULL ? NULL : (self->priv->_default_construction_method = (g_object_unref (self->priv->_default_construction_method), NULL))), _tmp2);
-	g_object_notify (((GObject *) (self)), "default-construction-method");
-}
-
-
-static void vala_struct_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
-	ValaStruct * self;
-	self = VALA_STRUCT (object);
-	switch (property_id) {
-		case VALA_STRUCT_DEFAULT_CONSTRUCTION_METHOD:
-		g_value_set_object (value, vala_struct_get_default_construction_method (self));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
-static void vala_struct_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
-	ValaStruct * self;
-	self = VALA_STRUCT (object);
-	switch (property_id) {
-		case VALA_STRUCT_DEFAULT_CONSTRUCTION_METHOD:
-		vala_struct_set_default_construction_method (self, g_value_get_object (value));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
+	self->priv->_default_construction_method = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1))), (self->priv->_default_construction_method == NULL ? NULL : (self->priv->_default_construction_method = (vala_code_node_unref (self->priv->_default_construction_method), NULL))), _tmp2);
 }
 
 
 static void vala_struct_class_init (ValaStructClass * klass) {
 	vala_struct_parent_class = g_type_class_peek_parent (klass);
+	VALA_CODE_NODE_CLASS (klass)->finalize = vala_struct_finalize;
 	g_type_class_add_private (klass, sizeof (ValaStructPrivate));
-	G_OBJECT_CLASS (klass)->get_property = vala_struct_get_property;
-	G_OBJECT_CLASS (klass)->set_property = vala_struct_set_property;
-	G_OBJECT_CLASS (klass)->finalize = vala_struct_finalize;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_struct_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_struct_real_accept_children;
 	VALA_TYPESYMBOL_CLASS (klass)->get_cname = vala_struct_real_get_cname;
@@ -1196,29 +1287,30 @@ static void vala_struct_class_init (ValaStructClass * klass) {
 	VALA_TYPESYMBOL_CLASS (klass)->get_type_parameter_index = vala_struct_real_get_type_parameter_index;
 	VALA_CODE_NODE_CLASS (klass)->replace_type = vala_struct_real_replace_type;
 	VALA_TYPESYMBOL_CLASS (klass)->is_subtype_of = vala_struct_real_is_subtype_of;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_STRUCT_DEFAULT_CONSTRUCTION_METHOD, g_param_spec_object ("default-construction-method", "default-construction-method", "default-construction-method", VALA_TYPE_METHOD, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	VALA_TYPESYMBOL_CLASS (klass)->get_copy_function = vala_struct_real_get_copy_function;
+	VALA_TYPESYMBOL_CLASS (klass)->get_destroy_function = vala_struct_real_get_destroy_function;
 }
 
 
 static void vala_struct_instance_init (ValaStruct * self) {
 	self->priv = VALA_STRUCT_GET_PRIVATE (self);
-	self->priv->type_parameters = GEE_LIST (gee_array_list_new (VALA_TYPE_TYPEPARAMETER, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal));
-	self->priv->constants = GEE_LIST (gee_array_list_new (VALA_TYPE_CONSTANT, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal));
-	self->priv->fields = GEE_LIST (gee_array_list_new (VALA_TYPE_FIELD, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal));
-	self->priv->methods = GEE_LIST (gee_array_list_new (VALA_TYPE_METHOD, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal));
-	self->priv->base_types = GEE_LIST (gee_array_list_new (VALA_TYPE_DATA_TYPE, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal));
+	self->priv->type_parameters = GEE_LIST (gee_array_list_new (VALA_TYPE_TYPEPARAMETER, ((GBoxedCopyFunc) (vala_code_node_ref)), vala_code_node_unref, g_direct_equal));
+	self->priv->constants = GEE_LIST (gee_array_list_new (VALA_TYPE_CONSTANT, ((GBoxedCopyFunc) (vala_code_node_ref)), vala_code_node_unref, g_direct_equal));
+	self->priv->fields = GEE_LIST (gee_array_list_new (VALA_TYPE_FIELD, ((GBoxedCopyFunc) (vala_code_node_ref)), vala_code_node_unref, g_direct_equal));
+	self->priv->methods = GEE_LIST (gee_array_list_new (VALA_TYPE_METHOD, ((GBoxedCopyFunc) (vala_code_node_ref)), vala_code_node_unref, g_direct_equal));
+	self->priv->base_types = GEE_LIST (gee_array_list_new (VALA_TYPE_DATA_TYPE, ((GBoxedCopyFunc) (vala_code_node_ref)), vala_code_node_unref, g_direct_equal));
 	self->priv->default_value = NULL;
 }
 
 
-static void vala_struct_finalize (GObject * obj) {
+static void vala_struct_finalize (ValaCodeNode* obj) {
 	ValaStruct * self;
 	self = VALA_STRUCT (obj);
-	(self->priv->type_parameters == NULL ? NULL : (self->priv->type_parameters = (g_object_unref (self->priv->type_parameters), NULL)));
-	(self->priv->constants == NULL ? NULL : (self->priv->constants = (g_object_unref (self->priv->constants), NULL)));
-	(self->priv->fields == NULL ? NULL : (self->priv->fields = (g_object_unref (self->priv->fields), NULL)));
-	(self->priv->methods == NULL ? NULL : (self->priv->methods = (g_object_unref (self->priv->methods), NULL)));
-	(self->priv->base_types == NULL ? NULL : (self->priv->base_types = (g_object_unref (self->priv->base_types), NULL)));
+	(self->priv->type_parameters == NULL ? NULL : (self->priv->type_parameters = (gee_collection_object_unref (self->priv->type_parameters), NULL)));
+	(self->priv->constants == NULL ? NULL : (self->priv->constants = (gee_collection_object_unref (self->priv->constants), NULL)));
+	(self->priv->fields == NULL ? NULL : (self->priv->fields = (gee_collection_object_unref (self->priv->fields), NULL)));
+	(self->priv->methods == NULL ? NULL : (self->priv->methods = (gee_collection_object_unref (self->priv->methods), NULL)));
+	(self->priv->base_types == NULL ? NULL : (self->priv->base_types = (gee_collection_object_unref (self->priv->base_types), NULL)));
 	self->priv->cname = (g_free (self->priv->cname), NULL);
 	self->priv->const_cname = (g_free (self->priv->const_cname), NULL);
 	self->priv->dup_function = (g_free (self->priv->dup_function), NULL);
@@ -1231,15 +1323,17 @@ static void vala_struct_finalize (GObject * obj) {
 	self->priv->set_value_function = (g_free (self->priv->set_value_function), NULL);
 	self->priv->default_value = (g_free (self->priv->default_value), NULL);
 	self->priv->type_signature = (g_free (self->priv->type_signature), NULL);
-	(self->priv->_default_construction_method == NULL ? NULL : (self->priv->_default_construction_method = (g_object_unref (self->priv->_default_construction_method), NULL)));
-	G_OBJECT_CLASS (vala_struct_parent_class)->finalize (obj);
+	self->priv->copy_function = (g_free (self->priv->copy_function), NULL);
+	self->priv->destroy_function = (g_free (self->priv->destroy_function), NULL);
+	(self->priv->_default_construction_method == NULL ? NULL : (self->priv->_default_construction_method = (vala_code_node_unref (self->priv->_default_construction_method), NULL)));
+	VALA_CODE_NODE_CLASS (vala_struct_parent_class)->finalize (obj);
 }
 
 
 GType vala_struct_get_type (void) {
 	static GType vala_struct_type_id = 0;
 	if (vala_struct_type_id == 0) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaStructClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_struct_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaStruct), 0, (GInstanceInitFunc) vala_struct_instance_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaStructClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_struct_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaStruct), 0, (GInstanceInitFunc) vala_struct_instance_init, NULL };
 		vala_struct_type_id = g_type_register_static (VALA_TYPE_TYPESYMBOL, "ValaStruct", &g_define_type_info, 0);
 	}
 	return vala_struct_type_id;
