@@ -39,14 +39,13 @@ struct _ValaSwitchStatementPrivate {
 
 #define VALA_SWITCH_STATEMENT_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_SWITCH_STATEMENT, ValaSwitchStatementPrivate))
 enum  {
-	VALA_SWITCH_STATEMENT_DUMMY_PROPERTY,
-	VALA_SWITCH_STATEMENT_EXPRESSION
+	VALA_SWITCH_STATEMENT_DUMMY_PROPERTY
 };
 static void vala_switch_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_switch_statement_real_replace_expression (ValaCodeNode* base, ValaExpression* old_node, ValaExpression* new_node);
 static gpointer vala_switch_statement_parent_class = NULL;
 static ValaStatementIface* vala_switch_statement_vala_statement_parent_iface = NULL;
-static void vala_switch_statement_dispose (GObject * obj);
+static void vala_switch_statement_finalize (ValaCodeNode* obj);
 
 
 
@@ -57,29 +56,22 @@ static void vala_switch_statement_dispose (GObject * obj);
  * @param source_reference reference to source code
  * @return                 newly created switch statement
  */
-ValaSwitchStatement* vala_switch_statement_new (ValaExpression* expression, ValaSourceReference* source_reference) {
-	GParameter * __params;
-	GParameter * __params_it;
-	ValaSwitchStatement * self;
+ValaSwitchStatement* vala_switch_statement_construct (GType object_type, ValaExpression* expression, ValaSourceReference* source_reference) {
+	ValaSwitchStatement* self;
 	g_return_val_if_fail (VALA_IS_EXPRESSION (expression), NULL);
 	g_return_val_if_fail (VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
-	__params = g_new0 (GParameter, 1);
-	__params_it = __params;
-	__params_it->name = "expression";
-	g_value_init (&__params_it->value, VALA_TYPE_EXPRESSION);
-	g_value_set_object (&__params_it->value, expression);
-	__params_it++;
-	self = g_object_newv (VALA_TYPE_SWITCH_STATEMENT, __params_it - __params, __params);
+	self = ((ValaSwitchStatement*) (g_type_create_instance (object_type)));
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
-	while (__params_it > __params) {
-		--__params_it;
-		g_value_unset (&__params_it->value);
-	}
-	g_free (__params);
+	vala_switch_statement_set_expression (self, expression);
 	return self;
 }
 
 
+ValaSwitchStatement* vala_switch_statement_new (ValaExpression* expression, ValaSourceReference* source_reference) {
+	return vala_switch_statement_construct (VALA_TYPE_SWITCH_STATEMENT, expression, source_reference);
+}
+
+
 /**
  * Appends the specified section to the list of switch sections.
  *
@@ -100,7 +92,7 @@ void vala_switch_statement_add_section (ValaSwitchStatement* self, ValaSwitchSec
  */
 GeeList* vala_switch_statement_get_sections (ValaSwitchStatement* self) {
 	g_return_val_if_fail (VALA_IS_SWITCH_STATEMENT (self), NULL);
-	return GEE_LIST (gee_read_only_list_new (VALA_TYPE_SWITCH_SECTION, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, self->priv->sections));
+	return GEE_LIST (gee_read_only_list_new (VALA_TYPE_SWITCH_SECTION, ((GBoxedCopyFunc) (vala_code_node_ref)), vala_code_node_unref, self->priv->sections));
 }
 
 
@@ -119,7 +111,7 @@ static void vala_switch_statement_real_accept (ValaCodeNode* base, ValaCodeVisit
 			section = ((ValaSwitchSection*) (gee_list_get (GEE_LIST (section_collection), section_it)));
 			{
 				vala_code_node_accept (VALA_CODE_NODE (section), visitor);
-				(section == NULL ? NULL : (section = (g_object_unref (section), NULL)));
+				(section == NULL ? NULL : (section = (vala_code_node_unref (section), NULL)));
 			}
 		}
 	}
@@ -150,48 +142,17 @@ void vala_switch_statement_set_expression (ValaSwitchStatement* self, ValaExpres
 	g_return_if_fail (VALA_IS_SWITCH_STATEMENT (self));
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_expression = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_expression == NULL ? NULL : (self->priv->_expression = (g_object_unref (self->priv->_expression), NULL))), _tmp2);
+	self->priv->_expression = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1))), (self->priv->_expression == NULL ? NULL : (self->priv->_expression = (vala_code_node_unref (self->priv->_expression), NULL))), _tmp2);
 	vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_expression), VALA_CODE_NODE (self));
 }
 
 
-static void vala_switch_statement_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
-	ValaSwitchStatement * self;
-	self = VALA_SWITCH_STATEMENT (object);
-	switch (property_id) {
-		case VALA_SWITCH_STATEMENT_EXPRESSION:
-		g_value_set_object (value, vala_switch_statement_get_expression (self));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
-static void vala_switch_statement_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
-	ValaSwitchStatement * self;
-	self = VALA_SWITCH_STATEMENT (object);
-	switch (property_id) {
-		case VALA_SWITCH_STATEMENT_EXPRESSION:
-		vala_switch_statement_set_expression (self, g_value_get_object (value));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
 static void vala_switch_statement_class_init (ValaSwitchStatementClass * klass) {
 	vala_switch_statement_parent_class = g_type_class_peek_parent (klass);
+	VALA_CODE_NODE_CLASS (klass)->finalize = vala_switch_statement_finalize;
 	g_type_class_add_private (klass, sizeof (ValaSwitchStatementPrivate));
-	G_OBJECT_CLASS (klass)->get_property = vala_switch_statement_get_property;
-	G_OBJECT_CLASS (klass)->set_property = vala_switch_statement_set_property;
-	G_OBJECT_CLASS (klass)->dispose = vala_switch_statement_dispose;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_switch_statement_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->replace_expression = vala_switch_statement_real_replace_expression;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SWITCH_STATEMENT_EXPRESSION, g_param_spec_object ("expression", "expression", "expression", VALA_TYPE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
 }
 
 
@@ -202,23 +163,23 @@ static void vala_switch_statement_vala_statement_interface_init (ValaStatementIf
 
 static void vala_switch_statement_instance_init (ValaSwitchStatement * self) {
 	self->priv = VALA_SWITCH_STATEMENT_GET_PRIVATE (self);
-	self->priv->sections = GEE_LIST (gee_array_list_new (VALA_TYPE_SWITCH_SECTION, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal));
+	self->priv->sections = GEE_LIST (gee_array_list_new (VALA_TYPE_SWITCH_SECTION, ((GBoxedCopyFunc) (vala_code_node_ref)), vala_code_node_unref, g_direct_equal));
 }
 
 
-static void vala_switch_statement_dispose (GObject * obj) {
+static void vala_switch_statement_finalize (ValaCodeNode* obj) {
 	ValaSwitchStatement * self;
 	self = VALA_SWITCH_STATEMENT (obj);
-	(self->priv->_expression == NULL ? NULL : (self->priv->_expression = (g_object_unref (self->priv->_expression), NULL)));
-	(self->priv->sections == NULL ? NULL : (self->priv->sections = (g_object_unref (self->priv->sections), NULL)));
-	G_OBJECT_CLASS (vala_switch_statement_parent_class)->dispose (obj);
+	(self->priv->_expression == NULL ? NULL : (self->priv->_expression = (vala_code_node_unref (self->priv->_expression), NULL)));
+	(self->priv->sections == NULL ? NULL : (self->priv->sections = (gee_collection_object_unref (self->priv->sections), NULL)));
+	VALA_CODE_NODE_CLASS (vala_switch_statement_parent_class)->finalize (obj);
 }
 
 
 GType vala_switch_statement_get_type (void) {
 	static GType vala_switch_statement_type_id = 0;
-	if (G_UNLIKELY (vala_switch_statement_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaSwitchStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_switch_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaSwitchStatement), 0, (GInstanceInitFunc) vala_switch_statement_instance_init };
+	if (vala_switch_statement_type_id == 0) {
+		static const GTypeInfo g_define_type_info = { sizeof (ValaSwitchStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_switch_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaSwitchStatement), 0, (GInstanceInitFunc) vala_switch_statement_instance_init, NULL };
 		static const GInterfaceInfo vala_statement_info = { (GInterfaceInitFunc) vala_switch_statement_vala_statement_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
 		vala_switch_statement_type_id = g_type_register_static (VALA_TYPE_CODE_NODE, "ValaSwitchStatement", &g_define_type_info, 0);
 		g_type_add_interface_static (vala_switch_statement_type_id, VALA_TYPE_STATEMENT, &vala_statement_info);
