@@ -41,23 +41,14 @@ struct _ValaSymbolPrivate {
 
 #define VALA_SYMBOL_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_SYMBOL, ValaSymbolPrivate))
 enum  {
-	VALA_SYMBOL_DUMMY_PROPERTY,
-	VALA_SYMBOL_PARENT_SYMBOL,
-	VALA_SYMBOL_OWNER,
-	VALA_SYMBOL_NAME,
-	VALA_SYMBOL_ACTIVE,
-	VALA_SYMBOL_ACCESS,
-	VALA_SYMBOL_SCOPE,
-	VALA_SYMBOL_EXTERNAL,
-	VALA_SYMBOL_EXTERNAL_PACKAGE
+	VALA_SYMBOL_DUMMY_PROPERTY
 };
 static char* vala_symbol_real_get_cprefix (ValaSymbol* self);
 static char* vala_symbol_real_get_lower_case_cname (ValaSymbol* self, const char* infix);
 static char* vala_symbol_real_get_lower_case_cprefix (ValaSymbol* self);
 static GeeList* vala_symbol_real_get_cheader_filenames (ValaSymbol* self);
-static GObject * vala_symbol_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
 static gpointer vala_symbol_parent_class = NULL;
-static void vala_symbol_finalize (GObject * obj);
+static void vala_symbol_finalize (ValaCodeNode* obj);
 
 
 
@@ -78,21 +69,29 @@ gboolean vala_symbol_is_internal_symbol (ValaSymbol* self) {
 		ValaSymbol* _tmp3;
 		ValaSymbol* _tmp2;
 		_tmp1 = NULL;
-		sym = (_tmp1 = self, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
+		sym = (_tmp1 = self, (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1)));
 		_tmp3 = NULL;
 		_tmp2 = NULL;
-		for (; NULL != sym; sym = (_tmp3 = (_tmp2 = vala_symbol_get_parent_symbol (sym), (_tmp2 == NULL ? NULL : g_object_ref (_tmp2))), (sym == NULL ? NULL : (sym = (g_object_unref (sym), NULL))), _tmp3)) {
+		for (; NULL != sym; sym = (_tmp3 = (_tmp2 = vala_symbol_get_parent_symbol (sym), (_tmp2 == NULL ? NULL : vala_code_node_ref (_tmp2))), (sym == NULL ? NULL : (sym = (vala_code_node_unref (sym), NULL))), _tmp3)) {
 			if (VALA_SYMBOL_ACCESSIBILITY_PRIVATE == sym->priv->_access) {
 				gboolean _tmp4;
-				return (_tmp4 = TRUE, (sym == NULL ? NULL : (sym = (g_object_unref (sym), NULL))), _tmp4);
+				return (_tmp4 = TRUE, (sym == NULL ? NULL : (sym = (vala_code_node_unref (sym), NULL))), _tmp4);
 			}
 		}
-		(sym == NULL ? NULL : (sym = (g_object_unref (sym), NULL)));
+		(sym == NULL ? NULL : (sym = (vala_code_node_unref (sym), NULL)));
 	}
 	return FALSE;
 }
 
 
+void vala_symbol_init (ValaSymbol* self) {
+	ValaScope* _tmp0;
+	g_return_if_fail (VALA_IS_SYMBOL (self));
+	_tmp0 = NULL;
+	self->priv->_scope = (_tmp0 = vala_scope_new (self), (self->priv->_scope == NULL ? NULL : (self->priv->_scope = (vala_scope_unref (self->priv->_scope), NULL))), _tmp0);
+}
+
+
 /**
  * Returns the fully expanded name of this symbol for use in
  * human-readable messages.
@@ -306,13 +305,13 @@ ValaScope* vala_symbol_get_top_accessible_scope (ValaSymbol* self) {
 		ValaScope* scope;
 		/* private symbols are accessible within the scope where the symbol has been declared*/
 		_tmp0 = NULL;
-		scope = (_tmp0 = vala_symbol_get_owner (self), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
+		scope = (_tmp0 = vala_symbol_get_owner (self), (_tmp0 == NULL ? NULL : vala_scope_ref (_tmp0)));
 		while (scope != NULL && VALA_IS_NAMESPACE (vala_scope_get_owner (scope)) && vala_scope_get_owner (scope)->priv->_name != NULL) {
 			ValaScope* _tmp2;
 			ValaScope* _tmp1;
 			_tmp2 = NULL;
 			_tmp1 = NULL;
-			scope = (_tmp2 = (_tmp1 = vala_scope_get_parent_scope (scope), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (scope == NULL ? NULL : (scope = (g_object_unref (scope), NULL))), _tmp2);
+			scope = (_tmp2 = (_tmp1 = vala_scope_get_parent_scope (scope), (_tmp1 == NULL ? NULL : vala_scope_ref (_tmp1))), (scope == NULL ? NULL : (scope = (vala_scope_unref (scope), NULL))), _tmp2);
 		}
 		return scope;
 	}
@@ -344,7 +343,6 @@ void vala_symbol_set_owner (ValaSymbol* self, ValaScope* value) {
 	g_return_if_fail (VALA_IS_SYMBOL (self));
 	self->priv->_owner = value;
 	vala_scope_set_parent_scope (self->priv->_scope, value);
-	g_object_notify (((GObject *) (self)), "owner");
 }
 
 
@@ -361,7 +359,6 @@ void vala_symbol_set_name (ValaSymbol* self, const char* value) {
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_name = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_name = (g_free (self->priv->_name), NULL)), _tmp2);
-	g_object_notify (((GObject *) (self)), "name");
 }
 
 
@@ -374,7 +371,6 @@ gboolean vala_symbol_get_active (ValaSymbol* self) {
 void vala_symbol_set_active (ValaSymbol* self, gboolean value) {
 	g_return_if_fail (VALA_IS_SYMBOL (self));
 	self->priv->_active = value;
-	g_object_notify (((GObject *) (self)), "active");
 }
 
 
@@ -387,7 +383,6 @@ ValaSymbolAccessibility vala_symbol_get_access (ValaSymbol* self) {
 void vala_symbol_set_access (ValaSymbol* self, ValaSymbolAccessibility value) {
 	g_return_if_fail (VALA_IS_SYMBOL (self));
 	self->priv->_access = value;
-	g_object_notify (((GObject *) (self)), "access");
 }
 
 
@@ -406,7 +401,6 @@ gboolean vala_symbol_get_external (ValaSymbol* self) {
 void vala_symbol_set_external (ValaSymbol* self, gboolean value) {
 	g_return_if_fail (VALA_IS_SYMBOL (self));
 	self->priv->_external = value;
-	g_object_notify (((GObject *) (self)), "external");
 }
 
 
@@ -416,126 +410,36 @@ gboolean vala_symbol_get_external_package (ValaSymbol* self) {
 }
 
 
-static GObject * vala_symbol_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
-	GObject * obj;
-	ValaSymbolClass * klass;
-	GObjectClass * parent_class;
-	ValaSymbol * self;
-	klass = VALA_SYMBOL_CLASS (g_type_class_peek (VALA_TYPE_SYMBOL));
-	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
-	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
-	self = VALA_SYMBOL (obj);
-	{
-		ValaScope* _tmp0;
-		_tmp0 = NULL;
-		self->priv->_scope = (_tmp0 = vala_scope_new (self), (self->priv->_scope == NULL ? NULL : (self->priv->_scope = (g_object_unref (self->priv->_scope), NULL))), _tmp0);
-		vala_symbol_set_active (self, TRUE);
-	}
-	return obj;
-}
-
-
-static void vala_symbol_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
-	ValaSymbol * self;
-	self = VALA_SYMBOL (object);
-	switch (property_id) {
-		case VALA_SYMBOL_PARENT_SYMBOL:
-		g_value_set_object (value, vala_symbol_get_parent_symbol (self));
-		break;
-		case VALA_SYMBOL_OWNER:
-		g_value_set_object (value, vala_symbol_get_owner (self));
-		break;
-		case VALA_SYMBOL_NAME:
-		g_value_set_string (value, vala_symbol_get_name (self));
-		break;
-		case VALA_SYMBOL_ACTIVE:
-		g_value_set_boolean (value, vala_symbol_get_active (self));
-		break;
-		case VALA_SYMBOL_ACCESS:
-		g_value_set_enum (value, vala_symbol_get_access (self));
-		break;
-		case VALA_SYMBOL_SCOPE:
-		g_value_set_object (value, vala_symbol_get_scope (self));
-		break;
-		case VALA_SYMBOL_EXTERNAL:
-		g_value_set_boolean (value, vala_symbol_get_external (self));
-		break;
-		case VALA_SYMBOL_EXTERNAL_PACKAGE:
-		g_value_set_boolean (value, vala_symbol_get_external_package (self));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
-static void vala_symbol_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
-	ValaSymbol * self;
-	self = VALA_SYMBOL (object);
-	switch (property_id) {
-		case VALA_SYMBOL_OWNER:
-		vala_symbol_set_owner (self, g_value_get_object (value));
-		break;
-		case VALA_SYMBOL_NAME:
-		vala_symbol_set_name (self, g_value_get_string (value));
-		break;
-		case VALA_SYMBOL_ACTIVE:
-		vala_symbol_set_active (self, g_value_get_boolean (value));
-		break;
-		case VALA_SYMBOL_ACCESS:
-		vala_symbol_set_access (self, g_value_get_enum (value));
-		break;
-		case VALA_SYMBOL_EXTERNAL:
-		vala_symbol_set_external (self, g_value_get_boolean (value));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
 static void vala_symbol_class_init (ValaSymbolClass * klass) {
 	vala_symbol_parent_class = g_type_class_peek_parent (klass);
+	VALA_CODE_NODE_CLASS (klass)->finalize = vala_symbol_finalize;
 	g_type_class_add_private (klass, sizeof (ValaSymbolPrivate));
-	G_OBJECT_CLASS (klass)->get_property = vala_symbol_get_property;
-	G_OBJECT_CLASS (klass)->set_property = vala_symbol_set_property;
-	G_OBJECT_CLASS (klass)->constructor = vala_symbol_constructor;
-	G_OBJECT_CLASS (klass)->finalize = vala_symbol_finalize;
 	VALA_SYMBOL_CLASS (klass)->get_cprefix = vala_symbol_real_get_cprefix;
 	VALA_SYMBOL_CLASS (klass)->get_lower_case_cname = vala_symbol_real_get_lower_case_cname;
 	VALA_SYMBOL_CLASS (klass)->get_lower_case_cprefix = vala_symbol_real_get_lower_case_cprefix;
 	VALA_SYMBOL_CLASS (klass)->get_cheader_filenames = vala_symbol_real_get_cheader_filenames;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SYMBOL_PARENT_SYMBOL, g_param_spec_object ("parent-symbol", "parent-symbol", "parent-symbol", VALA_TYPE_SYMBOL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SYMBOL_OWNER, g_param_spec_object ("owner", "owner", "owner", VALA_TYPE_SCOPE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SYMBOL_NAME, g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SYMBOL_ACTIVE, g_param_spec_boolean ("active", "active", "active", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SYMBOL_ACCESS, g_param_spec_enum ("access", "access", "access", VALA_TYPE_SYMBOL_ACCESSIBILITY, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SYMBOL_SCOPE, g_param_spec_object ("scope", "scope", "scope", VALA_TYPE_SCOPE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SYMBOL_EXTERNAL, g_param_spec_boolean ("external", "external", "external", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SYMBOL_EXTERNAL_PACKAGE, g_param_spec_boolean ("external-package", "external-package", "external-package", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
 }
 
 
 static void vala_symbol_instance_init (ValaSymbol * self) {
 	self->priv = VALA_SYMBOL_GET_PRIVATE (self);
+	self->priv->_active = TRUE;
 }
 
 
-static void vala_symbol_finalize (GObject * obj) {
+static void vala_symbol_finalize (ValaCodeNode* obj) {
 	ValaSymbol * self;
 	self = VALA_SYMBOL (obj);
 	self->priv->_name = (g_free (self->priv->_name), NULL);
-	(self->priv->_scope == NULL ? NULL : (self->priv->_scope = (g_object_unref (self->priv->_scope), NULL)));
-	G_OBJECT_CLASS (vala_symbol_parent_class)->finalize (obj);
+	(self->priv->_scope == NULL ? NULL : (self->priv->_scope = (vala_scope_unref (self->priv->_scope), NULL)));
+	VALA_CODE_NODE_CLASS (vala_symbol_parent_class)->finalize (obj);
 }
 
 
 GType vala_symbol_get_type (void) {
 	static GType vala_symbol_type_id = 0;
 	if (vala_symbol_type_id == 0) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaSymbolClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_symbol_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaSymbol), 0, (GInstanceInitFunc) vala_symbol_instance_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaSymbolClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_symbol_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaSymbol), 0, (GInstanceInitFunc) vala_symbol_instance_init, NULL };
 		vala_symbol_type_id = g_type_register_static (VALA_TYPE_CODE_NODE, "ValaSymbol", &g_define_type_info, G_TYPE_FLAG_ABSTRACT);
 	}
 	return vala_symbol_type_id;
