@@ -46,7 +46,7 @@
 #include <vala/valaconstructor.h>
 #include <vala/valadestructor.h>
 #include <vala/valablock.h>
-#include <vala/valanamespacereference.h>
+#include <vala/valausingdirective.h>
 #include <vala/valadatatype.h>
 #include <vala/valalocalvariable.h>
 #include <vala/valainitializerlist.h>
@@ -98,6 +98,7 @@ struct _ValaSymbolResolverClass {
 
 
 void vala_symbol_resolver_resolve (ValaSymbolResolver* self, ValaCodeContext* context);
+ValaSymbolResolver* vala_symbol_resolver_construct (GType object_type);
 ValaSymbolResolver* vala_symbol_resolver_new (void);
 GType vala_symbol_resolver_get_type (void);
 
