@@ -76,6 +76,7 @@ enum  {
 	VALA_VAPI_CHECK_GIDL,
 	VALA_VAPI_CHECK_METADATA
 };
+static ValaVAPICheck* vala_vapi_check_construct (GType object_type, const char* gidlname, ValaCodeContext* context);
 static ValaVAPICheck* vala_vapi_check_new (const char* gidlname, ValaCodeContext* context);
 static void _g_list_free_g_idl_module_free (GList* self);
 static void vala_vapi_check_parse_gidl (ValaVAPICheck* self);
@@ -94,13 +95,13 @@ static void vala_vapi_check_set_gidl (ValaVAPICheck* self, ValaSourceFile* value
 static ValaSourceFile* vala_vapi_check_get_metadata (ValaVAPICheck* self);
 static void vala_vapi_check_set_metadata (ValaVAPICheck* self, ValaSourceFile* value);
 static gpointer vala_vapi_check_parent_class = NULL;
-static void vala_vapi_check_dispose (GObject * obj);
+static void vala_vapi_check_finalize (GObject* obj);
 static GType vala_vapi_check_get_type (void);
 static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
 
 
 
-static ValaVAPICheck* vala_vapi_check_new (const char* gidlname, ValaCodeContext* context) {
+static ValaVAPICheck* vala_vapi_check_construct (GType object_type, const char* gidlname, ValaCodeContext* context) {
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaSourceFile* _tmp1;
@@ -118,26 +119,26 @@ static ValaVAPICheck* vala_vapi_check_new (const char* gidlname, ValaCodeContext
 	_tmp0 = NULL;
 	__params_it->name = "gidl";
 	g_value_init (&__params_it->value, VALA_TYPE_SOURCE_FILE);
-	g_value_set_object (&__params_it->value, (_tmp1 = vala_source_file_new (context, gidlname, FALSE)));
+	vala_value_set_source_file (&__params_it->value, (_tmp1 = vala_source_file_new (context, gidlname, FALSE, NULL)));
 	__params_it++;
-	(_tmp1 == NULL ? NULL : (_tmp1 = (g_object_unref (_tmp1), NULL)));
-	(_tmp0 == NULL ? NULL : (_tmp0 = (g_object_unref (_tmp0), NULL)));
+	(_tmp1 == NULL ? NULL : (_tmp1 = (vala_source_file_unref (_tmp1), NULL)));
+	(_tmp0 == NULL ? NULL : (_tmp0 = (vala_code_context_unref (_tmp0), NULL)));
 	_tmp5 = NULL;
 	_tmp4 = NULL;
 	_tmp3 = NULL;
 	_tmp2 = NULL;
 	__params_it->name = "metadata";
 	g_value_init (&__params_it->value, VALA_TYPE_SOURCE_FILE);
-	g_value_set_object (&__params_it->value, (_tmp5 = vala_source_file_new (context, (_tmp4 = g_strconcat ((_tmp3 = (_tmp2 = g_utf8_offset_to_pointer (gidlname, ((glong) (0))), g_strndup (_tmp2, g_utf8_offset_to_pointer (_tmp2, g_utf8_strlen (gidlname, -1) - 5) - _tmp2))), ".metadata", NULL)), FALSE)));
+	vala_value_set_source_file (&__params_it->value, (_tmp5 = vala_source_file_new (context, (_tmp4 = g_strconcat ((_tmp3 = (_tmp2 = g_utf8_offset_to_pointer (gidlname, ((glong) (0))), g_strndup (_tmp2, g_utf8_offset_to_pointer (_tmp2, g_utf8_strlen (gidlname, -1) - 5) - _tmp2))), ".metadata", NULL)), FALSE, NULL)));
 	__params_it++;
-	(_tmp5 == NULL ? NULL : (_tmp5 = (g_object_unref (_tmp5), NULL)));
+	(_tmp5 == NULL ? NULL : (_tmp5 = (vala_source_file_unref (_tmp5), NULL)));
 	_tmp4 = (g_free (_tmp4), NULL);
 	_tmp3 = (g_free (_tmp3), NULL);
 	__params_it->name = "context";
 	g_value_init (&__params_it->value, VALA_TYPE_CODE_CONTEXT);
-	g_value_set_object (&__params_it->value, context);
+	vala_value_set_code_context (&__params_it->value, context);
 	__params_it++;
-	self = g_object_newv (VALA_TYPE_VAPI_CHECK, __params_it - __params, __params);
+	self = g_object_newv (object_type, __params_it - __params, __params);
 	while (__params_it > __params) {
 		--__params_it;
 		g_value_unset (&__params_it->value);
@@ -147,6 +148,11 @@ static ValaVAPICheck* vala_vapi_check_new (const char* gidlname, ValaCodeContext
 }
 
 
+static ValaVAPICheck* vala_vapi_check_new (const char* gidlname, ValaCodeContext* context) {
+	return vala_vapi_check_construct (VALA_TYPE_VAPI_CHECK, gidlname, context);
+}
+
+
 static void _g_list_free_g_idl_module_free (GList* self) {
 	g_list_foreach (self, ((GFunc) (g_idl_module_free)), NULL);
 	g_list_free (self);
@@ -160,9 +166,9 @@ static void vala_vapi_check_parse_gidl (ValaVAPICheck* self) {
 	g_return_if_fail (VALA_IS_VAPI_CHECK (self));
 	inner_error = NULL;
 	_tmp0 = NULL;
-	self->priv->_scope = (_tmp0 = GEE_LIST (gee_array_list_new (G_TYPE_STRING, ((GBoxedCopyFunc) (g_strdup)), g_free, g_direct_equal)), (self->priv->_scope == NULL ? NULL : (self->priv->_scope = (g_object_unref (self->priv->_scope), NULL))), _tmp0);
+	self->priv->_scope = (_tmp0 = GEE_LIST (gee_array_list_new (G_TYPE_STRING, ((GBoxedCopyFunc) (g_strdup)), g_free, g_direct_equal)), (self->priv->_scope == NULL ? NULL : (self->priv->_scope = (gee_collection_object_unref (self->priv->_scope), NULL))), _tmp0);
 	_tmp1 = NULL;
-	self->priv->_symbols = (_tmp1 = GEE_SET (gee_hash_set_new (G_TYPE_STRING, ((GBoxedCopyFunc) (g_strdup)), g_free, g_str_hash, g_str_equal)), (self->priv->_symbols == NULL ? NULL : (self->priv->_symbols = (g_object_unref (self->priv->_symbols), NULL))), _tmp1);
+	self->priv->_symbols = (_tmp1 = GEE_SET (gee_hash_set_new (G_TYPE_STRING, ((GBoxedCopyFunc) (g_strdup)), g_free, g_str_hash, g_str_equal)), (self->priv->_symbols == NULL ? NULL : (self->priv->_symbols = (gee_collection_object_unref (self->priv->_symbols), NULL))), _tmp1);
 	{
 		{
 			GList* module_collection;
@@ -193,6 +199,7 @@ static void vala_vapi_check_parse_gidl (ValaVAPICheck* self) {
 		inner_error = NULL;
 		{
 			fprintf (stderr, "%s: %s\n", vala_source_file_get_filename (self->priv->_gidl), e->message);
+			(e == NULL ? NULL : (e = (g_error_free (e), NULL)));
 		}
 	}
 	__finally0:
@@ -288,7 +295,7 @@ static void vala_vapi_check_parse_members (ValaVAPICheck* self, const char* name
 					break;
 				} while (0); else
 				do {
-					g_warning ("valavapicheck.vala:121: TODO: %s: Implement support for type %d nodes", node->name, node->type);
+					g_warning ("valavapicheck.vala:121: TODO: %s: Implement support for type %d nodes", node->name, ((gint) (node->type)));
 					break;
 				} while (0);
 			}
@@ -339,7 +346,7 @@ static gint vala_vapi_check_check_metadata (ValaVAPICheck* self) {
 				_tmp5 = NULL;
 				vala_report_error (src, (_tmp5 = g_strdup_printf ("Symbol `%s' not found", symbol)));
 				_tmp5 = (g_free (_tmp5), NULL);
-				(src == NULL ? NULL : (src = (g_object_unref (src), NULL)));
+				(src == NULL ? NULL : (src = (vala_source_reference_unref (src), NULL)));
 			}
 			lineno = lineno + (1);
 			tokens = (_vala_array_free (tokens, tokens_length1, ((GDestroyNotify) (g_free))), NULL);
@@ -355,10 +362,11 @@ static gint vala_vapi_check_check_metadata (ValaVAPICheck* self) {
 		inner_error = NULL;
 		{
 			char* _tmp7;
+			gint _tmp8;
 			_tmp7 = NULL;
 			vala_report_error (NULL, (_tmp7 = g_strdup_printf ("%s: %s", vala_source_file_get_filename (self->priv->_metadata), error->message)));
 			_tmp7 = (g_free (_tmp7), NULL);
-			return 1;
+			return (_tmp8 = 1, (error == NULL ? NULL : (error = (g_error_free (error), NULL))), _tmp8);
 		}
 	}
 	__finally1:
@@ -401,7 +409,7 @@ static gint vala_vapi_check_main (char** args, int args_length1) {
 	}
 	_tmp2 = NULL;
 	_tmp3 = NULL;
-	vapicheck = (_tmp3 = vala_vapi_check_new (args[1], (_tmp2 = vala_code_context_new ())), (_tmp2 == NULL ? NULL : (_tmp2 = (g_object_unref (_tmp2), NULL))), _tmp3);
+	vapicheck = (_tmp3 = vala_vapi_check_new (args[1], (_tmp2 = vala_code_context_new ())), (_tmp2 == NULL ? NULL : (_tmp2 = (vala_code_context_unref (_tmp2), NULL))), _tmp3);
 	return (_tmp4 = vala_vapi_check_run (vapicheck), (vapicheck == NULL ? NULL : (vapicheck = (g_object_unref (vapicheck), NULL))), _tmp4);
 }
 
@@ -424,7 +432,8 @@ static void vala_vapi_check_set_context (ValaVAPICheck* self, ValaCodeContext* v
 	g_return_if_fail (VALA_IS_VAPI_CHECK (self));
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_context = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_context == NULL ? NULL : (self->priv->_context = (g_object_unref (self->priv->_context), NULL))), _tmp2);
+	self->priv->_context = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_code_context_ref (_tmp1))), (self->priv->_context == NULL ? NULL : (self->priv->_context = (vala_code_context_unref (self->priv->_context), NULL))), _tmp2);
+	g_object_notify (((GObject *) (self)), "context");
 }
 
 
@@ -440,7 +449,8 @@ static void vala_vapi_check_set_gidl (ValaVAPICheck* self, ValaSourceFile* value
 	g_return_if_fail (VALA_IS_VAPI_CHECK (self));
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_gidl = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_gidl == NULL ? NULL : (self->priv->_gidl = (g_object_unref (self->priv->_gidl), NULL))), _tmp2);
+	self->priv->_gidl = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_source_file_ref (_tmp1))), (self->priv->_gidl == NULL ? NULL : (self->priv->_gidl = (vala_source_file_unref (self->priv->_gidl), NULL))), _tmp2);
+	g_object_notify (((GObject *) (self)), "gidl");
 }
 
 
@@ -456,7 +466,8 @@ static void vala_vapi_check_set_metadata (ValaVAPICheck* self, ValaSourceFile* v
 	g_return_if_fail (VALA_IS_VAPI_CHECK (self));
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_metadata = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_metadata == NULL ? NULL : (self->priv->_metadata = (g_object_unref (self->priv->_metadata), NULL))), _tmp2);
+	self->priv->_metadata = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_source_file_ref (_tmp1))), (self->priv->_metadata == NULL ? NULL : (self->priv->_metadata = (vala_source_file_unref (self->priv->_metadata), NULL))), _tmp2);
+	g_object_notify (((GObject *) (self)), "metadata");
 }
 
 
@@ -465,13 +476,13 @@ static void vala_vapi_check_get_property (GObject * object, guint property_id, G
 	self = VALA_VAPI_CHECK (object);
 	switch (property_id) {
 		case VALA_VAPI_CHECK_CONTEXT:
-		g_value_set_object (value, vala_vapi_check_get_context (self));
+		vala_value_set_code_context (value, vala_vapi_check_get_context (self));
 		break;
 		case VALA_VAPI_CHECK_GIDL:
-		g_value_set_object (value, vala_vapi_check_get_gidl (self));
+		vala_value_set_source_file (value, vala_vapi_check_get_gidl (self));
 		break;
 		case VALA_VAPI_CHECK_METADATA:
-		g_value_set_object (value, vala_vapi_check_get_metadata (self));
+		vala_value_set_source_file (value, vala_vapi_check_get_metadata (self));
 		break;
 		default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
@@ -485,13 +496,13 @@ static void vala_vapi_check_set_property (GObject * object, guint property_id, c
 	self = VALA_VAPI_CHECK (object);
 	switch (property_id) {
 		case VALA_VAPI_CHECK_CONTEXT:
-		vala_vapi_check_set_context (self, g_value_get_object (value));
+		vala_vapi_check_set_context (self, vala_value_get_code_context (value));
 		break;
 		case VALA_VAPI_CHECK_GIDL:
-		vala_vapi_check_set_gidl (self, g_value_get_object (value));
+		vala_vapi_check_set_gidl (self, vala_value_get_source_file (value));
 		break;
 		case VALA_VAPI_CHECK_METADATA:
-		vala_vapi_check_set_metadata (self, g_value_get_object (value));
+		vala_vapi_check_set_metadata (self, vala_value_get_source_file (value));
 		break;
 		default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
@@ -505,10 +516,10 @@ static void vala_vapi_check_class_init (ValaVAPICheckClass * klass) {
 	g_type_class_add_private (klass, sizeof (ValaVAPICheckPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_vapi_check_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_vapi_check_set_property;
-	G_OBJECT_CLASS (klass)->dispose = vala_vapi_check_dispose;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_VAPI_CHECK_CONTEXT, g_param_spec_object ("context", "context", "context", VALA_TYPE_CODE_CONTEXT, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_VAPI_CHECK_GIDL, g_param_spec_object ("gidl", "gidl", "gidl", VALA_TYPE_SOURCE_FILE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_VAPI_CHECK_METADATA, g_param_spec_object ("metadata", "metadata", "metadata", VALA_TYPE_SOURCE_FILE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
+	G_OBJECT_CLASS (klass)->finalize = vala_vapi_check_finalize;
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_VAPI_CHECK_CONTEXT, vala_param_spec_code_context ("context", "context", "context", VALA_TYPE_CODE_CONTEXT, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_VAPI_CHECK_GIDL, vala_param_spec_source_file ("gidl", "gidl", "gidl", VALA_TYPE_SOURCE_FILE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_VAPI_CHECK_METADATA, vala_param_spec_source_file ("metadata", "metadata", "metadata", VALA_TYPE_SOURCE_FILE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
 }
 
 
@@ -517,22 +528,22 @@ static void vala_vapi_check_instance_init (ValaVAPICheck * self) {
 }
 
 
-static void vala_vapi_check_dispose (GObject * obj) {
+static void vala_vapi_check_finalize (GObject* obj) {
 	ValaVAPICheck * self;
 	self = VALA_VAPI_CHECK (obj);
-	(self->priv->_context == NULL ? NULL : (self->priv->_context = (g_object_unref (self->priv->_context), NULL)));
-	(self->priv->_gidl == NULL ? NULL : (self->priv->_gidl = (g_object_unref (self->priv->_gidl), NULL)));
-	(self->priv->_metadata == NULL ? NULL : (self->priv->_metadata = (g_object_unref (self->priv->_metadata), NULL)));
-	(self->priv->_scope == NULL ? NULL : (self->priv->_scope = (g_object_unref (self->priv->_scope), NULL)));
-	(self->priv->_symbols == NULL ? NULL : (self->priv->_symbols = (g_object_unref (self->priv->_symbols), NULL)));
-	G_OBJECT_CLASS (vala_vapi_check_parent_class)->dispose (obj);
+	(self->priv->_context == NULL ? NULL : (self->priv->_context = (vala_code_context_unref (self->priv->_context), NULL)));
+	(self->priv->_gidl == NULL ? NULL : (self->priv->_gidl = (vala_source_file_unref (self->priv->_gidl), NULL)));
+	(self->priv->_metadata == NULL ? NULL : (self->priv->_metadata = (vala_source_file_unref (self->priv->_metadata), NULL)));
+	(self->priv->_scope == NULL ? NULL : (self->priv->_scope = (gee_collection_object_unref (self->priv->_scope), NULL)));
+	(self->priv->_symbols == NULL ? NULL : (self->priv->_symbols = (gee_collection_object_unref (self->priv->_symbols), NULL)));
+	G_OBJECT_CLASS (vala_vapi_check_parent_class)->finalize (obj);
 }
 
 
 static GType vala_vapi_check_get_type (void) {
 	static GType vala_vapi_check_type_id = 0;
-	if (G_UNLIKELY (vala_vapi_check_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaVAPICheckClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_vapi_check_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaVAPICheck), 0, (GInstanceInitFunc) vala_vapi_check_instance_init };
+	if (vala_vapi_check_type_id == 0) {
+		static const GTypeInfo g_define_type_info = { sizeof (ValaVAPICheckClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_vapi_check_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaVAPICheck), 0, (GInstanceInitFunc) vala_vapi_check_instance_init, NULL };
 		vala_vapi_check_type_id = g_type_register_static (G_TYPE_OBJECT, "ValaVAPICheck", &g_define_type_info, 0);
 	}
 	return vala_vapi_check_type_id;
